/* Automatically generated by tree-sitter v0.25.3 (2a835ee029dca1c325e6f1c01dbce40396f6123e) */

#include "tree_sitter/parser.h"

#if defined(__GNUC__) || defined(__clang__)
#pragma GCC diagnostic ignored "-Wmissing-field-initializers"
#endif

#ifdef _MSC_VER
#pragma optimize("", off)
#elif defined(__clang__)
#pragma clang optimize off
#elif defined(__GNUC__)
#pragma GCC optimize ("O0")
#endif

#define LANGUAGE_VERSION 14
#define STATE_COUNT 2909
#define LARGE_STATE_COUNT 878
#define SYMBOL_COUNT 211
#define ALIAS_COUNT 0
#define TOKEN_COUNT 150
#define EXTERNAL_TOKEN_COUNT 0
#define FIELD_COUNT 0
#define MAX_ALIAS_SEQUENCE_LENGTH 12
#define MAX_RESERVED_WORD_SET_SIZE 0
#define PRODUCTION_ID_COUNT 2
#define SUPERTYPE_COUNT 0

enum ts_symbol_identifiers {
  anon_sym_module = 1,
  anon_sym_SEMI = 2,
  anon_sym_export = 3,
  anon_sym_LBRACE = 4,
  anon_sym_RBRACE = 5,
  anon_sym_global = 6,
  anon_sym_COLON = 7,
  anon_sym_option = 8,
  anon_sym_const = 9,
  anon_sym_redef = 10,
  anon_sym_enum = 11,
  anon_sym_PLUS_EQ = 12,
  anon_sym_record = 13,
  anon_sym_DASH_EQ = 14,
  anon_sym_type = 15,
  anon_sym_print = 16,
  anon_sym_event = 17,
  anon_sym_if = 18,
  anon_sym_LPAREN = 19,
  anon_sym_RPAREN = 20,
  anon_sym_else = 21,
  anon_sym_switch = 22,
  anon_sym_for = 23,
  anon_sym_COMMA = 24,
  anon_sym_in = 25,
  anon_sym_LBRACK = 26,
  anon_sym_RBRACK = 27,
  anon_sym_while = 28,
  anon_sym_next = 29,
  anon_sym_break = 30,
  anon_sym_fallthrough = 31,
  anon_sym_return = 32,
  anon_sym_add = 33,
  anon_sym_delete = 34,
  anon_sym_local = 35,
  anon_sym_when = 36,
  anon_sym_timeout = 37,
  anon_sym_EQ = 38,
  anon_sym_assert = 39,
  anon_sym_case = 40,
  anon_sym_default = 41,
  anon_sym_as = 42,
  anon_sym_function = 43,
  anon_sym_hook = 44,
  anon_sym_addr = 45,
  anon_sym_any = 46,
  anon_sym_bool = 47,
  anon_sym_count = 48,
  anon_sym_double = 49,
  anon_sym_file = 50,
  anon_sym_int = 51,
  anon_sym_interval = 52,
  anon_sym_list = 53,
  anon_sym_pattern = 54,
  anon_sym_port = 55,
  anon_sym_string = 56,
  anon_sym_subnet = 57,
  anon_sym_time = 58,
  anon_sym_of = 59,
  anon_sym_opaque = 60,
  anon_sym_set = 61,
  anon_sym_table = 62,
  anon_sym_union = 63,
  anon_sym_vector = 64,
  anon_sym_AMPbroker_allow_complex_type = 65,
  anon_sym_AMPdeprecated = 66,
  anon_sym_AMPerror_handler = 67,
  anon_sym_AMPis_assigned = 68,
  anon_sym_AMPis_used = 69,
  anon_sym_AMPlog = 70,
  anon_sym_AMPoptional = 71,
  anon_sym_AMPordered = 72,
  anon_sym_AMPraw_output = 73,
  anon_sym_AMPredef = 74,
  anon_sym_AMPadd_func = 75,
  anon_sym_AMPbackend = 76,
  anon_sym_AMPbroker_store = 77,
  anon_sym_AMPcreate_expire = 78,
  anon_sym_AMPdefault = 79,
  anon_sym_AMPdelete_func = 80,
  anon_sym_AMPexpire_func = 81,
  anon_sym_AMPgroup = 82,
  anon_sym_AMPon_change = 83,
  anon_sym_AMPpriority = 84,
  anon_sym_AMPread_expire = 85,
  anon_sym_AMPtype_column = 86,
  anon_sym_AMPwrite_expire = 87,
  anon_sym_DOLLAR = 88,
  anon_sym_PIPE = 89,
  anon_sym_PLUS_PLUS = 90,
  anon_sym_DASH_DASH = 91,
  anon_sym_BANG = 92,
  anon_sym_TILDE = 93,
  anon_sym_DASH = 94,
  anon_sym_PLUS = 95,
  anon_sym_is = 96,
  anon_sym_STAR = 97,
  anon_sym_SLASH = 98,
  anon_sym_PERCENT = 99,
  anon_sym_LT = 100,
  anon_sym_LT_EQ = 101,
  anon_sym_GT = 102,
  anon_sym_GT_EQ = 103,
  anon_sym_AMP = 104,
  anon_sym_CARET = 105,
  anon_sym_QMARK = 106,
  anon_sym_EQ_EQ = 107,
  anon_sym_BANG_EQ = 108,
  anon_sym_AMP_AMP = 109,
  anon_sym_PIPE_PIPE = 110,
  anon_sym_copy = 111,
  anon_sym_QMARK_DOLLAR = 112,
  anon_sym_schedule = 113,
  anon_sym_T = 114,
  anon_sym_F = 115,
  anon_sym_ATdeprecated = 116,
  anon_sym_ATload = 117,
  anon_sym_ATload_DASHsigs = 118,
  anon_sym_ATload_DASHplugin = 119,
  anon_sym_ATunload = 120,
  anon_sym_ATprefixes = 121,
  anon_sym_ATif = 122,
  anon_sym_ATifdef = 123,
  anon_sym_ATifndef = 124,
  anon_sym_ATendif = 125,
  anon_sym_ATelse = 126,
  anon_sym_ATpragma = 127,
  anon_sym_push = 128,
  anon_sym_pop = 129,
  aux_sym_pragma_token1 = 130,
  anon_sym_ATDIR = 131,
  anon_sym_ATFILENAME = 132,
  sym_id = 133,
  sym_file = 134,
  sym_pattern = 135,
  sym_ipv4 = 136,
  sym_ipv6 = 137,
  sym_port = 138,
  sym_integer = 139,
  sym_floatp = 140,
  sym_hex = 141,
  sym_time_unit = 142,
  sym_hostname = 143,
  aux_sym_string_token1 = 144,
  sym_zeekygen_head_comment = 145,
  sym_zeekygen_prev_comment = 146,
  sym_zeekygen_next_comment = 147,
  sym_minor_comment = 148,
  sym_nl = 149,
  sym_source_file = 150,
  sym_decl = 151,
  sym_module_decl = 152,
  sym_export_decl = 153,
  sym_global_decl = 154,
  sym_option_decl = 155,
  sym_const_decl = 156,
  sym_redef_decl = 157,
  sym_redef_enum_decl = 158,
  sym_redef_record_decl = 159,
  sym_type_decl = 160,
  sym_func_decl = 161,
  sym_stmt = 162,
  sym_stmt_list = 163,
  sym_case_list = 164,
  sym_case_type_list = 165,
  sym_assert_msg = 166,
  sym_type = 167,
  sym__simple_type = 168,
  sym_enum_body = 169,
  sym_enum_body_elem = 170,
  sym_func_params = 171,
  sym_formal_args = 172,
  sym_formal_arg = 173,
  sym_type_spec = 174,
  sym_initializer = 175,
  sym_init_class = 176,
  sym_attr_list = 177,
  sym_attr = 178,
  sym_expr = 179,
  sym_expr_list = 180,
  sym_constant = 181,
  sym_func_hdr = 182,
  sym_func = 183,
  sym_hook = 184,
  sym_event = 185,
  sym_func_body = 186,
  sym_index_slice = 187,
  sym_begin_lambda = 188,
  sym_capture_list = 189,
  sym_capture = 190,
  sym_preproc_directive = 191,
  sym_pragma = 192,
  sym_string_directive = 193,
  sym_event_hdr = 194,
  sym_subnet = 195,
  sym_interval = 196,
  sym_string = 197,
  aux_sym_source_file_repeat1 = 198,
  aux_sym_source_file_repeat2 = 199,
  aux_sym_redef_record_decl_repeat1 = 200,
  aux_sym_func_decl_repeat1 = 201,
  aux_sym_stmt_repeat1 = 202,
  aux_sym_case_list_repeat1 = 203,
  aux_sym_case_type_list_repeat1 = 204,
  aux_sym__simple_type_repeat1 = 205,
  aux_sym_enum_body_repeat1 = 206,
  aux_sym_formal_args_repeat1 = 207,
  aux_sym_attr_list_repeat1 = 208,
  aux_sym_expr_list_repeat1 = 209,
  aux_sym_capture_list_repeat1 = 210,
};

static const char * const ts_symbol_names[] = {
  [ts_builtin_sym_end] = "end",
  [anon_sym_module] = "module",
  [anon_sym_SEMI] = ";",
  [anon_sym_export] = "export",
  [anon_sym_LBRACE] = "{",
  [anon_sym_RBRACE] = "}",
  [anon_sym_global] = "global",
  [anon_sym_COLON] = ":",
  [anon_sym_option] = "option",
  [anon_sym_const] = "const",
  [anon_sym_redef] = "redef",
  [anon_sym_enum] = "enum",
  [anon_sym_PLUS_EQ] = "+=",
  [anon_sym_record] = "record",
  [anon_sym_DASH_EQ] = "-=",
  [anon_sym_type] = "type",
  [anon_sym_print] = "print",
  [anon_sym_event] = "event",
  [anon_sym_if] = "if",
  [anon_sym_LPAREN] = "(",
  [anon_sym_RPAREN] = ")",
  [anon_sym_else] = "else",
  [anon_sym_switch] = "switch",
  [anon_sym_for] = "for",
  [anon_sym_COMMA] = ",",
  [anon_sym_in] = "in",
  [anon_sym_LBRACK] = "[",
  [anon_sym_RBRACK] = "]",
  [anon_sym_while] = "while",
  [anon_sym_next] = "next",
  [anon_sym_break] = "break",
  [anon_sym_fallthrough] = "fallthrough",
  [anon_sym_return] = "return",
  [anon_sym_add] = "add",
  [anon_sym_delete] = "delete",
  [anon_sym_local] = "local",
  [anon_sym_when] = "when",
  [anon_sym_timeout] = "timeout",
  [anon_sym_EQ] = "=",
  [anon_sym_assert] = "assert",
  [anon_sym_case] = "case",
  [anon_sym_default] = "default",
  [anon_sym_as] = "as",
  [anon_sym_function] = "function",
  [anon_sym_hook] = "hook",
  [anon_sym_addr] = "addr",
  [anon_sym_any] = "any",
  [anon_sym_bool] = "bool",
  [anon_sym_count] = "count",
  [anon_sym_double] = "double",
  [anon_sym_file] = "file",
  [anon_sym_int] = "int",
  [anon_sym_interval] = "interval",
  [anon_sym_list] = "list",
  [anon_sym_pattern] = "pattern",
  [anon_sym_port] = "port",
  [anon_sym_string] = "string",
  [anon_sym_subnet] = "subnet",
  [anon_sym_time] = "time",
  [anon_sym_of] = "of",
  [anon_sym_opaque] = "opaque",
  [anon_sym_set] = "set",
  [anon_sym_table] = "table",
  [anon_sym_union] = "union",
  [anon_sym_vector] = "vector",
  [anon_sym_AMPbroker_allow_complex_type] = "&broker_allow_complex_type",
  [anon_sym_AMPdeprecated] = "&deprecated",
  [anon_sym_AMPerror_handler] = "&error_handler",
  [anon_sym_AMPis_assigned] = "&is_assigned",
  [anon_sym_AMPis_used] = "&is_used",
  [anon_sym_AMPlog] = "&log",
  [anon_sym_AMPoptional] = "&optional",
  [anon_sym_AMPordered] = "&ordered",
  [anon_sym_AMPraw_output] = "&raw_output",
  [anon_sym_AMPredef] = "&redef",
  [anon_sym_AMPadd_func] = "&add_func",
  [anon_sym_AMPbackend] = "&backend",
  [anon_sym_AMPbroker_store] = "&broker_store",
  [anon_sym_AMPcreate_expire] = "&create_expire",
  [anon_sym_AMPdefault] = "&default",
  [anon_sym_AMPdelete_func] = "&delete_func",
  [anon_sym_AMPexpire_func] = "&expire_func",
  [anon_sym_AMPgroup] = "&group",
  [anon_sym_AMPon_change] = "&on_change",
  [anon_sym_AMPpriority] = "&priority",
  [anon_sym_AMPread_expire] = "&read_expire",
  [anon_sym_AMPtype_column] = "&type_column",
  [anon_sym_AMPwrite_expire] = "&write_expire",
  [anon_sym_DOLLAR] = "$",
  [anon_sym_PIPE] = "|",
  [anon_sym_PLUS_PLUS] = "++",
  [anon_sym_DASH_DASH] = "--",
  [anon_sym_BANG] = "!",
  [anon_sym_TILDE] = "~",
  [anon_sym_DASH] = "-",
  [anon_sym_PLUS] = "+",
  [anon_sym_is] = "is",
  [anon_sym_STAR] = "*",
  [anon_sym_SLASH] = "/",
  [anon_sym_PERCENT] = "%",
  [anon_sym_LT] = "<",
  [anon_sym_LT_EQ] = "<=",
  [anon_sym_GT] = ">",
  [anon_sym_GT_EQ] = ">=",
  [anon_sym_AMP] = "&",
  [anon_sym_CARET] = "^",
  [anon_sym_QMARK] = "\?",
  [anon_sym_EQ_EQ] = "==",
  [anon_sym_BANG_EQ] = "!=",
  [anon_sym_AMP_AMP] = "&&",
  [anon_sym_PIPE_PIPE] = "||",
  [anon_sym_copy] = "copy",
  [anon_sym_QMARK_DOLLAR] = "\?$",
  [anon_sym_schedule] = "schedule",
  [anon_sym_T] = "T",
  [anon_sym_F] = "F",
  [anon_sym_ATdeprecated] = "@deprecated",
  [anon_sym_ATload] = "@load",
  [anon_sym_ATload_DASHsigs] = "@load-sigs",
  [anon_sym_ATload_DASHplugin] = "@load-plugin",
  [anon_sym_ATunload] = "@unload",
  [anon_sym_ATprefixes] = "@prefixes",
  [anon_sym_ATif] = "@if",
  [anon_sym_ATifdef] = "@ifdef",
  [anon_sym_ATifndef] = "@ifndef",
  [anon_sym_ATendif] = "@endif",
  [anon_sym_ATelse] = "@else",
  [anon_sym_ATpragma] = "@pragma",
  [anon_sym_push] = "push",
  [anon_sym_pop] = "pop",
  [aux_sym_pragma_token1] = "pragma_token1",
  [anon_sym_ATDIR] = "@DIR",
  [anon_sym_ATFILENAME] = "@FILENAME",
  [sym_id] = "id",
  [sym_file] = "file",
  [sym_pattern] = "pattern",
  [sym_ipv4] = "ipv4",
  [sym_ipv6] = "ipv6",
  [sym_port] = "port",
  [sym_integer] = "integer",
  [sym_floatp] = "floatp",
  [sym_hex] = "hex",
  [sym_time_unit] = "time_unit",
  [sym_hostname] = "hostname",
  [aux_sym_string_token1] = "string_token1",
  [sym_zeekygen_head_comment] = "zeekygen_head_comment",
  [sym_zeekygen_prev_comment] = "zeekygen_prev_comment",
  [sym_zeekygen_next_comment] = "zeekygen_next_comment",
  [sym_minor_comment] = "minor_comment",
  [sym_nl] = "nl",
  [sym_source_file] = "source_file",
  [sym_decl] = "decl",
  [sym_module_decl] = "module_decl",
  [sym_export_decl] = "export_decl",
  [sym_global_decl] = "global_decl",
  [sym_option_decl] = "option_decl",
  [sym_const_decl] = "const_decl",
  [sym_redef_decl] = "redef_decl",
  [sym_redef_enum_decl] = "redef_enum_decl",
  [sym_redef_record_decl] = "redef_record_decl",
  [sym_type_decl] = "type_decl",
  [sym_func_decl] = "func_decl",
  [sym_stmt] = "stmt",
  [sym_stmt_list] = "stmt_list",
  [sym_case_list] = "case_list",
  [sym_case_type_list] = "case_type_list",
  [sym_assert_msg] = "assert_msg",
  [sym_type] = "type",
  [sym__simple_type] = "_simple_type",
  [sym_enum_body] = "enum_body",
  [sym_enum_body_elem] = "enum_body_elem",
  [sym_func_params] = "func_params",
  [sym_formal_args] = "formal_args",
  [sym_formal_arg] = "formal_arg",
  [sym_type_spec] = "type_spec",
  [sym_initializer] = "initializer",
  [sym_init_class] = "init_class",
  [sym_attr_list] = "attr_list",
  [sym_attr] = "attr",
  [sym_expr] = "expr",
  [sym_expr_list] = "expr_list",
  [sym_constant] = "constant",
  [sym_func_hdr] = "func_hdr",
  [sym_func] = "func",
  [sym_hook] = "hook",
  [sym_event] = "event",
  [sym_func_body] = "func_body",
  [sym_index_slice] = "index_slice",
  [sym_begin_lambda] = "begin_lambda",
  [sym_capture_list] = "capture_list",
  [sym_capture] = "capture",
  [sym_preproc_directive] = "preproc_directive",
  [sym_pragma] = "pragma",
  [sym_string_directive] = "string_directive",
  [sym_event_hdr] = "event_hdr",
  [sym_subnet] = "subnet",
  [sym_interval] = "interval",
  [sym_string] = "string",
  [aux_sym_source_file_repeat1] = "source_file_repeat1",
  [aux_sym_source_file_repeat2] = "source_file_repeat2",
  [aux_sym_redef_record_decl_repeat1] = "redef_record_decl_repeat1",
  [aux_sym_func_decl_repeat1] = "func_decl_repeat1",
  [aux_sym_stmt_repeat1] = "stmt_repeat1",
  [aux_sym_case_list_repeat1] = "case_list_repeat1",
  [aux_sym_case_type_list_repeat1] = "case_type_list_repeat1",
  [aux_sym__simple_type_repeat1] = "_simple_type_repeat1",
  [aux_sym_enum_body_repeat1] = "enum_body_repeat1",
  [aux_sym_formal_args_repeat1] = "formal_args_repeat1",
  [aux_sym_attr_list_repeat1] = "attr_list_repeat1",
  [aux_sym_expr_list_repeat1] = "expr_list_repeat1",
  [aux_sym_capture_list_repeat1] = "capture_list_repeat1",
};

static const TSSymbol ts_symbol_map[] = {
  [ts_builtin_sym_end] = ts_builtin_sym_end,
  [anon_sym_module] = anon_sym_module,
  [anon_sym_SEMI] = anon_sym_SEMI,
  [anon_sym_export] = anon_sym_export,
  [anon_sym_LBRACE] = anon_sym_LBRACE,
  [anon_sym_RBRACE] = anon_sym_RBRACE,
  [anon_sym_global] = anon_sym_global,
  [anon_sym_COLON] = anon_sym_COLON,
  [anon_sym_option] = anon_sym_option,
  [anon_sym_const] = anon_sym_const,
  [anon_sym_redef] = anon_sym_redef,
  [anon_sym_enum] = anon_sym_enum,
  [anon_sym_PLUS_EQ] = anon_sym_PLUS_EQ,
  [anon_sym_record] = anon_sym_record,
  [anon_sym_DASH_EQ] = anon_sym_DASH_EQ,
  [anon_sym_type] = anon_sym_type,
  [anon_sym_print] = anon_sym_print,
  [anon_sym_event] = anon_sym_event,
  [anon_sym_if] = anon_sym_if,
  [anon_sym_LPAREN] = anon_sym_LPAREN,
  [anon_sym_RPAREN] = anon_sym_RPAREN,
  [anon_sym_else] = anon_sym_else,
  [anon_sym_switch] = anon_sym_switch,
  [anon_sym_for] = anon_sym_for,
  [anon_sym_COMMA] = anon_sym_COMMA,
  [anon_sym_in] = anon_sym_in,
  [anon_sym_LBRACK] = anon_sym_LBRACK,
  [anon_sym_RBRACK] = anon_sym_RBRACK,
  [anon_sym_while] = anon_sym_while,
  [anon_sym_next] = anon_sym_next,
  [anon_sym_break] = anon_sym_break,
  [anon_sym_fallthrough] = anon_sym_fallthrough,
  [anon_sym_return] = anon_sym_return,
  [anon_sym_add] = anon_sym_add,
  [anon_sym_delete] = anon_sym_delete,
  [anon_sym_local] = anon_sym_local,
  [anon_sym_when] = anon_sym_when,
  [anon_sym_timeout] = anon_sym_timeout,
  [anon_sym_EQ] = anon_sym_EQ,
  [anon_sym_assert] = anon_sym_assert,
  [anon_sym_case] = anon_sym_case,
  [anon_sym_default] = anon_sym_default,
  [anon_sym_as] = anon_sym_as,
  [anon_sym_function] = anon_sym_function,
  [anon_sym_hook] = anon_sym_hook,
  [anon_sym_addr] = anon_sym_addr,
  [anon_sym_any] = anon_sym_any,
  [anon_sym_bool] = anon_sym_bool,
  [anon_sym_count] = anon_sym_count,
  [anon_sym_double] = anon_sym_double,
  [anon_sym_file] = anon_sym_file,
  [anon_sym_int] = anon_sym_int,
  [anon_sym_interval] = anon_sym_interval,
  [anon_sym_list] = anon_sym_list,
  [anon_sym_pattern] = anon_sym_pattern,
  [anon_sym_port] = anon_sym_port,
  [anon_sym_string] = anon_sym_string,
  [anon_sym_subnet] = anon_sym_subnet,
  [anon_sym_time] = anon_sym_time,
  [anon_sym_of] = anon_sym_of,
  [anon_sym_opaque] = anon_sym_opaque,
  [anon_sym_set] = anon_sym_set,
  [anon_sym_table] = anon_sym_table,
  [anon_sym_union] = anon_sym_union,
  [anon_sym_vector] = anon_sym_vector,
  [anon_sym_AMPbroker_allow_complex_type] = anon_sym_AMPbroker_allow_complex_type,
  [anon_sym_AMPdeprecated] = anon_sym_AMPdeprecated,
  [anon_sym_AMPerror_handler] = anon_sym_AMPerror_handler,
  [anon_sym_AMPis_assigned] = anon_sym_AMPis_assigned,
  [anon_sym_AMPis_used] = anon_sym_AMPis_used,
  [anon_sym_AMPlog] = anon_sym_AMPlog,
  [anon_sym_AMPoptional] = anon_sym_AMPoptional,
  [anon_sym_AMPordered] = anon_sym_AMPordered,
  [anon_sym_AMPraw_output] = anon_sym_AMPraw_output,
  [anon_sym_AMPredef] = anon_sym_AMPredef,
  [anon_sym_AMPadd_func] = anon_sym_AMPadd_func,
  [anon_sym_AMPbackend] = anon_sym_AMPbackend,
  [anon_sym_AMPbroker_store] = anon_sym_AMPbroker_store,
  [anon_sym_AMPcreate_expire] = anon_sym_AMPcreate_expire,
  [anon_sym_AMPdefault] = anon_sym_AMPdefault,
  [anon_sym_AMPdelete_func] = anon_sym_AMPdelete_func,
  [anon_sym_AMPexpire_func] = anon_sym_AMPexpire_func,
  [anon_sym_AMPgroup] = anon_sym_AMPgroup,
  [anon_sym_AMPon_change] = anon_sym_AMPon_change,
  [anon_sym_AMPpriority] = anon_sym_AMPpriority,
  [anon_sym_AMPread_expire] = anon_sym_AMPread_expire,
  [anon_sym_AMPtype_column] = anon_sym_AMPtype_column,
  [anon_sym_AMPwrite_expire] = anon_sym_AMPwrite_expire,
  [anon_sym_DOLLAR] = anon_sym_DOLLAR,
  [anon_sym_PIPE] = anon_sym_PIPE,
  [anon_sym_PLUS_PLUS] = anon_sym_PLUS_PLUS,
  [anon_sym_DASH_DASH] = anon_sym_DASH_DASH,
  [anon_sym_BANG] = anon_sym_BANG,
  [anon_sym_TILDE] = anon_sym_TILDE,
  [anon_sym_DASH] = anon_sym_DASH,
  [anon_sym_PLUS] = anon_sym_PLUS,
  [anon_sym_is] = anon_sym_is,
  [anon_sym_STAR] = anon_sym_STAR,
  [anon_sym_SLASH] = anon_sym_SLASH,
  [anon_sym_PERCENT] = anon_sym_PERCENT,
  [anon_sym_LT] = anon_sym_LT,
  [anon_sym_LT_EQ] = anon_sym_LT_EQ,
  [anon_sym_GT] = anon_sym_GT,
  [anon_sym_GT_EQ] = anon_sym_GT_EQ,
  [anon_sym_AMP] = anon_sym_AMP,
  [anon_sym_CARET] = anon_sym_CARET,
  [anon_sym_QMARK] = anon_sym_QMARK,
  [anon_sym_EQ_EQ] = anon_sym_EQ_EQ,
  [anon_sym_BANG_EQ] = anon_sym_BANG_EQ,
  [anon_sym_AMP_AMP] = anon_sym_AMP_AMP,
  [anon_sym_PIPE_PIPE] = anon_sym_PIPE_PIPE,
  [anon_sym_copy] = anon_sym_copy,
  [anon_sym_QMARK_DOLLAR] = anon_sym_QMARK_DOLLAR,
  [anon_sym_schedule] = anon_sym_schedule,
  [anon_sym_T] = anon_sym_T,
  [anon_sym_F] = anon_sym_F,
  [anon_sym_ATdeprecated] = anon_sym_ATdeprecated,
  [anon_sym_ATload] = anon_sym_ATload,
  [anon_sym_ATload_DASHsigs] = anon_sym_ATload_DASHsigs,
  [anon_sym_ATload_DASHplugin] = anon_sym_ATload_DASHplugin,
  [anon_sym_ATunload] = anon_sym_ATunload,
  [anon_sym_ATprefixes] = anon_sym_ATprefixes,
  [anon_sym_ATif] = anon_sym_ATif,
  [anon_sym_ATifdef] = anon_sym_ATifdef,
  [anon_sym_ATifndef] = anon_sym_ATifndef,
  [anon_sym_ATendif] = anon_sym_ATendif,
  [anon_sym_ATelse] = anon_sym_ATelse,
  [anon_sym_ATpragma] = anon_sym_ATpragma,
  [anon_sym_push] = anon_sym_push,
  [anon_sym_pop] = anon_sym_pop,
  [aux_sym_pragma_token1] = aux_sym_pragma_token1,
  [anon_sym_ATDIR] = anon_sym_ATDIR,
  [anon_sym_ATFILENAME] = anon_sym_ATFILENAME,
  [sym_id] = sym_id,
  [sym_file] = sym_file,
  [sym_pattern] = sym_pattern,
  [sym_ipv4] = sym_ipv4,
  [sym_ipv6] = sym_ipv6,
  [sym_port] = sym_port,
  [sym_integer] = sym_integer,
  [sym_floatp] = sym_floatp,
  [sym_hex] = sym_hex,
  [sym_time_unit] = sym_time_unit,
  [sym_hostname] = sym_hostname,
  [aux_sym_string_token1] = aux_sym_string_token1,
  [sym_zeekygen_head_comment] = sym_zeekygen_head_comment,
  [sym_zeekygen_prev_comment] = sym_zeekygen_prev_comment,
  [sym_zeekygen_next_comment] = sym_zeekygen_next_comment,
  [sym_minor_comment] = sym_minor_comment,
  [sym_nl] = sym_nl,
  [sym_source_file] = sym_source_file,
  [sym_decl] = sym_decl,
  [sym_module_decl] = sym_module_decl,
  [sym_export_decl] = sym_export_decl,
  [sym_global_decl] = sym_global_decl,
  [sym_option_decl] = sym_option_decl,
  [sym_const_decl] = sym_const_decl,
  [sym_redef_decl] = sym_redef_decl,
  [sym_redef_enum_decl] = sym_redef_enum_decl,
  [sym_redef_record_decl] = sym_redef_record_decl,
  [sym_type_decl] = sym_type_decl,
  [sym_func_decl] = sym_func_decl,
  [sym_stmt] = sym_stmt,
  [sym_stmt_list] = sym_stmt_list,
  [sym_case_list] = sym_case_list,
  [sym_case_type_list] = sym_case_type_list,
  [sym_assert_msg] = sym_assert_msg,
  [sym_type] = sym_type,
  [sym__simple_type] = sym__simple_type,
  [sym_enum_body] = sym_enum_body,
  [sym_enum_body_elem] = sym_enum_body_elem,
  [sym_func_params] = sym_func_params,
  [sym_formal_args] = sym_formal_args,
  [sym_formal_arg] = sym_formal_arg,
  [sym_type_spec] = sym_type_spec,
  [sym_initializer] = sym_initializer,
  [sym_init_class] = sym_init_class,
  [sym_attr_list] = sym_attr_list,
  [sym_attr] = sym_attr,
  [sym_expr] = sym_expr,
  [sym_expr_list] = sym_expr_list,
  [sym_constant] = sym_constant,
  [sym_func_hdr] = sym_func_hdr,
  [sym_func] = sym_func,
  [sym_hook] = sym_hook,
  [sym_event] = sym_event,
  [sym_func_body] = sym_func_body,
  [sym_index_slice] = sym_index_slice,
  [sym_begin_lambda] = sym_begin_lambda,
  [sym_capture_list] = sym_capture_list,
  [sym_capture] = sym_capture,
  [sym_preproc_directive] = sym_preproc_directive,
  [sym_pragma] = sym_pragma,
  [sym_string_directive] = sym_string_directive,
  [sym_event_hdr] = sym_event_hdr,
  [sym_subnet] = sym_subnet,
  [sym_interval] = sym_interval,
  [sym_string] = sym_string,
  [aux_sym_source_file_repeat1] = aux_sym_source_file_repeat1,
  [aux_sym_source_file_repeat2] = aux_sym_source_file_repeat2,
  [aux_sym_redef_record_decl_repeat1] = aux_sym_redef_record_decl_repeat1,
  [aux_sym_func_decl_repeat1] = aux_sym_func_decl_repeat1,
  [aux_sym_stmt_repeat1] = aux_sym_stmt_repeat1,
  [aux_sym_case_list_repeat1] = aux_sym_case_list_repeat1,
  [aux_sym_case_type_list_repeat1] = aux_sym_case_type_list_repeat1,
  [aux_sym__simple_type_repeat1] = aux_sym__simple_type_repeat1,
  [aux_sym_enum_body_repeat1] = aux_sym_enum_body_repeat1,
  [aux_sym_formal_args_repeat1] = aux_sym_formal_args_repeat1,
  [aux_sym_attr_list_repeat1] = aux_sym_attr_list_repeat1,
  [aux_sym_expr_list_repeat1] = aux_sym_expr_list_repeat1,
  [aux_sym_capture_list_repeat1] = aux_sym_capture_list_repeat1,
};

static const TSSymbolMetadata ts_symbol_metadata[] = {
  [ts_builtin_sym_end] = {
    .visible = false,
    .named = true,
  },
  [anon_sym_module] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SEMI] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_export] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_global] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COLON] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_option] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_const] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_redef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_enum] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_record] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_print] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_event] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_if] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RPAREN] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_else] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_switch] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_for] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_COMMA] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_in] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_RBRACK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_while] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_next] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_break] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_fallthrough] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_return] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_add] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_delete] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_local] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_when] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_timeout] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_assert] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_case] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_default] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_as] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_function] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_hook] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_addr] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_any] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_bool] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_count] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_double] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_file] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_int] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_interval] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_list] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pattern] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_port] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_string] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_subnet] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_time] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_of] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_opaque] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_set] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_table] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_union] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_vector] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPbroker_allow_complex_type] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPdeprecated] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPerror_handler] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPis_assigned] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPis_used] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPlog] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPoptional] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPordered] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPraw_output] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPredef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPadd_func] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPbackend] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPbroker_store] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPcreate_expire] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPdefault] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPdelete_func] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPexpire_func] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPgroup] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPon_change] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPpriority] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPread_expire] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPtype_column] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMPwrite_expire] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_TILDE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_DASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PLUS] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_is] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_STAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_SLASH] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PERCENT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_LT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_GT_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_CARET] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_EQ_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_BANG_EQ] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_AMP_AMP] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_PIPE_PIPE] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_copy] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_QMARK_DOLLAR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_schedule] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_T] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_F] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATdeprecated] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATload] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATload_DASHsigs] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATload_DASHplugin] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATunload] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATprefixes] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATifdef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATifndef] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATendif] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATelse] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATpragma] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_push] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_pop] = {
    .visible = true,
    .named = false,
  },
  [aux_sym_pragma_token1] = {
    .visible = false,
    .named = false,
  },
  [anon_sym_ATDIR] = {
    .visible = true,
    .named = false,
  },
  [anon_sym_ATFILENAME] = {
    .visible = true,
    .named = false,
  },
  [sym_id] = {
    .visible = true,
    .named = true,
  },
  [sym_file] = {
    .visible = true,
    .named = true,
  },
  [sym_pattern] = {
    .visible = true,
    .named = true,
  },
  [sym_ipv4] = {
    .visible = true,
    .named = true,
  },
  [sym_ipv6] = {
    .visible = true,
    .named = true,
  },
  [sym_port] = {
    .visible = true,
    .named = true,
  },
  [sym_integer] = {
    .visible = true,
    .named = true,
  },
  [sym_floatp] = {
    .visible = true,
    .named = true,
  },
  [sym_hex] = {
    .visible = true,
    .named = true,
  },
  [sym_time_unit] = {
    .visible = true,
    .named = true,
  },
  [sym_hostname] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_string_token1] = {
    .visible = false,
    .named = false,
  },
  [sym_zeekygen_head_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_zeekygen_prev_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_zeekygen_next_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_minor_comment] = {
    .visible = true,
    .named = true,
  },
  [sym_nl] = {
    .visible = true,
    .named = true,
  },
  [sym_source_file] = {
    .visible = true,
    .named = true,
  },
  [sym_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_module_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_export_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_global_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_option_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_const_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_redef_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_redef_enum_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_redef_record_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_type_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_func_decl] = {
    .visible = true,
    .named = true,
  },
  [sym_stmt] = {
    .visible = true,
    .named = true,
  },
  [sym_stmt_list] = {
    .visible = true,
    .named = true,
  },
  [sym_case_list] = {
    .visible = true,
    .named = true,
  },
  [sym_case_type_list] = {
    .visible = true,
    .named = true,
  },
  [sym_assert_msg] = {
    .visible = true,
    .named = true,
  },
  [sym_type] = {
    .visible = true,
    .named = true,
  },
  [sym__simple_type] = {
    .visible = false,
    .named = true,
  },
  [sym_enum_body] = {
    .visible = true,
    .named = true,
  },
  [sym_enum_body_elem] = {
    .visible = true,
    .named = true,
  },
  [sym_func_params] = {
    .visible = true,
    .named = true,
  },
  [sym_formal_args] = {
    .visible = true,
    .named = true,
  },
  [sym_formal_arg] = {
    .visible = true,
    .named = true,
  },
  [sym_type_spec] = {
    .visible = true,
    .named = true,
  },
  [sym_initializer] = {
    .visible = true,
    .named = true,
  },
  [sym_init_class] = {
    .visible = true,
    .named = true,
  },
  [sym_attr_list] = {
    .visible = true,
    .named = true,
  },
  [sym_attr] = {
    .visible = true,
    .named = true,
  },
  [sym_expr] = {
    .visible = true,
    .named = true,
  },
  [sym_expr_list] = {
    .visible = true,
    .named = true,
  },
  [sym_constant] = {
    .visible = true,
    .named = true,
  },
  [sym_func_hdr] = {
    .visible = true,
    .named = true,
  },
  [sym_func] = {
    .visible = true,
    .named = true,
  },
  [sym_hook] = {
    .visible = true,
    .named = true,
  },
  [sym_event] = {
    .visible = true,
    .named = true,
  },
  [sym_func_body] = {
    .visible = true,
    .named = true,
  },
  [sym_index_slice] = {
    .visible = true,
    .named = true,
  },
  [sym_begin_lambda] = {
    .visible = true,
    .named = true,
  },
  [sym_capture_list] = {
    .visible = true,
    .named = true,
  },
  [sym_capture] = {
    .visible = true,
    .named = true,
  },
  [sym_preproc_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_pragma] = {
    .visible = true,
    .named = true,
  },
  [sym_string_directive] = {
    .visible = true,
    .named = true,
  },
  [sym_event_hdr] = {
    .visible = true,
    .named = true,
  },
  [sym_subnet] = {
    .visible = true,
    .named = true,
  },
  [sym_interval] = {
    .visible = true,
    .named = true,
  },
  [sym_string] = {
    .visible = true,
    .named = true,
  },
  [aux_sym_source_file_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_source_file_repeat2] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_redef_record_decl_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_func_decl_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_stmt_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_case_type_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym__simple_type_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_enum_body_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_formal_args_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_attr_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_expr_list_repeat1] = {
    .visible = false,
    .named = false,
  },
  [aux_sym_capture_list_repeat1] = {
    .visible = false,
    .named = false,
  },
};

static const TSSymbol ts_alias_sequences[PRODUCTION_ID_COUNT][MAX_ALIAS_SEQUENCE_LENGTH] = {
  [0] = {0},
  [1] = {
    [0] = sym_type,
  },
};

static const uint16_t ts_non_terminal_alias_map[] = {
  sym__simple_type, 2,
    sym__simple_type,
    sym_type,
  0,
};

static const TSStateId ts_primary_state_ids[STATE_COUNT] = {
  [0] = 0,
  [1] = 1,
  [2] = 2,
  [3] = 3,
  [4] = 4,
  [5] = 5,
  [6] = 2,
  [7] = 7,
  [8] = 8,
  [9] = 7,
  [10] = 7,
  [11] = 7,
  [12] = 7,
  [13] = 7,
  [14] = 7,
  [15] = 7,
  [16] = 7,
  [17] = 7,
  [18] = 7,
  [19] = 7,
  [20] = 7,
  [21] = 21,
  [22] = 22,
  [23] = 23,
  [24] = 23,
  [25] = 23,
  [26] = 23,
  [27] = 23,
  [28] = 23,
  [29] = 23,
  [30] = 23,
  [31] = 23,
  [32] = 23,
  [33] = 23,
  [34] = 23,
  [35] = 23,
  [36] = 36,
  [37] = 37,
  [38] = 38,
  [39] = 39,
  [40] = 40,
  [41] = 40,
  [42] = 42,
  [43] = 43,
  [44] = 44,
  [45] = 40,
  [46] = 42,
  [47] = 43,
  [48] = 44,
  [49] = 40,
  [50] = 43,
  [51] = 44,
  [52] = 40,
  [53] = 43,
  [54] = 44,
  [55] = 44,
  [56] = 43,
  [57] = 44,
  [58] = 40,
  [59] = 43,
  [60] = 44,
  [61] = 40,
  [62] = 43,
  [63] = 44,
  [64] = 40,
  [65] = 43,
  [66] = 43,
  [67] = 44,
  [68] = 40,
  [69] = 44,
  [70] = 43,
  [71] = 44,
  [72] = 40,
  [73] = 43,
  [74] = 44,
  [75] = 40,
  [76] = 42,
  [77] = 43,
  [78] = 40,
  [79] = 79,
  [80] = 80,
  [81] = 81,
  [82] = 39,
  [83] = 83,
  [84] = 38,
  [85] = 39,
  [86] = 86,
  [87] = 87,
  [88] = 88,
  [89] = 89,
  [90] = 90,
  [91] = 88,
  [92] = 88,
  [93] = 93,
  [94] = 88,
  [95] = 93,
  [96] = 90,
  [97] = 88,
  [98] = 90,
  [99] = 88,
  [100] = 90,
  [101] = 101,
  [102] = 90,
  [103] = 88,
  [104] = 90,
  [105] = 105,
  [106] = 90,
  [107] = 88,
  [108] = 90,
  [109] = 88,
  [110] = 88,
  [111] = 111,
  [112] = 101,
  [113] = 105,
  [114] = 90,
  [115] = 88,
  [116] = 90,
  [117] = 88,
  [118] = 89,
  [119] = 90,
  [120] = 90,
  [121] = 121,
  [122] = 122,
  [123] = 123,
  [124] = 124,
  [125] = 125,
  [126] = 126,
  [127] = 126,
  [128] = 128,
  [129] = 129,
  [130] = 122,
  [131] = 123,
  [132] = 124,
  [133] = 125,
  [134] = 126,
  [135] = 128,
  [136] = 128,
  [137] = 129,
  [138] = 122,
  [139] = 123,
  [140] = 124,
  [141] = 125,
  [142] = 126,
  [143] = 143,
  [144] = 121,
  [145] = 145,
  [146] = 128,
  [147] = 147,
  [148] = 148,
  [149] = 129,
  [150] = 148,
  [151] = 151,
  [152] = 152,
  [153] = 153,
  [154] = 143,
  [155] = 121,
  [156] = 145,
  [157] = 147,
  [158] = 158,
  [159] = 159,
  [160] = 122,
  [161] = 158,
  [162] = 123,
  [163] = 124,
  [164] = 125,
  [165] = 126,
  [166] = 129,
  [167] = 153,
  [168] = 143,
  [169] = 151,
  [170] = 145,
  [171] = 147,
  [172] = 159,
  [173] = 122,
  [174] = 128,
  [175] = 129,
  [176] = 122,
  [177] = 123,
  [178] = 124,
  [179] = 153,
  [180] = 143,
  [181] = 121,
  [182] = 145,
  [183] = 147,
  [184] = 159,
  [185] = 125,
  [186] = 126,
  [187] = 159,
  [188] = 188,
  [189] = 128,
  [190] = 129,
  [191] = 153,
  [192] = 143,
  [193] = 121,
  [194] = 145,
  [195] = 147,
  [196] = 159,
  [197] = 122,
  [198] = 123,
  [199] = 124,
  [200] = 125,
  [201] = 126,
  [202] = 123,
  [203] = 153,
  [204] = 143,
  [205] = 121,
  [206] = 145,
  [207] = 147,
  [208] = 159,
  [209] = 128,
  [210] = 129,
  [211] = 129,
  [212] = 123,
  [213] = 124,
  [214] = 125,
  [215] = 153,
  [216] = 143,
  [217] = 145,
  [218] = 126,
  [219] = 152,
  [220] = 128,
  [221] = 129,
  [222] = 122,
  [223] = 123,
  [224] = 153,
  [225] = 143,
  [226] = 145,
  [227] = 124,
  [228] = 125,
  [229] = 126,
  [230] = 124,
  [231] = 128,
  [232] = 129,
  [233] = 153,
  [234] = 143,
  [235] = 145,
  [236] = 122,
  [237] = 123,
  [238] = 124,
  [239] = 125,
  [240] = 126,
  [241] = 153,
  [242] = 153,
  [243] = 143,
  [244] = 145,
  [245] = 128,
  [246] = 129,
  [247] = 122,
  [248] = 123,
  [249] = 124,
  [250] = 125,
  [251] = 153,
  [252] = 143,
  [253] = 145,
  [254] = 126,
  [255] = 125,
  [256] = 128,
  [257] = 129,
  [258] = 122,
  [259] = 123,
  [260] = 143,
  [261] = 145,
  [262] = 124,
  [263] = 125,
  [264] = 126,
  [265] = 153,
  [266] = 128,
  [267] = 121,
  [268] = 147,
  [269] = 159,
  [270] = 121,
  [271] = 147,
  [272] = 159,
  [273] = 121,
  [274] = 147,
  [275] = 159,
  [276] = 121,
  [277] = 147,
  [278] = 159,
  [279] = 121,
  [280] = 147,
  [281] = 159,
  [282] = 121,
  [283] = 147,
  [284] = 159,
  [285] = 122,
  [286] = 286,
  [287] = 286,
  [288] = 288,
  [289] = 289,
  [290] = 290,
  [291] = 291,
  [292] = 292,
  [293] = 293,
  [294] = 294,
  [295] = 295,
  [296] = 296,
  [297] = 297,
  [298] = 298,
  [299] = 299,
  [300] = 300,
  [301] = 301,
  [302] = 302,
  [303] = 303,
  [304] = 304,
  [305] = 305,
  [306] = 306,
  [307] = 307,
  [308] = 308,
  [309] = 309,
  [310] = 310,
  [311] = 311,
  [312] = 312,
  [313] = 313,
  [314] = 314,
  [315] = 315,
  [316] = 316,
  [317] = 317,
  [318] = 318,
  [319] = 319,
  [320] = 320,
  [321] = 321,
  [322] = 322,
  [323] = 323,
  [324] = 324,
  [325] = 325,
  [326] = 326,
  [327] = 327,
  [328] = 328,
  [329] = 329,
  [330] = 330,
  [331] = 331,
  [332] = 332,
  [333] = 333,
  [334] = 334,
  [335] = 4,
  [336] = 5,
  [337] = 2,
  [338] = 289,
  [339] = 288,
  [340] = 340,
  [341] = 341,
  [342] = 342,
  [343] = 343,
  [344] = 344,
  [345] = 345,
  [346] = 346,
  [347] = 289,
  [348] = 348,
  [349] = 288,
  [350] = 350,
  [351] = 351,
  [352] = 352,
  [353] = 353,
  [354] = 354,
  [355] = 355,
  [356] = 356,
  [357] = 357,
  [358] = 358,
  [359] = 359,
  [360] = 360,
  [361] = 361,
  [362] = 362,
  [363] = 363,
  [364] = 364,
  [365] = 365,
  [366] = 366,
  [367] = 367,
  [368] = 4,
  [369] = 5,
  [370] = 289,
  [371] = 288,
  [372] = 296,
  [373] = 4,
  [374] = 5,
  [375] = 302,
  [376] = 322,
  [377] = 323,
  [378] = 291,
  [379] = 341,
  [380] = 342,
  [381] = 340,
  [382] = 343,
  [383] = 352,
  [384] = 351,
  [385] = 352,
  [386] = 353,
  [387] = 354,
  [388] = 355,
  [389] = 356,
  [390] = 357,
  [391] = 358,
  [392] = 359,
  [393] = 360,
  [394] = 361,
  [395] = 362,
  [396] = 363,
  [397] = 364,
  [398] = 365,
  [399] = 366,
  [400] = 367,
  [401] = 288,
  [402] = 296,
  [403] = 4,
  [404] = 5,
  [405] = 341,
  [406] = 342,
  [407] = 289,
  [408] = 302,
  [409] = 344,
  [410] = 4,
  [411] = 322,
  [412] = 323,
  [413] = 5,
  [414] = 345,
  [415] = 291,
  [416] = 346,
  [417] = 289,
  [418] = 348,
  [419] = 288,
  [420] = 350,
  [421] = 351,
  [422] = 288,
  [423] = 350,
  [424] = 354,
  [425] = 355,
  [426] = 356,
  [427] = 357,
  [428] = 358,
  [429] = 359,
  [430] = 340,
  [431] = 360,
  [432] = 296,
  [433] = 361,
  [434] = 362,
  [435] = 363,
  [436] = 302,
  [437] = 364,
  [438] = 322,
  [439] = 323,
  [440] = 291,
  [441] = 365,
  [442] = 366,
  [443] = 367,
  [444] = 344,
  [445] = 4,
  [446] = 5,
  [447] = 345,
  [448] = 343,
  [449] = 341,
  [450] = 346,
  [451] = 342,
  [452] = 340,
  [453] = 343,
  [454] = 289,
  [455] = 348,
  [456] = 353,
  [457] = 353,
  [458] = 364,
  [459] = 365,
  [460] = 302,
  [461] = 366,
  [462] = 367,
  [463] = 322,
  [464] = 323,
  [465] = 344,
  [466] = 296,
  [467] = 291,
  [468] = 4,
  [469] = 5,
  [470] = 345,
  [471] = 346,
  [472] = 359,
  [473] = 302,
  [474] = 348,
  [475] = 360,
  [476] = 322,
  [477] = 323,
  [478] = 350,
  [479] = 351,
  [480] = 291,
  [481] = 352,
  [482] = 353,
  [483] = 354,
  [484] = 343,
  [485] = 355,
  [486] = 356,
  [487] = 357,
  [488] = 358,
  [489] = 359,
  [490] = 361,
  [491] = 360,
  [492] = 362,
  [493] = 361,
  [494] = 362,
  [495] = 363,
  [496] = 364,
  [497] = 363,
  [498] = 365,
  [499] = 366,
  [500] = 367,
  [501] = 364,
  [502] = 296,
  [503] = 365,
  [504] = 366,
  [505] = 367,
  [506] = 344,
  [507] = 4,
  [508] = 302,
  [509] = 5,
  [510] = 345,
  [511] = 322,
  [512] = 323,
  [513] = 346,
  [514] = 289,
  [515] = 342,
  [516] = 291,
  [517] = 356,
  [518] = 288,
  [519] = 350,
  [520] = 340,
  [521] = 351,
  [522] = 352,
  [523] = 353,
  [524] = 354,
  [525] = 5,
  [526] = 289,
  [527] = 344,
  [528] = 355,
  [529] = 4,
  [530] = 356,
  [531] = 357,
  [532] = 358,
  [533] = 5,
  [534] = 359,
  [535] = 345,
  [536] = 346,
  [537] = 289,
  [538] = 341,
  [539] = 341,
  [540] = 288,
  [541] = 360,
  [542] = 348,
  [543] = 288,
  [544] = 350,
  [545] = 351,
  [546] = 289,
  [547] = 352,
  [548] = 341,
  [549] = 354,
  [550] = 288,
  [551] = 4,
  [552] = 355,
  [553] = 341,
  [554] = 342,
  [555] = 340,
  [556] = 343,
  [557] = 342,
  [558] = 340,
  [559] = 343,
  [560] = 342,
  [561] = 340,
  [562] = 343,
  [563] = 357,
  [564] = 361,
  [565] = 296,
  [566] = 358,
  [567] = 362,
  [568] = 363,
  [569] = 348,
  [570] = 361,
  [571] = 302,
  [572] = 363,
  [573] = 364,
  [574] = 322,
  [575] = 323,
  [576] = 365,
  [577] = 291,
  [578] = 366,
  [579] = 367,
  [580] = 344,
  [581] = 296,
  [582] = 360,
  [583] = 345,
  [584] = 346,
  [585] = 302,
  [586] = 348,
  [587] = 361,
  [588] = 322,
  [589] = 323,
  [590] = 350,
  [591] = 351,
  [592] = 342,
  [593] = 291,
  [594] = 352,
  [595] = 348,
  [596] = 353,
  [597] = 362,
  [598] = 354,
  [599] = 363,
  [600] = 364,
  [601] = 355,
  [602] = 356,
  [603] = 357,
  [604] = 358,
  [605] = 365,
  [606] = 359,
  [607] = 343,
  [608] = 360,
  [609] = 366,
  [610] = 361,
  [611] = 367,
  [612] = 362,
  [613] = 363,
  [614] = 364,
  [615] = 344,
  [616] = 365,
  [617] = 366,
  [618] = 367,
  [619] = 296,
  [620] = 296,
  [621] = 4,
  [622] = 5,
  [623] = 353,
  [624] = 345,
  [625] = 346,
  [626] = 302,
  [627] = 302,
  [628] = 348,
  [629] = 322,
  [630] = 323,
  [631] = 354,
  [632] = 322,
  [633] = 323,
  [634] = 291,
  [635] = 289,
  [636] = 350,
  [637] = 341,
  [638] = 351,
  [639] = 341,
  [640] = 350,
  [641] = 291,
  [642] = 362,
  [643] = 351,
  [644] = 288,
  [645] = 353,
  [646] = 341,
  [647] = 342,
  [648] = 354,
  [649] = 355,
  [650] = 340,
  [651] = 343,
  [652] = 356,
  [653] = 340,
  [654] = 346,
  [655] = 357,
  [656] = 344,
  [657] = 4,
  [658] = 5,
  [659] = 345,
  [660] = 346,
  [661] = 289,
  [662] = 348,
  [663] = 288,
  [664] = 350,
  [665] = 351,
  [666] = 355,
  [667] = 352,
  [668] = 356,
  [669] = 353,
  [670] = 357,
  [671] = 354,
  [672] = 355,
  [673] = 356,
  [674] = 357,
  [675] = 358,
  [676] = 342,
  [677] = 340,
  [678] = 343,
  [679] = 342,
  [680] = 340,
  [681] = 343,
  [682] = 358,
  [683] = 358,
  [684] = 359,
  [685] = 352,
  [686] = 296,
  [687] = 360,
  [688] = 341,
  [689] = 345,
  [690] = 359,
  [691] = 359,
  [692] = 360,
  [693] = 361,
  [694] = 362,
  [695] = 363,
  [696] = 364,
  [697] = 365,
  [698] = 366,
  [699] = 367,
  [700] = 344,
  [701] = 352,
  [702] = 361,
  [703] = 322,
  [704] = 323,
  [705] = 350,
  [706] = 351,
  [707] = 344,
  [708] = 291,
  [709] = 352,
  [710] = 353,
  [711] = 296,
  [712] = 354,
  [713] = 350,
  [714] = 355,
  [715] = 356,
  [716] = 357,
  [717] = 358,
  [718] = 356,
  [719] = 359,
  [720] = 361,
  [721] = 360,
  [722] = 357,
  [723] = 362,
  [724] = 363,
  [725] = 364,
  [726] = 365,
  [727] = 366,
  [728] = 367,
  [729] = 296,
  [730] = 352,
  [731] = 354,
  [732] = 367,
  [733] = 360,
  [734] = 302,
  [735] = 348,
  [736] = 346,
  [737] = 322,
  [738] = 323,
  [739] = 291,
  [740] = 345,
  [741] = 351,
  [742] = 355,
  [743] = 362,
  [744] = 346,
  [745] = 359,
  [746] = 302,
  [747] = 363,
  [748] = 348,
  [749] = 344,
  [750] = 365,
  [751] = 358,
  [752] = 345,
  [753] = 366,
  [754] = 353,
  [755] = 364,
  [756] = 756,
  [757] = 757,
  [758] = 758,
  [759] = 2,
  [760] = 760,
  [761] = 761,
  [762] = 762,
  [763] = 763,
  [764] = 764,
  [765] = 765,
  [766] = 766,
  [767] = 767,
  [768] = 768,
  [769] = 769,
  [770] = 770,
  [771] = 771,
  [772] = 80,
  [773] = 773,
  [774] = 774,
  [775] = 290,
  [776] = 776,
  [777] = 777,
  [778] = 778,
  [779] = 86,
  [780] = 292,
  [781] = 781,
  [782] = 764,
  [783] = 783,
  [784] = 37,
  [785] = 83,
  [786] = 786,
  [787] = 761,
  [788] = 756,
  [789] = 87,
  [790] = 757,
  [791] = 791,
  [792] = 792,
  [793] = 793,
  [794] = 794,
  [795] = 795,
  [796] = 765,
  [797] = 797,
  [798] = 798,
  [799] = 799,
  [800] = 800,
  [801] = 760,
  [802] = 802,
  [803] = 803,
  [804] = 763,
  [805] = 805,
  [806] = 762,
  [807] = 807,
  [808] = 808,
  [809] = 809,
  [810] = 758,
  [811] = 4,
  [812] = 5,
  [813] = 36,
  [814] = 814,
  [815] = 815,
  [816] = 816,
  [817] = 817,
  [818] = 818,
  [819] = 819,
  [820] = 820,
  [821] = 821,
  [822] = 822,
  [823] = 823,
  [824] = 824,
  [825] = 825,
  [826] = 825,
  [827] = 827,
  [828] = 828,
  [829] = 829,
  [830] = 830,
  [831] = 831,
  [832] = 832,
  [833] = 833,
  [834] = 834,
  [835] = 835,
  [836] = 836,
  [837] = 837,
  [838] = 836,
  [839] = 837,
  [840] = 840,
  [841] = 841,
  [842] = 837,
  [843] = 837,
  [844] = 844,
  [845] = 837,
  [846] = 846,
  [847] = 846,
  [848] = 837,
  [849] = 841,
  [850] = 844,
  [851] = 851,
  [852] = 834,
  [853] = 851,
  [854] = 854,
  [855] = 855,
  [856] = 851,
  [857] = 851,
  [858] = 854,
  [859] = 854,
  [860] = 854,
  [861] = 854,
  [862] = 854,
  [863] = 851,
  [864] = 854,
  [865] = 854,
  [866] = 854,
  [867] = 851,
  [868] = 854,
  [869] = 854,
  [870] = 855,
  [871] = 851,
  [872] = 851,
  [873] = 851,
  [874] = 851,
  [875] = 851,
  [876] = 851,
  [877] = 854,
  [878] = 878,
  [879] = 815,
  [880] = 815,
  [881] = 881,
  [882] = 814,
  [883] = 878,
  [884] = 878,
  [885] = 881,
  [886] = 881,
  [887] = 814,
  [888] = 888,
  [889] = 889,
  [890] = 890,
  [891] = 891,
  [892] = 892,
  [893] = 893,
  [894] = 894,
  [895] = 895,
  [896] = 896,
  [897] = 897,
  [898] = 898,
  [899] = 899,
  [900] = 896,
  [901] = 901,
  [902] = 902,
  [903] = 903,
  [904] = 904,
  [905] = 905,
  [906] = 906,
  [907] = 907,
  [908] = 908,
  [909] = 888,
  [910] = 910,
  [911] = 911,
  [912] = 912,
  [913] = 913,
  [914] = 818,
  [915] = 915,
  [916] = 906,
  [917] = 915,
  [918] = 911,
  [919] = 817,
  [920] = 920,
  [921] = 921,
  [922] = 911,
  [923] = 923,
  [924] = 924,
  [925] = 925,
  [926] = 920,
  [927] = 927,
  [928] = 889,
  [929] = 929,
  [930] = 905,
  [931] = 931,
  [932] = 932,
  [933] = 893,
  [934] = 896,
  [935] = 904,
  [936] = 923,
  [937] = 921,
  [938] = 929,
  [939] = 939,
  [940] = 907,
  [941] = 908,
  [942] = 888,
  [943] = 943,
  [944] = 910,
  [945] = 912,
  [946] = 946,
  [947] = 906,
  [948] = 915,
  [949] = 920,
  [950] = 927,
  [951] = 923,
  [952] = 952,
  [953] = 890,
  [954] = 894,
  [955] = 897,
  [956] = 911,
  [957] = 931,
  [958] = 932,
  [959] = 893,
  [960] = 921,
  [961] = 939,
  [962] = 946,
  [963] = 927,
  [964] = 952,
  [965] = 890,
  [966] = 897,
  [967] = 818,
  [968] = 931,
  [969] = 932,
  [970] = 893,
  [971] = 921,
  [972] = 939,
  [973] = 946,
  [974] = 927,
  [975] = 952,
  [976] = 890,
  [977] = 894,
  [978] = 897,
  [979] = 931,
  [980] = 932,
  [981] = 921,
  [982] = 939,
  [983] = 946,
  [984] = 927,
  [985] = 952,
  [986] = 890,
  [987] = 894,
  [988] = 897,
  [989] = 931,
  [990] = 932,
  [991] = 921,
  [992] = 939,
  [993] = 946,
  [994] = 927,
  [995] = 952,
  [996] = 890,
  [997] = 894,
  [998] = 897,
  [999] = 931,
  [1000] = 932,
  [1001] = 921,
  [1002] = 939,
  [1003] = 946,
  [1004] = 927,
  [1005] = 952,
  [1006] = 890,
  [1007] = 894,
  [1008] = 897,
  [1009] = 1009,
  [1010] = 931,
  [1011] = 932,
  [1012] = 921,
  [1013] = 939,
  [1014] = 946,
  [1015] = 927,
  [1016] = 952,
  [1017] = 890,
  [1018] = 894,
  [1019] = 897,
  [1020] = 931,
  [1021] = 932,
  [1022] = 921,
  [1023] = 939,
  [1024] = 946,
  [1025] = 927,
  [1026] = 952,
  [1027] = 890,
  [1028] = 894,
  [1029] = 897,
  [1030] = 931,
  [1031] = 932,
  [1032] = 921,
  [1033] = 939,
  [1034] = 946,
  [1035] = 927,
  [1036] = 952,
  [1037] = 890,
  [1038] = 894,
  [1039] = 897,
  [1040] = 939,
  [1041] = 931,
  [1042] = 932,
  [1043] = 921,
  [1044] = 939,
  [1045] = 946,
  [1046] = 927,
  [1047] = 952,
  [1048] = 890,
  [1049] = 894,
  [1050] = 897,
  [1051] = 931,
  [1052] = 932,
  [1053] = 921,
  [1054] = 939,
  [1055] = 946,
  [1056] = 927,
  [1057] = 952,
  [1058] = 890,
  [1059] = 894,
  [1060] = 897,
  [1061] = 939,
  [1062] = 939,
  [1063] = 1009,
  [1064] = 913,
  [1065] = 924,
  [1066] = 901,
  [1067] = 911,
  [1068] = 889,
  [1069] = 1069,
  [1070] = 892,
  [1071] = 895,
  [1072] = 896,
  [1073] = 904,
  [1074] = 907,
  [1075] = 908,
  [1076] = 888,
  [1077] = 910,
  [1078] = 912,
  [1079] = 906,
  [1080] = 907,
  [1081] = 915,
  [1082] = 908,
  [1083] = 920,
  [1084] = 923,
  [1085] = 911,
  [1086] = 943,
  [1087] = 1009,
  [1088] = 913,
  [1089] = 924,
  [1090] = 901,
  [1091] = 889,
  [1092] = 1069,
  [1093] = 892,
  [1094] = 895,
  [1095] = 896,
  [1096] = 904,
  [1097] = 907,
  [1098] = 908,
  [1099] = 888,
  [1100] = 910,
  [1101] = 912,
  [1102] = 906,
  [1103] = 915,
  [1104] = 920,
  [1105] = 923,
  [1106] = 943,
  [1107] = 1009,
  [1108] = 913,
  [1109] = 924,
  [1110] = 901,
  [1111] = 889,
  [1112] = 1069,
  [1113] = 892,
  [1114] = 895,
  [1115] = 1009,
  [1116] = 913,
  [1117] = 924,
  [1118] = 901,
  [1119] = 889,
  [1120] = 1069,
  [1121] = 892,
  [1122] = 895,
  [1123] = 1009,
  [1124] = 913,
  [1125] = 924,
  [1126] = 901,
  [1127] = 889,
  [1128] = 1069,
  [1129] = 892,
  [1130] = 895,
  [1131] = 1009,
  [1132] = 913,
  [1133] = 1069,
  [1134] = 892,
  [1135] = 895,
  [1136] = 1009,
  [1137] = 913,
  [1138] = 1069,
  [1139] = 892,
  [1140] = 895,
  [1141] = 1009,
  [1142] = 913,
  [1143] = 1069,
  [1144] = 892,
  [1145] = 895,
  [1146] = 1009,
  [1147] = 913,
  [1148] = 1069,
  [1149] = 892,
  [1150] = 895,
  [1151] = 1009,
  [1152] = 913,
  [1153] = 1069,
  [1154] = 892,
  [1155] = 895,
  [1156] = 1009,
  [1157] = 1069,
  [1158] = 892,
  [1159] = 895,
  [1160] = 896,
  [1161] = 898,
  [1162] = 904,
  [1163] = 913,
  [1164] = 907,
  [1165] = 908,
  [1166] = 943,
  [1167] = 910,
  [1168] = 912,
  [1169] = 906,
  [1170] = 915,
  [1171] = 925,
  [1172] = 920,
  [1173] = 923,
  [1174] = 888,
  [1175] = 943,
  [1176] = 910,
  [1177] = 912,
  [1178] = 946,
  [1179] = 931,
  [1180] = 932,
  [1181] = 1181,
  [1182] = 952,
  [1183] = 924,
  [1184] = 901,
  [1185] = 889,
  [1186] = 924,
  [1187] = 901,
  [1188] = 889,
  [1189] = 924,
  [1190] = 901,
  [1191] = 889,
  [1192] = 924,
  [1193] = 901,
  [1194] = 889,
  [1195] = 924,
  [1196] = 901,
  [1197] = 889,
  [1198] = 899,
  [1199] = 904,
  [1200] = 1069,
  [1201] = 943,
  [1202] = 924,
  [1203] = 901,
  [1204] = 894,
  [1205] = 824,
  [1206] = 814,
  [1207] = 827,
  [1208] = 4,
  [1209] = 5,
  [1210] = 814,
  [1211] = 828,
  [1212] = 829,
  [1213] = 819,
  [1214] = 820,
  [1215] = 290,
  [1216] = 822,
  [1217] = 823,
  [1218] = 821,
  [1219] = 292,
  [1220] = 825,
  [1221] = 815,
  [1222] = 815,
  [1223] = 1223,
  [1224] = 825,
  [1225] = 818,
  [1226] = 817,
  [1227] = 818,
  [1228] = 814,
  [1229] = 821,
  [1230] = 783,
  [1231] = 819,
  [1232] = 756,
  [1233] = 827,
  [1234] = 793,
  [1235] = 822,
  [1236] = 820,
  [1237] = 823,
  [1238] = 824,
  [1239] = 828,
  [1240] = 825,
  [1241] = 829,
  [1242] = 815,
  [1243] = 818,
  [1244] = 757,
  [1245] = 758,
  [1246] = 1246,
  [1247] = 1247,
  [1248] = 1248,
  [1249] = 799,
  [1250] = 8,
  [1251] = 1251,
  [1252] = 1251,
  [1253] = 1253,
  [1254] = 1253,
  [1255] = 757,
  [1256] = 758,
  [1257] = 756,
  [1258] = 1258,
  [1259] = 1259,
  [1260] = 1260,
  [1261] = 1261,
  [1262] = 1262,
  [1263] = 818,
  [1264] = 817,
  [1265] = 767,
  [1266] = 766,
  [1267] = 756,
  [1268] = 80,
  [1269] = 757,
  [1270] = 769,
  [1271] = 809,
  [1272] = 802,
  [1273] = 773,
  [1274] = 805,
  [1275] = 791,
  [1276] = 765,
  [1277] = 778,
  [1278] = 783,
  [1279] = 781,
  [1280] = 36,
  [1281] = 758,
  [1282] = 770,
  [1283] = 800,
  [1284] = 760,
  [1285] = 762,
  [1286] = 763,
  [1287] = 764,
  [1288] = 776,
  [1289] = 86,
  [1290] = 771,
  [1291] = 774,
  [1292] = 795,
  [1293] = 83,
  [1294] = 786,
  [1295] = 761,
  [1296] = 797,
  [1297] = 803,
  [1298] = 808,
  [1299] = 793,
  [1300] = 794,
  [1301] = 768,
  [1302] = 37,
  [1303] = 87,
  [1304] = 798,
  [1305] = 777,
  [1306] = 822,
  [1307] = 829,
  [1308] = 823,
  [1309] = 1309,
  [1310] = 819,
  [1311] = 820,
  [1312] = 827,
  [1313] = 824,
  [1314] = 1314,
  [1315] = 821,
  [1316] = 828,
  [1317] = 820,
  [1318] = 756,
  [1319] = 828,
  [1320] = 827,
  [1321] = 793,
  [1322] = 829,
  [1323] = 783,
  [1324] = 819,
  [1325] = 1325,
  [1326] = 822,
  [1327] = 1325,
  [1328] = 1325,
  [1329] = 823,
  [1330] = 821,
  [1331] = 824,
  [1332] = 1325,
  [1333] = 1333,
  [1334] = 1333,
  [1335] = 1335,
  [1336] = 1325,
  [1337] = 1325,
  [1338] = 1325,
  [1339] = 1325,
  [1340] = 1325,
  [1341] = 1333,
  [1342] = 1325,
  [1343] = 1325,
  [1344] = 1325,
  [1345] = 1314,
  [1346] = 757,
  [1347] = 825,
  [1348] = 1348,
  [1349] = 1309,
  [1350] = 758,
  [1351] = 1351,
  [1352] = 1352,
  [1353] = 1353,
  [1354] = 1354,
  [1355] = 1355,
  [1356] = 1356,
  [1357] = 1357,
  [1358] = 1358,
  [1359] = 1359,
  [1360] = 1359,
  [1361] = 1355,
  [1362] = 1362,
  [1363] = 1363,
  [1364] = 1364,
  [1365] = 1356,
  [1366] = 1366,
  [1367] = 1367,
  [1368] = 828,
  [1369] = 829,
  [1370] = 819,
  [1371] = 820,
  [1372] = 1372,
  [1373] = 1373,
  [1374] = 822,
  [1375] = 823,
  [1376] = 821,
  [1377] = 1366,
  [1378] = 1378,
  [1379] = 824,
  [1380] = 1380,
  [1381] = 1381,
  [1382] = 1363,
  [1383] = 1359,
  [1384] = 1351,
  [1385] = 1372,
  [1386] = 1352,
  [1387] = 1353,
  [1388] = 1354,
  [1389] = 1389,
  [1390] = 1372,
  [1391] = 1362,
  [1392] = 1355,
  [1393] = 1366,
  [1394] = 1367,
  [1395] = 1373,
  [1396] = 1378,
  [1397] = 1367,
  [1398] = 1380,
  [1399] = 1381,
  [1400] = 1356,
  [1401] = 1363,
  [1402] = 1362,
  [1403] = 1403,
  [1404] = 1352,
  [1405] = 1366,
  [1406] = 1367,
  [1407] = 1373,
  [1408] = 1378,
  [1409] = 1357,
  [1410] = 1380,
  [1411] = 1381,
  [1412] = 1363,
  [1413] = 1362,
  [1414] = 1357,
  [1415] = 1366,
  [1416] = 1367,
  [1417] = 1417,
  [1418] = 1373,
  [1419] = 1378,
  [1420] = 1358,
  [1421] = 1380,
  [1422] = 1381,
  [1423] = 1358,
  [1424] = 1363,
  [1425] = 1362,
  [1426] = 1426,
  [1427] = 1366,
  [1428] = 1367,
  [1429] = 1373,
  [1430] = 1378,
  [1431] = 1380,
  [1432] = 1381,
  [1433] = 1363,
  [1434] = 1362,
  [1435] = 1389,
  [1436] = 1366,
  [1437] = 1372,
  [1438] = 1380,
  [1439] = 1372,
  [1440] = 1381,
  [1441] = 1426,
  [1442] = 1363,
  [1443] = 1359,
  [1444] = 1444,
  [1445] = 1362,
  [1446] = 1359,
  [1447] = 1366,
  [1448] = 1351,
  [1449] = 1380,
  [1450] = 1381,
  [1451] = 1363,
  [1452] = 1452,
  [1453] = 1362,
  [1454] = 1366,
  [1455] = 1380,
  [1456] = 1381,
  [1457] = 1363,
  [1458] = 1362,
  [1459] = 1352,
  [1460] = 1359,
  [1461] = 1366,
  [1462] = 1380,
  [1463] = 1381,
  [1464] = 1363,
  [1465] = 1362,
  [1466] = 1353,
  [1467] = 1354,
  [1468] = 1366,
  [1469] = 1352,
  [1470] = 1355,
  [1471] = 1353,
  [1472] = 1380,
  [1473] = 1356,
  [1474] = 1381,
  [1475] = 1363,
  [1476] = 1362,
  [1477] = 1353,
  [1478] = 1354,
  [1479] = 1355,
  [1480] = 1380,
  [1481] = 1381,
  [1482] = 1363,
  [1483] = 1357,
  [1484] = 1356,
  [1485] = 1358,
  [1486] = 827,
  [1487] = 1364,
  [1488] = 1366,
  [1489] = 1357,
  [1490] = 1358,
  [1491] = 1354,
  [1492] = 1444,
  [1493] = 1351,
  [1494] = 1452,
  [1495] = 1372,
  [1496] = 1359,
  [1497] = 1351,
  [1498] = 1444,
  [1499] = 1389,
  [1500] = 1352,
  [1501] = 1372,
  [1502] = 1359,
  [1503] = 1351,
  [1504] = 1417,
  [1505] = 1452,
  [1506] = 1353,
  [1507] = 1354,
  [1508] = 1373,
  [1509] = 1357,
  [1510] = 1355,
  [1511] = 1444,
  [1512] = 1362,
  [1513] = 1352,
  [1514] = 1353,
  [1515] = 1354,
  [1516] = 1351,
  [1517] = 1355,
  [1518] = 1381,
  [1519] = 1356,
  [1520] = 1356,
  [1521] = 1357,
  [1522] = 1358,
  [1523] = 1354,
  [1524] = 1444,
  [1525] = 1372,
  [1526] = 1359,
  [1527] = 1351,
  [1528] = 1380,
  [1529] = 1352,
  [1530] = 1353,
  [1531] = 1354,
  [1532] = 1357,
  [1533] = 1355,
  [1534] = 1358,
  [1535] = 1356,
  [1536] = 1355,
  [1537] = 1357,
  [1538] = 1358,
  [1539] = 1539,
  [1540] = 1372,
  [1541] = 1359,
  [1542] = 1351,
  [1543] = 1543,
  [1544] = 1352,
  [1545] = 1372,
  [1546] = 1353,
  [1547] = 1354,
  [1548] = 1355,
  [1549] = 1358,
  [1550] = 1356,
  [1551] = 1359,
  [1552] = 1351,
  [1553] = 1357,
  [1554] = 1358,
  [1555] = 1352,
  [1556] = 1353,
  [1557] = 1354,
  [1558] = 1372,
  [1559] = 1355,
  [1560] = 1356,
  [1561] = 1352,
  [1562] = 1359,
  [1563] = 1378,
  [1564] = 1359,
  [1565] = 1357,
  [1566] = 1358,
  [1567] = 1356,
  [1568] = 1351,
  [1569] = 1367,
  [1570] = 1373,
  [1571] = 1378,
  [1572] = 1367,
  [1573] = 1373,
  [1574] = 1378,
  [1575] = 1367,
  [1576] = 1373,
  [1577] = 1378,
  [1578] = 1367,
  [1579] = 1373,
  [1580] = 1378,
  [1581] = 1367,
  [1582] = 1373,
  [1583] = 1378,
  [1584] = 1352,
  [1585] = 1353,
  [1586] = 1354,
  [1587] = 1355,
  [1588] = 1372,
  [1589] = 1356,
  [1590] = 1359,
  [1591] = 1444,
  [1592] = 1357,
  [1593] = 1351,
  [1594] = 1358,
  [1595] = 1367,
  [1596] = 1373,
  [1597] = 1378,
  [1598] = 1353,
  [1599] = 1599,
  [1600] = 1600,
  [1601] = 1601,
  [1602] = 1600,
  [1603] = 818,
  [1604] = 1601,
  [1605] = 817,
  [1606] = 1600,
  [1607] = 1600,
  [1608] = 1608,
  [1609] = 1609,
  [1610] = 1610,
  [1611] = 1609,
  [1612] = 1610,
  [1613] = 1613,
  [1614] = 1609,
  [1615] = 1610,
  [1616] = 1613,
  [1617] = 1617,
  [1618] = 1613,
  [1619] = 1610,
  [1620] = 1610,
  [1621] = 1610,
  [1622] = 1613,
  [1623] = 1617,
  [1624] = 1624,
  [1625] = 1613,
  [1626] = 1608,
  [1627] = 1627,
  [1628] = 1610,
  [1629] = 1613,
  [1630] = 1610,
  [1631] = 1624,
  [1632] = 1613,
  [1633] = 1608,
  [1634] = 1610,
  [1635] = 1613,
  [1636] = 1627,
  [1637] = 1613,
  [1638] = 1617,
  [1639] = 1627,
  [1640] = 1640,
  [1641] = 1641,
  [1642] = 1641,
  [1643] = 1643,
  [1644] = 1644,
  [1645] = 1645,
  [1646] = 1646,
  [1647] = 1643,
  [1648] = 1648,
  [1649] = 1649,
  [1650] = 1649,
  [1651] = 1651,
  [1652] = 1652,
  [1653] = 1653,
  [1654] = 1654,
  [1655] = 1641,
  [1656] = 1656,
  [1657] = 1657,
  [1658] = 1649,
  [1659] = 1652,
  [1660] = 1649,
  [1661] = 1641,
  [1662] = 1645,
  [1663] = 1653,
  [1664] = 1664,
  [1665] = 1653,
  [1666] = 1646,
  [1667] = 1667,
  [1668] = 1645,
  [1669] = 1669,
  [1670] = 1653,
  [1671] = 1671,
  [1672] = 1671,
  [1673] = 1673,
  [1674] = 1643,
  [1675] = 1643,
  [1676] = 1676,
  [1677] = 1654,
  [1678] = 1641,
  [1679] = 1648,
  [1680] = 1648,
  [1681] = 1656,
  [1682] = 1682,
  [1683] = 1646,
  [1684] = 1671,
  [1685] = 1641,
  [1686] = 1646,
  [1687] = 1649,
  [1688] = 1671,
  [1689] = 1651,
  [1690] = 1690,
  [1691] = 1643,
  [1692] = 1692,
  [1693] = 1693,
  [1694] = 1694,
  [1695] = 1695,
  [1696] = 1696,
  [1697] = 1667,
  [1698] = 1698,
  [1699] = 1654,
  [1700] = 1645,
  [1701] = 1656,
  [1702] = 1652,
  [1703] = 1657,
  [1704] = 1645,
  [1705] = 1645,
  [1706] = 1690,
  [1707] = 1653,
  [1708] = 1708,
  [1709] = 1646,
  [1710] = 1654,
  [1711] = 1671,
  [1712] = 1643,
  [1713] = 1646,
  [1714] = 1654,
  [1715] = 1645,
  [1716] = 1716,
  [1717] = 1653,
  [1718] = 1654,
  [1719] = 1719,
  [1720] = 1656,
  [1721] = 1654,
  [1722] = 1656,
  [1723] = 1694,
  [1724] = 1653,
  [1725] = 1646,
  [1726] = 1645,
  [1727] = 1648,
  [1728] = 1696,
  [1729] = 1653,
  [1730] = 1648,
  [1731] = 1656,
  [1732] = 1695,
  [1733] = 1671,
  [1734] = 1653,
  [1735] = 1735,
  [1736] = 1649,
  [1737] = 1645,
  [1738] = 1648,
  [1739] = 1645,
  [1740] = 1653,
  [1741] = 1741,
  [1742] = 1654,
  [1743] = 1648,
  [1744] = 1744,
  [1745] = 1656,
  [1746] = 1644,
  [1747] = 1671,
  [1748] = 1643,
  [1749] = 1749,
  [1750] = 1673,
  [1751] = 1652,
  [1752] = 1752,
  [1753] = 1645,
  [1754] = 1749,
  [1755] = 1682,
  [1756] = 1651,
  [1757] = 1671,
  [1758] = 1656,
  [1759] = 1641,
  [1760] = 1671,
  [1761] = 1671,
  [1762] = 1651,
  [1763] = 1646,
  [1764] = 1654,
  [1765] = 1656,
  [1766] = 1651,
  [1767] = 1643,
  [1768] = 1641,
  [1769] = 1653,
  [1770] = 1770,
  [1771] = 1771,
  [1772] = 1772,
  [1773] = 1641,
  [1774] = 1643,
  [1775] = 1770,
  [1776] = 1646,
  [1777] = 1708,
  [1778] = 1716,
  [1779] = 1692,
  [1780] = 1654,
  [1781] = 1656,
  [1782] = 1671,
  [1783] = 1643,
  [1784] = 1654,
  [1785] = 1698,
  [1786] = 1656,
  [1787] = 1651,
  [1788] = 1645,
  [1789] = 1649,
  [1790] = 1651,
  [1791] = 1671,
  [1792] = 1649,
  [1793] = 1643,
  [1794] = 1653,
  [1795] = 1693,
  [1796] = 1649,
  [1797] = 1654,
  [1798] = 1656,
  [1799] = 1643,
  [1800] = 1800,
  [1801] = 1801,
  [1802] = 289,
  [1803] = 288,
  [1804] = 311,
  [1805] = 334,
  [1806] = 322,
  [1807] = 308,
  [1808] = 306,
  [1809] = 328,
  [1810] = 302,
  [1811] = 331,
  [1812] = 315,
  [1813] = 309,
  [1814] = 332,
  [1815] = 316,
  [1816] = 314,
  [1817] = 330,
  [1818] = 326,
  [1819] = 293,
  [1820] = 310,
  [1821] = 294,
  [1822] = 296,
  [1823] = 300,
  [1824] = 317,
  [1825] = 325,
  [1826] = 304,
  [1827] = 297,
  [1828] = 303,
  [1829] = 298,
  [1830] = 318,
  [1831] = 324,
  [1832] = 329,
  [1833] = 299,
  [1834] = 319,
  [1835] = 321,
  [1836] = 327,
  [1837] = 291,
  [1838] = 307,
  [1839] = 313,
  [1840] = 323,
  [1841] = 1841,
  [1842] = 1841,
  [1843] = 1843,
  [1844] = 1843,
  [1845] = 1845,
  [1846] = 1846,
  [1847] = 1847,
  [1848] = 1848,
  [1849] = 1849,
  [1850] = 1850,
  [1851] = 1851,
  [1852] = 1852,
  [1853] = 1853,
  [1854] = 1854,
  [1855] = 1854,
  [1856] = 1854,
  [1857] = 1853,
  [1858] = 1853,
  [1859] = 1853,
  [1860] = 1854,
  [1861] = 1853,
  [1862] = 1853,
  [1863] = 1853,
  [1864] = 1853,
  [1865] = 1853,
  [1866] = 1854,
  [1867] = 1853,
  [1868] = 1853,
  [1869] = 1853,
  [1870] = 1853,
  [1871] = 1854,
  [1872] = 1853,
  [1873] = 1853,
  [1874] = 1874,
  [1875] = 1875,
  [1876] = 756,
  [1877] = 1874,
  [1878] = 1874,
  [1879] = 1879,
  [1880] = 1879,
  [1881] = 1879,
  [1882] = 1879,
  [1883] = 1874,
  [1884] = 1874,
  [1885] = 1875,
  [1886] = 1879,
  [1887] = 1879,
  [1888] = 1874,
  [1889] = 1889,
  [1890] = 757,
  [1891] = 1875,
  [1892] = 1874,
  [1893] = 1875,
  [1894] = 1874,
  [1895] = 1879,
  [1896] = 1889,
  [1897] = 758,
  [1898] = 1898,
  [1899] = 1875,
  [1900] = 1898,
  [1901] = 1875,
  [1902] = 1875,
  [1903] = 1879,
  [1904] = 1874,
  [1905] = 1879,
  [1906] = 1874,
  [1907] = 1879,
  [1908] = 1908,
  [1909] = 1879,
  [1910] = 1889,
  [1911] = 1879,
  [1912] = 1875,
  [1913] = 1874,
  [1914] = 1874,
  [1915] = 1874,
  [1916] = 1874,
  [1917] = 1874,
  [1918] = 1908,
  [1919] = 1875,
  [1920] = 1920,
  [1921] = 1921,
  [1922] = 1922,
  [1923] = 1923,
  [1924] = 1924,
  [1925] = 1925,
  [1926] = 1921,
  [1927] = 1925,
  [1928] = 1928,
  [1929] = 1929,
  [1930] = 1930,
  [1931] = 1931,
  [1932] = 1932,
  [1933] = 1933,
  [1934] = 1934,
  [1935] = 1933,
  [1936] = 1936,
  [1937] = 1937,
  [1938] = 1921,
  [1939] = 1932,
  [1940] = 1934,
  [1941] = 1924,
  [1942] = 1932,
  [1943] = 1922,
  [1944] = 1933,
  [1945] = 1945,
  [1946] = 1946,
  [1947] = 756,
  [1948] = 1948,
  [1949] = 1949,
  [1950] = 1950,
  [1951] = 757,
  [1952] = 1948,
  [1953] = 1953,
  [1954] = 1954,
  [1955] = 1955,
  [1956] = 1954,
  [1957] = 758,
  [1958] = 1958,
  [1959] = 1948,
  [1960] = 1948,
  [1961] = 1961,
  [1962] = 1948,
  [1963] = 1954,
  [1964] = 1948,
  [1965] = 1954,
  [1966] = 1948,
  [1967] = 1954,
  [1968] = 1948,
  [1969] = 1954,
  [1970] = 1948,
  [1971] = 1954,
  [1972] = 1948,
  [1973] = 1954,
  [1974] = 1948,
  [1975] = 1954,
  [1976] = 1948,
  [1977] = 1954,
  [1978] = 799,
  [1979] = 1954,
  [1980] = 1980,
  [1981] = 1954,
  [1982] = 1982,
  [1983] = 1983,
  [1984] = 1984,
  [1985] = 1985,
  [1986] = 1986,
  [1987] = 1987,
  [1988] = 1988,
  [1989] = 1989,
  [1990] = 1990,
  [1991] = 1991,
  [1992] = 1992,
  [1993] = 1983,
  [1994] = 1986,
  [1995] = 1995,
  [1996] = 1990,
  [1997] = 1991,
  [1998] = 1992,
  [1999] = 1984,
  [2000] = 2000,
  [2001] = 1992,
  [2002] = 1990,
  [2003] = 1991,
  [2004] = 1992,
  [2005] = 2005,
  [2006] = 2006,
  [2007] = 1984,
  [2008] = 2008,
  [2009] = 2009,
  [2010] = 1983,
  [2011] = 2011,
  [2012] = 1990,
  [2013] = 1991,
  [2014] = 1992,
  [2015] = 2015,
  [2016] = 2016,
  [2017] = 2017,
  [2018] = 1990,
  [2019] = 1991,
  [2020] = 1992,
  [2021] = 1989,
  [2022] = 2022,
  [2023] = 2023,
  [2024] = 1990,
  [2025] = 1991,
  [2026] = 1992,
  [2027] = 2023,
  [2028] = 1988,
  [2029] = 1990,
  [2030] = 1991,
  [2031] = 1992,
  [2032] = 2032,
  [2033] = 1982,
  [2034] = 1987,
  [2035] = 1990,
  [2036] = 1991,
  [2037] = 1990,
  [2038] = 1991,
  [2039] = 2039,
  [2040] = 1983,
  [2041] = 1984,
  [2042] = 1990,
  [2043] = 1986,
  [2044] = 1986,
  [2045] = 2045,
  [2046] = 2046,
  [2047] = 2047,
  [2048] = 2048,
  [2049] = 2049,
  [2050] = 2050,
  [2051] = 2051,
  [2052] = 2052,
  [2053] = 1984,
  [2054] = 2047,
  [2055] = 1984,
  [2056] = 2056,
  [2057] = 2039,
  [2058] = 1984,
  [2059] = 2059,
  [2060] = 2039,
  [2061] = 1983,
  [2062] = 1986,
  [2063] = 2045,
  [2064] = 2046,
  [2065] = 756,
  [2066] = 2066,
  [2067] = 2056,
  [2068] = 2039,
  [2069] = 2045,
  [2070] = 2046,
  [2071] = 2000,
  [2072] = 2039,
  [2073] = 1991,
  [2074] = 2045,
  [2075] = 2046,
  [2076] = 2000,
  [2077] = 2016,
  [2078] = 2078,
  [2079] = 2039,
  [2080] = 1986,
  [2081] = 2045,
  [2082] = 2046,
  [2083] = 2016,
  [2084] = 2039,
  [2085] = 2045,
  [2086] = 2046,
  [2087] = 2078,
  [2088] = 2039,
  [2089] = 2045,
  [2090] = 2046,
  [2091] = 2091,
  [2092] = 2039,
  [2093] = 2045,
  [2094] = 2046,
  [2095] = 2095,
  [2096] = 2039,
  [2097] = 2045,
  [2098] = 2046,
  [2099] = 1989,
  [2100] = 2100,
  [2101] = 2039,
  [2102] = 2045,
  [2103] = 2046,
  [2104] = 2039,
  [2105] = 2045,
  [2106] = 2046,
  [2107] = 1990,
  [2108] = 1989,
  [2109] = 1991,
  [2110] = 1992,
  [2111] = 1992,
  [2112] = 2112,
  [2113] = 1983,
  [2114] = 2114,
  [2115] = 2032,
  [2116] = 1986,
  [2117] = 2117,
  [2118] = 2118,
  [2119] = 1984,
  [2120] = 1991,
  [2121] = 1984,
  [2122] = 2045,
  [2123] = 1983,
  [2124] = 2124,
  [2125] = 2125,
  [2126] = 2117,
  [2127] = 2047,
  [2128] = 1983,
  [2129] = 1986,
  [2130] = 2052,
  [2131] = 2124,
  [2132] = 2032,
  [2133] = 2117,
  [2134] = 2134,
  [2135] = 2052,
  [2136] = 2136,
  [2137] = 2032,
  [2138] = 2117,
  [2139] = 2139,
  [2140] = 2052,
  [2141] = 1990,
  [2142] = 2032,
  [2143] = 2117,
  [2144] = 1991,
  [2145] = 2052,
  [2146] = 1992,
  [2147] = 2032,
  [2148] = 2117,
  [2149] = 2149,
  [2150] = 2052,
  [2151] = 2151,
  [2152] = 2032,
  [2153] = 2117,
  [2154] = 757,
  [2155] = 2052,
  [2156] = 2156,
  [2157] = 2032,
  [2158] = 2117,
  [2159] = 1983,
  [2160] = 2052,
  [2161] = 2161,
  [2162] = 2032,
  [2163] = 2117,
  [2164] = 1986,
  [2165] = 2052,
  [2166] = 2046,
  [2167] = 2032,
  [2168] = 2117,
  [2169] = 2125,
  [2170] = 2052,
  [2171] = 1990,
  [2172] = 2032,
  [2173] = 2117,
  [2174] = 2052,
  [2175] = 2032,
  [2176] = 2117,
  [2177] = 2124,
  [2178] = 2125,
  [2179] = 2048,
  [2180] = 1991,
  [2181] = 1982,
  [2182] = 2066,
  [2183] = 2183,
  [2184] = 2056,
  [2185] = 2124,
  [2186] = 2125,
  [2187] = 2048,
  [2188] = 1992,
  [2189] = 2048,
  [2190] = 1982,
  [2191] = 2048,
  [2192] = 1982,
  [2193] = 2048,
  [2194] = 1982,
  [2195] = 2048,
  [2196] = 1982,
  [2197] = 2048,
  [2198] = 1982,
  [2199] = 2048,
  [2200] = 1982,
  [2201] = 2048,
  [2202] = 1982,
  [2203] = 2048,
  [2204] = 1982,
  [2205] = 2048,
  [2206] = 1982,
  [2207] = 2124,
  [2208] = 2125,
  [2209] = 2124,
  [2210] = 2125,
  [2211] = 2211,
  [2212] = 1990,
  [2213] = 758,
  [2214] = 2052,
  [2215] = 2215,
  [2216] = 2216,
  [2217] = 2217,
  [2218] = 2218,
  [2219] = 2219,
  [2220] = 2220,
  [2221] = 2221,
  [2222] = 2222,
  [2223] = 2223,
  [2224] = 2224,
  [2225] = 2225,
  [2226] = 2226,
  [2227] = 2227,
  [2228] = 2228,
  [2229] = 2229,
  [2230] = 2230,
  [2231] = 2231,
  [2232] = 2232,
  [2233] = 2223,
  [2234] = 2234,
  [2235] = 2235,
  [2236] = 2236,
  [2237] = 2236,
  [2238] = 2238,
  [2239] = 2238,
  [2240] = 2218,
  [2241] = 2241,
  [2242] = 2242,
  [2243] = 768,
  [2244] = 2244,
  [2245] = 2245,
  [2246] = 2246,
  [2247] = 2215,
  [2248] = 2218,
  [2249] = 2249,
  [2250] = 2226,
  [2251] = 2226,
  [2252] = 2252,
  [2253] = 2253,
  [2254] = 2230,
  [2255] = 2255,
  [2256] = 2249,
  [2257] = 2255,
  [2258] = 2258,
  [2259] = 2235,
  [2260] = 2260,
  [2261] = 2261,
  [2262] = 2262,
  [2263] = 2263,
  [2264] = 2264,
  [2265] = 2265,
  [2266] = 2241,
  [2267] = 2267,
  [2268] = 2265,
  [2269] = 2269,
  [2270] = 2270,
  [2271] = 2271,
  [2272] = 2272,
  [2273] = 2222,
  [2274] = 2226,
  [2275] = 2232,
  [2276] = 2230,
  [2277] = 2255,
  [2278] = 2230,
  [2279] = 2279,
  [2280] = 2280,
  [2281] = 2216,
  [2282] = 2282,
  [2283] = 2235,
  [2284] = 2279,
  [2285] = 2285,
  [2286] = 2286,
  [2287] = 2287,
  [2288] = 2222,
  [2289] = 2289,
  [2290] = 2224,
  [2291] = 2291,
  [2292] = 2227,
  [2293] = 2224,
  [2294] = 2223,
  [2295] = 2260,
  [2296] = 2296,
  [2297] = 778,
  [2298] = 2235,
  [2299] = 2235,
  [2300] = 2263,
  [2301] = 2301,
  [2302] = 2235,
  [2303] = 2303,
  [2304] = 2236,
  [2305] = 2305,
  [2306] = 2238,
  [2307] = 2307,
  [2308] = 2308,
  [2309] = 2309,
  [2310] = 2310,
  [2311] = 2311,
  [2312] = 2312,
  [2313] = 2246,
  [2314] = 2218,
  [2315] = 2241,
  [2316] = 2215,
  [2317] = 2317,
  [2318] = 2318,
  [2319] = 2319,
  [2320] = 2246,
  [2321] = 2215,
  [2322] = 2319,
  [2323] = 2323,
  [2324] = 2301,
  [2325] = 2325,
  [2326] = 2235,
  [2327] = 2236,
  [2328] = 2279,
  [2329] = 2329,
  [2330] = 2231,
  [2331] = 2227,
  [2332] = 2332,
  [2333] = 2255,
  [2334] = 2238,
  [2335] = 2260,
  [2336] = 2336,
  [2337] = 2336,
  [2338] = 2263,
  [2339] = 2265,
  [2340] = 2265,
  [2341] = 2341,
  [2342] = 2342,
  [2343] = 2267,
  [2344] = 2246,
  [2345] = 2228,
  [2346] = 2346,
  [2347] = 2269,
  [2348] = 2348,
  [2349] = 2267,
  [2350] = 2267,
  [2351] = 2279,
  [2352] = 2352,
  [2353] = 2229,
  [2354] = 2272,
  [2355] = 2285,
  [2356] = 2219,
  [2357] = 2357,
  [2358] = 2232,
  [2359] = 2217,
  [2360] = 2280,
  [2361] = 2216,
  [2362] = 2221,
  [2363] = 2363,
  [2364] = 2270,
  [2365] = 2301,
  [2366] = 2253,
  [2367] = 2222,
  [2368] = 2363,
  [2369] = 2224,
  [2370] = 2228,
  [2371] = 2227,
  [2372] = 2372,
  [2373] = 2223,
  [2374] = 2231,
  [2375] = 2255,
  [2376] = 2236,
  [2377] = 2238,
  [2378] = 2269,
  [2379] = 2218,
  [2380] = 2241,
  [2381] = 2279,
  [2382] = 2382,
  [2383] = 2383,
  [2384] = 2384,
  [2385] = 2246,
  [2386] = 2215,
  [2387] = 2387,
  [2388] = 2319,
  [2389] = 2301,
  [2390] = 2260,
  [2391] = 2391,
  [2392] = 2272,
  [2393] = 771,
  [2394] = 2255,
  [2395] = 2229,
  [2396] = 2396,
  [2397] = 2261,
  [2398] = 2260,
  [2399] = 2260,
  [2400] = 2336,
  [2401] = 2231,
  [2402] = 2228,
  [2403] = 2229,
  [2404] = 2303,
  [2405] = 2405,
  [2406] = 2305,
  [2407] = 2228,
  [2408] = 2307,
  [2409] = 2309,
  [2410] = 2310,
  [2411] = 2311,
  [2412] = 2309,
  [2413] = 2263,
  [2414] = 2286,
  [2415] = 2232,
  [2416] = 2265,
  [2417] = 2329,
  [2418] = 2286,
  [2419] = 2235,
  [2420] = 2267,
  [2421] = 2280,
  [2422] = 2216,
  [2423] = 2352,
  [2424] = 2424,
  [2425] = 2425,
  [2426] = 2357,
  [2427] = 2269,
  [2428] = 2217,
  [2429] = 2226,
  [2430] = 2263,
  [2431] = 2272,
  [2432] = 2311,
  [2433] = 2232,
  [2434] = 2280,
  [2435] = 2216,
  [2436] = 2262,
  [2437] = 2437,
  [2438] = 2215,
  [2439] = 2439,
  [2440] = 2317,
  [2441] = 2222,
  [2442] = 2319,
  [2443] = 2301,
  [2444] = 2444,
  [2445] = 2396,
  [2446] = 2261,
  [2447] = 2224,
  [2448] = 2448,
  [2449] = 2305,
  [2450] = 2309,
  [2451] = 2310,
  [2452] = 2311,
  [2453] = 2227,
  [2454] = 2454,
  [2455] = 2223,
  [2456] = 2456,
  [2457] = 2265,
  [2458] = 2310,
  [2459] = 2236,
  [2460] = 2261,
  [2461] = 2352,
  [2462] = 2230,
  [2463] = 2238,
  [2464] = 2357,
  [2465] = 2465,
  [2466] = 2217,
  [2467] = 2218,
  [2468] = 2241,
  [2469] = 2305,
  [2470] = 2309,
  [2471] = 2310,
  [2472] = 2311,
  [2473] = 2267,
  [2474] = 2255,
  [2475] = 2269,
  [2476] = 2226,
  [2477] = 2305,
  [2478] = 2246,
  [2479] = 2272,
  [2480] = 2222,
  [2481] = 2352,
  [2482] = 2235,
  [2483] = 2228,
  [2484] = 2357,
  [2485] = 2263,
  [2486] = 2217,
  [2487] = 2228,
  [2488] = 2224,
  [2489] = 2305,
  [2490] = 2309,
  [2491] = 2310,
  [2492] = 2311,
  [2493] = 2255,
  [2494] = 2272,
  [2495] = 2260,
  [2496] = 2227,
  [2497] = 2497,
  [2498] = 2498,
  [2499] = 2263,
  [2500] = 2500,
  [2501] = 2352,
  [2502] = 2223,
  [2503] = 2503,
  [2504] = 2357,
  [2505] = 2265,
  [2506] = 2217,
  [2507] = 2507,
  [2508] = 2267,
  [2509] = 2305,
  [2510] = 2309,
  [2511] = 2310,
  [2512] = 2311,
  [2513] = 2269,
  [2514] = 2229,
  [2515] = 2515,
  [2516] = 2352,
  [2517] = 2236,
  [2518] = 2269,
  [2519] = 2357,
  [2520] = 2520,
  [2521] = 2217,
  [2522] = 2522,
  [2523] = 2272,
  [2524] = 2305,
  [2525] = 2309,
  [2526] = 2310,
  [2527] = 2311,
  [2528] = 2238,
  [2529] = 2529,
  [2530] = 2218,
  [2531] = 2352,
  [2532] = 2241,
  [2533] = 2232,
  [2534] = 2357,
  [2535] = 2280,
  [2536] = 2217,
  [2537] = 2216,
  [2538] = 2538,
  [2539] = 2305,
  [2540] = 2309,
  [2541] = 2310,
  [2542] = 2311,
  [2543] = 2543,
  [2544] = 2232,
  [2545] = 2336,
  [2546] = 2352,
  [2547] = 2263,
  [2548] = 2548,
  [2549] = 2357,
  [2550] = 2550,
  [2551] = 2217,
  [2552] = 2497,
  [2553] = 2222,
  [2554] = 2305,
  [2555] = 2309,
  [2556] = 2310,
  [2557] = 2311,
  [2558] = 2226,
  [2559] = 2307,
  [2560] = 2279,
  [2561] = 2352,
  [2562] = 2228,
  [2563] = 2224,
  [2564] = 2357,
  [2565] = 2230,
  [2566] = 2217,
  [2567] = 2227,
  [2568] = 2265,
  [2569] = 2305,
  [2570] = 2309,
  [2571] = 2310,
  [2572] = 2311,
  [2573] = 2223,
  [2574] = 2246,
  [2575] = 2215,
  [2576] = 2352,
  [2577] = 2280,
  [2578] = 2272,
  [2579] = 2357,
  [2580] = 2318,
  [2581] = 2217,
  [2582] = 2236,
  [2583] = 2238,
  [2584] = 2305,
  [2585] = 2309,
  [2586] = 2310,
  [2587] = 2311,
  [2588] = 2235,
  [2589] = 2303,
  [2590] = 2352,
  [2591] = 2280,
  [2592] = 2500,
  [2593] = 2357,
  [2594] = 2218,
  [2595] = 2217,
  [2596] = 2241,
  [2597] = 2309,
  [2598] = 2310,
  [2599] = 2309,
  [2600] = 2310,
  [2601] = 2601,
  [2602] = 2602,
  [2603] = 2230,
  [2604] = 2604,
  [2605] = 2255,
  [2606] = 2396,
  [2607] = 2229,
  [2608] = 2279,
  [2609] = 2609,
  [2610] = 2246,
  [2611] = 2261,
  [2612] = 2215,
  [2613] = 2216,
  [2614] = 2279,
  [2615] = 2260,
  [2616] = 2515,
  [2617] = 2232,
  [2618] = 2252,
  [2619] = 2296,
  [2620] = 2255,
  [2621] = 2621,
  [2622] = 2260,
  [2623] = 2391,
  [2624] = 2503,
  [2625] = 2263,
  [2626] = 2280,
  [2627] = 2336,
  [2628] = 2265,
  [2629] = 2319,
  [2630] = 2448,
  [2631] = 2329,
  [2632] = 2267,
  [2633] = 2384,
  [2634] = 2382,
  [2635] = 2260,
  [2636] = 2269,
  [2637] = 2637,
  [2638] = 2216,
  [2639] = 2639,
  [2640] = 2272,
  [2641] = 2641,
  [2642] = 2336,
  [2643] = 2289,
  [2644] = 2232,
  [2645] = 2229,
  [2646] = 2280,
  [2647] = 2216,
  [2648] = 2263,
  [2649] = 2649,
  [2650] = 2507,
  [2651] = 2269,
  [2652] = 2652,
  [2653] = 2437,
  [2654] = 2654,
  [2655] = 2655,
  [2656] = 2222,
  [2657] = 2265,
  [2658] = 2224,
  [2659] = 2352,
  [2660] = 2227,
  [2661] = 2522,
  [2662] = 2223,
  [2663] = 2382,
  [2664] = 2222,
  [2665] = 2236,
  [2666] = 2238,
  [2667] = 2285,
  [2668] = 2218,
  [2669] = 2241,
  [2670] = 2224,
  [2671] = 2267,
  [2672] = 2227,
  [2673] = 2363,
  [2674] = 2246,
  [2675] = 2215,
  [2676] = 2384,
  [2677] = 2231,
  [2678] = 2231,
  [2679] = 2538,
  [2680] = 2231,
  [2681] = 2255,
  [2682] = 2329,
  [2683] = 2260,
  [2684] = 2231,
  [2685] = 2685,
  [2686] = 2263,
  [2687] = 2265,
  [2688] = 2637,
  [2689] = 2267,
  [2690] = 2228,
  [2691] = 2269,
  [2692] = 2226,
  [2693] = 2244,
  [2694] = 2223,
  [2695] = 2312,
  [2696] = 2272,
  [2697] = 2223,
  [2698] = 2232,
  [2699] = 2280,
  [2700] = 2216,
  [2701] = 2236,
  [2702] = 2238,
  [2703] = 2384,
  [2704] = 2218,
  [2705] = 2346,
  [2706] = 2222,
  [2707] = 2241,
  [2708] = 2224,
  [2709] = 2267,
  [2710] = 2227,
  [2711] = 2329,
  [2712] = 2548,
  [2713] = 2323,
  [2714] = 2236,
  [2715] = 2238,
  [2716] = 2716,
  [2717] = 2246,
  [2718] = 2215,
  [2719] = 2230,
  [2720] = 2260,
  [2721] = 2287,
  [2722] = 2236,
  [2723] = 2238,
  [2724] = 2246,
  [2725] = 2602,
  [2726] = 2383,
  [2727] = 2269,
  [2728] = 2216,
  [2729] = 2515,
  [2730] = 2215,
  [2731] = 2448,
  [2732] = 2329,
  [2733] = 2733,
  [2734] = 2348,
  [2735] = 2289,
  [2736] = 2235,
  [2737] = 2507,
  [2738] = 2652,
  [2739] = 2329,
  [2740] = 2602,
  [2741] = 2396,
  [2742] = 2272,
  [2743] = 2229,
  [2744] = 2515,
  [2745] = 2448,
  [2746] = 2439,
  [2747] = 2289,
  [2748] = 2500,
  [2749] = 2507,
  [2750] = 2652,
  [2751] = 2329,
  [2752] = 2602,
  [2753] = 2232,
  [2754] = 2641,
  [2755] = 2280,
  [2756] = 2515,
  [2757] = 2448,
  [2758] = 2222,
  [2759] = 2289,
  [2760] = 2216,
  [2761] = 2507,
  [2762] = 2652,
  [2763] = 2602,
  [2764] = 2287,
  [2765] = 2649,
  [2766] = 2602,
  [2767] = 2515,
  [2768] = 2448,
  [2769] = 2769,
  [2770] = 2289,
  [2771] = 2621,
  [2772] = 2507,
  [2773] = 2652,
  [2774] = 2602,
  [2775] = 2222,
  [2776] = 2639,
  [2777] = 2224,
  [2778] = 2515,
  [2779] = 2448,
  [2780] = 2780,
  [2781] = 2289,
  [2782] = 2226,
  [2783] = 2507,
  [2784] = 2652,
  [2785] = 2602,
  [2786] = 2227,
  [2787] = 2224,
  [2788] = 2788,
  [2789] = 2515,
  [2790] = 2448,
  [2791] = 2230,
  [2792] = 2289,
  [2793] = 2227,
  [2794] = 2507,
  [2795] = 2652,
  [2796] = 2602,
  [2797] = 2797,
  [2798] = 2223,
  [2799] = 2799,
  [2800] = 2515,
  [2801] = 2448,
  [2802] = 2235,
  [2803] = 2289,
  [2804] = 2223,
  [2805] = 2507,
  [2806] = 2652,
  [2807] = 2602,
  [2808] = 2236,
  [2809] = 2238,
  [2810] = 2341,
  [2811] = 2515,
  [2812] = 2448,
  [2813] = 2218,
  [2814] = 2289,
  [2815] = 2241,
  [2816] = 2507,
  [2817] = 2652,
  [2818] = 2602,
  [2819] = 2357,
  [2820] = 2820,
  [2821] = 2652,
  [2822] = 2515,
  [2823] = 2448,
  [2824] = 2824,
  [2825] = 2289,
  [2826] = 2230,
  [2827] = 2507,
  [2828] = 2652,
  [2829] = 2246,
  [2830] = 2215,
  [2831] = 2289,
  [2832] = 2405,
  [2833] = 2507,
  [2834] = 2652,
  [2835] = 2602,
  [2836] = 2291,
  [2837] = 2226,
  [2838] = 2444,
  [2839] = 2260,
  [2840] = 2550,
  [2841] = 2841,
  [2842] = 2225,
  [2843] = 2319,
  [2844] = 2824,
  [2845] = 2220,
  [2846] = 2301,
  [2847] = 2229,
  [2848] = 2329,
  [2849] = 2384,
  [2850] = 2325,
  [2851] = 2236,
  [2852] = 2230,
  [2853] = 2238,
  [2854] = 2246,
  [2855] = 2215,
  [2856] = 2856,
  [2857] = 2226,
  [2858] = 2218,
  [2859] = 2384,
  [2860] = 2255,
  [2861] = 2235,
  [2862] = 2291,
  [2863] = 2279,
  [2864] = 2241,
  [2865] = 2291,
  [2866] = 2231,
  [2867] = 2260,
  [2868] = 2291,
  [2869] = 2841,
  [2870] = 2654,
  [2871] = 2291,
  [2872] = 2263,
  [2873] = 2873,
  [2874] = 2291,
  [2875] = 2265,
  [2876] = 2876,
  [2877] = 2291,
  [2878] = 2267,
  [2879] = 2601,
  [2880] = 2291,
  [2881] = 2655,
  [2882] = 2269,
  [2883] = 2291,
  [2884] = 2226,
  [2885] = 2885,
  [2886] = 2291,
  [2887] = 2609,
  [2888] = 2271,
  [2889] = 2291,
  [2890] = 2230,
  [2891] = 2246,
  [2892] = 2892,
  [2893] = 2215,
  [2894] = 2396,
  [2895] = 2454,
  [2896] = 2261,
  [2897] = 2253,
  [2898] = 2272,
  [2899] = 2235,
  [2900] = 2396,
  [2901] = 2221,
  [2902] = 2308,
  [2903] = 2232,
  [2904] = 2241,
  [2905] = 2280,
  [2906] = 2515,
  [2907] = 2448,
  [2908] = 2342,
};

static bool ts_lex(TSLexer *lexer, TSStateId state) {
  START_LEXER();
  eof = lexer->eof(lexer);
  switch (state) {
    case 0:
      if (eof) ADVANCE(526);
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 722,
        '(', 561,
        ')', 562,
        '*', 713,
        '+', 709,
        ',', 569,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1081,
        ':', 536,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 73,
        'F', 738,
        'T', 735,
        '[', 574,
        ']', 575,
        '^', 723,
        'a', 158,
        'b', 358,
        'c', 102,
        'd', 106,
        'e', 311,
        'f', 101,
        'g', 297,
        'h', 361,
        'i', 232,
        'l', 265,
        'm', 266,
        'n', 171,
        'o', 234,
        'p', 97,
        'r', 172,
        's', 134,
        't', 103,
        'u', 335,
        'v', 193,
        'w', 256,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(0);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1082);
      END_STATE();
    case 1:
      if (lookahead == '\n') ADVANCE(1118);
      END_STATE();
    case 2:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 722,
        '(', 561,
        ')', 562,
        '*', 713,
        '+', 709,
        ',', 569,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1083,
        ':', 537,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        ']', 575,
        '^', 723,
        '_', 1049,
        'a', 790,
        'b', 892,
        'c', 888,
        'd', 886,
        'e', 877,
        'f', 843,
        'h', 895,
        'i', 874,
        'l', 837,
        'o', 904,
        'p', 761,
        'r', 815,
        's', 777,
        't', 763,
        'u', 878,
        'v', 814,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(2);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 3:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 721,
        '(', 561,
        ')', 562,
        '*', 713,
        '+', 709,
        ',', 569,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1083,
        ':', 537,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 72,
        'F', 739,
        'T', 736,
        '[', 574,
        ']', 575,
        '^', 723,
        '_', 1049,
        'a', 790,
        'b', 892,
        'c', 888,
        'd', 886,
        'e', 877,
        'f', 843,
        'h', 895,
        'i', 874,
        'l', 837,
        'o', 904,
        'p', 761,
        'r', 815,
        's', 777,
        't', 763,
        'u', 878,
        'v', 814,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(3);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 4:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 721,
        '(', 561,
        '*', 713,
        '+', 709,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1083,
        ':', 70,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '^', 723,
        '_', 1049,
        'a', 786,
        'b', 891,
        'c', 771,
        'd', 808,
        'e', 862,
        'f', 766,
        'h', 895,
        'i', 825,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 763,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(4);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 5:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 721,
        '(', 561,
        '*', 713,
        '+', 709,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1083,
        ':', 70,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '^', 723,
        '_', 1049,
        'a', 786,
        'b', 891,
        'c', 771,
        'd', 808,
        'e', 862,
        'f', 766,
        'h', 895,
        'i', 825,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 764,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(5);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 6:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 721,
        '(', 561,
        '*', 713,
        '+', 709,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1083,
        ':', 70,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '^', 723,
        '_', 1049,
        'a', 786,
        'b', 891,
        'c', 771,
        'd', 808,
        'e', 876,
        'f', 766,
        'h', 895,
        'i', 825,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 763,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(6);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 7:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 721,
        '(', 561,
        '*', 713,
        '+', 709,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1083,
        ':', 70,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '^', 723,
        '_', 1049,
        'a', 786,
        'b', 891,
        'c', 771,
        'd', 808,
        'e', 876,
        'f', 766,
        'h', 895,
        'i', 825,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 764,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(7);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 8:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 722,
        '(', 561,
        ')', 562,
        '*', 713,
        '+', 710,
        ',', 569,
        '-', 707,
        '/', 714,
        ':', 536,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 162,
        '[', 573,
        ']', 575,
        '^', 723,
        'a', 430,
        'd', 105,
        'h', 397,
        'i', 333,
        'm', 267,
        'o', 233,
        's', 202,
        'u', 435,
        '{', 532,
        '|', 699,
        '}', 533,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(8);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1089);
      END_STATE();
    case 9:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 721,
        '(', 561,
        ')', 562,
        '*', 713,
        '+', 710,
        ',', 569,
        '-', 707,
        '/', 714,
        ':', 536,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 162,
        '[', 573,
        ']', 575,
        '^', 723,
        'a', 430,
        'c', 372,
        'd', 105,
        'e', 492,
        'f', 473,
        'g', 297,
        'h', 361,
        'i', 333,
        'm', 266,
        'o', 235,
        'r', 220,
        's', 202,
        't', 508,
        'u', 435,
        '{', 532,
        '|', 699,
        '}', 533,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(9);
      END_STATE();
    case 10:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '&', 96,
        '(', 561,
        ')', 562,
        '+', 709,
        ',', 569,
        '-', 706,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 537,
        ';', 529,
        '=', 596,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        ']', 575,
        '_', 1049,
        'a', 791,
        'b', 892,
        'c', 888,
        'd', 886,
        'e', 877,
        'f', 843,
        'h', 895,
        'i', 866,
        'l', 837,
        'o', 904,
        'p', 761,
        'r', 815,
        's', 777,
        't', 763,
        'u', 878,
        'v', 814,
        '{', 532,
        '|', 698,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(10);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 11:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '&', 96,
        '(', 561,
        '+', 709,
        '-', 706,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '=', 596,
        '@', 72,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 791,
        'b', 892,
        'c', 888,
        'd', 886,
        'e', 877,
        'f', 843,
        'h', 895,
        'i', 866,
        'l', 837,
        'o', 827,
        'p', 761,
        'r', 815,
        's', 777,
        't', 763,
        'u', 878,
        'v', 814,
        '{', 532,
        '|', 698,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(11);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 12:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '(', 561,
        ')', 562,
        '+', 708,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 785,
        'b', 891,
        'c', 771,
        'd', 808,
        'e', 862,
        'f', 766,
        'h', 895,
        'i', 824,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 763,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 698,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(12);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 13:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '(', 561,
        ')', 562,
        '+', 708,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 785,
        'b', 891,
        'c', 771,
        'd', 808,
        'e', 862,
        'f', 766,
        'h', 895,
        'i', 824,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 764,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 698,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(13);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 14:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '(', 561,
        ')', 562,
        '+', 708,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 785,
        'b', 891,
        'c', 771,
        'd', 808,
        'e', 876,
        'f', 766,
        'h', 895,
        'i', 824,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 763,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 698,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(14);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 15:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '(', 561,
        ')', 562,
        '+', 708,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 785,
        'b', 891,
        'c', 771,
        'd', 808,
        'e', 876,
        'f', 766,
        'h', 895,
        'i', 824,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 764,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 698,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(15);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 16:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '(', 561,
        '+', 708,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '@', 72,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 791,
        'b', 892,
        'c', 888,
        'd', 886,
        'e', 877,
        'f', 843,
        'h', 895,
        'i', 866,
        'l', 837,
        'o', 904,
        'p', 761,
        'r', 815,
        's', 777,
        't', 763,
        'u', 878,
        'v', 814,
        'w', 836,
        '{', 532,
        '|', 698,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(16);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 17:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '(', 561,
        '+', 708,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        '@', 72,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 791,
        'b', 892,
        'c', 888,
        'd', 886,
        'e', 877,
        'f', 843,
        'h', 895,
        'i', 866,
        'l', 837,
        'o', 904,
        'p', 761,
        'r', 815,
        's', 777,
        't', 762,
        'u', 878,
        'v', 814,
        '{', 532,
        '|', 698,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(17);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 18:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '"', 28,
        '#', 1116,
        '.', 512,
        '0', 1083,
        ':', 536,
        '=', 596,
        '@', 72,
        'F', 740,
        'T', 737,
        '[', 69,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(18);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 19:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '#', 1116,
        '(', 561,
        ')', 562,
        ':', 70,
        '[', 573,
        '}', 533,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(19);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 20:
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '#', 1116,
        '(', 561,
        ':', 70,
        '=', 596,
        '[', 573,
        'a', 970,
        'b', 1014,
        'c', 1009,
        'd', 1012,
        'e', 1004,
        'f', 985,
        'h', 1015,
        'i', 998,
        'l', 986,
        'o', 1020,
        'p', 961,
        'r', 973,
        's', 980,
        't', 962,
        'u', 1003,
        'v', 979,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(20);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 21:
      if (lookahead == '\n') ADVANCE(1118);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(1116);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'c') ADVANCE(1011);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(21);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 22:
      if (lookahead == '\n') ADVANCE(1118);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(1116);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(1004);
      if (lookahead == 'r') ADVANCE(973);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(22);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 23:
      if (lookahead == '\n') ADVANCE(1118);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(1116);
      if (lookahead == '=') ADVANCE(596);
      if (lookahead == 'o') ADVANCE(233);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(23);
      END_STATE();
    case 24:
      if (lookahead == '\n') ADVANCE(1118);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(1116);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(24);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(755);
      END_STATE();
    case 25:
      if (lookahead == '\n') ADVANCE(1118);
      if (lookahead == '\r') ADVANCE(1);
      if (lookahead == '#') ADVANCE(1051);
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(25);
      if (lookahead != 0) ADVANCE(1056);
      END_STATE();
    case 26:
      if (lookahead == '"') ADVANCE(1111);
      if (lookahead == '\\') ADVANCE(497);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(26);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(28);
      END_STATE();
    case 27:
      if (lookahead == '"') ADVANCE(1111);
      if (lookahead == '\\') ADVANCE(497);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(27);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(28);
      END_STATE();
    case 28:
      if (lookahead == '"') ADVANCE(1111);
      if (lookahead == '\\') ADVANCE(497);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(28);
      END_STATE();
    case 29:
      if (lookahead == '+') ADVANCE(513);
      if (lookahead == '-') ADVANCE(33);
      if (lookahead == '.') ADVANCE(514);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1092);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 30:
      if (lookahead == '.') ADVANCE(30);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(44);
      END_STATE();
    case 31:
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == ']') ADVANCE(1079);
      END_STATE();
    case 32:
      if (lookahead == '.') ADVANCE(31);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(32);
      END_STATE();
    case 33:
      if (lookahead == '.') ADVANCE(514);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1092);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 34:
      if (lookahead == '.') ADVANCE(514);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(1104);
      if (lookahead == '-' ||
          ('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 35:
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 36:
      if (lookahead == '.') ADVANCE(36);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1063);
      END_STATE();
    case 37:
      if (lookahead == '.') ADVANCE(36);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1066);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 38:
      if (lookahead == '.') ADVANCE(36);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1069);
      END_STATE();
    case 39:
      if (lookahead == '.') ADVANCE(37);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1070);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 40:
      if (lookahead == '.') ADVANCE(40);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(32);
      END_STATE();
    case 41:
      if (lookahead == '.') ADVANCE(40);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(43);
      END_STATE();
    case 42:
      if (lookahead == '.') ADVANCE(42);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(32);
      END_STATE();
    case 43:
      if (lookahead == '.') ADVANCE(42);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(43);
      END_STATE();
    case 44:
      if (lookahead == '.') ADVANCE(46);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(51);
      END_STATE();
    case 45:
      if (lookahead == '.') ADVANCE(46);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(39);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 46:
      if (lookahead == '.') ADVANCE(46);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(38);
      END_STATE();
    case 47:
      if (lookahead == '.') ADVANCE(48);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(54);
      END_STATE();
    case 48:
      if (lookahead == '.') ADVANCE(48);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(41);
      END_STATE();
    case 49:
      if (lookahead == '.') ADVANCE(50);
      if (lookahead == ':') ADVANCE(68);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(57);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(69);
      END_STATE();
    case 50:
      if (lookahead == '.') ADVANCE(50);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(47);
      END_STATE();
    case 51:
      if (lookahead == '.') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1072);
      END_STATE();
    case 52:
      if (lookahead == '.') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1070);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 53:
      if (lookahead == '.') ADVANCE(53);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1069);
      END_STATE();
    case 54:
      if (lookahead == '.') ADVANCE(55);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(59);
      END_STATE();
    case 55:
      if (lookahead == '.') ADVANCE(55);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(43);
      END_STATE();
    case 56:
      if (lookahead == '.') ADVANCE(56);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(51);
      END_STATE();
    case 57:
      if (lookahead == '.') ADVANCE(58);
      if (lookahead == ':') ADVANCE(68);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(62);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(69);
      END_STATE();
    case 58:
      if (lookahead == '.') ADVANCE(58);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(54);
      END_STATE();
    case 59:
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(59);
      END_STATE();
    case 60:
      if (lookahead == '.') ADVANCE(60);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(43);
      END_STATE();
    case 61:
      if (lookahead == '.') ADVANCE(61);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1072);
      END_STATE();
    case 62:
      if (lookahead == '.') ADVANCE(63);
      if (lookahead == ':') ADVANCE(68);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(69);
      END_STATE();
    case 63:
      if (lookahead == '.') ADVANCE(63);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(59);
      END_STATE();
    case 64:
      if (lookahead == '.') ADVANCE(65);
      if (lookahead == ':') ADVANCE(68);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(64);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(69);
      END_STATE();
    case 65:
      if (lookahead == '.') ADVANCE(65);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(59);
      END_STATE();
    case 66:
      if (lookahead == '/') ADVANCE(1060);
      if (lookahead == '\\') ADVANCE(67);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(66);
      END_STATE();
    case 67:
      if (lookahead == '/') ADVANCE(1058);
      if (lookahead == '\\') ADVANCE(67);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(66);
      END_STATE();
    case 68:
      if (lookahead == ':') ADVANCE(68);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(49);
      if (('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(69);
      END_STATE();
    case 69:
      if (lookahead == ':') ADVANCE(68);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(69);
      END_STATE();
    case 70:
      if (lookahead == ':') ADVANCE(516);
      END_STATE();
    case 71:
      if (lookahead == 'A') ADVANCE(79);
      END_STATE();
    case 72:
      if (lookahead == 'D') ADVANCE(76);
      if (lookahead == 'F') ADVANCE(77);
      END_STATE();
    case 73:
      ADVANCE_MAP(
        'D', 76,
        'F', 77,
        'd', 197,
        'e', 316,
        'i', 236,
        'l', 355,
        'p', 402,
        'u', 349,
      );
      END_STATE();
    case 74:
      if (lookahead == 'E') ADVANCE(80);
      END_STATE();
    case 75:
      if (lookahead == 'E') ADVANCE(757);
      END_STATE();
    case 76:
      if (lookahead == 'I') ADVANCE(81);
      END_STATE();
    case 77:
      if (lookahead == 'I') ADVANCE(78);
      END_STATE();
    case 78:
      if (lookahead == 'L') ADVANCE(74);
      END_STATE();
    case 79:
      if (lookahead == 'M') ADVANCE(75);
      END_STATE();
    case 80:
      if (lookahead == 'N') ADVANCE(71);
      END_STATE();
    case 81:
      if (lookahead == 'R') ADVANCE(756);
      END_STATE();
    case 82:
      if (lookahead == '_') ADVANCE(109);
      END_STATE();
    case 83:
      if (lookahead == '_') ADVANCE(118);
      END_STATE();
    case 84:
      if (lookahead == '_') ADVANCE(244);
      END_STATE();
    case 85:
      if (lookahead == '_') ADVANCE(137);
      END_STATE();
    case 86:
      if (lookahead == '_') ADVANCE(144);
      END_STATE();
    case 87:
      if (lookahead == '_') ADVANCE(143);
      END_STATE();
    case 88:
      if (lookahead == '_') ADVANCE(378);
      END_STATE();
    case 89:
      if (lookahead == '_') ADVANCE(471);
      END_STATE();
    case 90:
      if (lookahead == '_') ADVANCE(196);
      END_STATE();
    case 91:
      if (lookahead == '_') ADVANCE(262);
      END_STATE();
    case 92:
      if (lookahead == '_') ADVANCE(245);
      END_STATE();
    case 93:
      if (lookahead == '_') ADVANCE(246);
      END_STATE();
    case 94:
      if (lookahead == '_') ADVANCE(226);
      END_STATE();
    case 95:
      if (lookahead == '_') ADVANCE(228);
      END_STATE();
    case 96:
      ADVANCE_MAP(
        'a', 161,
        'b', 107,
        'c', 406,
        'd', 173,
        'e', 420,
        'g', 404,
        'i', 427,
        'l', 354,
        'o', 334,
        'p', 422,
        'r', 98,
        't', 509,
        'w', 421,
      );
      END_STATE();
    case 97:
      if (lookahead == 'a') ADVANCE(457);
      if (lookahead == 'o') ADVANCE(381);
      if (lookahead == 'r') ADVANCE(283);
      if (lookahead == 'u') ADVANCE(431);
      END_STATE();
    case 98:
      if (lookahead == 'a') ADVANCE(494);
      if (lookahead == 'e') ADVANCE(113);
      END_STATE();
    case 99:
      if (lookahead == 'a') ADVANCE(396);
      if (lookahead == 't') ADVANCE(276);
      END_STATE();
    case 100:
      if (lookahead == 'a') ADVANCE(752);
      END_STATE();
    case 101:
      if (lookahead == 'a') ADVANCE(298);
      if (lookahead == 'i') ADVANCE(301);
      if (lookahead == 'o') ADVANCE(398);
      if (lookahead == 'u') ADVANCE(350);
      END_STATE();
    case 102:
      if (lookahead == 'a') ADVANCE(437);
      if (lookahead == 'o') ADVANCE(352);
      END_STATE();
    case 103:
      if (lookahead == 'a') ADVANCE(126);
      if (lookahead == 'i') ADVANCE(321);
      if (lookahead == 'y') ADVANCE(388);
      END_STATE();
    case 104:
      if (lookahead == 'a') ADVANCE(250);
      if (lookahead == 'e') ADVANCE(243);
      END_STATE();
    case 105:
      if (lookahead == 'a') ADVANCE(504);
      END_STATE();
    case 106:
      if (lookahead == 'a') ADVANCE(504);
      if (lookahead == 'e') ADVANCE(242);
      if (lookahead == 'o') ADVANCE(491);
      END_STATE();
    case 107:
      if (lookahead == 'a') ADVANCE(135);
      if (lookahead == 'r') ADVANCE(375);
      END_STATE();
    case 108:
      if (lookahead == 'a') ADVANCE(288);
      END_STATE();
    case 109:
      if (lookahead == 'a') ADVANCE(433);
      if (lookahead == 'u') ADVANCE(440);
      END_STATE();
    case 110:
      if (lookahead == 'a') ADVANCE(293);
      END_STATE();
    case 111:
      if (lookahead == 'a') ADVANCE(485);
      END_STATE();
    case 112:
      if (lookahead == 'a') ADVANCE(294);
      END_STATE();
    case 113:
      if (lookahead == 'a') ADVANCE(165);
      if (lookahead == 'd') ADVANCE(199);
      END_STATE();
    case 114:
      if (lookahead == 'a') ADVANCE(149);
      END_STATE();
    case 115:
      if (lookahead == 'a') ADVANCE(295);
      END_STATE();
    case 116:
      if (lookahead == 'a') ADVANCE(296);
      END_STATE();
    case 117:
      if (lookahead == 'a') ADVANCE(151);
      END_STATE();
    case 118:
      if (lookahead == 'a') ADVANCE(314);
      if (lookahead == 's') ADVANCE(460);
      END_STATE();
    case 119:
      if (lookahead == 'a') ADVANCE(337);
      END_STATE();
    case 120:
      if (lookahead == 'a') ADVANCE(345);
      END_STATE();
    case 121:
      if (lookahead == 'a') ADVANCE(465);
      END_STATE();
    case 122:
      if (lookahead == 'a') ADVANCE(466);
      END_STATE();
    case 123:
      if (lookahead == 'a') ADVANCE(487);
      END_STATE();
    case 124:
      if (lookahead == 'a') ADVANCE(472);
      END_STATE();
    case 125:
      if (lookahead == 'b') ADVANCE(347);
      END_STATE();
    case 126:
      if (lookahead == 'b') ADVANCE(305);
      END_STATE();
    case 127:
      if (lookahead == 'b') ADVANCE(112);
      END_STATE();
    case 128:
      if (lookahead == 'b') ADVANCE(307);
      END_STATE();
    case 129:
      if (lookahead == 'c') ADVANCE(1107);
      END_STATE();
    case 130:
      if (lookahead == 'c') ADVANCE(1107);
      if (lookahead == 't') ADVANCE(662);
      END_STATE();
    case 131:
      if (lookahead == 'c') ADVANCE(684);
      END_STATE();
    case 132:
      if (lookahead == 'c') ADVANCE(689);
      END_STATE();
    case 133:
      if (lookahead == 'c') ADVANCE(690);
      END_STATE();
    case 134:
      if (lookahead == 'c') ADVANCE(261);
      if (lookahead == 'e') ADVANCE(130);
      if (lookahead == 't') ADVANCE(419);
      if (lookahead == 'u') ADVANCE(125);
      if (lookahead == 'w') ADVANCE(273);
      END_STATE();
    case 135:
      if (lookahead == 'c') ADVANCE(290);
      END_STATE();
    case 136:
      if (lookahead == 'c') ADVANCE(318);
      END_STATE();
    case 137:
      if (lookahead == 'c') ADVANCE(260);
      END_STATE();
    case 138:
      if (lookahead == 'c') ADVANCE(110);
      END_STATE();
    case 139:
      if (lookahead == 'c') ADVANCE(382);
      END_STATE();
    case 140:
      if (lookahead == 'c') ADVANCE(258);
      END_STATE();
    case 141:
      if (lookahead == 'c') ADVANCE(468);
      END_STATE();
    case 142:
      if (lookahead == 'c') ADVANCE(364);
      if (lookahead == 'd') ADVANCE(195);
      if (lookahead == 't') ADVANCE(479);
      END_STATE();
    case 143:
      if (lookahead == 'c') ADVANCE(376);
      END_STATE();
    case 144:
      if (lookahead == 'c') ADVANCE(366);
      END_STATE();
    case 145:
      if (lookahead == 'c') ADVANCE(470);
      END_STATE();
    case 146:
      if (lookahead == 'c') ADVANCE(121);
      END_STATE();
    case 147:
      if (lookahead == 'c') ADVANCE(122);
      END_STATE();
    case 148:
      if (lookahead == 'd') ADVANCE(587);
      END_STATE();
    case 149:
      if (lookahead == 'd') ADVANCE(742);
      END_STATE();
    case 150:
      if (lookahead == 'd') ADVANCE(548);
      END_STATE();
    case 151:
      if (lookahead == 'd') ADVANCE(745);
      END_STATE();
    case 152:
      if (lookahead == 'd') ADVANCE(685);
      END_STATE();
    case 153:
      if (lookahead == 'd') ADVANCE(678);
      END_STATE();
    case 154:
      if (lookahead == 'd') ADVANCE(681);
      END_STATE();
    case 155:
      if (lookahead == 'd') ADVANCE(675);
      END_STATE();
    case 156:
      if (lookahead == 'd') ADVANCE(741);
      END_STATE();
    case 157:
      if (lookahead == 'd') ADVANCE(677);
      END_STATE();
    case 158:
      if (lookahead == 'd') ADVANCE(148);
      if (lookahead == 'n') ADVANCE(505);
      if (lookahead == 's') ADVANCE(607);
      END_STATE();
    case 159:
      if (lookahead == 'd') ADVANCE(489);
      END_STATE();
    case 160:
      if (lookahead == 'd') ADVANCE(84);
      END_STATE();
    case 161:
      if (lookahead == 'd') ADVANCE(160);
      END_STATE();
    case 162:
      if (lookahead == 'd') ADVANCE(197);
      if (lookahead == 'e') ADVANCE(316);
      if (lookahead == 'i') ADVANCE(236);
      if (lookahead == 'l') ADVANCE(355);
      if (lookahead == 'p') ADVANCE(402);
      if (lookahead == 'u') ADVANCE(349);
      END_STATE();
    case 163:
      if (lookahead == 'd') ADVANCE(382);
      if (lookahead == 'n') ADVANCE(289);
      END_STATE();
    case 164:
      if (lookahead == 'd') ADVANCE(270);
      END_STATE();
    case 165:
      if (lookahead == 'd') ADVANCE(90);
      END_STATE();
    case 166:
      if (lookahead == 'd') ADVANCE(195);
      END_STATE();
    case 167:
      if (lookahead == 'd') ADVANCE(222);
      END_STATE();
    case 168:
      if (lookahead == 'd') ADVANCE(206);
      END_STATE();
    case 169:
      if (lookahead == 'd') ADVANCE(310);
      END_STATE();
    case 170:
      if (lookahead == 'd') ADVANCE(490);
      END_STATE();
    case 171:
      if (lookahead == 'e') ADVANCE(498);
      END_STATE();
    case 172:
      if (lookahead == 'e') ADVANCE(142);
      END_STATE();
    case 173:
      if (lookahead == 'e') ADVANCE(247);
      END_STATE();
    case 174:
      if (lookahead == 'e') ADVANCE(600);
      END_STATE();
    case 175:
      if (lookahead == 'e') ADVANCE(563);
      END_STATE();
    case 176:
      if (lookahead == 'e') ADVANCE(629);
      END_STATE();
    case 177:
      if (lookahead == 'e') ADVANCE(656);
      END_STATE();
    case 178:
      if (lookahead == 'e') ADVANCE(552);
      END_STATE();
    case 179:
      if (lookahead == 'e') ADVANCE(751);
      END_STATE();
    case 180:
      if (lookahead == 'e') ADVANCE(665);
      END_STATE();
    case 181:
      if (lookahead == 'e') ADVANCE(576);
      END_STATE();
    case 182:
      if (lookahead == 'e') ADVANCE(588);
      END_STATE();
    case 183:
      if (lookahead == 'e') ADVANCE(626);
      END_STATE();
    case 184:
      if (lookahead == 'e') ADVANCE(527);
      END_STATE();
    case 185:
      if (lookahead == 'e') ADVANCE(659);
      END_STATE();
    case 186:
      if (lookahead == 'e') ADVANCE(733);
      END_STATE();
    case 187:
      if (lookahead == 'e') ADVANCE(692);
      END_STATE();
    case 188:
      if (lookahead == 'e') ADVANCE(694);
      END_STATE();
    case 189:
      if (lookahead == 'e') ADVANCE(686);
      END_STATE();
    case 190:
      if (lookahead == 'e') ADVANCE(696);
      END_STATE();
    case 191:
      if (lookahead == 'e') ADVANCE(687);
      END_STATE();
    case 192:
      if (lookahead == 'e') ADVANCE(674);
      END_STATE();
    case 193:
      if (lookahead == 'e') ADVANCE(141);
      END_STATE();
    case 194:
      if (lookahead == 'e') ADVANCE(108);
      END_STATE();
    case 195:
      if (lookahead == 'e') ADVANCE(237);
      END_STATE();
    case 196:
      if (lookahead == 'e') ADVANCE(501);
      END_STATE();
    case 197:
      if (lookahead == 'e') ADVANCE(395);
      END_STATE();
    case 198:
      if (lookahead == 'e') ADVANCE(499);
      END_STATE();
    case 199:
      if (lookahead == 'e') ADVANCE(238);
      END_STATE();
    case 200:
      if (lookahead == 'e') ADVANCE(124);
      END_STATE();
    case 201:
      if (lookahead == 'e') ADVANCE(324);
      if (lookahead == 'i') ADVANCE(306);
      END_STATE();
    case 202:
      if (lookahead == 'e') ADVANCE(129);
      END_STATE();
    case 203:
      if (lookahead == 'e') ADVANCE(428);
      END_STATE();
    case 204:
      if (lookahead == 'e') ADVANCE(240);
      END_STATE();
    case 205:
      if (lookahead == 'e') ADVANCE(410);
      END_STATE();
    case 206:
      if (lookahead == 'e') ADVANCE(241);
      END_STATE();
    case 207:
      if (lookahead == 'e') ADVANCE(153);
      END_STATE();
    case 208:
      if (lookahead == 'e') ADVANCE(340);
      END_STATE();
    case 209:
      if (lookahead == 'e') ADVANCE(154);
      END_STATE();
    case 210:
      if (lookahead == 'e') ADVANCE(155);
      END_STATE();
    case 211:
      if (lookahead == 'e') ADVANCE(405);
      END_STATE();
    case 212:
      if (lookahead == 'e') ADVANCE(401);
      END_STATE();
    case 213:
      if (lookahead == 'e') ADVANCE(156);
      END_STATE();
    case 214:
      if (lookahead == 'e') ADVANCE(450);
      END_STATE();
    case 215:
      if (lookahead == 'e') ADVANCE(157);
      END_STATE();
    case 216:
      if (lookahead == 'e') ADVANCE(146);
      END_STATE();
    case 217:
      if (lookahead == 'e') ADVANCE(86);
      END_STATE();
    case 218:
      if (lookahead == 'e') ADVANCE(342);
      END_STATE();
    case 219:
      if (lookahead == 'e') ADVANCE(409);
      END_STATE();
    case 220:
      if (lookahead == 'e') ADVANCE(166);
      END_STATE();
    case 221:
      if (lookahead == 'e') ADVANCE(463);
      END_STATE();
    case 222:
      if (lookahead == 'e') ADVANCE(414);
      END_STATE();
    case 223:
      if (lookahead == 'e') ADVANCE(464);
      END_STATE();
    case 224:
      if (lookahead == 'e') ADVANCE(170);
      END_STATE();
    case 225:
      if (lookahead == 'e') ADVANCE(147);
      END_STATE();
    case 226:
      if (lookahead == 'e') ADVANCE(502);
      END_STATE();
    case 227:
      if (lookahead == 'e') ADVANCE(92);
      END_STATE();
    case 228:
      if (lookahead == 'e') ADVANCE(503);
      END_STATE();
    case 229:
      if (lookahead == 'e') ADVANCE(93);
      END_STATE();
    case 230:
      if (lookahead == 'e') ADVANCE(94);
      END_STATE();
    case 231:
      if (lookahead == 'e') ADVANCE(95);
      END_STATE();
    case 232:
      if (lookahead == 'f') ADVANCE(559);
      if (lookahead == 'n') ADVANCE(572);
      if (lookahead == 's') ADVANCE(711);
      END_STATE();
    case 233:
      if (lookahead == 'f') ADVANCE(657);
      END_STATE();
    case 234:
      if (lookahead == 'f') ADVANCE(657);
      if (lookahead == 'p') ADVANCE(99);
      END_STATE();
    case 235:
      if (lookahead == 'f') ADVANCE(657);
      if (lookahead == 'p') ADVANCE(467);
      END_STATE();
    case 236:
      if (lookahead == 'f') ADVANCE(747);
      END_STATE();
    case 237:
      if (lookahead == 'f') ADVANCE(542);
      END_STATE();
    case 238:
      if (lookahead == 'f') ADVANCE(683);
      END_STATE();
    case 239:
      if (lookahead == 'f') ADVANCE(750);
      END_STATE();
    case 240:
      if (lookahead == 'f') ADVANCE(748);
      END_STATE();
    case 241:
      if (lookahead == 'f') ADVANCE(749);
      END_STATE();
    case 242:
      if (lookahead == 'f') ADVANCE(111);
      if (lookahead == 'l') ADVANCE(221);
      END_STATE();
    case 243:
      if (lookahead == 'f') ADVANCE(264);
      END_STATE();
    case 244:
      if (lookahead == 'f') ADVANCE(484);
      END_STATE();
    case 245:
      if (lookahead == 'f') ADVANCE(486);
      END_STATE();
    case 246:
      if (lookahead == 'f') ADVANCE(488);
      END_STATE();
    case 247:
      if (lookahead == 'f') ADVANCE(123);
      if (lookahead == 'l') ADVANCE(223);
      if (lookahead == 'p') ADVANCE(413);
      END_STATE();
    case 248:
      if (lookahead == 'g') ADVANCE(679);
      END_STATE();
    case 249:
      if (lookahead == 'g') ADVANCE(647);
      END_STATE();
    case 250:
      if (lookahead == 'g') ADVANCE(319);
      END_STATE();
    case 251:
      if (lookahead == 'g') ADVANCE(259);
      END_STATE();
    case 252:
      if (lookahead == 'g') ADVANCE(429);
      END_STATE();
    case 253:
      if (lookahead == 'g') ADVANCE(187);
      END_STATE();
    case 254:
      if (lookahead == 'g') ADVANCE(348);
      END_STATE();
    case 255:
      if (lookahead == 'g') ADVANCE(278);
      END_STATE();
    case 256:
      if (lookahead == 'h') ADVANCE(201);
      END_STATE();
    case 257:
      if (lookahead == 'h') ADVANCE(753);
      END_STATE();
    case 258:
      if (lookahead == 'h') ADVANCE(565);
      END_STATE();
    case 259:
      if (lookahead == 'h') ADVANCE(582);
      END_STATE();
    case 260:
      if (lookahead == 'h') ADVANCE(119);
      END_STATE();
    case 261:
      if (lookahead == 'h') ADVANCE(224);
      END_STATE();
    case 262:
      if (lookahead == 'h') ADVANCE(120);
      END_STATE();
    case 263:
      if (lookahead == 'h') ADVANCE(412);
      END_STATE();
    case 264:
      if (lookahead == 'i') ADVANCE(500);
      END_STATE();
    case 265:
      if (lookahead == 'i') ADVANCE(432);
      if (lookahead == 'o') ADVANCE(138);
      END_STATE();
    case 266:
      if (lookahead == 'i') ADVANCE(323);
      if (lookahead == 'o') ADVANCE(159);
      if (lookahead == 's') ADVANCE(202);
      END_STATE();
    case 267:
      if (lookahead == 'i') ADVANCE(323);
      if (lookahead == 's') ADVANCE(202);
      END_STATE();
    case 268:
      if (lookahead == 'i') ADVANCE(136);
      if (lookahead == 't') ADVANCE(139);
      if (lookahead == 'u') ADVANCE(163);
      END_STATE();
    case 269:
      if (lookahead == 'i') ADVANCE(254);
      END_STATE();
    case 270:
      if (lookahead == 'i') ADVANCE(239);
      END_STATE();
    case 271:
      if (lookahead == 'i') ADVANCE(252);
      END_STATE();
    case 272:
      if (lookahead == 'i') ADVANCE(336);
      END_STATE();
    case 273:
      if (lookahead == 'i') ADVANCE(459);
      END_STATE();
    case 274:
      if (lookahead == 'i') ADVANCE(363);
      END_STATE();
    case 275:
      if (lookahead == 'i') ADVANCE(380);
      END_STATE();
    case 276:
      if (lookahead == 'i') ADVANCE(365);
      END_STATE();
    case 277:
      if (lookahead == 'i') ADVANCE(370);
      END_STATE();
    case 278:
      if (lookahead == 'i') ADVANCE(332);
      END_STATE();
    case 279:
      if (lookahead == 'i') ADVANCE(456);
      END_STATE();
    case 280:
      if (lookahead == 'i') ADVANCE(462);
      END_STATE();
    case 281:
      if (lookahead == 'i') ADVANCE(371);
      END_STATE();
    case 282:
      if (lookahead == 'i') ADVANCE(426);
      END_STATE();
    case 283:
      if (lookahead == 'i') ADVANCE(344);
      END_STATE();
    case 284:
      if (lookahead == 'i') ADVANCE(415);
      END_STATE();
    case 285:
      if (lookahead == 'i') ADVANCE(417);
      END_STATE();
    case 286:
      if (lookahead == 'i') ADVANCE(418);
      END_STATE();
    case 287:
      if (lookahead == 'k') ADVANCE(611);
      END_STATE();
    case 288:
      if (lookahead == 'k') ADVANCE(580);
      END_STATE();
    case 289:
      if (lookahead == 'k') ADVANCE(346);
      END_STATE();
    case 290:
      if (lookahead == 'k') ADVANCE(208);
      END_STATE();
    case 291:
      if (lookahead == 'k') ADVANCE(211);
      END_STATE();
    case 292:
      if (lookahead == 'l') ADVANCE(620);
      END_STATE();
    case 293:
      if (lookahead == 'l') ADVANCE(590);
      END_STATE();
    case 294:
      if (lookahead == 'l') ADVANCE(534);
      END_STATE();
    case 295:
      if (lookahead == 'l') ADVANCE(635);
      END_STATE();
    case 296:
      if (lookahead == 'l') ADVANCE(680);
      END_STATE();
    case 297:
      if (lookahead == 'l') ADVANCE(359);
      END_STATE();
    case 298:
      if (lookahead == 'l') ADVANCE(300);
      END_STATE();
    case 299:
      if (lookahead == 'l') ADVANCE(477);
      END_STATE();
    case 300:
      if (lookahead == 'l') ADVANCE(455);
      END_STATE();
    case 301:
      if (lookahead == 'l') ADVANCE(176);
      END_STATE();
    case 302:
      if (lookahead == 'l') ADVANCE(451);
      END_STATE();
    case 303:
      if (lookahead == 'l') ADVANCE(373);
      END_STATE();
    case 304:
      if (lookahead == 'l') ADVANCE(453);
      END_STATE();
    case 305:
      if (lookahead == 'l') ADVANCE(180);
      END_STATE();
    case 306:
      if (lookahead == 'l') ADVANCE(181);
      END_STATE();
    case 307:
      if (lookahead == 'l') ADVANCE(183);
      END_STATE();
    case 308:
      if (lookahead == 'l') ADVANCE(184);
      END_STATE();
    case 309:
      if (lookahead == 'l') ADVANCE(186);
      END_STATE();
    case 310:
      if (lookahead == 'l') ADVANCE(212);
      END_STATE();
    case 311:
      if (lookahead == 'l') ADVANCE(438);
      if (lookahead == 'n') ADVANCE(474);
      if (lookahead == 'v') ADVANCE(218);
      if (lookahead == 'x') ADVANCE(386);
      END_STATE();
    case 312:
      if (lookahead == 'l') ADVANCE(374);
      END_STATE();
    case 313:
      if (lookahead == 'l') ADVANCE(475);
      END_STATE();
    case 314:
      if (lookahead == 'l') ADVANCE(303);
      END_STATE();
    case 315:
      if (lookahead == 'l') ADVANCE(198);
      END_STATE();
    case 316:
      if (lookahead == 'l') ADVANCE(439);
      if (lookahead == 'n') ADVANCE(164);
      END_STATE();
    case 317:
      if (lookahead == 'm') ADVANCE(544);
      END_STATE();
    case 318:
      if (lookahead == 'm') ADVANCE(382);
      END_STATE();
    case 319:
      if (lookahead == 'm') ADVANCE(100);
      END_STATE();
    case 320:
      if (lookahead == 'm') ADVANCE(387);
      END_STATE();
    case 321:
      if (lookahead == 'm') ADVANCE(177);
      END_STATE();
    case 322:
      if (lookahead == 'm') ADVANCE(331);
      END_STATE();
    case 323:
      if (lookahead == 'n') ADVANCE(1107);
      END_STATE();
    case 324:
      if (lookahead == 'n') ADVANCE(592);
      END_STATE();
    case 325:
      if (lookahead == 'n') ADVANCE(1080);
      END_STATE();
    case 326:
      if (lookahead == 'n') ADVANCE(668);
      END_STATE();
    case 327:
      if (lookahead == 'n') ADVANCE(538);
      END_STATE();
    case 328:
      if (lookahead == 'n') ADVANCE(584);
      END_STATE();
    case 329:
      if (lookahead == 'n') ADVANCE(641);
      END_STATE();
    case 330:
      if (lookahead == 'n') ADVANCE(608);
      END_STATE();
    case 331:
      if (lookahead == 'n') ADVANCE(695);
      END_STATE();
    case 332:
      if (lookahead == 'n') ADVANCE(744);
      END_STATE();
    case 333:
      if (lookahead == 'n') ADVANCE(570);
      if (lookahead == 's') ADVANCE(711);
      END_STATE();
    case 334:
      if (lookahead == 'n') ADVANCE(85);
      if (lookahead == 'p') ADVANCE(469);
      if (lookahead == 'r') ADVANCE(167);
      END_STATE();
    case 335:
      if (lookahead == 'n') ADVANCE(274);
      if (lookahead == 's') ADVANCE(202);
      END_STATE();
    case 336:
      if (lookahead == 'n') ADVANCE(249);
      END_STATE();
    case 337:
      if (lookahead == 'n') ADVANCE(253);
      END_STATE();
    case 338:
      if (lookahead == 'n') ADVANCE(131);
      END_STATE();
    case 339:
      if (lookahead == 'n') ADVANCE(445);
      END_STATE();
    case 340:
      if (lookahead == 'n') ADVANCE(152);
      END_STATE();
    case 341:
      if (lookahead == 'n') ADVANCE(132);
      END_STATE();
    case 342:
      if (lookahead == 'n') ADVANCE(446);
      END_STATE();
    case 343:
      if (lookahead == 'n') ADVANCE(133);
      END_STATE();
    case 344:
      if (lookahead == 'n') ADVANCE(447);
      END_STATE();
    case 345:
      if (lookahead == 'n') ADVANCE(169);
      END_STATE();
    case 346:
      if (lookahead == 'n') ADVANCE(357);
      END_STATE();
    case 347:
      if (lookahead == 'n') ADVANCE(214);
      END_STATE();
    case 348:
      if (lookahead == 'n') ADVANCE(215);
      END_STATE();
    case 349:
      if (lookahead == 'n') ADVANCE(312);
      END_STATE();
    case 350:
      if (lookahead == 'n') ADVANCE(145);
      END_STATE();
    case 351:
      if (lookahead == 'n') ADVANCE(436);
      END_STATE();
    case 352:
      if (lookahead == 'n') ADVANCE(436);
      if (lookahead == 'p') ADVANCE(506);
      if (lookahead == 'u') ADVANCE(339);
      END_STATE();
    case 353:
      if (lookahead == 'n') ADVANCE(116);
      END_STATE();
    case 354:
      if (lookahead == 'o') ADVANCE(248);
      END_STATE();
    case 355:
      if (lookahead == 'o') ADVANCE(114);
      END_STATE();
    case 356:
      if (lookahead == 'o') ADVANCE(287);
      END_STATE();
    case 357:
      if (lookahead == 'o') ADVANCE(495);
      END_STATE();
    case 358:
      if (lookahead == 'o') ADVANCE(360);
      if (lookahead == 'r') ADVANCE(194);
      END_STATE();
    case 359:
      if (lookahead == 'o') ADVANCE(127);
      END_STATE();
    case 360:
      if (lookahead == 'o') ADVANCE(292);
      END_STATE();
    case 361:
      if (lookahead == 'o') ADVANCE(356);
      if (lookahead == 'r') ADVANCE(1107);
      END_STATE();
    case 362:
      if (lookahead == 'o') ADVANCE(476);
      END_STATE();
    case 363:
      if (lookahead == 'o') ADVANCE(326);
      END_STATE();
    case 364:
      if (lookahead == 'o') ADVANCE(407);
      END_STATE();
    case 365:
      if (lookahead == 'o') ADVANCE(327);
      END_STATE();
    case 366:
      if (lookahead == 'o') ADVANCE(313);
      END_STATE();
    case 367:
      if (lookahead == 'o') ADVANCE(478);
      END_STATE();
    case 368:
      if (lookahead == 'o') ADVANCE(403);
      END_STATE();
    case 369:
      if (lookahead == 'o') ADVANCE(400);
      END_STATE();
    case 370:
      if (lookahead == 'o') ADVANCE(353);
      END_STATE();
    case 371:
      if (lookahead == 'o') ADVANCE(330);
      END_STATE();
    case 372:
      if (lookahead == 'o') ADVANCE(351);
      END_STATE();
    case 373:
      if (lookahead == 'o') ADVANCE(496);
      END_STATE();
    case 374:
      if (lookahead == 'o') ADVANCE(117);
      END_STATE();
    case 375:
      if (lookahead == 'o') ADVANCE(291);
      END_STATE();
    case 376:
      if (lookahead == 'o') ADVANCE(320);
      END_STATE();
    case 377:
      if (lookahead == 'o') ADVANCE(411);
      END_STATE();
    case 378:
      if (lookahead == 'o') ADVANCE(481);
      END_STATE();
    case 379:
      if (lookahead == 'o') ADVANCE(416);
      END_STATE();
    case 380:
      if (lookahead == 'o') ADVANCE(424);
      END_STATE();
    case 381:
      if (lookahead == 'p') ADVANCE(754);
      if (lookahead == 'r') ADVANCE(443);
      END_STATE();
    case 382:
      if (lookahead == 'p') ADVANCE(1080);
      END_STATE();
    case 383:
      if (lookahead == 'p') ADVANCE(691);
      END_STATE();
    case 384:
      if (lookahead == 'p') ADVANCE(282);
      END_STATE();
    case 385:
      if (lookahead == 'p') ADVANCE(299);
      if (lookahead == 's') ADVANCE(271);
      END_STATE();
    case 386:
      if (lookahead == 'p') ADVANCE(377);
      END_STATE();
    case 387:
      if (lookahead == 'p') ADVANCE(315);
      END_STATE();
    case 388:
      if (lookahead == 'p') ADVANCE(178);
      END_STATE();
    case 389:
      if (lookahead == 'p') ADVANCE(217);
      END_STATE();
    case 390:
      if (lookahead == 'p') ADVANCE(192);
      END_STATE();
    case 391:
      if (lookahead == 'p') ADVANCE(482);
      END_STATE();
    case 392:
      if (lookahead == 'p') ADVANCE(284);
      END_STATE();
    case 393:
      if (lookahead == 'p') ADVANCE(285);
      END_STATE();
    case 394:
      if (lookahead == 'p') ADVANCE(286);
      END_STATE();
    case 395:
      if (lookahead == 'p') ADVANCE(425);
      END_STATE();
    case 396:
      if (lookahead == 'q') ADVANCE(483);
      END_STATE();
    case 397:
      if (lookahead == 'r') ADVANCE(1107);
      END_STATE();
    case 398:
      if (lookahead == 'r') ADVANCE(567);
      END_STATE();
    case 399:
      if (lookahead == 'r') ADVANCE(493);
      END_STATE();
    case 400:
      if (lookahead == 'r') ADVANCE(671);
      END_STATE();
    case 401:
      if (lookahead == 'r') ADVANCE(676);
      END_STATE();
    case 402:
      if (lookahead == 'r') ADVANCE(104);
      END_STATE();
    case 403:
      if (lookahead == 'r') ADVANCE(91);
      END_STATE();
    case 404:
      if (lookahead == 'r') ADVANCE(362);
      END_STATE();
    case 405:
      if (lookahead == 'r') ADVANCE(83);
      END_STATE();
    case 406:
      if (lookahead == 'r') ADVANCE(200);
      END_STATE();
    case 407:
      if (lookahead == 'r') ADVANCE(150);
      END_STATE();
    case 408:
      if (lookahead == 'r') ADVANCE(328);
      END_STATE();
    case 409:
      if (lookahead == 'r') ADVANCE(329);
      END_STATE();
    case 410:
      if (lookahead == 'r') ADVANCE(448);
      END_STATE();
    case 411:
      if (lookahead == 'r') ADVANCE(449);
      END_STATE();
    case 412:
      if (lookahead == 'r') ADVANCE(367);
      END_STATE();
    case 413:
      if (lookahead == 'r') ADVANCE(216);
      END_STATE();
    case 414:
      if (lookahead == 'r') ADVANCE(209);
      END_STATE();
    case 415:
      if (lookahead == 'r') ADVANCE(188);
      END_STATE();
    case 416:
      if (lookahead == 'r') ADVANCE(189);
      END_STATE();
    case 417:
      if (lookahead == 'r') ADVANCE(190);
      END_STATE();
    case 418:
      if (lookahead == 'r') ADVANCE(191);
      END_STATE();
    case 419:
      if (lookahead == 'r') ADVANCE(272);
      END_STATE();
    case 420:
      if (lookahead == 'r') ADVANCE(423);
      if (lookahead == 'x') ADVANCE(384);
      END_STATE();
    case 421:
      if (lookahead == 'r') ADVANCE(280);
      END_STATE();
    case 422:
      if (lookahead == 'r') ADVANCE(275);
      END_STATE();
    case 423:
      if (lookahead == 'r') ADVANCE(368);
      END_STATE();
    case 424:
      if (lookahead == 'r') ADVANCE(279);
      END_STATE();
    case 425:
      if (lookahead == 'r') ADVANCE(225);
      END_STATE();
    case 426:
      if (lookahead == 'r') ADVANCE(229);
      END_STATE();
    case 427:
      if (lookahead == 's') ADVANCE(82);
      END_STATE();
    case 428:
      if (lookahead == 's') ADVANCE(746);
      END_STATE();
    case 429:
      if (lookahead == 's') ADVANCE(743);
      END_STATE();
    case 430:
      if (lookahead == 's') ADVANCE(604);
      END_STATE();
    case 431:
      if (lookahead == 's') ADVANCE(257);
      END_STATE();
    case 432:
      if (lookahead == 's') ADVANCE(441);
      END_STATE();
    case 433:
      if (lookahead == 's') ADVANCE(434);
      END_STATE();
    case 434:
      if (lookahead == 's') ADVANCE(269);
      END_STATE();
    case 435:
      if (lookahead == 's') ADVANCE(202);
      END_STATE();
    case 436:
      if (lookahead == 's') ADVANCE(444);
      END_STATE();
    case 437:
      if (lookahead == 's') ADVANCE(174);
      END_STATE();
    case 438:
      if (lookahead == 's') ADVANCE(175);
      END_STATE();
    case 439:
      if (lookahead == 's') ADVANCE(179);
      END_STATE();
    case 440:
      if (lookahead == 's') ADVANCE(207);
      END_STATE();
    case 441:
      if (lookahead == 't') ADVANCE(638);
      END_STATE();
    case 442:
      if (lookahead == 't') ADVANCE(578);
      END_STATE();
    case 443:
      if (lookahead == 't') ADVANCE(644);
      END_STATE();
    case 444:
      if (lookahead == 't') ADVANCE(540);
      END_STATE();
    case 445:
      if (lookahead == 't') ADVANCE(623);
      END_STATE();
    case 446:
      if (lookahead == 't') ADVANCE(556);
      END_STATE();
    case 447:
      if (lookahead == 't') ADVANCE(554);
      END_STATE();
    case 448:
      if (lookahead == 't') ADVANCE(598);
      END_STATE();
    case 449:
      if (lookahead == 't') ADVANCE(530);
      END_STATE();
    case 450:
      if (lookahead == 't') ADVANCE(650);
      END_STATE();
    case 451:
      if (lookahead == 't') ADVANCE(602);
      END_STATE();
    case 452:
      if (lookahead == 't') ADVANCE(594);
      END_STATE();
    case 453:
      if (lookahead == 't') ADVANCE(688);
      END_STATE();
    case 454:
      if (lookahead == 't') ADVANCE(682);
      END_STATE();
    case 455:
      if (lookahead == 't') ADVANCE(263);
      END_STATE();
    case 456:
      if (lookahead == 't') ADVANCE(507);
      END_STATE();
    case 457:
      if (lookahead == 't') ADVANCE(461);
      END_STATE();
    case 458:
      if (lookahead == 't') ADVANCE(391);
      END_STATE();
    case 459:
      if (lookahead == 't') ADVANCE(140);
      END_STATE();
    case 460:
      if (lookahead == 't') ADVANCE(379);
      END_STATE();
    case 461:
      if (lookahead == 't') ADVANCE(219);
      END_STATE();
    case 462:
      if (lookahead == 't') ADVANCE(230);
      END_STATE();
    case 463:
      if (lookahead == 't') ADVANCE(182);
      END_STATE();
    case 464:
      if (lookahead == 't') ADVANCE(227);
      END_STATE();
    case 465:
      if (lookahead == 't') ADVANCE(210);
      END_STATE();
    case 466:
      if (lookahead == 't') ADVANCE(213);
      END_STATE();
    case 467:
      if (lookahead == 't') ADVANCE(276);
      END_STATE();
    case 468:
      if (lookahead == 't') ADVANCE(369);
      END_STATE();
    case 469:
      if (lookahead == 't') ADVANCE(277);
      END_STATE();
    case 470:
      if (lookahead == 't') ADVANCE(281);
      END_STATE();
    case 471:
      if (lookahead == 't') ADVANCE(510);
      END_STATE();
    case 472:
      if (lookahead == 't') ADVANCE(231);
      END_STATE();
    case 473:
      if (lookahead == 'u') ADVANCE(350);
      END_STATE();
    case 474:
      if (lookahead == 'u') ADVANCE(317);
      END_STATE();
    case 475:
      if (lookahead == 'u') ADVANCE(322);
      END_STATE();
    case 476:
      if (lookahead == 'u') ADVANCE(383);
      END_STATE();
    case 477:
      if (lookahead == 'u') ADVANCE(255);
      END_STATE();
    case 478:
      if (lookahead == 'u') ADVANCE(251);
      END_STATE();
    case 479:
      if (lookahead == 'u') ADVANCE(408);
      END_STATE();
    case 480:
      if (lookahead == 'u') ADVANCE(452);
      END_STATE();
    case 481:
      if (lookahead == 'u') ADVANCE(458);
      END_STATE();
    case 482:
      if (lookahead == 'u') ADVANCE(454);
      END_STATE();
    case 483:
      if (lookahead == 'u') ADVANCE(185);
      END_STATE();
    case 484:
      if (lookahead == 'u') ADVANCE(338);
      END_STATE();
    case 485:
      if (lookahead == 'u') ADVANCE(302);
      END_STATE();
    case 486:
      if (lookahead == 'u') ADVANCE(341);
      END_STATE();
    case 487:
      if (lookahead == 'u') ADVANCE(304);
      END_STATE();
    case 488:
      if (lookahead == 'u') ADVANCE(343);
      END_STATE();
    case 489:
      if (lookahead == 'u') ADVANCE(308);
      END_STATE();
    case 490:
      if (lookahead == 'u') ADVANCE(309);
      END_STATE();
    case 491:
      if (lookahead == 'u') ADVANCE(128);
      END_STATE();
    case 492:
      if (lookahead == 'v') ADVANCE(218);
      if (lookahead == 'x') ADVANCE(386);
      END_STATE();
    case 493:
      if (lookahead == 'v') ADVANCE(115);
      END_STATE();
    case 494:
      if (lookahead == 'w') ADVANCE(88);
      END_STATE();
    case 495:
      if (lookahead == 'w') ADVANCE(325);
      END_STATE();
    case 496:
      if (lookahead == 'w') ADVANCE(87);
      END_STATE();
    case 497:
      if (lookahead == 'x') ADVANCE(27);
      if (('0' <= lookahead && lookahead <= '7')) ADVANCE(26);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(28);
      END_STATE();
    case 498:
      if (lookahead == 'x') ADVANCE(442);
      END_STATE();
    case 499:
      if (lookahead == 'x') ADVANCE(89);
      END_STATE();
    case 500:
      if (lookahead == 'x') ADVANCE(203);
      END_STATE();
    case 501:
      if (lookahead == 'x') ADVANCE(392);
      END_STATE();
    case 502:
      if (lookahead == 'x') ADVANCE(393);
      END_STATE();
    case 503:
      if (lookahead == 'x') ADVANCE(394);
      END_STATE();
    case 504:
      if (lookahead == 'y') ADVANCE(1107);
      END_STATE();
    case 505:
      if (lookahead == 'y') ADVANCE(617);
      END_STATE();
    case 506:
      if (lookahead == 'y') ADVANCE(729);
      END_STATE();
    case 507:
      if (lookahead == 'y') ADVANCE(693);
      END_STATE();
    case 508:
      if (lookahead == 'y') ADVANCE(388);
      END_STATE();
    case 509:
      if (lookahead == 'y') ADVANCE(389);
      END_STATE();
    case 510:
      if (lookahead == 'y') ADVANCE(390);
      END_STATE();
    case 511:
      if (lookahead == '+' ||
          lookahead == '-') ADVANCE(513);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1103);
      END_STATE();
    case 512:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1102);
      END_STATE();
    case 513:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1103);
      END_STATE();
    case 514:
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(35);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 515:
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(1105);
      END_STATE();
    case 516:
      if (('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 517:
      if (eof) ADVANCE(526);
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 721,
        '(', 561,
        '*', 713,
        '+', 709,
        ',', 569,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1083,
        ':', 70,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '^', 723,
        '_', 1049,
        'a', 786,
        'b', 891,
        'c', 885,
        'd', 813,
        'e', 876,
        'f', 766,
        'h', 895,
        'i', 825,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 763,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(517);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 518:
      if (eof) ADVANCE(526);
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 721,
        '(', 561,
        '*', 713,
        '+', 709,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1083,
        ':', 70,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '^', 723,
        '_', 1049,
        'a', 786,
        'b', 891,
        'c', 885,
        'd', 813,
        'e', 862,
        'f', 766,
        'h', 895,
        'i', 825,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 763,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(518);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 519:
      if (eof) ADVANCE(526);
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 721,
        '(', 561,
        '*', 713,
        '+', 709,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1083,
        ':', 70,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '^', 723,
        '_', 1049,
        'a', 786,
        'b', 891,
        'c', 885,
        'd', 813,
        'e', 862,
        'f', 766,
        'h', 895,
        'i', 825,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 764,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(519);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 520:
      if (eof) ADVANCE(526);
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 703,
        '"', 28,
        '#', 1116,
        '$', 697,
        '%', 716,
        '&', 721,
        '(', 561,
        '*', 713,
        '+', 709,
        '-', 706,
        '.', 512,
        '/', 715,
        '0', 1083,
        ':', 70,
        ';', 529,
        '<', 717,
        '=', 597,
        '>', 719,
        '?', 724,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '^', 723,
        '_', 1049,
        'a', 786,
        'b', 891,
        'c', 885,
        'd', 813,
        'e', 876,
        'f', 766,
        'h', 895,
        'i', 825,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 764,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 699,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(520);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 521:
      if (eof) ADVANCE(526);
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '&', 96,
        '(', 561,
        ')', 562,
        '+', 709,
        ',', 569,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '=', 596,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 785,
        'b', 891,
        'c', 885,
        'd', 813,
        'e', 875,
        'f', 766,
        'g', 851,
        'h', 895,
        'i', 824,
        'l', 837,
        'm', 889,
        'n', 794,
        'o', 902,
        'p', 760,
        'r', 795,
        's', 776,
        't', 762,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 698,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(521);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('j' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 522:
      if (eof) ADVANCE(526);
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '(', 561,
        ')', 562,
        '+', 708,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 785,
        'b', 891,
        'c', 885,
        'd', 813,
        'e', 862,
        'f', 766,
        'h', 895,
        'i', 824,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 763,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 698,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(522);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 523:
      if (eof) ADVANCE(526);
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '(', 561,
        ')', 562,
        '+', 708,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 785,
        'b', 891,
        'c', 885,
        'd', 813,
        'e', 862,
        'f', 766,
        'h', 895,
        'i', 824,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 764,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 698,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(523);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 524:
      if (eof) ADVANCE(526);
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '(', 561,
        ')', 562,
        '+', 708,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 785,
        'b', 891,
        'c', 885,
        'd', 813,
        'e', 876,
        'f', 766,
        'h', 895,
        'i', 824,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 763,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 698,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(524);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 525:
      if (eof) ADVANCE(526);
      ADVANCE_MAP(
        '\n', 1118,
        '\r', 1,
        '!', 702,
        '"', 28,
        '#', 1116,
        '$', 697,
        '(', 561,
        ')', 562,
        '+', 708,
        '-', 705,
        '.', 512,
        '/', 66,
        '0', 1083,
        ':', 70,
        ';', 529,
        '@', 73,
        'F', 739,
        'T', 736,
        '[', 574,
        '_', 1049,
        'a', 785,
        'b', 891,
        'c', 885,
        'd', 813,
        'e', 876,
        'f', 766,
        'h', 895,
        'i', 824,
        'l', 837,
        'n', 794,
        'o', 904,
        'p', 760,
        'r', 809,
        's', 776,
        't', 764,
        'u', 878,
        'v', 814,
        'w', 831,
        '{', 532,
        '|', 698,
        '}', 533,
        '~', 704,
      );
      if (lookahead == '\t' ||
          lookahead == ' ') SKIP(525);
      if (('1' <= lookahead && lookahead <= '9')) ADVANCE(1084);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 526:
      ACCEPT_TOKEN(ts_builtin_sym_end);
      END_STATE();
    case 527:
      ACCEPT_TOKEN(anon_sym_module);
      END_STATE();
    case 528:
      ACCEPT_TOKEN(anon_sym_module);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 529:
      ACCEPT_TOKEN(anon_sym_SEMI);
      END_STATE();
    case 530:
      ACCEPT_TOKEN(anon_sym_export);
      END_STATE();
    case 531:
      ACCEPT_TOKEN(anon_sym_export);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 532:
      ACCEPT_TOKEN(anon_sym_LBRACE);
      END_STATE();
    case 533:
      ACCEPT_TOKEN(anon_sym_RBRACE);
      END_STATE();
    case 534:
      ACCEPT_TOKEN(anon_sym_global);
      END_STATE();
    case 535:
      ACCEPT_TOKEN(anon_sym_global);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 536:
      ACCEPT_TOKEN(anon_sym_COLON);
      END_STATE();
    case 537:
      ACCEPT_TOKEN(anon_sym_COLON);
      if (lookahead == ':') ADVANCE(516);
      END_STATE();
    case 538:
      ACCEPT_TOKEN(anon_sym_option);
      END_STATE();
    case 539:
      ACCEPT_TOKEN(anon_sym_option);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 540:
      ACCEPT_TOKEN(anon_sym_const);
      END_STATE();
    case 541:
      ACCEPT_TOKEN(anon_sym_const);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 542:
      ACCEPT_TOKEN(anon_sym_redef);
      END_STATE();
    case 543:
      ACCEPT_TOKEN(anon_sym_redef);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 544:
      ACCEPT_TOKEN(anon_sym_enum);
      END_STATE();
    case 545:
      ACCEPT_TOKEN(anon_sym_enum);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 546:
      ACCEPT_TOKEN(anon_sym_enum);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 547:
      ACCEPT_TOKEN(anon_sym_PLUS_EQ);
      END_STATE();
    case 548:
      ACCEPT_TOKEN(anon_sym_record);
      END_STATE();
    case 549:
      ACCEPT_TOKEN(anon_sym_record);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 550:
      ACCEPT_TOKEN(anon_sym_record);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 551:
      ACCEPT_TOKEN(anon_sym_DASH_EQ);
      END_STATE();
    case 552:
      ACCEPT_TOKEN(anon_sym_type);
      END_STATE();
    case 553:
      ACCEPT_TOKEN(anon_sym_type);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 554:
      ACCEPT_TOKEN(anon_sym_print);
      END_STATE();
    case 555:
      ACCEPT_TOKEN(anon_sym_print);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 556:
      ACCEPT_TOKEN(anon_sym_event);
      END_STATE();
    case 557:
      ACCEPT_TOKEN(anon_sym_event);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 558:
      ACCEPT_TOKEN(anon_sym_event);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 559:
      ACCEPT_TOKEN(anon_sym_if);
      END_STATE();
    case 560:
      ACCEPT_TOKEN(anon_sym_if);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 561:
      ACCEPT_TOKEN(anon_sym_LPAREN);
      END_STATE();
    case 562:
      ACCEPT_TOKEN(anon_sym_RPAREN);
      END_STATE();
    case 563:
      ACCEPT_TOKEN(anon_sym_else);
      END_STATE();
    case 564:
      ACCEPT_TOKEN(anon_sym_else);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 565:
      ACCEPT_TOKEN(anon_sym_switch);
      END_STATE();
    case 566:
      ACCEPT_TOKEN(anon_sym_switch);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 567:
      ACCEPT_TOKEN(anon_sym_for);
      END_STATE();
    case 568:
      ACCEPT_TOKEN(anon_sym_for);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 569:
      ACCEPT_TOKEN(anon_sym_COMMA);
      END_STATE();
    case 570:
      ACCEPT_TOKEN(anon_sym_in);
      END_STATE();
    case 571:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(632);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 572:
      ACCEPT_TOKEN(anon_sym_in);
      if (lookahead == 't') ADVANCE(634);
      END_STATE();
    case 573:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      END_STATE();
    case 574:
      ACCEPT_TOKEN(anon_sym_LBRACK);
      if (lookahead == ':') ADVANCE(68);
      if (lookahead == ']') ADVANCE(1079);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(69);
      END_STATE();
    case 575:
      ACCEPT_TOKEN(anon_sym_RBRACK);
      END_STATE();
    case 576:
      ACCEPT_TOKEN(anon_sym_while);
      END_STATE();
    case 577:
      ACCEPT_TOKEN(anon_sym_while);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 578:
      ACCEPT_TOKEN(anon_sym_next);
      END_STATE();
    case 579:
      ACCEPT_TOKEN(anon_sym_next);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 580:
      ACCEPT_TOKEN(anon_sym_break);
      END_STATE();
    case 581:
      ACCEPT_TOKEN(anon_sym_break);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 582:
      ACCEPT_TOKEN(anon_sym_fallthrough);
      END_STATE();
    case 583:
      ACCEPT_TOKEN(anon_sym_fallthrough);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 584:
      ACCEPT_TOKEN(anon_sym_return);
      END_STATE();
    case 585:
      ACCEPT_TOKEN(anon_sym_return);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 586:
      ACCEPT_TOKEN(anon_sym_add);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(615);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 587:
      ACCEPT_TOKEN(anon_sym_add);
      if (lookahead == 'r') ADVANCE(614);
      END_STATE();
    case 588:
      ACCEPT_TOKEN(anon_sym_delete);
      END_STATE();
    case 589:
      ACCEPT_TOKEN(anon_sym_delete);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 590:
      ACCEPT_TOKEN(anon_sym_local);
      END_STATE();
    case 591:
      ACCEPT_TOKEN(anon_sym_local);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 592:
      ACCEPT_TOKEN(anon_sym_when);
      END_STATE();
    case 593:
      ACCEPT_TOKEN(anon_sym_when);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 594:
      ACCEPT_TOKEN(anon_sym_timeout);
      END_STATE();
    case 595:
      ACCEPT_TOKEN(anon_sym_timeout);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 596:
      ACCEPT_TOKEN(anon_sym_EQ);
      END_STATE();
    case 597:
      ACCEPT_TOKEN(anon_sym_EQ);
      if (lookahead == '=') ADVANCE(725);
      END_STATE();
    case 598:
      ACCEPT_TOKEN(anon_sym_assert);
      END_STATE();
    case 599:
      ACCEPT_TOKEN(anon_sym_assert);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 600:
      ACCEPT_TOKEN(anon_sym_case);
      END_STATE();
    case 601:
      ACCEPT_TOKEN(anon_sym_case);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 602:
      ACCEPT_TOKEN(anon_sym_default);
      END_STATE();
    case 603:
      ACCEPT_TOKEN(anon_sym_default);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 604:
      ACCEPT_TOKEN(anon_sym_as);
      END_STATE();
    case 605:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 's') ADVANCE(819);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 606:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 607:
      ACCEPT_TOKEN(anon_sym_as);
      if (lookahead == 's') ADVANCE(205);
      END_STATE();
    case 608:
      ACCEPT_TOKEN(anon_sym_function);
      END_STATE();
    case 609:
      ACCEPT_TOKEN(anon_sym_function);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 610:
      ACCEPT_TOKEN(anon_sym_function);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 611:
      ACCEPT_TOKEN(anon_sym_hook);
      END_STATE();
    case 612:
      ACCEPT_TOKEN(anon_sym_hook);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 613:
      ACCEPT_TOKEN(anon_sym_hook);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 614:
      ACCEPT_TOKEN(anon_sym_addr);
      END_STATE();
    case 615:
      ACCEPT_TOKEN(anon_sym_addr);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 616:
      ACCEPT_TOKEN(anon_sym_addr);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 617:
      ACCEPT_TOKEN(anon_sym_any);
      END_STATE();
    case 618:
      ACCEPT_TOKEN(anon_sym_any);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 619:
      ACCEPT_TOKEN(anon_sym_any);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 620:
      ACCEPT_TOKEN(anon_sym_bool);
      END_STATE();
    case 621:
      ACCEPT_TOKEN(anon_sym_bool);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 622:
      ACCEPT_TOKEN(anon_sym_bool);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 623:
      ACCEPT_TOKEN(anon_sym_count);
      END_STATE();
    case 624:
      ACCEPT_TOKEN(anon_sym_count);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 625:
      ACCEPT_TOKEN(anon_sym_count);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 626:
      ACCEPT_TOKEN(anon_sym_double);
      END_STATE();
    case 627:
      ACCEPT_TOKEN(anon_sym_double);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 628:
      ACCEPT_TOKEN(anon_sym_double);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 629:
      ACCEPT_TOKEN(anon_sym_file);
      END_STATE();
    case 630:
      ACCEPT_TOKEN(anon_sym_file);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 631:
      ACCEPT_TOKEN(anon_sym_file);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 632:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(910);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 633:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(1024);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 634:
      ACCEPT_TOKEN(anon_sym_int);
      if (lookahead == 'e') ADVANCE(399);
      END_STATE();
    case 635:
      ACCEPT_TOKEN(anon_sym_interval);
      END_STATE();
    case 636:
      ACCEPT_TOKEN(anon_sym_interval);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 637:
      ACCEPT_TOKEN(anon_sym_interval);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 638:
      ACCEPT_TOKEN(anon_sym_list);
      END_STATE();
    case 639:
      ACCEPT_TOKEN(anon_sym_list);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 640:
      ACCEPT_TOKEN(anon_sym_list);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 641:
      ACCEPT_TOKEN(anon_sym_pattern);
      END_STATE();
    case 642:
      ACCEPT_TOKEN(anon_sym_pattern);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 643:
      ACCEPT_TOKEN(anon_sym_pattern);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 644:
      ACCEPT_TOKEN(anon_sym_port);
      END_STATE();
    case 645:
      ACCEPT_TOKEN(anon_sym_port);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 646:
      ACCEPT_TOKEN(anon_sym_port);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 647:
      ACCEPT_TOKEN(anon_sym_string);
      END_STATE();
    case 648:
      ACCEPT_TOKEN(anon_sym_string);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 649:
      ACCEPT_TOKEN(anon_sym_string);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 650:
      ACCEPT_TOKEN(anon_sym_subnet);
      END_STATE();
    case 651:
      ACCEPT_TOKEN(anon_sym_subnet);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 652:
      ACCEPT_TOKEN(anon_sym_subnet);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 653:
      ACCEPT_TOKEN(anon_sym_time);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(950);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 654:
      ACCEPT_TOKEN(anon_sym_time);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 655:
      ACCEPT_TOKEN(anon_sym_time);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 656:
      ACCEPT_TOKEN(anon_sym_time);
      if (lookahead == 'o') ADVANCE(480);
      END_STATE();
    case 657:
      ACCEPT_TOKEN(anon_sym_of);
      END_STATE();
    case 658:
      ACCEPT_TOKEN(anon_sym_of);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 659:
      ACCEPT_TOKEN(anon_sym_opaque);
      END_STATE();
    case 660:
      ACCEPT_TOKEN(anon_sym_opaque);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 661:
      ACCEPT_TOKEN(anon_sym_opaque);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 662:
      ACCEPT_TOKEN(anon_sym_set);
      END_STATE();
    case 663:
      ACCEPT_TOKEN(anon_sym_set);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 664:
      ACCEPT_TOKEN(anon_sym_set);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 665:
      ACCEPT_TOKEN(anon_sym_table);
      END_STATE();
    case 666:
      ACCEPT_TOKEN(anon_sym_table);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 667:
      ACCEPT_TOKEN(anon_sym_table);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 668:
      ACCEPT_TOKEN(anon_sym_union);
      END_STATE();
    case 669:
      ACCEPT_TOKEN(anon_sym_union);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 670:
      ACCEPT_TOKEN(anon_sym_union);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 671:
      ACCEPT_TOKEN(anon_sym_vector);
      END_STATE();
    case 672:
      ACCEPT_TOKEN(anon_sym_vector);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 673:
      ACCEPT_TOKEN(anon_sym_vector);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 674:
      ACCEPT_TOKEN(anon_sym_AMPbroker_allow_complex_type);
      END_STATE();
    case 675:
      ACCEPT_TOKEN(anon_sym_AMPdeprecated);
      END_STATE();
    case 676:
      ACCEPT_TOKEN(anon_sym_AMPerror_handler);
      END_STATE();
    case 677:
      ACCEPT_TOKEN(anon_sym_AMPis_assigned);
      END_STATE();
    case 678:
      ACCEPT_TOKEN(anon_sym_AMPis_used);
      END_STATE();
    case 679:
      ACCEPT_TOKEN(anon_sym_AMPlog);
      END_STATE();
    case 680:
      ACCEPT_TOKEN(anon_sym_AMPoptional);
      END_STATE();
    case 681:
      ACCEPT_TOKEN(anon_sym_AMPordered);
      END_STATE();
    case 682:
      ACCEPT_TOKEN(anon_sym_AMPraw_output);
      END_STATE();
    case 683:
      ACCEPT_TOKEN(anon_sym_AMPredef);
      END_STATE();
    case 684:
      ACCEPT_TOKEN(anon_sym_AMPadd_func);
      END_STATE();
    case 685:
      ACCEPT_TOKEN(anon_sym_AMPbackend);
      END_STATE();
    case 686:
      ACCEPT_TOKEN(anon_sym_AMPbroker_store);
      END_STATE();
    case 687:
      ACCEPT_TOKEN(anon_sym_AMPcreate_expire);
      END_STATE();
    case 688:
      ACCEPT_TOKEN(anon_sym_AMPdefault);
      END_STATE();
    case 689:
      ACCEPT_TOKEN(anon_sym_AMPdelete_func);
      END_STATE();
    case 690:
      ACCEPT_TOKEN(anon_sym_AMPexpire_func);
      END_STATE();
    case 691:
      ACCEPT_TOKEN(anon_sym_AMPgroup);
      END_STATE();
    case 692:
      ACCEPT_TOKEN(anon_sym_AMPon_change);
      END_STATE();
    case 693:
      ACCEPT_TOKEN(anon_sym_AMPpriority);
      END_STATE();
    case 694:
      ACCEPT_TOKEN(anon_sym_AMPread_expire);
      END_STATE();
    case 695:
      ACCEPT_TOKEN(anon_sym_AMPtype_column);
      END_STATE();
    case 696:
      ACCEPT_TOKEN(anon_sym_AMPwrite_expire);
      END_STATE();
    case 697:
      ACCEPT_TOKEN(anon_sym_DOLLAR);
      END_STATE();
    case 698:
      ACCEPT_TOKEN(anon_sym_PIPE);
      END_STATE();
    case 699:
      ACCEPT_TOKEN(anon_sym_PIPE);
      if (lookahead == '|') ADVANCE(728);
      END_STATE();
    case 700:
      ACCEPT_TOKEN(anon_sym_PLUS_PLUS);
      END_STATE();
    case 701:
      ACCEPT_TOKEN(anon_sym_DASH_DASH);
      END_STATE();
    case 702:
      ACCEPT_TOKEN(anon_sym_BANG);
      END_STATE();
    case 703:
      ACCEPT_TOKEN(anon_sym_BANG);
      if (lookahead == '=') ADVANCE(726);
      END_STATE();
    case 704:
      ACCEPT_TOKEN(anon_sym_TILDE);
      END_STATE();
    case 705:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(701);
      END_STATE();
    case 706:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '-') ADVANCE(701);
      if (lookahead == '=') ADVANCE(551);
      END_STATE();
    case 707:
      ACCEPT_TOKEN(anon_sym_DASH);
      if (lookahead == '=') ADVANCE(551);
      END_STATE();
    case 708:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(700);
      END_STATE();
    case 709:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '+') ADVANCE(700);
      if (lookahead == '=') ADVANCE(547);
      END_STATE();
    case 710:
      ACCEPT_TOKEN(anon_sym_PLUS);
      if (lookahead == '=') ADVANCE(547);
      END_STATE();
    case 711:
      ACCEPT_TOKEN(anon_sym_is);
      END_STATE();
    case 712:
      ACCEPT_TOKEN(anon_sym_is);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 713:
      ACCEPT_TOKEN(anon_sym_STAR);
      END_STATE();
    case 714:
      ACCEPT_TOKEN(anon_sym_SLASH);
      END_STATE();
    case 715:
      ACCEPT_TOKEN(anon_sym_SLASH);
      if (lookahead == '/') ADVANCE(1060);
      if (lookahead == '\\') ADVANCE(67);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(66);
      END_STATE();
    case 716:
      ACCEPT_TOKEN(anon_sym_PERCENT);
      END_STATE();
    case 717:
      ACCEPT_TOKEN(anon_sym_LT);
      if (lookahead == '=') ADVANCE(718);
      END_STATE();
    case 718:
      ACCEPT_TOKEN(anon_sym_LT_EQ);
      END_STATE();
    case 719:
      ACCEPT_TOKEN(anon_sym_GT);
      if (lookahead == '=') ADVANCE(720);
      END_STATE();
    case 720:
      ACCEPT_TOKEN(anon_sym_GT_EQ);
      END_STATE();
    case 721:
      ACCEPT_TOKEN(anon_sym_AMP);
      if (lookahead == '&') ADVANCE(727);
      END_STATE();
    case 722:
      ACCEPT_TOKEN(anon_sym_AMP);
      ADVANCE_MAP(
        '&', 727,
        'a', 161,
        'b', 107,
        'c', 406,
        'd', 173,
        'e', 420,
        'g', 404,
        'i', 427,
        'l', 354,
        'o', 334,
        'p', 422,
        'r', 98,
        't', 509,
        'w', 421,
      );
      END_STATE();
    case 723:
      ACCEPT_TOKEN(anon_sym_CARET);
      END_STATE();
    case 724:
      ACCEPT_TOKEN(anon_sym_QMARK);
      if (lookahead == '$') ADVANCE(732);
      END_STATE();
    case 725:
      ACCEPT_TOKEN(anon_sym_EQ_EQ);
      END_STATE();
    case 726:
      ACCEPT_TOKEN(anon_sym_BANG_EQ);
      END_STATE();
    case 727:
      ACCEPT_TOKEN(anon_sym_AMP_AMP);
      END_STATE();
    case 728:
      ACCEPT_TOKEN(anon_sym_PIPE_PIPE);
      END_STATE();
    case 729:
      ACCEPT_TOKEN(anon_sym_copy);
      END_STATE();
    case 730:
      ACCEPT_TOKEN(anon_sym_copy);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 731:
      ACCEPT_TOKEN(anon_sym_copy);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 732:
      ACCEPT_TOKEN(anon_sym_QMARK_DOLLAR);
      END_STATE();
    case 733:
      ACCEPT_TOKEN(anon_sym_schedule);
      END_STATE();
    case 734:
      ACCEPT_TOKEN(anon_sym_schedule);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 735:
      ACCEPT_TOKEN(anon_sym_T);
      END_STATE();
    case 736:
      ACCEPT_TOKEN(anon_sym_T);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 737:
      ACCEPT_TOKEN(anon_sym_T);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 738:
      ACCEPT_TOKEN(anon_sym_F);
      END_STATE();
    case 739:
      ACCEPT_TOKEN(anon_sym_F);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 740:
      ACCEPT_TOKEN(anon_sym_F);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 741:
      ACCEPT_TOKEN(anon_sym_ATdeprecated);
      END_STATE();
    case 742:
      ACCEPT_TOKEN(anon_sym_ATload);
      if (lookahead == '-') ADVANCE(385);
      END_STATE();
    case 743:
      ACCEPT_TOKEN(anon_sym_ATload_DASHsigs);
      END_STATE();
    case 744:
      ACCEPT_TOKEN(anon_sym_ATload_DASHplugin);
      END_STATE();
    case 745:
      ACCEPT_TOKEN(anon_sym_ATunload);
      END_STATE();
    case 746:
      ACCEPT_TOKEN(anon_sym_ATprefixes);
      END_STATE();
    case 747:
      ACCEPT_TOKEN(anon_sym_ATif);
      if (lookahead == 'd') ADVANCE(204);
      if (lookahead == 'n') ADVANCE(168);
      END_STATE();
    case 748:
      ACCEPT_TOKEN(anon_sym_ATifdef);
      END_STATE();
    case 749:
      ACCEPT_TOKEN(anon_sym_ATifndef);
      END_STATE();
    case 750:
      ACCEPT_TOKEN(anon_sym_ATendif);
      END_STATE();
    case 751:
      ACCEPT_TOKEN(anon_sym_ATelse);
      END_STATE();
    case 752:
      ACCEPT_TOKEN(anon_sym_ATpragma);
      END_STATE();
    case 753:
      ACCEPT_TOKEN(anon_sym_push);
      END_STATE();
    case 754:
      ACCEPT_TOKEN(anon_sym_pop);
      END_STATE();
    case 755:
      ACCEPT_TOKEN(aux_sym_pragma_token1);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(755);
      END_STATE();
    case 756:
      ACCEPT_TOKEN(anon_sym_ATDIR);
      END_STATE();
    case 757:
      ACCEPT_TOKEN(anon_sym_ATFILENAME);
      END_STATE();
    case 758:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(907);
      if (lookahead == 't') ADVANCE(841);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 759:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(907);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 760:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(941);
      if (lookahead == 'o') ADVANCE(913);
      if (lookahead == 'r') ADVANCE(844);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 761:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(941);
      if (lookahead == 'o') ADVANCE(913);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 762:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(774);
      if (lookahead == 'i') ADVANCE(864);
      if (lookahead == 'y') ADVANCE(906);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 763:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(774);
      if (lookahead == 'i') ADVANCE(864);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 764:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(774);
      if (lookahead == 'i') ADVANCE(865);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 765:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(846);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 766:
      ACCEPT_TOKEN(sym_id);
      ADVANCE_MAP(
        '-', 35,
        '.', 514,
        ':', 70,
        '_', 1049,
        'a', 852,
        'i', 854,
        'o', 908,
        'u', 884,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 767:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(848);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 768:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(849);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 769:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(951);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 770:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(850);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 771:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'a') ADVANCE(923);
      if (lookahead == 'o') ADVANCE(883);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 772:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'b') ADVANCE(881);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 773:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'b') ADVANCE(768);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 774:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'b') ADVANCE(856);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 775:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'b') ADVANCE(858);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 776:
      ACCEPT_TOKEN(sym_id);
      ADVANCE_MAP(
        '-', 35,
        '.', 514,
        ':', 70,
        '_', 1049,
        'c', 835,
        'e', 926,
        't', 919,
        'u', 772,
        'w', 839,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 777:
      ACCEPT_TOKEN(sym_id);
      ADVANCE_MAP(
        '-', 35,
        '.', 514,
        ':', 70,
        '_', 1049,
        'c', 835,
        'e', 926,
        't', 919,
        'u', 772,
      );
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 778:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'c') ADVANCE(767);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 779:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'c') ADVANCE(832);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 780:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'c') ADVANCE(894);
      if (lookahead == 'd') ADVANCE(798);
      if (lookahead == 't') ADVANCE(948);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 781:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'c') ADVANCE(894);
      if (lookahead == 't') ADVANCE(948);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 782:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'c') ADVANCE(894);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 783:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'c') ADVANCE(942);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 784:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'c') ADVANCE(945);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 785:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'd') ADVANCE(787);
      if (lookahead == 'n') ADVANCE(957);
      if (lookahead == 's') ADVANCE(921);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 786:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'd') ADVANCE(787);
      if (lookahead == 'n') ADVANCE(957);
      if (lookahead == 's') ADVANCE(605);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 787:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'd') ADVANCE(586);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 788:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'd') ADVANCE(549);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 789:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'd') ADVANCE(952);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 790:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'd') ADVANCE(792);
      if (lookahead == 'n') ADVANCE(957);
      if (lookahead == 's') ADVANCE(606);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 791:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'd') ADVANCE(792);
      if (lookahead == 'n') ADVANCE(957);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 792:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'd') ADVANCE(909);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 793:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'd') ADVANCE(953);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 794:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(956);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 795:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(780);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 796:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(765);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 797:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(630);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 798:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(826);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 799:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(654);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 800:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(553);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 801:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(666);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 802:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(577);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 803:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(589);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 804:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(627);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 805:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(528);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 806:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(660);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 807:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(734);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 808:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(828);
      if (lookahead == 'o') ADVANCE(954);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 809:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(781);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 810:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(601);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 811:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(564);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 812:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(653);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 813:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(853);
      if (lookahead == 'o') ADVANCE(954);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 814:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(783);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 815:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(782);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 816:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(867);
      if (lookahead == 'i') ADVANCE(857);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 817:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(867);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 818:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(936);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 819:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(917);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 820:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(880);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 821:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(915);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 822:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(944);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 823:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'e') ADVANCE(793);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 824:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'f') ADVANCE(560);
      if (lookahead == 'n') ADVANCE(925);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 825:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'f') ADVANCE(560);
      if (lookahead == 'n') ADVANCE(571);
      if (lookahead == 's') ADVANCE(712);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 826:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'f') ADVANCE(543);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 827:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'f') ADVANCE(658);
      if (lookahead == 'p') ADVANCE(759);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 828:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'f') ADVANCE(769);
      if (lookahead == 'l') ADVANCE(822);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 829:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'g') ADVANCE(648);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 830:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'g') ADVANCE(833);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 831:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'h') ADVANCE(816);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 832:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'h') ADVANCE(566);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 833:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'h') ADVANCE(583);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 834:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'h') ADVANCE(916);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 835:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'h') ADVANCE(823);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 836:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'h') ADVANCE(817);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 837:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'i') ADVANCE(920);
      if (lookahead == 'o') ADVANCE(778);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 838:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'i') ADVANCE(868);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 839:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'i') ADVANCE(940);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 840:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'i') ADVANCE(897);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 841:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'i') ADVANCE(899);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 842:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'i') ADVANCE(900);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 843:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'i') ADVANCE(854);
      if (lookahead == 'u') ADVANCE(884);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 844:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'i') ADVANCE(882);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 845:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'k') ADVANCE(612);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 846:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'k') ADVANCE(581);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 847:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(621);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 848:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(591);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 849:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(535);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 850:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(636);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 851:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(890);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 852:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(855);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 853:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(822);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 854:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(797);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 855:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(939);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 856:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(801);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 857:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(802);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 858:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(804);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 859:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(805);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 860:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(937);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 861:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(807);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 862:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'l') ADVANCE(924);
      if (lookahead == 'n') ADVANCE(946);
      if (lookahead == 'v') ADVANCE(820);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 863:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'm') ADVANCE(545);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 864:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'm') ADVANCE(799);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 865:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'm') ADVANCE(812);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 866:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(925);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 867:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(593);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 868:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(829);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 869:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(669);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 870:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(539);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 871:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(585);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 872:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(642);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 873:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(609);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 874:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(571);
      if (lookahead == 's') ADVANCE(712);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 875:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(946);
      if (lookahead == 'v') ADVANCE(820);
      if (lookahead == 'x') ADVANCE(905);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 876:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(946);
      if (lookahead == 'v') ADVANCE(820);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 877:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(946);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 878:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(840);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 879:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(931);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 880:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(932);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 881:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(818);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 882:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(933);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 883:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(922);
      if (lookahead == 'p') ADVANCE(958);
      if (lookahead == 'u') ADVANCE(879);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 884:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'n') ADVANCE(784);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 885:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(883);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 886:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(954);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 887:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(845);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 888:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(903);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 889:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(789);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 890:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(773);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 891:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(893);
      if (lookahead == 'r') ADVANCE(796);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 892:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(893);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 893:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(847);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 894:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(912);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 895:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(887);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 896:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(947);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 897:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(869);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 898:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(911);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 899:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(870);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 900:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(873);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 901:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'o') ADVANCE(918);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 902:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'p') ADVANCE(758);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 903:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'p') ADVANCE(958);
      if (lookahead == 'u') ADVANCE(879);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 904:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'p') ADVANCE(759);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 905:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'p') ADVANCE(901);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 906:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'p') ADVANCE(800);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 907:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'q') ADVANCE(949);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 908:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(568);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 909:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(615);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 910:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(955);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 911:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(672);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 912:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(788);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 913:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(929);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 914:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(871);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 915:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(872);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 916:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(896);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 917:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(934);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 918:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(935);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 919:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'r') ADVANCE(838);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 920:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 's') ADVANCE(927);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 921:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 's') ADVANCE(819);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 922:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 's') ADVANCE(930);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 923:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 's') ADVANCE(810);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 924:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 's') ADVANCE(811);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 925:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(632);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 926:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(663);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 927:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(639);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 928:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(579);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 929:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(645);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 930:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(541);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 931:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(624);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 932:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(557);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 933:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(555);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 934:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(599);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 935:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(531);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 936:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(651);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 937:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(603);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 938:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(595);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 939:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(834);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 940:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(779);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 941:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(943);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 942:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(898);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 943:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(821);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 944:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(803);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 945:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 't') ADVANCE(842);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 946:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'u') ADVANCE(863);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 947:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'u') ADVANCE(830);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 948:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'u') ADVANCE(914);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 949:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'u') ADVANCE(806);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 950:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'u') ADVANCE(938);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 951:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'u') ADVANCE(860);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 952:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'u') ADVANCE(859);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 953:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'u') ADVANCE(861);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 954:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'u') ADVANCE(775);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 955:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'v') ADVANCE(770);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 956:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'x') ADVANCE(928);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 957:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'y') ADVANCE(618);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 958:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (lookahead == 'y') ADVANCE(730);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 959:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == '-') ADVANCE(35);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == '_') ADVANCE(1049);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(959);
      END_STATE();
    case 960:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'a') ADVANCE(1022);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 961:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'a') ADVANCE(1039);
      if (lookahead == 'o') ADVANCE(1028);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 962:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'a') ADVANCE(965);
      if (lookahead == 'i') ADVANCE(997);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 963:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'a') ADVANCE(992);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('b' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 964:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'b') ADVANCE(1005);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 965:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'b') ADVANCE(994);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 966:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'b') ADVANCE(995);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 967:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'c') ADVANCE(1016);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 968:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'c') ADVANCE(1040);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 969:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'c') ADVANCE(1041);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 970:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'd') ADVANCE(972);
      if (lookahead == 'n') ADVANCE(1047);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 971:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'd') ADVANCE(550);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 972:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'd') ADVANCE(1023);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 973:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(967);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 974:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(631);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 975:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(655);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 976:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(667);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 977:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(628);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 978:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(661);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 979:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(968);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 980:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(1032);
      if (lookahead == 't') ADVANCE(1027);
      if (lookahead == 'u') ADVANCE(964);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 981:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(1029);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 982:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(1037);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 983:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'e') ADVANCE(1007);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 984:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'g') ADVANCE(649);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 985:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'i') ADVANCE(993);
      if (lookahead == 'u') ADVANCE(1008);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 986:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'i') ADVANCE(1030);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 987:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'i') ADVANCE(999);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 988:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'i') ADVANCE(1017);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 989:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'i') ADVANCE(1019);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 990:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'k') ADVANCE(613);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 991:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'l') ADVANCE(622);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 992:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'l') ADVANCE(637);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 993:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'l') ADVANCE(974);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 994:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'l') ADVANCE(976);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 995:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'l') ADVANCE(977);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 996:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'm') ADVANCE(546);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 997:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'm') ADVANCE(975);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 998:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(1031);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 999:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(984);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1000:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(670);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1001:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(643);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1002:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(610);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1003:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(988);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1004:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(1042);
      if (lookahead == 'v') ADVANCE(983);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1005:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(982);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1006:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(1035);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1007:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(1036);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1008:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'n') ADVANCE(969);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1009:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(1044);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1010:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(990);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1011:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(1021);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1012:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(1045);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1013:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(991);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1014:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(1013);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1015:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(1010);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1016:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(1026);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1017:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(1000);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1018:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(1025);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1019:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'o') ADVANCE(1002);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1020:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'p') ADVANCE(960);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1021:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'p') ADVANCE(1048);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1022:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'q') ADVANCE(1043);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1023:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'r') ADVANCE(616);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1024:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'r') ADVANCE(1046);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1025:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'r') ADVANCE(673);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1026:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'r') ADVANCE(971);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1027:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'r') ADVANCE(987);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1028:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'r') ADVANCE(1034);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1029:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'r') ADVANCE(1001);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1030:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 's') ADVANCE(1033);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1031:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(633);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1032:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(664);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1033:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(640);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1034:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(646);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1035:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(625);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1036:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(558);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1037:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(652);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1038:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(981);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1039:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(1038);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1040:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(1018);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1041:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 't') ADVANCE(989);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1042:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'u') ADVANCE(996);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1043:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'u') ADVANCE(978);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1044:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'u') ADVANCE(1006);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1045:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'u') ADVANCE(966);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1046:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'v') ADVANCE(963);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1047:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'y') ADVANCE(619);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1048:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (lookahead == 'y') ADVANCE(731);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1049:
      ACCEPT_TOKEN(sym_id);
      if (lookahead == ':') ADVANCE(70);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          lookahead == '_' ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1049);
      END_STATE();
    case 1050:
      ACCEPT_TOKEN(sym_file);
      if (lookahead == '!') ADVANCE(1053);
      if (lookahead == '<') ADVANCE(1054);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(1115);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1055);
      END_STATE();
    case 1051:
      ACCEPT_TOKEN(sym_file);
      if (lookahead == '#') ADVANCE(1050);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(1117);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1052);
      END_STATE();
    case 1052:
      ACCEPT_TOKEN(sym_file);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(1117);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1052);
      END_STATE();
    case 1053:
      ACCEPT_TOKEN(sym_file);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(1112);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1053);
      END_STATE();
    case 1054:
      ACCEPT_TOKEN(sym_file);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(1113);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1054);
      END_STATE();
    case 1055:
      ACCEPT_TOKEN(sym_file);
      if (lookahead == '\t' ||
          lookahead == ' ') ADVANCE(1115);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1055);
      END_STATE();
    case 1056:
      ACCEPT_TOKEN(sym_file);
      if (lookahead != 0 &&
          lookahead != '\t' &&
          lookahead != '\n' &&
          lookahead != '\r' &&
          lookahead != ' ') ADVANCE(1056);
      END_STATE();
    case 1057:
      ACCEPT_TOKEN(sym_pattern);
      END_STATE();
    case 1058:
      ACCEPT_TOKEN(sym_pattern);
      if (lookahead == '/') ADVANCE(1060);
      if (lookahead == '\\') ADVANCE(67);
      if (lookahead == 'i') ADVANCE(1059);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(66);
      END_STATE();
    case 1059:
      ACCEPT_TOKEN(sym_pattern);
      if (lookahead == '/') ADVANCE(1060);
      if (lookahead == '\\') ADVANCE(67);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(66);
      END_STATE();
    case 1060:
      ACCEPT_TOKEN(sym_pattern);
      if (lookahead == 'i') ADVANCE(1057);
      END_STATE();
    case 1061:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1061);
      END_STATE();
    case 1062:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1061);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(35);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1063:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1061);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1063);
      END_STATE();
    case 1064:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1077);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(29);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1064);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1065:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1073);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(29);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1065);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1066:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1062);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1066);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1067:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1067);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1063);
      END_STATE();
    case 1068:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1067);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1066);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1069:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1067);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1069);
      END_STATE();
    case 1070:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1068);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1070);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1071:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1074);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1071);
      END_STATE();
    case 1072:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1074);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1072);
      END_STATE();
    case 1073:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1074);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1070);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1074:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1074);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1069);
      END_STATE();
    case 1075:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1076);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1075);
      END_STATE();
    case 1076:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1078);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1071);
      END_STATE();
    case 1077:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1078);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1108);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1065);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1078:
      ACCEPT_TOKEN(sym_ipv4);
      if (lookahead == '.') ADVANCE(1078);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1072);
      END_STATE();
    case 1079:
      ACCEPT_TOKEN(sym_ipv6);
      END_STATE();
    case 1080:
      ACCEPT_TOKEN(sym_port);
      END_STATE();
    case 1081:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(1090);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == 'x') ADVANCE(515);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1087);
      END_STATE();
    case 1082:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(1090);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1087);
      END_STATE();
    case 1083:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(1091);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == 'x') ADVANCE(34);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(29);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1086);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1084:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(1091);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(29);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1086);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1085:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(1101);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(29);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1064);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1086:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(1099);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(29);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1085);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1087:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(1098);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1088);
      END_STATE();
    case 1088:
      ACCEPT_TOKEN(sym_integer);
      if (lookahead == '.') ADVANCE(1100);
      if (lookahead == '/') ADVANCE(268);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1075);
      END_STATE();
    case 1089:
      ACCEPT_TOKEN(sym_integer);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1089);
      END_STATE();
    case 1090:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(30);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1096);
      END_STATE();
    case 1091:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(30);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1108);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1094);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1092:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(514);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1092);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1093:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(514);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1093);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1094:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(45);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(29);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1095);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1095:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(52);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(29);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1065);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1096:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(46);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1097);
      END_STATE();
    case 1097:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(53);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1071);
      END_STATE();
    case 1098:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(56);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1097);
      END_STATE();
    case 1099:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(56);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1108);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1095);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1100:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(61);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1071);
      END_STATE();
    case 1101:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == '.') ADVANCE(61);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(1108);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1065);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1102:
      ACCEPT_TOKEN(sym_floatp);
      if (lookahead == 'E' ||
          lookahead == 'e') ADVANCE(511);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1102);
      END_STATE();
    case 1103:
      ACCEPT_TOKEN(sym_floatp);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1103);
      END_STATE();
    case 1104:
      ACCEPT_TOKEN(sym_hex);
      if (lookahead == '.') ADVANCE(514);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(1104);
      if (lookahead == '-' ||
          ('G' <= lookahead && lookahead <= 'Z') ||
          ('g' <= lookahead && lookahead <= 'z')) ADVANCE(35);
      END_STATE();
    case 1105:
      ACCEPT_TOKEN(sym_hex);
      if (('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'F') ||
          ('a' <= lookahead && lookahead <= 'f')) ADVANCE(1105);
      END_STATE();
    case 1106:
      ACCEPT_TOKEN(sym_time_unit);
      END_STATE();
    case 1107:
      ACCEPT_TOKEN(sym_time_unit);
      if (lookahead == 's') ADVANCE(1106);
      END_STATE();
    case 1108:
      ACCEPT_TOKEN(sym_hostname);
      if (lookahead == '+') ADVANCE(513);
      if (lookahead == '-') ADVANCE(1109);
      if (lookahead == '.') ADVANCE(514);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1093);
      if (('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1109:
      ACCEPT_TOKEN(sym_hostname);
      if (lookahead == '.') ADVANCE(514);
      if (('0' <= lookahead && lookahead <= '9')) ADVANCE(1093);
      if (lookahead == '-' ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1110:
      ACCEPT_TOKEN(sym_hostname);
      if (lookahead == '.') ADVANCE(514);
      if (lookahead == '-' ||
          ('0' <= lookahead && lookahead <= '9') ||
          ('A' <= lookahead && lookahead <= 'Z') ||
          ('a' <= lookahead && lookahead <= 'z')) ADVANCE(1110);
      END_STATE();
    case 1111:
      ACCEPT_TOKEN(aux_sym_string_token1);
      END_STATE();
    case 1112:
      ACCEPT_TOKEN(sym_zeekygen_head_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1112);
      END_STATE();
    case 1113:
      ACCEPT_TOKEN(sym_zeekygen_prev_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1113);
      END_STATE();
    case 1114:
      ACCEPT_TOKEN(sym_zeekygen_next_comment);
      if (lookahead == '!') ADVANCE(1112);
      if (lookahead == '<') ADVANCE(1113);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1115);
      END_STATE();
    case 1115:
      ACCEPT_TOKEN(sym_zeekygen_next_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1115);
      END_STATE();
    case 1116:
      ACCEPT_TOKEN(sym_minor_comment);
      if (lookahead == '#') ADVANCE(1114);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1117);
      END_STATE();
    case 1117:
      ACCEPT_TOKEN(sym_minor_comment);
      if (lookahead != 0 &&
          lookahead != '\n' &&
          lookahead != '\r') ADVANCE(1117);
      END_STATE();
    case 1118:
      ACCEPT_TOKEN(sym_nl);
      END_STATE();
    default:
      return false;
  }
}

static const TSLexMode ts_lex_modes[STATE_COUNT] = {
  [0] = {.lex_state = 0},
  [1] = {.lex_state = 521},
  [2] = {.lex_state = 2},
  [3] = {.lex_state = 521},
  [4] = {.lex_state = 521},
  [5] = {.lex_state = 521},
  [6] = {.lex_state = 2},
  [7] = {.lex_state = 5},
  [8] = {.lex_state = 521},
  [9] = {.lex_state = 4},
  [10] = {.lex_state = 7},
  [11] = {.lex_state = 519},
  [12] = {.lex_state = 519},
  [13] = {.lex_state = 6},
  [14] = {.lex_state = 518},
  [15] = {.lex_state = 517},
  [16] = {.lex_state = 520},
  [17] = {.lex_state = 520},
  [18] = {.lex_state = 518},
  [19] = {.lex_state = 517},
  [20] = {.lex_state = 517},
  [21] = {.lex_state = 14},
  [22] = {.lex_state = 14},
  [23] = {.lex_state = 524},
  [24] = {.lex_state = 524},
  [25] = {.lex_state = 524},
  [26] = {.lex_state = 524},
  [27] = {.lex_state = 524},
  [28] = {.lex_state = 524},
  [29] = {.lex_state = 524},
  [30] = {.lex_state = 524},
  [31] = {.lex_state = 524},
  [32] = {.lex_state = 524},
  [33] = {.lex_state = 524},
  [34] = {.lex_state = 524},
  [35] = {.lex_state = 524},
  [36] = {.lex_state = 10},
  [37] = {.lex_state = 10},
  [38] = {.lex_state = 14},
  [39] = {.lex_state = 14},
  [40] = {.lex_state = 524},
  [41] = {.lex_state = 524},
  [42] = {.lex_state = 524},
  [43] = {.lex_state = 524},
  [44] = {.lex_state = 524},
  [45] = {.lex_state = 524},
  [46] = {.lex_state = 524},
  [47] = {.lex_state = 524},
  [48] = {.lex_state = 524},
  [49] = {.lex_state = 524},
  [50] = {.lex_state = 524},
  [51] = {.lex_state = 524},
  [52] = {.lex_state = 524},
  [53] = {.lex_state = 524},
  [54] = {.lex_state = 524},
  [55] = {.lex_state = 524},
  [56] = {.lex_state = 524},
  [57] = {.lex_state = 524},
  [58] = {.lex_state = 524},
  [59] = {.lex_state = 524},
  [60] = {.lex_state = 524},
  [61] = {.lex_state = 524},
  [62] = {.lex_state = 524},
  [63] = {.lex_state = 524},
  [64] = {.lex_state = 524},
  [65] = {.lex_state = 524},
  [66] = {.lex_state = 524},
  [67] = {.lex_state = 524},
  [68] = {.lex_state = 524},
  [69] = {.lex_state = 524},
  [70] = {.lex_state = 524},
  [71] = {.lex_state = 524},
  [72] = {.lex_state = 524},
  [73] = {.lex_state = 524},
  [74] = {.lex_state = 524},
  [75] = {.lex_state = 524},
  [76] = {.lex_state = 524},
  [77] = {.lex_state = 524},
  [78] = {.lex_state = 524},
  [79] = {.lex_state = 524},
  [80] = {.lex_state = 10},
  [81] = {.lex_state = 524},
  [82] = {.lex_state = 524},
  [83] = {.lex_state = 10},
  [84] = {.lex_state = 524},
  [85] = {.lex_state = 524},
  [86] = {.lex_state = 10},
  [87] = {.lex_state = 10},
  [88] = {.lex_state = 10},
  [89] = {.lex_state = 10},
  [90] = {.lex_state = 10},
  [91] = {.lex_state = 10},
  [92] = {.lex_state = 10},
  [93] = {.lex_state = 10},
  [94] = {.lex_state = 10},
  [95] = {.lex_state = 10},
  [96] = {.lex_state = 10},
  [97] = {.lex_state = 10},
  [98] = {.lex_state = 10},
  [99] = {.lex_state = 10},
  [100] = {.lex_state = 10},
  [101] = {.lex_state = 10},
  [102] = {.lex_state = 10},
  [103] = {.lex_state = 10},
  [104] = {.lex_state = 10},
  [105] = {.lex_state = 10},
  [106] = {.lex_state = 10},
  [107] = {.lex_state = 10},
  [108] = {.lex_state = 10},
  [109] = {.lex_state = 10},
  [110] = {.lex_state = 10},
  [111] = {.lex_state = 10},
  [112] = {.lex_state = 10},
  [113] = {.lex_state = 10},
  [114] = {.lex_state = 10},
  [115] = {.lex_state = 10},
  [116] = {.lex_state = 10},
  [117] = {.lex_state = 10},
  [118] = {.lex_state = 10},
  [119] = {.lex_state = 10},
  [120] = {.lex_state = 10},
  [121] = {.lex_state = 524},
  [122] = {.lex_state = 524},
  [123] = {.lex_state = 524},
  [124] = {.lex_state = 524},
  [125] = {.lex_state = 524},
  [126] = {.lex_state = 524},
  [127] = {.lex_state = 524},
  [128] = {.lex_state = 524},
  [129] = {.lex_state = 524},
  [130] = {.lex_state = 524},
  [131] = {.lex_state = 524},
  [132] = {.lex_state = 524},
  [133] = {.lex_state = 524},
  [134] = {.lex_state = 524},
  [135] = {.lex_state = 524},
  [136] = {.lex_state = 524},
  [137] = {.lex_state = 524},
  [138] = {.lex_state = 524},
  [139] = {.lex_state = 524},
  [140] = {.lex_state = 524},
  [141] = {.lex_state = 524},
  [142] = {.lex_state = 524},
  [143] = {.lex_state = 10},
  [144] = {.lex_state = 524},
  [145] = {.lex_state = 10},
  [146] = {.lex_state = 524},
  [147] = {.lex_state = 524},
  [148] = {.lex_state = 10},
  [149] = {.lex_state = 524},
  [150] = {.lex_state = 10},
  [151] = {.lex_state = 10},
  [152] = {.lex_state = 10},
  [153] = {.lex_state = 524},
  [154] = {.lex_state = 10},
  [155] = {.lex_state = 524},
  [156] = {.lex_state = 10},
  [157] = {.lex_state = 524},
  [158] = {.lex_state = 10},
  [159] = {.lex_state = 524},
  [160] = {.lex_state = 524},
  [161] = {.lex_state = 10},
  [162] = {.lex_state = 524},
  [163] = {.lex_state = 524},
  [164] = {.lex_state = 524},
  [165] = {.lex_state = 524},
  [166] = {.lex_state = 524},
  [167] = {.lex_state = 524},
  [168] = {.lex_state = 10},
  [169] = {.lex_state = 10},
  [170] = {.lex_state = 10},
  [171] = {.lex_state = 524},
  [172] = {.lex_state = 524},
  [173] = {.lex_state = 524},
  [174] = {.lex_state = 524},
  [175] = {.lex_state = 524},
  [176] = {.lex_state = 524},
  [177] = {.lex_state = 524},
  [178] = {.lex_state = 524},
  [179] = {.lex_state = 524},
  [180] = {.lex_state = 10},
  [181] = {.lex_state = 524},
  [182] = {.lex_state = 10},
  [183] = {.lex_state = 524},
  [184] = {.lex_state = 524},
  [185] = {.lex_state = 524},
  [186] = {.lex_state = 524},
  [187] = {.lex_state = 524},
  [188] = {.lex_state = 10},
  [189] = {.lex_state = 524},
  [190] = {.lex_state = 524},
  [191] = {.lex_state = 524},
  [192] = {.lex_state = 10},
  [193] = {.lex_state = 524},
  [194] = {.lex_state = 10},
  [195] = {.lex_state = 524},
  [196] = {.lex_state = 524},
  [197] = {.lex_state = 524},
  [198] = {.lex_state = 524},
  [199] = {.lex_state = 524},
  [200] = {.lex_state = 524},
  [201] = {.lex_state = 524},
  [202] = {.lex_state = 524},
  [203] = {.lex_state = 524},
  [204] = {.lex_state = 10},
  [205] = {.lex_state = 524},
  [206] = {.lex_state = 10},
  [207] = {.lex_state = 524},
  [208] = {.lex_state = 524},
  [209] = {.lex_state = 524},
  [210] = {.lex_state = 524},
  [211] = {.lex_state = 524},
  [212] = {.lex_state = 524},
  [213] = {.lex_state = 524},
  [214] = {.lex_state = 524},
  [215] = {.lex_state = 524},
  [216] = {.lex_state = 10},
  [217] = {.lex_state = 10},
  [218] = {.lex_state = 524},
  [219] = {.lex_state = 10},
  [220] = {.lex_state = 524},
  [221] = {.lex_state = 524},
  [222] = {.lex_state = 524},
  [223] = {.lex_state = 524},
  [224] = {.lex_state = 524},
  [225] = {.lex_state = 10},
  [226] = {.lex_state = 10},
  [227] = {.lex_state = 524},
  [228] = {.lex_state = 524},
  [229] = {.lex_state = 524},
  [230] = {.lex_state = 524},
  [231] = {.lex_state = 524},
  [232] = {.lex_state = 524},
  [233] = {.lex_state = 524},
  [234] = {.lex_state = 10},
  [235] = {.lex_state = 10},
  [236] = {.lex_state = 524},
  [237] = {.lex_state = 524},
  [238] = {.lex_state = 524},
  [239] = {.lex_state = 524},
  [240] = {.lex_state = 524},
  [241] = {.lex_state = 524},
  [242] = {.lex_state = 524},
  [243] = {.lex_state = 10},
  [244] = {.lex_state = 10},
  [245] = {.lex_state = 524},
  [246] = {.lex_state = 524},
  [247] = {.lex_state = 524},
  [248] = {.lex_state = 524},
  [249] = {.lex_state = 524},
  [250] = {.lex_state = 524},
  [251] = {.lex_state = 524},
  [252] = {.lex_state = 10},
  [253] = {.lex_state = 10},
  [254] = {.lex_state = 524},
  [255] = {.lex_state = 524},
  [256] = {.lex_state = 524},
  [257] = {.lex_state = 524},
  [258] = {.lex_state = 524},
  [259] = {.lex_state = 524},
  [260] = {.lex_state = 10},
  [261] = {.lex_state = 10},
  [262] = {.lex_state = 524},
  [263] = {.lex_state = 524},
  [264] = {.lex_state = 524},
  [265] = {.lex_state = 524},
  [266] = {.lex_state = 524},
  [267] = {.lex_state = 524},
  [268] = {.lex_state = 524},
  [269] = {.lex_state = 524},
  [270] = {.lex_state = 524},
  [271] = {.lex_state = 524},
  [272] = {.lex_state = 524},
  [273] = {.lex_state = 524},
  [274] = {.lex_state = 524},
  [275] = {.lex_state = 524},
  [276] = {.lex_state = 524},
  [277] = {.lex_state = 524},
  [278] = {.lex_state = 524},
  [279] = {.lex_state = 524},
  [280] = {.lex_state = 524},
  [281] = {.lex_state = 524},
  [282] = {.lex_state = 524},
  [283] = {.lex_state = 524},
  [284] = {.lex_state = 524},
  [285] = {.lex_state = 524},
  [286] = {.lex_state = 10},
  [287] = {.lex_state = 10},
  [288] = {.lex_state = 521},
  [289] = {.lex_state = 521},
  [290] = {.lex_state = 521},
  [291] = {.lex_state = 521},
  [292] = {.lex_state = 521},
  [293] = {.lex_state = 521},
  [294] = {.lex_state = 521},
  [295] = {.lex_state = 521},
  [296] = {.lex_state = 521},
  [297] = {.lex_state = 521},
  [298] = {.lex_state = 521},
  [299] = {.lex_state = 521},
  [300] = {.lex_state = 521},
  [301] = {.lex_state = 521},
  [302] = {.lex_state = 521},
  [303] = {.lex_state = 521},
  [304] = {.lex_state = 521},
  [305] = {.lex_state = 521},
  [306] = {.lex_state = 521},
  [307] = {.lex_state = 521},
  [308] = {.lex_state = 521},
  [309] = {.lex_state = 521},
  [310] = {.lex_state = 521},
  [311] = {.lex_state = 521},
  [312] = {.lex_state = 521},
  [313] = {.lex_state = 521},
  [314] = {.lex_state = 521},
  [315] = {.lex_state = 521},
  [316] = {.lex_state = 521},
  [317] = {.lex_state = 521},
  [318] = {.lex_state = 521},
  [319] = {.lex_state = 521},
  [320] = {.lex_state = 521},
  [321] = {.lex_state = 521},
  [322] = {.lex_state = 521},
  [323] = {.lex_state = 521},
  [324] = {.lex_state = 521},
  [325] = {.lex_state = 521},
  [326] = {.lex_state = 521},
  [327] = {.lex_state = 521},
  [328] = {.lex_state = 521},
  [329] = {.lex_state = 521},
  [330] = {.lex_state = 521},
  [331] = {.lex_state = 521},
  [332] = {.lex_state = 521},
  [333] = {.lex_state = 521},
  [334] = {.lex_state = 521},
  [335] = {.lex_state = 13},
  [336] = {.lex_state = 13},
  [337] = {.lex_state = 3},
  [338] = {.lex_state = 13},
  [339] = {.lex_state = 13},
  [340] = {.lex_state = 13},
  [341] = {.lex_state = 13},
  [342] = {.lex_state = 13},
  [343] = {.lex_state = 13},
  [344] = {.lex_state = 13},
  [345] = {.lex_state = 13},
  [346] = {.lex_state = 13},
  [347] = {.lex_state = 12},
  [348] = {.lex_state = 13},
  [349] = {.lex_state = 12},
  [350] = {.lex_state = 13},
  [351] = {.lex_state = 13},
  [352] = {.lex_state = 13},
  [353] = {.lex_state = 13},
  [354] = {.lex_state = 13},
  [355] = {.lex_state = 13},
  [356] = {.lex_state = 13},
  [357] = {.lex_state = 13},
  [358] = {.lex_state = 13},
  [359] = {.lex_state = 13},
  [360] = {.lex_state = 13},
  [361] = {.lex_state = 13},
  [362] = {.lex_state = 13},
  [363] = {.lex_state = 13},
  [364] = {.lex_state = 13},
  [365] = {.lex_state = 13},
  [366] = {.lex_state = 13},
  [367] = {.lex_state = 13},
  [368] = {.lex_state = 12},
  [369] = {.lex_state = 12},
  [370] = {.lex_state = 15},
  [371] = {.lex_state = 15},
  [372] = {.lex_state = 13},
  [373] = {.lex_state = 15},
  [374] = {.lex_state = 15},
  [375] = {.lex_state = 13},
  [376] = {.lex_state = 13},
  [377] = {.lex_state = 13},
  [378] = {.lex_state = 13},
  [379] = {.lex_state = 13},
  [380] = {.lex_state = 13},
  [381] = {.lex_state = 13},
  [382] = {.lex_state = 13},
  [383] = {.lex_state = 12},
  [384] = {.lex_state = 15},
  [385] = {.lex_state = 15},
  [386] = {.lex_state = 15},
  [387] = {.lex_state = 15},
  [388] = {.lex_state = 15},
  [389] = {.lex_state = 15},
  [390] = {.lex_state = 15},
  [391] = {.lex_state = 15},
  [392] = {.lex_state = 15},
  [393] = {.lex_state = 15},
  [394] = {.lex_state = 15},
  [395] = {.lex_state = 15},
  [396] = {.lex_state = 15},
  [397] = {.lex_state = 15},
  [398] = {.lex_state = 15},
  [399] = {.lex_state = 15},
  [400] = {.lex_state = 15},
  [401] = {.lex_state = 14},
  [402] = {.lex_state = 12},
  [403] = {.lex_state = 523},
  [404] = {.lex_state = 523},
  [405] = {.lex_state = 12},
  [406] = {.lex_state = 15},
  [407] = {.lex_state = 14},
  [408] = {.lex_state = 12},
  [409] = {.lex_state = 12},
  [410] = {.lex_state = 14},
  [411] = {.lex_state = 12},
  [412] = {.lex_state = 12},
  [413] = {.lex_state = 14},
  [414] = {.lex_state = 12},
  [415] = {.lex_state = 12},
  [416] = {.lex_state = 12},
  [417] = {.lex_state = 523},
  [418] = {.lex_state = 12},
  [419] = {.lex_state = 523},
  [420] = {.lex_state = 12},
  [421] = {.lex_state = 12},
  [422] = {.lex_state = 523},
  [423] = {.lex_state = 15},
  [424] = {.lex_state = 12},
  [425] = {.lex_state = 12},
  [426] = {.lex_state = 12},
  [427] = {.lex_state = 12},
  [428] = {.lex_state = 12},
  [429] = {.lex_state = 12},
  [430] = {.lex_state = 15},
  [431] = {.lex_state = 12},
  [432] = {.lex_state = 15},
  [433] = {.lex_state = 12},
  [434] = {.lex_state = 12},
  [435] = {.lex_state = 12},
  [436] = {.lex_state = 15},
  [437] = {.lex_state = 12},
  [438] = {.lex_state = 15},
  [439] = {.lex_state = 15},
  [440] = {.lex_state = 15},
  [441] = {.lex_state = 12},
  [442] = {.lex_state = 12},
  [443] = {.lex_state = 12},
  [444] = {.lex_state = 15},
  [445] = {.lex_state = 523},
  [446] = {.lex_state = 523},
  [447] = {.lex_state = 15},
  [448] = {.lex_state = 15},
  [449] = {.lex_state = 12},
  [450] = {.lex_state = 15},
  [451] = {.lex_state = 15},
  [452] = {.lex_state = 15},
  [453] = {.lex_state = 15},
  [454] = {.lex_state = 523},
  [455] = {.lex_state = 15},
  [456] = {.lex_state = 12},
  [457] = {.lex_state = 14},
  [458] = {.lex_state = 523},
  [459] = {.lex_state = 523},
  [460] = {.lex_state = 523},
  [461] = {.lex_state = 523},
  [462] = {.lex_state = 523},
  [463] = {.lex_state = 523},
  [464] = {.lex_state = 523},
  [465] = {.lex_state = 523},
  [466] = {.lex_state = 14},
  [467] = {.lex_state = 523},
  [468] = {.lex_state = 525},
  [469] = {.lex_state = 525},
  [470] = {.lex_state = 523},
  [471] = {.lex_state = 523},
  [472] = {.lex_state = 14},
  [473] = {.lex_state = 14},
  [474] = {.lex_state = 523},
  [475] = {.lex_state = 14},
  [476] = {.lex_state = 14},
  [477] = {.lex_state = 14},
  [478] = {.lex_state = 523},
  [479] = {.lex_state = 523},
  [480] = {.lex_state = 14},
  [481] = {.lex_state = 523},
  [482] = {.lex_state = 523},
  [483] = {.lex_state = 523},
  [484] = {.lex_state = 523},
  [485] = {.lex_state = 523},
  [486] = {.lex_state = 523},
  [487] = {.lex_state = 523},
  [488] = {.lex_state = 523},
  [489] = {.lex_state = 523},
  [490] = {.lex_state = 14},
  [491] = {.lex_state = 523},
  [492] = {.lex_state = 14},
  [493] = {.lex_state = 523},
  [494] = {.lex_state = 523},
  [495] = {.lex_state = 523},
  [496] = {.lex_state = 523},
  [497] = {.lex_state = 14},
  [498] = {.lex_state = 523},
  [499] = {.lex_state = 523},
  [500] = {.lex_state = 523},
  [501] = {.lex_state = 14},
  [502] = {.lex_state = 523},
  [503] = {.lex_state = 14},
  [504] = {.lex_state = 14},
  [505] = {.lex_state = 14},
  [506] = {.lex_state = 523},
  [507] = {.lex_state = 522},
  [508] = {.lex_state = 523},
  [509] = {.lex_state = 522},
  [510] = {.lex_state = 523},
  [511] = {.lex_state = 523},
  [512] = {.lex_state = 523},
  [513] = {.lex_state = 523},
  [514] = {.lex_state = 525},
  [515] = {.lex_state = 523},
  [516] = {.lex_state = 523},
  [517] = {.lex_state = 14},
  [518] = {.lex_state = 525},
  [519] = {.lex_state = 523},
  [520] = {.lex_state = 523},
  [521] = {.lex_state = 523},
  [522] = {.lex_state = 523},
  [523] = {.lex_state = 523},
  [524] = {.lex_state = 523},
  [525] = {.lex_state = 522},
  [526] = {.lex_state = 525},
  [527] = {.lex_state = 14},
  [528] = {.lex_state = 523},
  [529] = {.lex_state = 525},
  [530] = {.lex_state = 523},
  [531] = {.lex_state = 523},
  [532] = {.lex_state = 523},
  [533] = {.lex_state = 525},
  [534] = {.lex_state = 523},
  [535] = {.lex_state = 14},
  [536] = {.lex_state = 14},
  [537] = {.lex_state = 522},
  [538] = {.lex_state = 523},
  [539] = {.lex_state = 523},
  [540] = {.lex_state = 525},
  [541] = {.lex_state = 523},
  [542] = {.lex_state = 14},
  [543] = {.lex_state = 522},
  [544] = {.lex_state = 14},
  [545] = {.lex_state = 14},
  [546] = {.lex_state = 522},
  [547] = {.lex_state = 14},
  [548] = {.lex_state = 523},
  [549] = {.lex_state = 14},
  [550] = {.lex_state = 522},
  [551] = {.lex_state = 522},
  [552] = {.lex_state = 14},
  [553] = {.lex_state = 523},
  [554] = {.lex_state = 523},
  [555] = {.lex_state = 523},
  [556] = {.lex_state = 523},
  [557] = {.lex_state = 523},
  [558] = {.lex_state = 523},
  [559] = {.lex_state = 523},
  [560] = {.lex_state = 523},
  [561] = {.lex_state = 523},
  [562] = {.lex_state = 523},
  [563] = {.lex_state = 14},
  [564] = {.lex_state = 523},
  [565] = {.lex_state = 523},
  [566] = {.lex_state = 14},
  [567] = {.lex_state = 523},
  [568] = {.lex_state = 523},
  [569] = {.lex_state = 523},
  [570] = {.lex_state = 522},
  [571] = {.lex_state = 525},
  [572] = {.lex_state = 522},
  [573] = {.lex_state = 522},
  [574] = {.lex_state = 525},
  [575] = {.lex_state = 525},
  [576] = {.lex_state = 522},
  [577] = {.lex_state = 525},
  [578] = {.lex_state = 522},
  [579] = {.lex_state = 522},
  [580] = {.lex_state = 525},
  [581] = {.lex_state = 525},
  [582] = {.lex_state = 525},
  [583] = {.lex_state = 525},
  [584] = {.lex_state = 525},
  [585] = {.lex_state = 525},
  [586] = {.lex_state = 525},
  [587] = {.lex_state = 525},
  [588] = {.lex_state = 525},
  [589] = {.lex_state = 525},
  [590] = {.lex_state = 525},
  [591] = {.lex_state = 525},
  [592] = {.lex_state = 525},
  [593] = {.lex_state = 525},
  [594] = {.lex_state = 525},
  [595] = {.lex_state = 525},
  [596] = {.lex_state = 525},
  [597] = {.lex_state = 525},
  [598] = {.lex_state = 525},
  [599] = {.lex_state = 525},
  [600] = {.lex_state = 525},
  [601] = {.lex_state = 525},
  [602] = {.lex_state = 525},
  [603] = {.lex_state = 525},
  [604] = {.lex_state = 525},
  [605] = {.lex_state = 525},
  [606] = {.lex_state = 525},
  [607] = {.lex_state = 525},
  [608] = {.lex_state = 525},
  [609] = {.lex_state = 525},
  [610] = {.lex_state = 525},
  [611] = {.lex_state = 525},
  [612] = {.lex_state = 525},
  [613] = {.lex_state = 525},
  [614] = {.lex_state = 525},
  [615] = {.lex_state = 522},
  [616] = {.lex_state = 525},
  [617] = {.lex_state = 525},
  [618] = {.lex_state = 525},
  [619] = {.lex_state = 522},
  [620] = {.lex_state = 522},
  [621] = {.lex_state = 524},
  [622] = {.lex_state = 524},
  [623] = {.lex_state = 525},
  [624] = {.lex_state = 522},
  [625] = {.lex_state = 522},
  [626] = {.lex_state = 522},
  [627] = {.lex_state = 522},
  [628] = {.lex_state = 522},
  [629] = {.lex_state = 522},
  [630] = {.lex_state = 522},
  [631] = {.lex_state = 525},
  [632] = {.lex_state = 522},
  [633] = {.lex_state = 522},
  [634] = {.lex_state = 522},
  [635] = {.lex_state = 524},
  [636] = {.lex_state = 522},
  [637] = {.lex_state = 522},
  [638] = {.lex_state = 522},
  [639] = {.lex_state = 522},
  [640] = {.lex_state = 525},
  [641] = {.lex_state = 522},
  [642] = {.lex_state = 522},
  [643] = {.lex_state = 525},
  [644] = {.lex_state = 524},
  [645] = {.lex_state = 522},
  [646] = {.lex_state = 522},
  [647] = {.lex_state = 525},
  [648] = {.lex_state = 522},
  [649] = {.lex_state = 525},
  [650] = {.lex_state = 525},
  [651] = {.lex_state = 525},
  [652] = {.lex_state = 525},
  [653] = {.lex_state = 525},
  [654] = {.lex_state = 525},
  [655] = {.lex_state = 525},
  [656] = {.lex_state = 522},
  [657] = {.lex_state = 524},
  [658] = {.lex_state = 524},
  [659] = {.lex_state = 522},
  [660] = {.lex_state = 522},
  [661] = {.lex_state = 524},
  [662] = {.lex_state = 522},
  [663] = {.lex_state = 524},
  [664] = {.lex_state = 522},
  [665] = {.lex_state = 522},
  [666] = {.lex_state = 522},
  [667] = {.lex_state = 522},
  [668] = {.lex_state = 522},
  [669] = {.lex_state = 522},
  [670] = {.lex_state = 522},
  [671] = {.lex_state = 522},
  [672] = {.lex_state = 522},
  [673] = {.lex_state = 522},
  [674] = {.lex_state = 522},
  [675] = {.lex_state = 522},
  [676] = {.lex_state = 525},
  [677] = {.lex_state = 525},
  [678] = {.lex_state = 525},
  [679] = {.lex_state = 525},
  [680] = {.lex_state = 525},
  [681] = {.lex_state = 525},
  [682] = {.lex_state = 522},
  [683] = {.lex_state = 525},
  [684] = {.lex_state = 522},
  [685] = {.lex_state = 525},
  [686] = {.lex_state = 525},
  [687] = {.lex_state = 522},
  [688] = {.lex_state = 522},
  [689] = {.lex_state = 525},
  [690] = {.lex_state = 525},
  [691] = {.lex_state = 522},
  [692] = {.lex_state = 522},
  [693] = {.lex_state = 522},
  [694] = {.lex_state = 522},
  [695] = {.lex_state = 522},
  [696] = {.lex_state = 522},
  [697] = {.lex_state = 522},
  [698] = {.lex_state = 522},
  [699] = {.lex_state = 522},
  [700] = {.lex_state = 525},
  [701] = {.lex_state = 522},
  [702] = {.lex_state = 524},
  [703] = {.lex_state = 524},
  [704] = {.lex_state = 524},
  [705] = {.lex_state = 524},
  [706] = {.lex_state = 524},
  [707] = {.lex_state = 524},
  [708] = {.lex_state = 524},
  [709] = {.lex_state = 524},
  [710] = {.lex_state = 524},
  [711] = {.lex_state = 524},
  [712] = {.lex_state = 524},
  [713] = {.lex_state = 524},
  [714] = {.lex_state = 524},
  [715] = {.lex_state = 524},
  [716] = {.lex_state = 524},
  [717] = {.lex_state = 524},
  [718] = {.lex_state = 524},
  [719] = {.lex_state = 524},
  [720] = {.lex_state = 524},
  [721] = {.lex_state = 524},
  [722] = {.lex_state = 524},
  [723] = {.lex_state = 524},
  [724] = {.lex_state = 524},
  [725] = {.lex_state = 524},
  [726] = {.lex_state = 524},
  [727] = {.lex_state = 524},
  [728] = {.lex_state = 524},
  [729] = {.lex_state = 524},
  [730] = {.lex_state = 524},
  [731] = {.lex_state = 524},
  [732] = {.lex_state = 524},
  [733] = {.lex_state = 524},
  [734] = {.lex_state = 524},
  [735] = {.lex_state = 524},
  [736] = {.lex_state = 524},
  [737] = {.lex_state = 524},
  [738] = {.lex_state = 524},
  [739] = {.lex_state = 524},
  [740] = {.lex_state = 524},
  [741] = {.lex_state = 524},
  [742] = {.lex_state = 524},
  [743] = {.lex_state = 524},
  [744] = {.lex_state = 524},
  [745] = {.lex_state = 524},
  [746] = {.lex_state = 524},
  [747] = {.lex_state = 524},
  [748] = {.lex_state = 524},
  [749] = {.lex_state = 524},
  [750] = {.lex_state = 524},
  [751] = {.lex_state = 524},
  [752] = {.lex_state = 524},
  [753] = {.lex_state = 524},
  [754] = {.lex_state = 524},
  [755] = {.lex_state = 524},
  [756] = {.lex_state = 11},
  [757] = {.lex_state = 10},
  [758] = {.lex_state = 10},
  [759] = {.lex_state = 3},
  [760] = {.lex_state = 10},
  [761] = {.lex_state = 10},
  [762] = {.lex_state = 10},
  [763] = {.lex_state = 10},
  [764] = {.lex_state = 10},
  [765] = {.lex_state = 10},
  [766] = {.lex_state = 8},
  [767] = {.lex_state = 8},
  [768] = {.lex_state = 8},
  [769] = {.lex_state = 8},
  [770] = {.lex_state = 8},
  [771] = {.lex_state = 8},
  [772] = {.lex_state = 8},
  [773] = {.lex_state = 8},
  [774] = {.lex_state = 8},
  [775] = {.lex_state = 8},
  [776] = {.lex_state = 8},
  [777] = {.lex_state = 8},
  [778] = {.lex_state = 8},
  [779] = {.lex_state = 8},
  [780] = {.lex_state = 8},
  [781] = {.lex_state = 8},
  [782] = {.lex_state = 8},
  [783] = {.lex_state = 8},
  [784] = {.lex_state = 8},
  [785] = {.lex_state = 8},
  [786] = {.lex_state = 8},
  [787] = {.lex_state = 8},
  [788] = {.lex_state = 8},
  [789] = {.lex_state = 8},
  [790] = {.lex_state = 8},
  [791] = {.lex_state = 8},
  [792] = {.lex_state = 8},
  [793] = {.lex_state = 8},
  [794] = {.lex_state = 8},
  [795] = {.lex_state = 8},
  [796] = {.lex_state = 8},
  [797] = {.lex_state = 8},
  [798] = {.lex_state = 8},
  [799] = {.lex_state = 8},
  [800] = {.lex_state = 8},
  [801] = {.lex_state = 8},
  [802] = {.lex_state = 8},
  [803] = {.lex_state = 8},
  [804] = {.lex_state = 8},
  [805] = {.lex_state = 8},
  [806] = {.lex_state = 8},
  [807] = {.lex_state = 8},
  [808] = {.lex_state = 8},
  [809] = {.lex_state = 8},
  [810] = {.lex_state = 8},
  [811] = {.lex_state = 8},
  [812] = {.lex_state = 8},
  [813] = {.lex_state = 8},
  [814] = {.lex_state = 8},
  [815] = {.lex_state = 8},
  [816] = {.lex_state = 8},
  [817] = {.lex_state = 8},
  [818] = {.lex_state = 8},
  [819] = {.lex_state = 8},
  [820] = {.lex_state = 8},
  [821] = {.lex_state = 8},
  [822] = {.lex_state = 8},
  [823] = {.lex_state = 8},
  [824] = {.lex_state = 8},
  [825] = {.lex_state = 8},
  [826] = {.lex_state = 8},
  [827] = {.lex_state = 8},
  [828] = {.lex_state = 8},
  [829] = {.lex_state = 8},
  [830] = {.lex_state = 10},
  [831] = {.lex_state = 10},
  [832] = {.lex_state = 10},
  [833] = {.lex_state = 17},
  [834] = {.lex_state = 10},
  [835] = {.lex_state = 10},
  [836] = {.lex_state = 10},
  [837] = {.lex_state = 10},
  [838] = {.lex_state = 10},
  [839] = {.lex_state = 10},
  [840] = {.lex_state = 10},
  [841] = {.lex_state = 10},
  [842] = {.lex_state = 10},
  [843] = {.lex_state = 10},
  [844] = {.lex_state = 10},
  [845] = {.lex_state = 10},
  [846] = {.lex_state = 10},
  [847] = {.lex_state = 10},
  [848] = {.lex_state = 10},
  [849] = {.lex_state = 10},
  [850] = {.lex_state = 10},
  [851] = {.lex_state = 16},
  [852] = {.lex_state = 10},
  [853] = {.lex_state = 16},
  [854] = {.lex_state = 10},
  [855] = {.lex_state = 10},
  [856] = {.lex_state = 16},
  [857] = {.lex_state = 16},
  [858] = {.lex_state = 10},
  [859] = {.lex_state = 10},
  [860] = {.lex_state = 10},
  [861] = {.lex_state = 10},
  [862] = {.lex_state = 10},
  [863] = {.lex_state = 16},
  [864] = {.lex_state = 10},
  [865] = {.lex_state = 10},
  [866] = {.lex_state = 10},
  [867] = {.lex_state = 16},
  [868] = {.lex_state = 10},
  [869] = {.lex_state = 10},
  [870] = {.lex_state = 10},
  [871] = {.lex_state = 16},
  [872] = {.lex_state = 16},
  [873] = {.lex_state = 16},
  [874] = {.lex_state = 16},
  [875] = {.lex_state = 16},
  [876] = {.lex_state = 16},
  [877] = {.lex_state = 10},
  [878] = {.lex_state = 10},
  [879] = {.lex_state = 8},
  [880] = {.lex_state = 8},
  [881] = {.lex_state = 10},
  [882] = {.lex_state = 8},
  [883] = {.lex_state = 10},
  [884] = {.lex_state = 10},
  [885] = {.lex_state = 10},
  [886] = {.lex_state = 10},
  [887] = {.lex_state = 8},
  [888] = {.lex_state = 10},
  [889] = {.lex_state = 10},
  [890] = {.lex_state = 10},
  [891] = {.lex_state = 10},
  [892] = {.lex_state = 10},
  [893] = {.lex_state = 10},
  [894] = {.lex_state = 10},
  [895] = {.lex_state = 10},
  [896] = {.lex_state = 10},
  [897] = {.lex_state = 10},
  [898] = {.lex_state = 10},
  [899] = {.lex_state = 10},
  [900] = {.lex_state = 10},
  [901] = {.lex_state = 10},
  [902] = {.lex_state = 10},
  [903] = {.lex_state = 10},
  [904] = {.lex_state = 10},
  [905] = {.lex_state = 10},
  [906] = {.lex_state = 10},
  [907] = {.lex_state = 10},
  [908] = {.lex_state = 10},
  [909] = {.lex_state = 10},
  [910] = {.lex_state = 10},
  [911] = {.lex_state = 10},
  [912] = {.lex_state = 10},
  [913] = {.lex_state = 10},
  [914] = {.lex_state = 8},
  [915] = {.lex_state = 10},
  [916] = {.lex_state = 10},
  [917] = {.lex_state = 10},
  [918] = {.lex_state = 10},
  [919] = {.lex_state = 8},
  [920] = {.lex_state = 10},
  [921] = {.lex_state = 10},
  [922] = {.lex_state = 10},
  [923] = {.lex_state = 10},
  [924] = {.lex_state = 10},
  [925] = {.lex_state = 10},
  [926] = {.lex_state = 10},
  [927] = {.lex_state = 10},
  [928] = {.lex_state = 10},
  [929] = {.lex_state = 10},
  [930] = {.lex_state = 10},
  [931] = {.lex_state = 10},
  [932] = {.lex_state = 10},
  [933] = {.lex_state = 10},
  [934] = {.lex_state = 10},
  [935] = {.lex_state = 10},
  [936] = {.lex_state = 10},
  [937] = {.lex_state = 10},
  [938] = {.lex_state = 10},
  [939] = {.lex_state = 10},
  [940] = {.lex_state = 10},
  [941] = {.lex_state = 10},
  [942] = {.lex_state = 10},
  [943] = {.lex_state = 10},
  [944] = {.lex_state = 10},
  [945] = {.lex_state = 10},
  [946] = {.lex_state = 10},
  [947] = {.lex_state = 10},
  [948] = {.lex_state = 10},
  [949] = {.lex_state = 10},
  [950] = {.lex_state = 10},
  [951] = {.lex_state = 10},
  [952] = {.lex_state = 10},
  [953] = {.lex_state = 10},
  [954] = {.lex_state = 10},
  [955] = {.lex_state = 10},
  [956] = {.lex_state = 10},
  [957] = {.lex_state = 10},
  [958] = {.lex_state = 10},
  [959] = {.lex_state = 10},
  [960] = {.lex_state = 10},
  [961] = {.lex_state = 10},
  [962] = {.lex_state = 10},
  [963] = {.lex_state = 10},
  [964] = {.lex_state = 10},
  [965] = {.lex_state = 10},
  [966] = {.lex_state = 10},
  [967] = {.lex_state = 8},
  [968] = {.lex_state = 10},
  [969] = {.lex_state = 10},
  [970] = {.lex_state = 10},
  [971] = {.lex_state = 10},
  [972] = {.lex_state = 10},
  [973] = {.lex_state = 10},
  [974] = {.lex_state = 10},
  [975] = {.lex_state = 10},
  [976] = {.lex_state = 10},
  [977] = {.lex_state = 10},
  [978] = {.lex_state = 10},
  [979] = {.lex_state = 10},
  [980] = {.lex_state = 10},
  [981] = {.lex_state = 10},
  [982] = {.lex_state = 10},
  [983] = {.lex_state = 10},
  [984] = {.lex_state = 10},
  [985] = {.lex_state = 10},
  [986] = {.lex_state = 10},
  [987] = {.lex_state = 10},
  [988] = {.lex_state = 10},
  [989] = {.lex_state = 10},
  [990] = {.lex_state = 10},
  [991] = {.lex_state = 10},
  [992] = {.lex_state = 10},
  [993] = {.lex_state = 10},
  [994] = {.lex_state = 10},
  [995] = {.lex_state = 10},
  [996] = {.lex_state = 10},
  [997] = {.lex_state = 10},
  [998] = {.lex_state = 10},
  [999] = {.lex_state = 10},
  [1000] = {.lex_state = 10},
  [1001] = {.lex_state = 10},
  [1002] = {.lex_state = 10},
  [1003] = {.lex_state = 10},
  [1004] = {.lex_state = 10},
  [1005] = {.lex_state = 10},
  [1006] = {.lex_state = 10},
  [1007] = {.lex_state = 10},
  [1008] = {.lex_state = 10},
  [1009] = {.lex_state = 10},
  [1010] = {.lex_state = 10},
  [1011] = {.lex_state = 10},
  [1012] = {.lex_state = 10},
  [1013] = {.lex_state = 10},
  [1014] = {.lex_state = 10},
  [1015] = {.lex_state = 10},
  [1016] = {.lex_state = 10},
  [1017] = {.lex_state = 10},
  [1018] = {.lex_state = 10},
  [1019] = {.lex_state = 10},
  [1020] = {.lex_state = 10},
  [1021] = {.lex_state = 10},
  [1022] = {.lex_state = 10},
  [1023] = {.lex_state = 10},
  [1024] = {.lex_state = 10},
  [1025] = {.lex_state = 10},
  [1026] = {.lex_state = 10},
  [1027] = {.lex_state = 10},
  [1028] = {.lex_state = 10},
  [1029] = {.lex_state = 10},
  [1030] = {.lex_state = 10},
  [1031] = {.lex_state = 10},
  [1032] = {.lex_state = 10},
  [1033] = {.lex_state = 10},
  [1034] = {.lex_state = 10},
  [1035] = {.lex_state = 10},
  [1036] = {.lex_state = 10},
  [1037] = {.lex_state = 10},
  [1038] = {.lex_state = 10},
  [1039] = {.lex_state = 10},
  [1040] = {.lex_state = 10},
  [1041] = {.lex_state = 10},
  [1042] = {.lex_state = 10},
  [1043] = {.lex_state = 10},
  [1044] = {.lex_state = 10},
  [1045] = {.lex_state = 10},
  [1046] = {.lex_state = 10},
  [1047] = {.lex_state = 10},
  [1048] = {.lex_state = 10},
  [1049] = {.lex_state = 10},
  [1050] = {.lex_state = 10},
  [1051] = {.lex_state = 10},
  [1052] = {.lex_state = 10},
  [1053] = {.lex_state = 10},
  [1054] = {.lex_state = 10},
  [1055] = {.lex_state = 10},
  [1056] = {.lex_state = 10},
  [1057] = {.lex_state = 10},
  [1058] = {.lex_state = 10},
  [1059] = {.lex_state = 10},
  [1060] = {.lex_state = 10},
  [1061] = {.lex_state = 10},
  [1062] = {.lex_state = 10},
  [1063] = {.lex_state = 10},
  [1064] = {.lex_state = 10},
  [1065] = {.lex_state = 10},
  [1066] = {.lex_state = 10},
  [1067] = {.lex_state = 10},
  [1068] = {.lex_state = 10},
  [1069] = {.lex_state = 10},
  [1070] = {.lex_state = 10},
  [1071] = {.lex_state = 10},
  [1072] = {.lex_state = 10},
  [1073] = {.lex_state = 10},
  [1074] = {.lex_state = 10},
  [1075] = {.lex_state = 10},
  [1076] = {.lex_state = 10},
  [1077] = {.lex_state = 10},
  [1078] = {.lex_state = 10},
  [1079] = {.lex_state = 10},
  [1080] = {.lex_state = 10},
  [1081] = {.lex_state = 10},
  [1082] = {.lex_state = 10},
  [1083] = {.lex_state = 10},
  [1084] = {.lex_state = 10},
  [1085] = {.lex_state = 10},
  [1086] = {.lex_state = 10},
  [1087] = {.lex_state = 10},
  [1088] = {.lex_state = 10},
  [1089] = {.lex_state = 10},
  [1090] = {.lex_state = 10},
  [1091] = {.lex_state = 10},
  [1092] = {.lex_state = 10},
  [1093] = {.lex_state = 10},
  [1094] = {.lex_state = 10},
  [1095] = {.lex_state = 10},
  [1096] = {.lex_state = 10},
  [1097] = {.lex_state = 10},
  [1098] = {.lex_state = 10},
  [1099] = {.lex_state = 10},
  [1100] = {.lex_state = 10},
  [1101] = {.lex_state = 10},
  [1102] = {.lex_state = 10},
  [1103] = {.lex_state = 10},
  [1104] = {.lex_state = 10},
  [1105] = {.lex_state = 10},
  [1106] = {.lex_state = 10},
  [1107] = {.lex_state = 10},
  [1108] = {.lex_state = 10},
  [1109] = {.lex_state = 10},
  [1110] = {.lex_state = 10},
  [1111] = {.lex_state = 10},
  [1112] = {.lex_state = 10},
  [1113] = {.lex_state = 10},
  [1114] = {.lex_state = 10},
  [1115] = {.lex_state = 10},
  [1116] = {.lex_state = 10},
  [1117] = {.lex_state = 10},
  [1118] = {.lex_state = 10},
  [1119] = {.lex_state = 10},
  [1120] = {.lex_state = 10},
  [1121] = {.lex_state = 10},
  [1122] = {.lex_state = 10},
  [1123] = {.lex_state = 10},
  [1124] = {.lex_state = 10},
  [1125] = {.lex_state = 10},
  [1126] = {.lex_state = 10},
  [1127] = {.lex_state = 10},
  [1128] = {.lex_state = 10},
  [1129] = {.lex_state = 10},
  [1130] = {.lex_state = 10},
  [1131] = {.lex_state = 10},
  [1132] = {.lex_state = 10},
  [1133] = {.lex_state = 10},
  [1134] = {.lex_state = 10},
  [1135] = {.lex_state = 10},
  [1136] = {.lex_state = 10},
  [1137] = {.lex_state = 10},
  [1138] = {.lex_state = 10},
  [1139] = {.lex_state = 10},
  [1140] = {.lex_state = 10},
  [1141] = {.lex_state = 10},
  [1142] = {.lex_state = 10},
  [1143] = {.lex_state = 10},
  [1144] = {.lex_state = 10},
  [1145] = {.lex_state = 10},
  [1146] = {.lex_state = 10},
  [1147] = {.lex_state = 10},
  [1148] = {.lex_state = 10},
  [1149] = {.lex_state = 10},
  [1150] = {.lex_state = 10},
  [1151] = {.lex_state = 10},
  [1152] = {.lex_state = 10},
  [1153] = {.lex_state = 10},
  [1154] = {.lex_state = 10},
  [1155] = {.lex_state = 10},
  [1156] = {.lex_state = 10},
  [1157] = {.lex_state = 10},
  [1158] = {.lex_state = 10},
  [1159] = {.lex_state = 10},
  [1160] = {.lex_state = 10},
  [1161] = {.lex_state = 10},
  [1162] = {.lex_state = 10},
  [1163] = {.lex_state = 10},
  [1164] = {.lex_state = 10},
  [1165] = {.lex_state = 10},
  [1166] = {.lex_state = 10},
  [1167] = {.lex_state = 10},
  [1168] = {.lex_state = 10},
  [1169] = {.lex_state = 10},
  [1170] = {.lex_state = 10},
  [1171] = {.lex_state = 10},
  [1172] = {.lex_state = 10},
  [1173] = {.lex_state = 10},
  [1174] = {.lex_state = 10},
  [1175] = {.lex_state = 10},
  [1176] = {.lex_state = 10},
  [1177] = {.lex_state = 10},
  [1178] = {.lex_state = 10},
  [1179] = {.lex_state = 10},
  [1180] = {.lex_state = 10},
  [1181] = {.lex_state = 10},
  [1182] = {.lex_state = 10},
  [1183] = {.lex_state = 10},
  [1184] = {.lex_state = 10},
  [1185] = {.lex_state = 10},
  [1186] = {.lex_state = 10},
  [1187] = {.lex_state = 10},
  [1188] = {.lex_state = 10},
  [1189] = {.lex_state = 10},
  [1190] = {.lex_state = 10},
  [1191] = {.lex_state = 10},
  [1192] = {.lex_state = 10},
  [1193] = {.lex_state = 10},
  [1194] = {.lex_state = 10},
  [1195] = {.lex_state = 10},
  [1196] = {.lex_state = 10},
  [1197] = {.lex_state = 10},
  [1198] = {.lex_state = 10},
  [1199] = {.lex_state = 10},
  [1200] = {.lex_state = 10},
  [1201] = {.lex_state = 10},
  [1202] = {.lex_state = 10},
  [1203] = {.lex_state = 10},
  [1204] = {.lex_state = 10},
  [1205] = {.lex_state = 8},
  [1206] = {.lex_state = 8},
  [1207] = {.lex_state = 8},
  [1208] = {.lex_state = 9},
  [1209] = {.lex_state = 9},
  [1210] = {.lex_state = 8},
  [1211] = {.lex_state = 8},
  [1212] = {.lex_state = 8},
  [1213] = {.lex_state = 8},
  [1214] = {.lex_state = 8},
  [1215] = {.lex_state = 9},
  [1216] = {.lex_state = 8},
  [1217] = {.lex_state = 8},
  [1218] = {.lex_state = 8},
  [1219] = {.lex_state = 9},
  [1220] = {.lex_state = 8},
  [1221] = {.lex_state = 8},
  [1222] = {.lex_state = 8},
  [1223] = {.lex_state = 10},
  [1224] = {.lex_state = 8},
  [1225] = {.lex_state = 8},
  [1226] = {.lex_state = 8},
  [1227] = {.lex_state = 8},
  [1228] = {.lex_state = 8},
  [1229] = {.lex_state = 8},
  [1230] = {.lex_state = 8},
  [1231] = {.lex_state = 8},
  [1232] = {.lex_state = 8},
  [1233] = {.lex_state = 8},
  [1234] = {.lex_state = 8},
  [1235] = {.lex_state = 8},
  [1236] = {.lex_state = 8},
  [1237] = {.lex_state = 8},
  [1238] = {.lex_state = 8},
  [1239] = {.lex_state = 8},
  [1240] = {.lex_state = 8},
  [1241] = {.lex_state = 8},
  [1242] = {.lex_state = 8},
  [1243] = {.lex_state = 8},
  [1244] = {.lex_state = 8},
  [1245] = {.lex_state = 8},
  [1246] = {.lex_state = 8},
  [1247] = {.lex_state = 8},
  [1248] = {.lex_state = 10},
  [1249] = {.lex_state = 521},
  [1250] = {.lex_state = 0},
  [1251] = {.lex_state = 0},
  [1252] = {.lex_state = 0},
  [1253] = {.lex_state = 0},
  [1254] = {.lex_state = 0},
  [1255] = {.lex_state = 0},
  [1256] = {.lex_state = 0},
  [1257] = {.lex_state = 0},
  [1258] = {.lex_state = 0},
  [1259] = {.lex_state = 0},
  [1260] = {.lex_state = 0},
  [1261] = {.lex_state = 0},
  [1262] = {.lex_state = 0},
  [1263] = {.lex_state = 0},
  [1264] = {.lex_state = 0},
  [1265] = {.lex_state = 9},
  [1266] = {.lex_state = 9},
  [1267] = {.lex_state = 9},
  [1268] = {.lex_state = 9},
  [1269] = {.lex_state = 9},
  [1270] = {.lex_state = 9},
  [1271] = {.lex_state = 9},
  [1272] = {.lex_state = 9},
  [1273] = {.lex_state = 9},
  [1274] = {.lex_state = 9},
  [1275] = {.lex_state = 9},
  [1276] = {.lex_state = 9},
  [1277] = {.lex_state = 9},
  [1278] = {.lex_state = 9},
  [1279] = {.lex_state = 9},
  [1280] = {.lex_state = 9},
  [1281] = {.lex_state = 9},
  [1282] = {.lex_state = 9},
  [1283] = {.lex_state = 9},
  [1284] = {.lex_state = 9},
  [1285] = {.lex_state = 9},
  [1286] = {.lex_state = 9},
  [1287] = {.lex_state = 9},
  [1288] = {.lex_state = 9},
  [1289] = {.lex_state = 9},
  [1290] = {.lex_state = 9},
  [1291] = {.lex_state = 9},
  [1292] = {.lex_state = 9},
  [1293] = {.lex_state = 9},
  [1294] = {.lex_state = 9},
  [1295] = {.lex_state = 9},
  [1296] = {.lex_state = 9},
  [1297] = {.lex_state = 9},
  [1298] = {.lex_state = 9},
  [1299] = {.lex_state = 9},
  [1300] = {.lex_state = 9},
  [1301] = {.lex_state = 9},
  [1302] = {.lex_state = 9},
  [1303] = {.lex_state = 9},
  [1304] = {.lex_state = 9},
  [1305] = {.lex_state = 9},
  [1306] = {.lex_state = 9},
  [1307] = {.lex_state = 9},
  [1308] = {.lex_state = 9},
  [1309] = {.lex_state = 9},
  [1310] = {.lex_state = 9},
  [1311] = {.lex_state = 9},
  [1312] = {.lex_state = 9},
  [1313] = {.lex_state = 9},
  [1314] = {.lex_state = 9},
  [1315] = {.lex_state = 9},
  [1316] = {.lex_state = 9},
  [1317] = {.lex_state = 9},
  [1318] = {.lex_state = 9},
  [1319] = {.lex_state = 9},
  [1320] = {.lex_state = 9},
  [1321] = {.lex_state = 9},
  [1322] = {.lex_state = 9},
  [1323] = {.lex_state = 9},
  [1324] = {.lex_state = 9},
  [1325] = {.lex_state = 9},
  [1326] = {.lex_state = 9},
  [1327] = {.lex_state = 9},
  [1328] = {.lex_state = 9},
  [1329] = {.lex_state = 9},
  [1330] = {.lex_state = 9},
  [1331] = {.lex_state = 9},
  [1332] = {.lex_state = 9},
  [1333] = {.lex_state = 9},
  [1334] = {.lex_state = 9},
  [1335] = {.lex_state = 9},
  [1336] = {.lex_state = 9},
  [1337] = {.lex_state = 9},
  [1338] = {.lex_state = 9},
  [1339] = {.lex_state = 9},
  [1340] = {.lex_state = 9},
  [1341] = {.lex_state = 9},
  [1342] = {.lex_state = 9},
  [1343] = {.lex_state = 9},
  [1344] = {.lex_state = 9},
  [1345] = {.lex_state = 9},
  [1346] = {.lex_state = 9},
  [1347] = {.lex_state = 9},
  [1348] = {.lex_state = 9},
  [1349] = {.lex_state = 9},
  [1350] = {.lex_state = 9},
  [1351] = {.lex_state = 9},
  [1352] = {.lex_state = 9},
  [1353] = {.lex_state = 9},
  [1354] = {.lex_state = 9},
  [1355] = {.lex_state = 9},
  [1356] = {.lex_state = 9},
  [1357] = {.lex_state = 9},
  [1358] = {.lex_state = 9},
  [1359] = {.lex_state = 9},
  [1360] = {.lex_state = 9},
  [1361] = {.lex_state = 9},
  [1362] = {.lex_state = 9},
  [1363] = {.lex_state = 9},
  [1364] = {.lex_state = 9},
  [1365] = {.lex_state = 9},
  [1366] = {.lex_state = 9},
  [1367] = {.lex_state = 9},
  [1368] = {.lex_state = 9},
  [1369] = {.lex_state = 9},
  [1370] = {.lex_state = 9},
  [1371] = {.lex_state = 9},
  [1372] = {.lex_state = 9},
  [1373] = {.lex_state = 9},
  [1374] = {.lex_state = 9},
  [1375] = {.lex_state = 9},
  [1376] = {.lex_state = 9},
  [1377] = {.lex_state = 9},
  [1378] = {.lex_state = 9},
  [1379] = {.lex_state = 9},
  [1380] = {.lex_state = 9},
  [1381] = {.lex_state = 9},
  [1382] = {.lex_state = 9},
  [1383] = {.lex_state = 9},
  [1384] = {.lex_state = 9},
  [1385] = {.lex_state = 9},
  [1386] = {.lex_state = 9},
  [1387] = {.lex_state = 9},
  [1388] = {.lex_state = 9},
  [1389] = {.lex_state = 9},
  [1390] = {.lex_state = 9},
  [1391] = {.lex_state = 9},
  [1392] = {.lex_state = 9},
  [1393] = {.lex_state = 9},
  [1394] = {.lex_state = 9},
  [1395] = {.lex_state = 9},
  [1396] = {.lex_state = 9},
  [1397] = {.lex_state = 9},
  [1398] = {.lex_state = 9},
  [1399] = {.lex_state = 9},
  [1400] = {.lex_state = 9},
  [1401] = {.lex_state = 9},
  [1402] = {.lex_state = 9},
  [1403] = {.lex_state = 9},
  [1404] = {.lex_state = 9},
  [1405] = {.lex_state = 9},
  [1406] = {.lex_state = 9},
  [1407] = {.lex_state = 9},
  [1408] = {.lex_state = 9},
  [1409] = {.lex_state = 9},
  [1410] = {.lex_state = 9},
  [1411] = {.lex_state = 9},
  [1412] = {.lex_state = 9},
  [1413] = {.lex_state = 9},
  [1414] = {.lex_state = 9},
  [1415] = {.lex_state = 9},
  [1416] = {.lex_state = 9},
  [1417] = {.lex_state = 9},
  [1418] = {.lex_state = 9},
  [1419] = {.lex_state = 9},
  [1420] = {.lex_state = 9},
  [1421] = {.lex_state = 9},
  [1422] = {.lex_state = 9},
  [1423] = {.lex_state = 9},
  [1424] = {.lex_state = 9},
  [1425] = {.lex_state = 9},
  [1426] = {.lex_state = 9},
  [1427] = {.lex_state = 9},
  [1428] = {.lex_state = 9},
  [1429] = {.lex_state = 9},
  [1430] = {.lex_state = 9},
  [1431] = {.lex_state = 9},
  [1432] = {.lex_state = 9},
  [1433] = {.lex_state = 9},
  [1434] = {.lex_state = 9},
  [1435] = {.lex_state = 9},
  [1436] = {.lex_state = 9},
  [1437] = {.lex_state = 9},
  [1438] = {.lex_state = 9},
  [1439] = {.lex_state = 9},
  [1440] = {.lex_state = 9},
  [1441] = {.lex_state = 9},
  [1442] = {.lex_state = 9},
  [1443] = {.lex_state = 9},
  [1444] = {.lex_state = 9},
  [1445] = {.lex_state = 9},
  [1446] = {.lex_state = 9},
  [1447] = {.lex_state = 9},
  [1448] = {.lex_state = 9},
  [1449] = {.lex_state = 9},
  [1450] = {.lex_state = 9},
  [1451] = {.lex_state = 9},
  [1452] = {.lex_state = 9},
  [1453] = {.lex_state = 9},
  [1454] = {.lex_state = 9},
  [1455] = {.lex_state = 9},
  [1456] = {.lex_state = 9},
  [1457] = {.lex_state = 9},
  [1458] = {.lex_state = 9},
  [1459] = {.lex_state = 9},
  [1460] = {.lex_state = 9},
  [1461] = {.lex_state = 9},
  [1462] = {.lex_state = 9},
  [1463] = {.lex_state = 9},
  [1464] = {.lex_state = 9},
  [1465] = {.lex_state = 9},
  [1466] = {.lex_state = 9},
  [1467] = {.lex_state = 9},
  [1468] = {.lex_state = 9},
  [1469] = {.lex_state = 9},
  [1470] = {.lex_state = 9},
  [1471] = {.lex_state = 9},
  [1472] = {.lex_state = 9},
  [1473] = {.lex_state = 9},
  [1474] = {.lex_state = 9},
  [1475] = {.lex_state = 9},
  [1476] = {.lex_state = 9},
  [1477] = {.lex_state = 9},
  [1478] = {.lex_state = 9},
  [1479] = {.lex_state = 9},
  [1480] = {.lex_state = 9},
  [1481] = {.lex_state = 9},
  [1482] = {.lex_state = 9},
  [1483] = {.lex_state = 9},
  [1484] = {.lex_state = 9},
  [1485] = {.lex_state = 9},
  [1486] = {.lex_state = 9},
  [1487] = {.lex_state = 9},
  [1488] = {.lex_state = 9},
  [1489] = {.lex_state = 9},
  [1490] = {.lex_state = 9},
  [1491] = {.lex_state = 9},
  [1492] = {.lex_state = 9},
  [1493] = {.lex_state = 9},
  [1494] = {.lex_state = 9},
  [1495] = {.lex_state = 9},
  [1496] = {.lex_state = 9},
  [1497] = {.lex_state = 9},
  [1498] = {.lex_state = 9},
  [1499] = {.lex_state = 9},
  [1500] = {.lex_state = 9},
  [1501] = {.lex_state = 9},
  [1502] = {.lex_state = 9},
  [1503] = {.lex_state = 9},
  [1504] = {.lex_state = 9},
  [1505] = {.lex_state = 9},
  [1506] = {.lex_state = 9},
  [1507] = {.lex_state = 9},
  [1508] = {.lex_state = 9},
  [1509] = {.lex_state = 9},
  [1510] = {.lex_state = 9},
  [1511] = {.lex_state = 9},
  [1512] = {.lex_state = 9},
  [1513] = {.lex_state = 9},
  [1514] = {.lex_state = 9},
  [1515] = {.lex_state = 9},
  [1516] = {.lex_state = 9},
  [1517] = {.lex_state = 9},
  [1518] = {.lex_state = 9},
  [1519] = {.lex_state = 9},
  [1520] = {.lex_state = 9},
  [1521] = {.lex_state = 9},
  [1522] = {.lex_state = 9},
  [1523] = {.lex_state = 9},
  [1524] = {.lex_state = 9},
  [1525] = {.lex_state = 9},
  [1526] = {.lex_state = 9},
  [1527] = {.lex_state = 9},
  [1528] = {.lex_state = 9},
  [1529] = {.lex_state = 9},
  [1530] = {.lex_state = 9},
  [1531] = {.lex_state = 9},
  [1532] = {.lex_state = 9},
  [1533] = {.lex_state = 9},
  [1534] = {.lex_state = 9},
  [1535] = {.lex_state = 9},
  [1536] = {.lex_state = 9},
  [1537] = {.lex_state = 9},
  [1538] = {.lex_state = 9},
  [1539] = {.lex_state = 9},
  [1540] = {.lex_state = 9},
  [1541] = {.lex_state = 9},
  [1542] = {.lex_state = 9},
  [1543] = {.lex_state = 9},
  [1544] = {.lex_state = 9},
  [1545] = {.lex_state = 9},
  [1546] = {.lex_state = 9},
  [1547] = {.lex_state = 9},
  [1548] = {.lex_state = 9},
  [1549] = {.lex_state = 9},
  [1550] = {.lex_state = 9},
  [1551] = {.lex_state = 9},
  [1552] = {.lex_state = 9},
  [1553] = {.lex_state = 9},
  [1554] = {.lex_state = 9},
  [1555] = {.lex_state = 9},
  [1556] = {.lex_state = 9},
  [1557] = {.lex_state = 9},
  [1558] = {.lex_state = 9},
  [1559] = {.lex_state = 9},
  [1560] = {.lex_state = 9},
  [1561] = {.lex_state = 9},
  [1562] = {.lex_state = 9},
  [1563] = {.lex_state = 9},
  [1564] = {.lex_state = 9},
  [1565] = {.lex_state = 9},
  [1566] = {.lex_state = 9},
  [1567] = {.lex_state = 9},
  [1568] = {.lex_state = 9},
  [1569] = {.lex_state = 9},
  [1570] = {.lex_state = 9},
  [1571] = {.lex_state = 9},
  [1572] = {.lex_state = 9},
  [1573] = {.lex_state = 9},
  [1574] = {.lex_state = 9},
  [1575] = {.lex_state = 9},
  [1576] = {.lex_state = 9},
  [1577] = {.lex_state = 9},
  [1578] = {.lex_state = 9},
  [1579] = {.lex_state = 9},
  [1580] = {.lex_state = 9},
  [1581] = {.lex_state = 9},
  [1582] = {.lex_state = 9},
  [1583] = {.lex_state = 9},
  [1584] = {.lex_state = 9},
  [1585] = {.lex_state = 9},
  [1586] = {.lex_state = 9},
  [1587] = {.lex_state = 9},
  [1588] = {.lex_state = 9},
  [1589] = {.lex_state = 9},
  [1590] = {.lex_state = 9},
  [1591] = {.lex_state = 9},
  [1592] = {.lex_state = 9},
  [1593] = {.lex_state = 9},
  [1594] = {.lex_state = 9},
  [1595] = {.lex_state = 9},
  [1596] = {.lex_state = 9},
  [1597] = {.lex_state = 9},
  [1598] = {.lex_state = 9},
  [1599] = {.lex_state = 0},
  [1600] = {.lex_state = 9},
  [1601] = {.lex_state = 9},
  [1602] = {.lex_state = 9},
  [1603] = {.lex_state = 0},
  [1604] = {.lex_state = 9},
  [1605] = {.lex_state = 0},
  [1606] = {.lex_state = 9},
  [1607] = {.lex_state = 9},
  [1608] = {.lex_state = 20},
  [1609] = {.lex_state = 20},
  [1610] = {.lex_state = 20},
  [1611] = {.lex_state = 20},
  [1612] = {.lex_state = 20},
  [1613] = {.lex_state = 20},
  [1614] = {.lex_state = 20},
  [1615] = {.lex_state = 20},
  [1616] = {.lex_state = 20},
  [1617] = {.lex_state = 20},
  [1618] = {.lex_state = 20},
  [1619] = {.lex_state = 20},
  [1620] = {.lex_state = 20},
  [1621] = {.lex_state = 20},
  [1622] = {.lex_state = 20},
  [1623] = {.lex_state = 20},
  [1624] = {.lex_state = 9},
  [1625] = {.lex_state = 20},
  [1626] = {.lex_state = 20},
  [1627] = {.lex_state = 20},
  [1628] = {.lex_state = 20},
  [1629] = {.lex_state = 20},
  [1630] = {.lex_state = 20},
  [1631] = {.lex_state = 9},
  [1632] = {.lex_state = 20},
  [1633] = {.lex_state = 20},
  [1634] = {.lex_state = 20},
  [1635] = {.lex_state = 20},
  [1636] = {.lex_state = 20},
  [1637] = {.lex_state = 20},
  [1638] = {.lex_state = 20},
  [1639] = {.lex_state = 20},
  [1640] = {.lex_state = 20},
  [1641] = {.lex_state = 20},
  [1642] = {.lex_state = 20},
  [1643] = {.lex_state = 0},
  [1644] = {.lex_state = 0},
  [1645] = {.lex_state = 0},
  [1646] = {.lex_state = 20},
  [1647] = {.lex_state = 0},
  [1648] = {.lex_state = 20},
  [1649] = {.lex_state = 20},
  [1650] = {.lex_state = 20},
  [1651] = {.lex_state = 20},
  [1652] = {.lex_state = 20},
  [1653] = {.lex_state = 0},
  [1654] = {.lex_state = 20},
  [1655] = {.lex_state = 20},
  [1656] = {.lex_state = 20},
  [1657] = {.lex_state = 20},
  [1658] = {.lex_state = 20},
  [1659] = {.lex_state = 20},
  [1660] = {.lex_state = 20},
  [1661] = {.lex_state = 20},
  [1662] = {.lex_state = 0},
  [1663] = {.lex_state = 0},
  [1664] = {.lex_state = 20},
  [1665] = {.lex_state = 0},
  [1666] = {.lex_state = 20},
  [1667] = {.lex_state = 0},
  [1668] = {.lex_state = 0},
  [1669] = {.lex_state = 521},
  [1670] = {.lex_state = 0},
  [1671] = {.lex_state = 0},
  [1672] = {.lex_state = 0},
  [1673] = {.lex_state = 0},
  [1674] = {.lex_state = 0},
  [1675] = {.lex_state = 0},
  [1676] = {.lex_state = 0},
  [1677] = {.lex_state = 20},
  [1678] = {.lex_state = 20},
  [1679] = {.lex_state = 20},
  [1680] = {.lex_state = 20},
  [1681] = {.lex_state = 20},
  [1682] = {.lex_state = 0},
  [1683] = {.lex_state = 20},
  [1684] = {.lex_state = 0},
  [1685] = {.lex_state = 20},
  [1686] = {.lex_state = 20},
  [1687] = {.lex_state = 20},
  [1688] = {.lex_state = 0},
  [1689] = {.lex_state = 20},
  [1690] = {.lex_state = 20},
  [1691] = {.lex_state = 0},
  [1692] = {.lex_state = 20},
  [1693] = {.lex_state = 20},
  [1694] = {.lex_state = 0},
  [1695] = {.lex_state = 0},
  [1696] = {.lex_state = 0},
  [1697] = {.lex_state = 0},
  [1698] = {.lex_state = 20},
  [1699] = {.lex_state = 20},
  [1700] = {.lex_state = 0},
  [1701] = {.lex_state = 20},
  [1702] = {.lex_state = 20},
  [1703] = {.lex_state = 20},
  [1704] = {.lex_state = 0},
  [1705] = {.lex_state = 0},
  [1706] = {.lex_state = 20},
  [1707] = {.lex_state = 0},
  [1708] = {.lex_state = 0},
  [1709] = {.lex_state = 20},
  [1710] = {.lex_state = 20},
  [1711] = {.lex_state = 0},
  [1712] = {.lex_state = 0},
  [1713] = {.lex_state = 20},
  [1714] = {.lex_state = 20},
  [1715] = {.lex_state = 0},
  [1716] = {.lex_state = 0},
  [1717] = {.lex_state = 0},
  [1718] = {.lex_state = 20},
  [1719] = {.lex_state = 20},
  [1720] = {.lex_state = 20},
  [1721] = {.lex_state = 20},
  [1722] = {.lex_state = 20},
  [1723] = {.lex_state = 0},
  [1724] = {.lex_state = 0},
  [1725] = {.lex_state = 20},
  [1726] = {.lex_state = 0},
  [1727] = {.lex_state = 20},
  [1728] = {.lex_state = 0},
  [1729] = {.lex_state = 0},
  [1730] = {.lex_state = 20},
  [1731] = {.lex_state = 20},
  [1732] = {.lex_state = 0},
  [1733] = {.lex_state = 0},
  [1734] = {.lex_state = 0},
  [1735] = {.lex_state = 0},
  [1736] = {.lex_state = 20},
  [1737] = {.lex_state = 0},
  [1738] = {.lex_state = 20},
  [1739] = {.lex_state = 0},
  [1740] = {.lex_state = 0},
  [1741] = {.lex_state = 0},
  [1742] = {.lex_state = 20},
  [1743] = {.lex_state = 20},
  [1744] = {.lex_state = 20},
  [1745] = {.lex_state = 20},
  [1746] = {.lex_state = 0},
  [1747] = {.lex_state = 0},
  [1748] = {.lex_state = 0},
  [1749] = {.lex_state = 0},
  [1750] = {.lex_state = 0},
  [1751] = {.lex_state = 20},
  [1752] = {.lex_state = 20},
  [1753] = {.lex_state = 0},
  [1754] = {.lex_state = 0},
  [1755] = {.lex_state = 0},
  [1756] = {.lex_state = 20},
  [1757] = {.lex_state = 0},
  [1758] = {.lex_state = 20},
  [1759] = {.lex_state = 20},
  [1760] = {.lex_state = 0},
  [1761] = {.lex_state = 0},
  [1762] = {.lex_state = 20},
  [1763] = {.lex_state = 20},
  [1764] = {.lex_state = 20},
  [1765] = {.lex_state = 20},
  [1766] = {.lex_state = 20},
  [1767] = {.lex_state = 0},
  [1768] = {.lex_state = 20},
  [1769] = {.lex_state = 0},
  [1770] = {.lex_state = 0},
  [1771] = {.lex_state = 20},
  [1772] = {.lex_state = 20},
  [1773] = {.lex_state = 20},
  [1774] = {.lex_state = 0},
  [1775] = {.lex_state = 0},
  [1776] = {.lex_state = 20},
  [1777] = {.lex_state = 0},
  [1778] = {.lex_state = 0},
  [1779] = {.lex_state = 20},
  [1780] = {.lex_state = 20},
  [1781] = {.lex_state = 20},
  [1782] = {.lex_state = 0},
  [1783] = {.lex_state = 0},
  [1784] = {.lex_state = 20},
  [1785] = {.lex_state = 20},
  [1786] = {.lex_state = 20},
  [1787] = {.lex_state = 20},
  [1788] = {.lex_state = 0},
  [1789] = {.lex_state = 20},
  [1790] = {.lex_state = 20},
  [1791] = {.lex_state = 0},
  [1792] = {.lex_state = 20},
  [1793] = {.lex_state = 0},
  [1794] = {.lex_state = 0},
  [1795] = {.lex_state = 20},
  [1796] = {.lex_state = 20},
  [1797] = {.lex_state = 20},
  [1798] = {.lex_state = 20},
  [1799] = {.lex_state = 0},
  [1800] = {.lex_state = 0},
  [1801] = {.lex_state = 20},
  [1802] = {.lex_state = 0},
  [1803] = {.lex_state = 0},
  [1804] = {.lex_state = 0},
  [1805] = {.lex_state = 0},
  [1806] = {.lex_state = 0},
  [1807] = {.lex_state = 0},
  [1808] = {.lex_state = 0},
  [1809] = {.lex_state = 0},
  [1810] = {.lex_state = 0},
  [1811] = {.lex_state = 0},
  [1812] = {.lex_state = 0},
  [1813] = {.lex_state = 0},
  [1814] = {.lex_state = 0},
  [1815] = {.lex_state = 0},
  [1816] = {.lex_state = 0},
  [1817] = {.lex_state = 0},
  [1818] = {.lex_state = 0},
  [1819] = {.lex_state = 0},
  [1820] = {.lex_state = 0},
  [1821] = {.lex_state = 0},
  [1822] = {.lex_state = 0},
  [1823] = {.lex_state = 0},
  [1824] = {.lex_state = 0},
  [1825] = {.lex_state = 0},
  [1826] = {.lex_state = 0},
  [1827] = {.lex_state = 0},
  [1828] = {.lex_state = 0},
  [1829] = {.lex_state = 0},
  [1830] = {.lex_state = 0},
  [1831] = {.lex_state = 0},
  [1832] = {.lex_state = 0},
  [1833] = {.lex_state = 0},
  [1834] = {.lex_state = 0},
  [1835] = {.lex_state = 0},
  [1836] = {.lex_state = 0},
  [1837] = {.lex_state = 0},
  [1838] = {.lex_state = 0},
  [1839] = {.lex_state = 0},
  [1840] = {.lex_state = 0},
  [1841] = {.lex_state = 0},
  [1842] = {.lex_state = 0},
  [1843] = {.lex_state = 0},
  [1844] = {.lex_state = 0},
  [1845] = {.lex_state = 18},
  [1846] = {.lex_state = 0},
  [1847] = {.lex_state = 0},
  [1848] = {.lex_state = 0},
  [1849] = {.lex_state = 0},
  [1850] = {.lex_state = 0},
  [1851] = {.lex_state = 0},
  [1852] = {.lex_state = 19},
  [1853] = {.lex_state = 0},
  [1854] = {.lex_state = 20},
  [1855] = {.lex_state = 20},
  [1856] = {.lex_state = 20},
  [1857] = {.lex_state = 0},
  [1858] = {.lex_state = 0},
  [1859] = {.lex_state = 0},
  [1860] = {.lex_state = 20},
  [1861] = {.lex_state = 0},
  [1862] = {.lex_state = 0},
  [1863] = {.lex_state = 0},
  [1864] = {.lex_state = 0},
  [1865] = {.lex_state = 0},
  [1866] = {.lex_state = 20},
  [1867] = {.lex_state = 0},
  [1868] = {.lex_state = 0},
  [1869] = {.lex_state = 0},
  [1870] = {.lex_state = 0},
  [1871] = {.lex_state = 20},
  [1872] = {.lex_state = 0},
  [1873] = {.lex_state = 0},
  [1874] = {.lex_state = 0},
  [1875] = {.lex_state = 19},
  [1876] = {.lex_state = 0},
  [1877] = {.lex_state = 0},
  [1878] = {.lex_state = 0},
  [1879] = {.lex_state = 0},
  [1880] = {.lex_state = 0},
  [1881] = {.lex_state = 0},
  [1882] = {.lex_state = 0},
  [1883] = {.lex_state = 0},
  [1884] = {.lex_state = 0},
  [1885] = {.lex_state = 19},
  [1886] = {.lex_state = 0},
  [1887] = {.lex_state = 0},
  [1888] = {.lex_state = 0},
  [1889] = {.lex_state = 19},
  [1890] = {.lex_state = 0},
  [1891] = {.lex_state = 19},
  [1892] = {.lex_state = 0},
  [1893] = {.lex_state = 19},
  [1894] = {.lex_state = 0},
  [1895] = {.lex_state = 0},
  [1896] = {.lex_state = 19},
  [1897] = {.lex_state = 0},
  [1898] = {.lex_state = 8},
  [1899] = {.lex_state = 19},
  [1900] = {.lex_state = 8},
  [1901] = {.lex_state = 19},
  [1902] = {.lex_state = 19},
  [1903] = {.lex_state = 0},
  [1904] = {.lex_state = 0},
  [1905] = {.lex_state = 0},
  [1906] = {.lex_state = 0},
  [1907] = {.lex_state = 0},
  [1908] = {.lex_state = 0},
  [1909] = {.lex_state = 0},
  [1910] = {.lex_state = 19},
  [1911] = {.lex_state = 0},
  [1912] = {.lex_state = 19},
  [1913] = {.lex_state = 0},
  [1914] = {.lex_state = 0},
  [1915] = {.lex_state = 0},
  [1916] = {.lex_state = 0},
  [1917] = {.lex_state = 0},
  [1918] = {.lex_state = 0},
  [1919] = {.lex_state = 19},
  [1920] = {.lex_state = 0},
  [1921] = {.lex_state = 19},
  [1922] = {.lex_state = 22},
  [1923] = {.lex_state = 0},
  [1924] = {.lex_state = 19},
  [1925] = {.lex_state = 19},
  [1926] = {.lex_state = 19},
  [1927] = {.lex_state = 19},
  [1928] = {.lex_state = 21},
  [1929] = {.lex_state = 19},
  [1930] = {.lex_state = 19},
  [1931] = {.lex_state = 19},
  [1932] = {.lex_state = 19},
  [1933] = {.lex_state = 19},
  [1934] = {.lex_state = 19},
  [1935] = {.lex_state = 19},
  [1936] = {.lex_state = 21},
  [1937] = {.lex_state = 21},
  [1938] = {.lex_state = 19},
  [1939] = {.lex_state = 19},
  [1940] = {.lex_state = 19},
  [1941] = {.lex_state = 19},
  [1942] = {.lex_state = 19},
  [1943] = {.lex_state = 22},
  [1944] = {.lex_state = 19},
  [1945] = {.lex_state = 0},
  [1946] = {.lex_state = 0},
  [1947] = {.lex_state = 8},
  [1948] = {.lex_state = 8},
  [1949] = {.lex_state = 19},
  [1950] = {.lex_state = 8},
  [1951] = {.lex_state = 8},
  [1952] = {.lex_state = 8},
  [1953] = {.lex_state = 0},
  [1954] = {.lex_state = 8},
  [1955] = {.lex_state = 19},
  [1956] = {.lex_state = 8},
  [1957] = {.lex_state = 8},
  [1958] = {.lex_state = 8},
  [1959] = {.lex_state = 8},
  [1960] = {.lex_state = 8},
  [1961] = {.lex_state = 0},
  [1962] = {.lex_state = 8},
  [1963] = {.lex_state = 8},
  [1964] = {.lex_state = 8},
  [1965] = {.lex_state = 8},
  [1966] = {.lex_state = 8},
  [1967] = {.lex_state = 8},
  [1968] = {.lex_state = 8},
  [1969] = {.lex_state = 8},
  [1970] = {.lex_state = 8},
  [1971] = {.lex_state = 8},
  [1972] = {.lex_state = 8},
  [1973] = {.lex_state = 8},
  [1974] = {.lex_state = 8},
  [1975] = {.lex_state = 8},
  [1976] = {.lex_state = 8},
  [1977] = {.lex_state = 8},
  [1978] = {.lex_state = 521},
  [1979] = {.lex_state = 8},
  [1980] = {.lex_state = 0},
  [1981] = {.lex_state = 8},
  [1982] = {.lex_state = 19},
  [1983] = {.lex_state = 0},
  [1984] = {.lex_state = 0},
  [1985] = {.lex_state = 521},
  [1986] = {.lex_state = 0},
  [1987] = {.lex_state = 0},
  [1988] = {.lex_state = 0},
  [1989] = {.lex_state = 0},
  [1990] = {.lex_state = 521},
  [1991] = {.lex_state = 0},
  [1992] = {.lex_state = 19},
  [1993] = {.lex_state = 0},
  [1994] = {.lex_state = 0},
  [1995] = {.lex_state = 19},
  [1996] = {.lex_state = 521},
  [1997] = {.lex_state = 0},
  [1998] = {.lex_state = 19},
  [1999] = {.lex_state = 0},
  [2000] = {.lex_state = 0},
  [2001] = {.lex_state = 19},
  [2002] = {.lex_state = 521},
  [2003] = {.lex_state = 0},
  [2004] = {.lex_state = 19},
  [2005] = {.lex_state = 0},
  [2006] = {.lex_state = 0},
  [2007] = {.lex_state = 0},
  [2008] = {.lex_state = 19},
  [2009] = {.lex_state = 0},
  [2010] = {.lex_state = 0},
  [2011] = {.lex_state = 0},
  [2012] = {.lex_state = 521},
  [2013] = {.lex_state = 0},
  [2014] = {.lex_state = 19},
  [2015] = {.lex_state = 8},
  [2016] = {.lex_state = 0},
  [2017] = {.lex_state = 0},
  [2018] = {.lex_state = 521},
  [2019] = {.lex_state = 0},
  [2020] = {.lex_state = 19},
  [2021] = {.lex_state = 0},
  [2022] = {.lex_state = 0},
  [2023] = {.lex_state = 19},
  [2024] = {.lex_state = 521},
  [2025] = {.lex_state = 0},
  [2026] = {.lex_state = 19},
  [2027] = {.lex_state = 19},
  [2028] = {.lex_state = 0},
  [2029] = {.lex_state = 521},
  [2030] = {.lex_state = 0},
  [2031] = {.lex_state = 19},
  [2032] = {.lex_state = 0},
  [2033] = {.lex_state = 19},
  [2034] = {.lex_state = 0},
  [2035] = {.lex_state = 521},
  [2036] = {.lex_state = 0},
  [2037] = {.lex_state = 521},
  [2038] = {.lex_state = 0},
  [2039] = {.lex_state = 8},
  [2040] = {.lex_state = 0},
  [2041] = {.lex_state = 0},
  [2042] = {.lex_state = 521},
  [2043] = {.lex_state = 0},
  [2044] = {.lex_state = 0},
  [2045] = {.lex_state = 8},
  [2046] = {.lex_state = 8},
  [2047] = {.lex_state = 0},
  [2048] = {.lex_state = 19},
  [2049] = {.lex_state = 0},
  [2050] = {.lex_state = 21},
  [2051] = {.lex_state = 0},
  [2052] = {.lex_state = 19},
  [2053] = {.lex_state = 0},
  [2054] = {.lex_state = 0},
  [2055] = {.lex_state = 0},
  [2056] = {.lex_state = 0},
  [2057] = {.lex_state = 8},
  [2058] = {.lex_state = 0},
  [2059] = {.lex_state = 0},
  [2060] = {.lex_state = 8},
  [2061] = {.lex_state = 0},
  [2062] = {.lex_state = 0},
  [2063] = {.lex_state = 8},
  [2064] = {.lex_state = 8},
  [2065] = {.lex_state = 23},
  [2066] = {.lex_state = 0},
  [2067] = {.lex_state = 0},
  [2068] = {.lex_state = 8},
  [2069] = {.lex_state = 8},
  [2070] = {.lex_state = 8},
  [2071] = {.lex_state = 0},
  [2072] = {.lex_state = 8},
  [2073] = {.lex_state = 0},
  [2074] = {.lex_state = 8},
  [2075] = {.lex_state = 8},
  [2076] = {.lex_state = 0},
  [2077] = {.lex_state = 0},
  [2078] = {.lex_state = 0},
  [2079] = {.lex_state = 8},
  [2080] = {.lex_state = 0},
  [2081] = {.lex_state = 8},
  [2082] = {.lex_state = 8},
  [2083] = {.lex_state = 0},
  [2084] = {.lex_state = 8},
  [2085] = {.lex_state = 8},
  [2086] = {.lex_state = 8},
  [2087] = {.lex_state = 0},
  [2088] = {.lex_state = 8},
  [2089] = {.lex_state = 8},
  [2090] = {.lex_state = 8},
  [2091] = {.lex_state = 0},
  [2092] = {.lex_state = 8},
  [2093] = {.lex_state = 8},
  [2094] = {.lex_state = 8},
  [2095] = {.lex_state = 0},
  [2096] = {.lex_state = 8},
  [2097] = {.lex_state = 8},
  [2098] = {.lex_state = 8},
  [2099] = {.lex_state = 0},
  [2100] = {.lex_state = 19},
  [2101] = {.lex_state = 8},
  [2102] = {.lex_state = 8},
  [2103] = {.lex_state = 8},
  [2104] = {.lex_state = 8},
  [2105] = {.lex_state = 8},
  [2106] = {.lex_state = 8},
  [2107] = {.lex_state = 521},
  [2108] = {.lex_state = 0},
  [2109] = {.lex_state = 0},
  [2110] = {.lex_state = 19},
  [2111] = {.lex_state = 19},
  [2112] = {.lex_state = 0},
  [2113] = {.lex_state = 0},
  [2114] = {.lex_state = 521},
  [2115] = {.lex_state = 0},
  [2116] = {.lex_state = 0},
  [2117] = {.lex_state = 0},
  [2118] = {.lex_state = 0},
  [2119] = {.lex_state = 0},
  [2120] = {.lex_state = 0},
  [2121] = {.lex_state = 0},
  [2122] = {.lex_state = 8},
  [2123] = {.lex_state = 0},
  [2124] = {.lex_state = 8},
  [2125] = {.lex_state = 8},
  [2126] = {.lex_state = 0},
  [2127] = {.lex_state = 0},
  [2128] = {.lex_state = 0},
  [2129] = {.lex_state = 0},
  [2130] = {.lex_state = 19},
  [2131] = {.lex_state = 8},
  [2132] = {.lex_state = 0},
  [2133] = {.lex_state = 0},
  [2134] = {.lex_state = 0},
  [2135] = {.lex_state = 19},
  [2136] = {.lex_state = 19},
  [2137] = {.lex_state = 0},
  [2138] = {.lex_state = 0},
  [2139] = {.lex_state = 0},
  [2140] = {.lex_state = 19},
  [2141] = {.lex_state = 521},
  [2142] = {.lex_state = 0},
  [2143] = {.lex_state = 0},
  [2144] = {.lex_state = 0},
  [2145] = {.lex_state = 19},
  [2146] = {.lex_state = 19},
  [2147] = {.lex_state = 0},
  [2148] = {.lex_state = 0},
  [2149] = {.lex_state = 19},
  [2150] = {.lex_state = 19},
  [2151] = {.lex_state = 0},
  [2152] = {.lex_state = 0},
  [2153] = {.lex_state = 0},
  [2154] = {.lex_state = 18},
  [2155] = {.lex_state = 19},
  [2156] = {.lex_state = 0},
  [2157] = {.lex_state = 0},
  [2158] = {.lex_state = 0},
  [2159] = {.lex_state = 0},
  [2160] = {.lex_state = 19},
  [2161] = {.lex_state = 0},
  [2162] = {.lex_state = 0},
  [2163] = {.lex_state = 0},
  [2164] = {.lex_state = 0},
  [2165] = {.lex_state = 19},
  [2166] = {.lex_state = 8},
  [2167] = {.lex_state = 0},
  [2168] = {.lex_state = 0},
  [2169] = {.lex_state = 8},
  [2170] = {.lex_state = 19},
  [2171] = {.lex_state = 521},
  [2172] = {.lex_state = 0},
  [2173] = {.lex_state = 0},
  [2174] = {.lex_state = 19},
  [2175] = {.lex_state = 0},
  [2176] = {.lex_state = 0},
  [2177] = {.lex_state = 8},
  [2178] = {.lex_state = 8},
  [2179] = {.lex_state = 19},
  [2180] = {.lex_state = 0},
  [2181] = {.lex_state = 19},
  [2182] = {.lex_state = 0},
  [2183] = {.lex_state = 0},
  [2184] = {.lex_state = 0},
  [2185] = {.lex_state = 8},
  [2186] = {.lex_state = 8},
  [2187] = {.lex_state = 19},
  [2188] = {.lex_state = 19},
  [2189] = {.lex_state = 19},
  [2190] = {.lex_state = 19},
  [2191] = {.lex_state = 19},
  [2192] = {.lex_state = 19},
  [2193] = {.lex_state = 19},
  [2194] = {.lex_state = 19},
  [2195] = {.lex_state = 19},
  [2196] = {.lex_state = 19},
  [2197] = {.lex_state = 19},
  [2198] = {.lex_state = 19},
  [2199] = {.lex_state = 19},
  [2200] = {.lex_state = 19},
  [2201] = {.lex_state = 19},
  [2202] = {.lex_state = 19},
  [2203] = {.lex_state = 19},
  [2204] = {.lex_state = 19},
  [2205] = {.lex_state = 19},
  [2206] = {.lex_state = 19},
  [2207] = {.lex_state = 8},
  [2208] = {.lex_state = 8},
  [2209] = {.lex_state = 8},
  [2210] = {.lex_state = 8},
  [2211] = {.lex_state = 0},
  [2212] = {.lex_state = 521},
  [2213] = {.lex_state = 18},
  [2214] = {.lex_state = 19},
  [2215] = {.lex_state = 24},
  [2216] = {.lex_state = 0},
  [2217] = {.lex_state = 8},
  [2218] = {.lex_state = 0},
  [2219] = {.lex_state = 0},
  [2220] = {.lex_state = 19},
  [2221] = {.lex_state = 0},
  [2222] = {.lex_state = 0},
  [2223] = {.lex_state = 0},
  [2224] = {.lex_state = 0},
  [2225] = {.lex_state = 0},
  [2226] = {.lex_state = 19},
  [2227] = {.lex_state = 0},
  [2228] = {.lex_state = 0},
  [2229] = {.lex_state = 0},
  [2230] = {.lex_state = 19},
  [2231] = {.lex_state = 0},
  [2232] = {.lex_state = 0},
  [2233] = {.lex_state = 0},
  [2234] = {.lex_state = 0},
  [2235] = {.lex_state = 19},
  [2236] = {.lex_state = 25},
  [2237] = {.lex_state = 25},
  [2238] = {.lex_state = 19},
  [2239] = {.lex_state = 19},
  [2240] = {.lex_state = 0},
  [2241] = {.lex_state = 0},
  [2242] = {.lex_state = 0},
  [2243] = {.lex_state = 521},
  [2244] = {.lex_state = 0},
  [2245] = {.lex_state = 19},
  [2246] = {.lex_state = 25},
  [2247] = {.lex_state = 24},
  [2248] = {.lex_state = 0},
  [2249] = {.lex_state = 0},
  [2250] = {.lex_state = 19},
  [2251] = {.lex_state = 19},
  [2252] = {.lex_state = 0},
  [2253] = {.lex_state = 0},
  [2254] = {.lex_state = 19},
  [2255] = {.lex_state = 0},
  [2256] = {.lex_state = 0},
  [2257] = {.lex_state = 0},
  [2258] = {.lex_state = 0},
  [2259] = {.lex_state = 19},
  [2260] = {.lex_state = 0},
  [2261] = {.lex_state = 19},
  [2262] = {.lex_state = 521},
  [2263] = {.lex_state = 0},
  [2264] = {.lex_state = 0},
  [2265] = {.lex_state = 0},
  [2266] = {.lex_state = 0},
  [2267] = {.lex_state = 0},
  [2268] = {.lex_state = 0},
  [2269] = {.lex_state = 0},
  [2270] = {.lex_state = 0},
  [2271] = {.lex_state = 0},
  [2272] = {.lex_state = 0},
  [2273] = {.lex_state = 0},
  [2274] = {.lex_state = 19},
  [2275] = {.lex_state = 0},
  [2276] = {.lex_state = 19},
  [2277] = {.lex_state = 0},
  [2278] = {.lex_state = 19},
  [2279] = {.lex_state = 0},
  [2280] = {.lex_state = 0},
  [2281] = {.lex_state = 0},
  [2282] = {.lex_state = 0},
  [2283] = {.lex_state = 19},
  [2284] = {.lex_state = 0},
  [2285] = {.lex_state = 0},
  [2286] = {.lex_state = 0},
  [2287] = {.lex_state = 19},
  [2288] = {.lex_state = 0},
  [2289] = {.lex_state = 19},
  [2290] = {.lex_state = 0},
  [2291] = {.lex_state = 0},
  [2292] = {.lex_state = 0},
  [2293] = {.lex_state = 0},
  [2294] = {.lex_state = 0},
  [2295] = {.lex_state = 0},
  [2296] = {.lex_state = 0},
  [2297] = {.lex_state = 521},
  [2298] = {.lex_state = 19},
  [2299] = {.lex_state = 19},
  [2300] = {.lex_state = 0},
  [2301] = {.lex_state = 521},
  [2302] = {.lex_state = 19},
  [2303] = {.lex_state = 0},
  [2304] = {.lex_state = 25},
  [2305] = {.lex_state = 0},
  [2306] = {.lex_state = 19},
  [2307] = {.lex_state = 0},
  [2308] = {.lex_state = 0},
  [2309] = {.lex_state = 0},
  [2310] = {.lex_state = 0},
  [2311] = {.lex_state = 521},
  [2312] = {.lex_state = 0},
  [2313] = {.lex_state = 25},
  [2314] = {.lex_state = 0},
  [2315] = {.lex_state = 0},
  [2316] = {.lex_state = 24},
  [2317] = {.lex_state = 8},
  [2318] = {.lex_state = 19},
  [2319] = {.lex_state = 8},
  [2320] = {.lex_state = 25},
  [2321] = {.lex_state = 24},
  [2322] = {.lex_state = 8},
  [2323] = {.lex_state = 19},
  [2324] = {.lex_state = 521},
  [2325] = {.lex_state = 19},
  [2326] = {.lex_state = 19},
  [2327] = {.lex_state = 25},
  [2328] = {.lex_state = 0},
  [2329] = {.lex_state = 8},
  [2330] = {.lex_state = 0},
  [2331] = {.lex_state = 0},
  [2332] = {.lex_state = 0},
  [2333] = {.lex_state = 0},
  [2334] = {.lex_state = 19},
  [2335] = {.lex_state = 0},
  [2336] = {.lex_state = 521},
  [2337] = {.lex_state = 521},
  [2338] = {.lex_state = 0},
  [2339] = {.lex_state = 0},
  [2340] = {.lex_state = 0},
  [2341] = {.lex_state = 0},
  [2342] = {.lex_state = 0},
  [2343] = {.lex_state = 0},
  [2344] = {.lex_state = 25},
  [2345] = {.lex_state = 0},
  [2346] = {.lex_state = 0},
  [2347] = {.lex_state = 0},
  [2348] = {.lex_state = 0},
  [2349] = {.lex_state = 0},
  [2350] = {.lex_state = 0},
  [2351] = {.lex_state = 0},
  [2352] = {.lex_state = 8},
  [2353] = {.lex_state = 0},
  [2354] = {.lex_state = 0},
  [2355] = {.lex_state = 0},
  [2356] = {.lex_state = 0},
  [2357] = {.lex_state = 8},
  [2358] = {.lex_state = 0},
  [2359] = {.lex_state = 8},
  [2360] = {.lex_state = 0},
  [2361] = {.lex_state = 0},
  [2362] = {.lex_state = 0},
  [2363] = {.lex_state = 8},
  [2364] = {.lex_state = 0},
  [2365] = {.lex_state = 521},
  [2366] = {.lex_state = 0},
  [2367] = {.lex_state = 0},
  [2368] = {.lex_state = 8},
  [2369] = {.lex_state = 0},
  [2370] = {.lex_state = 0},
  [2371] = {.lex_state = 0},
  [2372] = {.lex_state = 0},
  [2373] = {.lex_state = 0},
  [2374] = {.lex_state = 0},
  [2375] = {.lex_state = 0},
  [2376] = {.lex_state = 25},
  [2377] = {.lex_state = 19},
  [2378] = {.lex_state = 0},
  [2379] = {.lex_state = 0},
  [2380] = {.lex_state = 0},
  [2381] = {.lex_state = 0},
  [2382] = {.lex_state = 0},
  [2383] = {.lex_state = 0},
  [2384] = {.lex_state = 0},
  [2385] = {.lex_state = 25},
  [2386] = {.lex_state = 24},
  [2387] = {.lex_state = 0},
  [2388] = {.lex_state = 8},
  [2389] = {.lex_state = 521},
  [2390] = {.lex_state = 0},
  [2391] = {.lex_state = 0},
  [2392] = {.lex_state = 0},
  [2393] = {.lex_state = 521},
  [2394] = {.lex_state = 0},
  [2395] = {.lex_state = 0},
  [2396] = {.lex_state = 19},
  [2397] = {.lex_state = 19},
  [2398] = {.lex_state = 0},
  [2399] = {.lex_state = 0},
  [2400] = {.lex_state = 521},
  [2401] = {.lex_state = 0},
  [2402] = {.lex_state = 0},
  [2403] = {.lex_state = 0},
  [2404] = {.lex_state = 0},
  [2405] = {.lex_state = 0},
  [2406] = {.lex_state = 0},
  [2407] = {.lex_state = 0},
  [2408] = {.lex_state = 0},
  [2409] = {.lex_state = 0},
  [2410] = {.lex_state = 0},
  [2411] = {.lex_state = 521},
  [2412] = {.lex_state = 0},
  [2413] = {.lex_state = 0},
  [2414] = {.lex_state = 0},
  [2415] = {.lex_state = 0},
  [2416] = {.lex_state = 0},
  [2417] = {.lex_state = 8},
  [2418] = {.lex_state = 0},
  [2419] = {.lex_state = 19},
  [2420] = {.lex_state = 0},
  [2421] = {.lex_state = 0},
  [2422] = {.lex_state = 0},
  [2423] = {.lex_state = 8},
  [2424] = {.lex_state = 0},
  [2425] = {.lex_state = 19},
  [2426] = {.lex_state = 8},
  [2427] = {.lex_state = 0},
  [2428] = {.lex_state = 8},
  [2429] = {.lex_state = 19},
  [2430] = {.lex_state = 0},
  [2431] = {.lex_state = 0},
  [2432] = {.lex_state = 521},
  [2433] = {.lex_state = 0},
  [2434] = {.lex_state = 0},
  [2435] = {.lex_state = 0},
  [2436] = {.lex_state = 521},
  [2437] = {.lex_state = 0},
  [2438] = {.lex_state = 24},
  [2439] = {.lex_state = 0},
  [2440] = {.lex_state = 8},
  [2441] = {.lex_state = 0},
  [2442] = {.lex_state = 8},
  [2443] = {.lex_state = 521},
  [2444] = {.lex_state = 0},
  [2445] = {.lex_state = 19},
  [2446] = {.lex_state = 19},
  [2447] = {.lex_state = 0},
  [2448] = {.lex_state = 0},
  [2449] = {.lex_state = 0},
  [2450] = {.lex_state = 0},
  [2451] = {.lex_state = 0},
  [2452] = {.lex_state = 521},
  [2453] = {.lex_state = 0},
  [2454] = {.lex_state = 19},
  [2455] = {.lex_state = 0},
  [2456] = {.lex_state = 19},
  [2457] = {.lex_state = 0},
  [2458] = {.lex_state = 0},
  [2459] = {.lex_state = 25},
  [2460] = {.lex_state = 19},
  [2461] = {.lex_state = 8},
  [2462] = {.lex_state = 19},
  [2463] = {.lex_state = 19},
  [2464] = {.lex_state = 8},
  [2465] = {.lex_state = 19},
  [2466] = {.lex_state = 8},
  [2467] = {.lex_state = 0},
  [2468] = {.lex_state = 0},
  [2469] = {.lex_state = 0},
  [2470] = {.lex_state = 0},
  [2471] = {.lex_state = 0},
  [2472] = {.lex_state = 521},
  [2473] = {.lex_state = 0},
  [2474] = {.lex_state = 0},
  [2475] = {.lex_state = 0},
  [2476] = {.lex_state = 19},
  [2477] = {.lex_state = 0},
  [2478] = {.lex_state = 25},
  [2479] = {.lex_state = 0},
  [2480] = {.lex_state = 0},
  [2481] = {.lex_state = 8},
  [2482] = {.lex_state = 19},
  [2483] = {.lex_state = 0},
  [2484] = {.lex_state = 8},
  [2485] = {.lex_state = 0},
  [2486] = {.lex_state = 8},
  [2487] = {.lex_state = 0},
  [2488] = {.lex_state = 0},
  [2489] = {.lex_state = 0},
  [2490] = {.lex_state = 0},
  [2491] = {.lex_state = 0},
  [2492] = {.lex_state = 521},
  [2493] = {.lex_state = 0},
  [2494] = {.lex_state = 0},
  [2495] = {.lex_state = 0},
  [2496] = {.lex_state = 0},
  [2497] = {.lex_state = 0},
  [2498] = {.lex_state = 0},
  [2499] = {.lex_state = 0},
  [2500] = {.lex_state = 0},
  [2501] = {.lex_state = 8},
  [2502] = {.lex_state = 0},
  [2503] = {.lex_state = 0},
  [2504] = {.lex_state = 8},
  [2505] = {.lex_state = 0},
  [2506] = {.lex_state = 8},
  [2507] = {.lex_state = 19},
  [2508] = {.lex_state = 0},
  [2509] = {.lex_state = 0},
  [2510] = {.lex_state = 0},
  [2511] = {.lex_state = 0},
  [2512] = {.lex_state = 521},
  [2513] = {.lex_state = 0},
  [2514] = {.lex_state = 0},
  [2515] = {.lex_state = 0},
  [2516] = {.lex_state = 8},
  [2517] = {.lex_state = 25},
  [2518] = {.lex_state = 0},
  [2519] = {.lex_state = 8},
  [2520] = {.lex_state = 19},
  [2521] = {.lex_state = 8},
  [2522] = {.lex_state = 0},
  [2523] = {.lex_state = 0},
  [2524] = {.lex_state = 0},
  [2525] = {.lex_state = 0},
  [2526] = {.lex_state = 0},
  [2527] = {.lex_state = 521},
  [2528] = {.lex_state = 19},
  [2529] = {.lex_state = 0},
  [2530] = {.lex_state = 0},
  [2531] = {.lex_state = 8},
  [2532] = {.lex_state = 0},
  [2533] = {.lex_state = 0},
  [2534] = {.lex_state = 8},
  [2535] = {.lex_state = 0},
  [2536] = {.lex_state = 8},
  [2537] = {.lex_state = 0},
  [2538] = {.lex_state = 0},
  [2539] = {.lex_state = 0},
  [2540] = {.lex_state = 0},
  [2541] = {.lex_state = 0},
  [2542] = {.lex_state = 521},
  [2543] = {.lex_state = 0},
  [2544] = {.lex_state = 0},
  [2545] = {.lex_state = 521},
  [2546] = {.lex_state = 8},
  [2547] = {.lex_state = 0},
  [2548] = {.lex_state = 0},
  [2549] = {.lex_state = 8},
  [2550] = {.lex_state = 0},
  [2551] = {.lex_state = 8},
  [2552] = {.lex_state = 0},
  [2553] = {.lex_state = 0},
  [2554] = {.lex_state = 0},
  [2555] = {.lex_state = 0},
  [2556] = {.lex_state = 0},
  [2557] = {.lex_state = 521},
  [2558] = {.lex_state = 19},
  [2559] = {.lex_state = 0},
  [2560] = {.lex_state = 0},
  [2561] = {.lex_state = 8},
  [2562] = {.lex_state = 0},
  [2563] = {.lex_state = 0},
  [2564] = {.lex_state = 8},
  [2565] = {.lex_state = 19},
  [2566] = {.lex_state = 8},
  [2567] = {.lex_state = 0},
  [2568] = {.lex_state = 0},
  [2569] = {.lex_state = 0},
  [2570] = {.lex_state = 0},
  [2571] = {.lex_state = 0},
  [2572] = {.lex_state = 521},
  [2573] = {.lex_state = 0},
  [2574] = {.lex_state = 25},
  [2575] = {.lex_state = 24},
  [2576] = {.lex_state = 8},
  [2577] = {.lex_state = 0},
  [2578] = {.lex_state = 0},
  [2579] = {.lex_state = 8},
  [2580] = {.lex_state = 19},
  [2581] = {.lex_state = 8},
  [2582] = {.lex_state = 25},
  [2583] = {.lex_state = 19},
  [2584] = {.lex_state = 0},
  [2585] = {.lex_state = 0},
  [2586] = {.lex_state = 0},
  [2587] = {.lex_state = 521},
  [2588] = {.lex_state = 19},
  [2589] = {.lex_state = 0},
  [2590] = {.lex_state = 8},
  [2591] = {.lex_state = 0},
  [2592] = {.lex_state = 0},
  [2593] = {.lex_state = 8},
  [2594] = {.lex_state = 0},
  [2595] = {.lex_state = 8},
  [2596] = {.lex_state = 0},
  [2597] = {.lex_state = 0},
  [2598] = {.lex_state = 0},
  [2599] = {.lex_state = 0},
  [2600] = {.lex_state = 0},
  [2601] = {.lex_state = 19},
  [2602] = {.lex_state = 0},
  [2603] = {.lex_state = 19},
  [2604] = {.lex_state = 0},
  [2605] = {.lex_state = 0},
  [2606] = {.lex_state = 19},
  [2607] = {.lex_state = 0},
  [2608] = {.lex_state = 0},
  [2609] = {.lex_state = 0},
  [2610] = {.lex_state = 25},
  [2611] = {.lex_state = 19},
  [2612] = {.lex_state = 24},
  [2613] = {.lex_state = 0},
  [2614] = {.lex_state = 0},
  [2615] = {.lex_state = 0},
  [2616] = {.lex_state = 0},
  [2617] = {.lex_state = 0},
  [2618] = {.lex_state = 0},
  [2619] = {.lex_state = 0},
  [2620] = {.lex_state = 0},
  [2621] = {.lex_state = 19},
  [2622] = {.lex_state = 0},
  [2623] = {.lex_state = 0},
  [2624] = {.lex_state = 0},
  [2625] = {.lex_state = 0},
  [2626] = {.lex_state = 0},
  [2627] = {.lex_state = 521},
  [2628] = {.lex_state = 0},
  [2629] = {.lex_state = 8},
  [2630] = {.lex_state = 0},
  [2631] = {.lex_state = 8},
  [2632] = {.lex_state = 0},
  [2633] = {.lex_state = 0},
  [2634] = {.lex_state = 0},
  [2635] = {.lex_state = 0},
  [2636] = {.lex_state = 0},
  [2637] = {.lex_state = 0},
  [2638] = {.lex_state = 0},
  [2639] = {.lex_state = 0},
  [2640] = {.lex_state = 0},
  [2641] = {.lex_state = 0},
  [2642] = {.lex_state = 521},
  [2643] = {.lex_state = 19},
  [2644] = {.lex_state = 0},
  [2645] = {.lex_state = 0},
  [2646] = {.lex_state = 0},
  [2647] = {.lex_state = 0},
  [2648] = {.lex_state = 0},
  [2649] = {.lex_state = 0},
  [2650] = {.lex_state = 19},
  [2651] = {.lex_state = 0},
  [2652] = {.lex_state = 19},
  [2653] = {.lex_state = 0},
  [2654] = {.lex_state = 0},
  [2655] = {.lex_state = 0},
  [2656] = {.lex_state = 0},
  [2657] = {.lex_state = 0},
  [2658] = {.lex_state = 0},
  [2659] = {.lex_state = 8},
  [2660] = {.lex_state = 0},
  [2661] = {.lex_state = 0},
  [2662] = {.lex_state = 0},
  [2663] = {.lex_state = 0},
  [2664] = {.lex_state = 0},
  [2665] = {.lex_state = 25},
  [2666] = {.lex_state = 19},
  [2667] = {.lex_state = 0},
  [2668] = {.lex_state = 0},
  [2669] = {.lex_state = 0},
  [2670] = {.lex_state = 0},
  [2671] = {.lex_state = 0},
  [2672] = {.lex_state = 0},
  [2673] = {.lex_state = 8},
  [2674] = {.lex_state = 25},
  [2675] = {.lex_state = 24},
  [2676] = {.lex_state = 0},
  [2677] = {.lex_state = 0},
  [2678] = {.lex_state = 0},
  [2679] = {.lex_state = 0},
  [2680] = {.lex_state = 0},
  [2681] = {.lex_state = 0},
  [2682] = {.lex_state = 8},
  [2683] = {.lex_state = 0},
  [2684] = {.lex_state = 0},
  [2685] = {.lex_state = 0},
  [2686] = {.lex_state = 0},
  [2687] = {.lex_state = 0},
  [2688] = {.lex_state = 0},
  [2689] = {.lex_state = 0},
  [2690] = {.lex_state = 0},
  [2691] = {.lex_state = 0},
  [2692] = {.lex_state = 19},
  [2693] = {.lex_state = 0},
  [2694] = {.lex_state = 0},
  [2695] = {.lex_state = 0},
  [2696] = {.lex_state = 0},
  [2697] = {.lex_state = 0},
  [2698] = {.lex_state = 0},
  [2699] = {.lex_state = 0},
  [2700] = {.lex_state = 0},
  [2701] = {.lex_state = 25},
  [2702] = {.lex_state = 19},
  [2703] = {.lex_state = 0},
  [2704] = {.lex_state = 0},
  [2705] = {.lex_state = 0},
  [2706] = {.lex_state = 0},
  [2707] = {.lex_state = 0},
  [2708] = {.lex_state = 0},
  [2709] = {.lex_state = 0},
  [2710] = {.lex_state = 0},
  [2711] = {.lex_state = 8},
  [2712] = {.lex_state = 0},
  [2713] = {.lex_state = 19},
  [2714] = {.lex_state = 25},
  [2715] = {.lex_state = 19},
  [2716] = {.lex_state = 0},
  [2717] = {.lex_state = 25},
  [2718] = {.lex_state = 24},
  [2719] = {.lex_state = 19},
  [2720] = {.lex_state = 0},
  [2721] = {.lex_state = 19},
  [2722] = {.lex_state = 25},
  [2723] = {.lex_state = 19},
  [2724] = {.lex_state = 25},
  [2725] = {.lex_state = 0},
  [2726] = {.lex_state = 0},
  [2727] = {.lex_state = 0},
  [2728] = {.lex_state = 0},
  [2729] = {.lex_state = 0},
  [2730] = {.lex_state = 24},
  [2731] = {.lex_state = 0},
  [2732] = {.lex_state = 8},
  [2733] = {.lex_state = 19},
  [2734] = {.lex_state = 0},
  [2735] = {.lex_state = 19},
  [2736] = {.lex_state = 19},
  [2737] = {.lex_state = 19},
  [2738] = {.lex_state = 19},
  [2739] = {.lex_state = 8},
  [2740] = {.lex_state = 0},
  [2741] = {.lex_state = 19},
  [2742] = {.lex_state = 0},
  [2743] = {.lex_state = 0},
  [2744] = {.lex_state = 0},
  [2745] = {.lex_state = 0},
  [2746] = {.lex_state = 0},
  [2747] = {.lex_state = 19},
  [2748] = {.lex_state = 0},
  [2749] = {.lex_state = 19},
  [2750] = {.lex_state = 19},
  [2751] = {.lex_state = 8},
  [2752] = {.lex_state = 0},
  [2753] = {.lex_state = 0},
  [2754] = {.lex_state = 0},
  [2755] = {.lex_state = 0},
  [2756] = {.lex_state = 0},
  [2757] = {.lex_state = 0},
  [2758] = {.lex_state = 0},
  [2759] = {.lex_state = 19},
  [2760] = {.lex_state = 0},
  [2761] = {.lex_state = 19},
  [2762] = {.lex_state = 19},
  [2763] = {.lex_state = 0},
  [2764] = {.lex_state = 19},
  [2765] = {.lex_state = 0},
  [2766] = {.lex_state = 0},
  [2767] = {.lex_state = 0},
  [2768] = {.lex_state = 0},
  [2769] = {.lex_state = 0},
  [2770] = {.lex_state = 19},
  [2771] = {.lex_state = 19},
  [2772] = {.lex_state = 19},
  [2773] = {.lex_state = 19},
  [2774] = {.lex_state = 0},
  [2775] = {.lex_state = 0},
  [2776] = {.lex_state = 0},
  [2777] = {.lex_state = 0},
  [2778] = {.lex_state = 0},
  [2779] = {.lex_state = 0},
  [2780] = {.lex_state = 0},
  [2781] = {.lex_state = 19},
  [2782] = {.lex_state = 19},
  [2783] = {.lex_state = 19},
  [2784] = {.lex_state = 19},
  [2785] = {.lex_state = 0},
  [2786] = {.lex_state = 0},
  [2787] = {.lex_state = 0},
  [2788] = {.lex_state = 19},
  [2789] = {.lex_state = 0},
  [2790] = {.lex_state = 0},
  [2791] = {.lex_state = 19},
  [2792] = {.lex_state = 19},
  [2793] = {.lex_state = 0},
  [2794] = {.lex_state = 19},
  [2795] = {.lex_state = 19},
  [2796] = {.lex_state = 0},
  [2797] = {.lex_state = 19},
  [2798] = {.lex_state = 0},
  [2799] = {.lex_state = 0},
  [2800] = {.lex_state = 0},
  [2801] = {.lex_state = 0},
  [2802] = {.lex_state = 19},
  [2803] = {.lex_state = 19},
  [2804] = {.lex_state = 0},
  [2805] = {.lex_state = 19},
  [2806] = {.lex_state = 19},
  [2807] = {.lex_state = 0},
  [2808] = {.lex_state = 25},
  [2809] = {.lex_state = 19},
  [2810] = {.lex_state = 0},
  [2811] = {.lex_state = 0},
  [2812] = {.lex_state = 0},
  [2813] = {.lex_state = 0},
  [2814] = {.lex_state = 19},
  [2815] = {.lex_state = 0},
  [2816] = {.lex_state = 19},
  [2817] = {.lex_state = 19},
  [2818] = {.lex_state = 0},
  [2819] = {.lex_state = 8},
  [2820] = {.lex_state = 0},
  [2821] = {.lex_state = 19},
  [2822] = {.lex_state = 0},
  [2823] = {.lex_state = 0},
  [2824] = {.lex_state = 0},
  [2825] = {.lex_state = 19},
  [2826] = {.lex_state = 19},
  [2827] = {.lex_state = 19},
  [2828] = {.lex_state = 19},
  [2829] = {.lex_state = 25},
  [2830] = {.lex_state = 24},
  [2831] = {.lex_state = 19},
  [2832] = {.lex_state = 0},
  [2833] = {.lex_state = 19},
  [2834] = {.lex_state = 19},
  [2835] = {.lex_state = 0},
  [2836] = {.lex_state = 0},
  [2837] = {.lex_state = 19},
  [2838] = {.lex_state = 0},
  [2839] = {.lex_state = 0},
  [2840] = {.lex_state = 0},
  [2841] = {.lex_state = 19},
  [2842] = {.lex_state = 0},
  [2843] = {.lex_state = 8},
  [2844] = {.lex_state = 0},
  [2845] = {.lex_state = 19},
  [2846] = {.lex_state = 521},
  [2847] = {.lex_state = 0},
  [2848] = {.lex_state = 8},
  [2849] = {.lex_state = 0},
  [2850] = {.lex_state = 19},
  [2851] = {.lex_state = 25},
  [2852] = {.lex_state = 19},
  [2853] = {.lex_state = 19},
  [2854] = {.lex_state = 25},
  [2855] = {.lex_state = 24},
  [2856] = {.lex_state = 19},
  [2857] = {.lex_state = 19},
  [2858] = {.lex_state = 0},
  [2859] = {.lex_state = 0},
  [2860] = {.lex_state = 0},
  [2861] = {.lex_state = 19},
  [2862] = {.lex_state = 0},
  [2863] = {.lex_state = 0},
  [2864] = {.lex_state = 0},
  [2865] = {.lex_state = 0},
  [2866] = {.lex_state = 0},
  [2867] = {.lex_state = 0},
  [2868] = {.lex_state = 0},
  [2869] = {.lex_state = 19},
  [2870] = {.lex_state = 0},
  [2871] = {.lex_state = 0},
  [2872] = {.lex_state = 0},
  [2873] = {.lex_state = 19},
  [2874] = {.lex_state = 0},
  [2875] = {.lex_state = 0},
  [2876] = {.lex_state = 0},
  [2877] = {.lex_state = 0},
  [2878] = {.lex_state = 0},
  [2879] = {.lex_state = 19},
  [2880] = {.lex_state = 0},
  [2881] = {.lex_state = 0},
  [2882] = {.lex_state = 0},
  [2883] = {.lex_state = 0},
  [2884] = {.lex_state = 19},
  [2885] = {.lex_state = 0},
  [2886] = {.lex_state = 0},
  [2887] = {.lex_state = 0},
  [2888] = {.lex_state = 0},
  [2889] = {.lex_state = 0},
  [2890] = {.lex_state = 19},
  [2891] = {.lex_state = 25},
  [2892] = {.lex_state = 19},
  [2893] = {.lex_state = 24},
  [2894] = {.lex_state = 19},
  [2895] = {.lex_state = 19},
  [2896] = {.lex_state = 19},
  [2897] = {.lex_state = 0},
  [2898] = {.lex_state = 0},
  [2899] = {.lex_state = 19},
  [2900] = {.lex_state = 19},
  [2901] = {.lex_state = 0},
  [2902] = {.lex_state = 0},
  [2903] = {.lex_state = 0},
  [2904] = {.lex_state = 0},
  [2905] = {.lex_state = 0},
  [2906] = {.lex_state = 0},
  [2907] = {.lex_state = 0},
  [2908] = {.lex_state = 0},
};

static const uint16_t ts_parse_table[LARGE_STATE_COUNT][SYMBOL_COUNT] = {
  [STATE(0)] = {
    [ts_builtin_sym_end] = ACTIONS(1),
    [anon_sym_module] = ACTIONS(1),
    [anon_sym_SEMI] = ACTIONS(1),
    [anon_sym_export] = ACTIONS(1),
    [anon_sym_LBRACE] = ACTIONS(1),
    [anon_sym_RBRACE] = ACTIONS(1),
    [anon_sym_global] = ACTIONS(1),
    [anon_sym_COLON] = ACTIONS(1),
    [anon_sym_option] = ACTIONS(1),
    [anon_sym_const] = ACTIONS(1),
    [anon_sym_redef] = ACTIONS(1),
    [anon_sym_enum] = ACTIONS(1),
    [anon_sym_PLUS_EQ] = ACTIONS(1),
    [anon_sym_record] = ACTIONS(1),
    [anon_sym_DASH_EQ] = ACTIONS(1),
    [anon_sym_type] = ACTIONS(1),
    [anon_sym_print] = ACTIONS(1),
    [anon_sym_event] = ACTIONS(1),
    [anon_sym_if] = ACTIONS(1),
    [anon_sym_LPAREN] = ACTIONS(1),
    [anon_sym_RPAREN] = ACTIONS(1),
    [anon_sym_else] = ACTIONS(1),
    [anon_sym_switch] = ACTIONS(1),
    [anon_sym_for] = ACTIONS(1),
    [anon_sym_COMMA] = ACTIONS(1),
    [anon_sym_in] = ACTIONS(1),
    [anon_sym_LBRACK] = ACTIONS(1),
    [anon_sym_RBRACK] = ACTIONS(1),
    [anon_sym_while] = ACTIONS(1),
    [anon_sym_next] = ACTIONS(1),
    [anon_sym_break] = ACTIONS(1),
    [anon_sym_fallthrough] = ACTIONS(1),
    [anon_sym_return] = ACTIONS(1),
    [anon_sym_add] = ACTIONS(1),
    [anon_sym_delete] = ACTIONS(1),
    [anon_sym_local] = ACTIONS(1),
    [anon_sym_when] = ACTIONS(1),
    [anon_sym_timeout] = ACTIONS(1),
    [anon_sym_EQ] = ACTIONS(1),
    [anon_sym_assert] = ACTIONS(1),
    [anon_sym_case] = ACTIONS(1),
    [anon_sym_default] = ACTIONS(1),
    [anon_sym_as] = ACTIONS(1),
    [anon_sym_function] = ACTIONS(1),
    [anon_sym_hook] = ACTIONS(1),
    [anon_sym_addr] = ACTIONS(1),
    [anon_sym_any] = ACTIONS(1),
    [anon_sym_bool] = ACTIONS(1),
    [anon_sym_count] = ACTIONS(1),
    [anon_sym_double] = ACTIONS(1),
    [anon_sym_file] = ACTIONS(1),
    [anon_sym_int] = ACTIONS(1),
    [anon_sym_interval] = ACTIONS(1),
    [anon_sym_list] = ACTIONS(1),
    [anon_sym_pattern] = ACTIONS(1),
    [anon_sym_port] = ACTIONS(1),
    [anon_sym_string] = ACTIONS(1),
    [anon_sym_subnet] = ACTIONS(1),
    [anon_sym_time] = ACTIONS(1),
    [anon_sym_of] = ACTIONS(1),
    [anon_sym_opaque] = ACTIONS(1),
    [anon_sym_set] = ACTIONS(1),
    [anon_sym_table] = ACTIONS(1),
    [anon_sym_union] = ACTIONS(1),
    [anon_sym_vector] = ACTIONS(1),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1),
    [anon_sym_AMPdeprecated] = ACTIONS(1),
    [anon_sym_AMPerror_handler] = ACTIONS(1),
    [anon_sym_AMPis_assigned] = ACTIONS(1),
    [anon_sym_AMPis_used] = ACTIONS(1),
    [anon_sym_AMPlog] = ACTIONS(1),
    [anon_sym_AMPoptional] = ACTIONS(1),
    [anon_sym_AMPordered] = ACTIONS(1),
    [anon_sym_AMPraw_output] = ACTIONS(1),
    [anon_sym_AMPredef] = ACTIONS(1),
    [anon_sym_AMPadd_func] = ACTIONS(1),
    [anon_sym_AMPbackend] = ACTIONS(1),
    [anon_sym_AMPbroker_store] = ACTIONS(1),
    [anon_sym_AMPcreate_expire] = ACTIONS(1),
    [anon_sym_AMPdefault] = ACTIONS(1),
    [anon_sym_AMPdelete_func] = ACTIONS(1),
    [anon_sym_AMPexpire_func] = ACTIONS(1),
    [anon_sym_AMPgroup] = ACTIONS(1),
    [anon_sym_AMPon_change] = ACTIONS(1),
    [anon_sym_AMPpriority] = ACTIONS(1),
    [anon_sym_AMPread_expire] = ACTIONS(1),
    [anon_sym_AMPtype_column] = ACTIONS(1),
    [anon_sym_AMPwrite_expire] = ACTIONS(1),
    [anon_sym_DOLLAR] = ACTIONS(1),
    [anon_sym_PIPE] = ACTIONS(1),
    [anon_sym_PLUS_PLUS] = ACTIONS(1),
    [anon_sym_DASH_DASH] = ACTIONS(1),
    [anon_sym_BANG] = ACTIONS(1),
    [anon_sym_TILDE] = ACTIONS(1),
    [anon_sym_DASH] = ACTIONS(1),
    [anon_sym_PLUS] = ACTIONS(1),
    [anon_sym_is] = ACTIONS(1),
    [anon_sym_STAR] = ACTIONS(1),
    [anon_sym_SLASH] = ACTIONS(1),
    [anon_sym_PERCENT] = ACTIONS(1),
    [anon_sym_LT] = ACTIONS(1),
    [anon_sym_LT_EQ] = ACTIONS(1),
    [anon_sym_GT] = ACTIONS(1),
    [anon_sym_GT_EQ] = ACTIONS(1),
    [anon_sym_AMP] = ACTIONS(1),
    [anon_sym_CARET] = ACTIONS(1),
    [anon_sym_QMARK] = ACTIONS(1),
    [anon_sym_EQ_EQ] = ACTIONS(1),
    [anon_sym_BANG_EQ] = ACTIONS(1),
    [anon_sym_AMP_AMP] = ACTIONS(1),
    [anon_sym_PIPE_PIPE] = ACTIONS(1),
    [anon_sym_copy] = ACTIONS(1),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1),
    [anon_sym_schedule] = ACTIONS(1),
    [anon_sym_T] = ACTIONS(1),
    [anon_sym_F] = ACTIONS(1),
    [anon_sym_ATdeprecated] = ACTIONS(1),
    [anon_sym_ATload] = ACTIONS(1),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1),
    [anon_sym_ATunload] = ACTIONS(1),
    [anon_sym_ATprefixes] = ACTIONS(1),
    [anon_sym_ATif] = ACTIONS(1),
    [anon_sym_ATifdef] = ACTIONS(1),
    [anon_sym_ATifndef] = ACTIONS(1),
    [anon_sym_ATendif] = ACTIONS(1),
    [anon_sym_ATelse] = ACTIONS(1),
    [anon_sym_ATpragma] = ACTIONS(1),
    [anon_sym_push] = ACTIONS(1),
    [anon_sym_pop] = ACTIONS(1),
    [anon_sym_ATDIR] = ACTIONS(1),
    [anon_sym_ATFILENAME] = ACTIONS(1),
    [sym_pattern] = ACTIONS(1),
    [sym_ipv4] = ACTIONS(1),
    [sym_ipv6] = ACTIONS(1),
    [sym_port] = ACTIONS(1),
    [sym_integer] = ACTIONS(1),
    [sym_floatp] = ACTIONS(1),
    [sym_hex] = ACTIONS(1),
    [sym_time_unit] = ACTIONS(1),
    [aux_sym_string_token1] = ACTIONS(1),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(1)] = {
    [sym_source_file] = STATE(2876),
    [sym_decl] = STATE(3),
    [sym_module_decl] = STATE(300),
    [sym_export_decl] = STATE(300),
    [sym_global_decl] = STATE(300),
    [sym_option_decl] = STATE(300),
    [sym_const_decl] = STATE(300),
    [sym_redef_decl] = STATE(300),
    [sym_redef_enum_decl] = STATE(300),
    [sym_redef_record_decl] = STATE(300),
    [sym_type_decl] = STATE(300),
    [sym_func_decl] = STATE(300),
    [sym_stmt] = STATE(81),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_func_hdr] = STATE(1844),
    [sym_func] = STATE(1850),
    [sym_hook] = STATE(1850),
    [sym_event] = STATE(1850),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(301),
    [sym_pragma] = STATE(296),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat1] = STATE(3),
    [aux_sym_source_file_repeat2] = STATE(81),
    [ts_builtin_sym_end] = ACTIONS(7),
    [anon_sym_module] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_global] = ACTIONS(17),
    [anon_sym_option] = ACTIONS(19),
    [anon_sym_const] = ACTIONS(21),
    [anon_sym_redef] = ACTIONS(23),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_type] = ACTIONS(29),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(59),
    [anon_sym_hook] = ACTIONS(61),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(91),
    [anon_sym_ATload] = ACTIONS(93),
    [anon_sym_ATload_DASHsigs] = ACTIONS(95),
    [anon_sym_ATload_DASHplugin] = ACTIONS(97),
    [anon_sym_ATunload] = ACTIONS(95),
    [anon_sym_ATprefixes] = ACTIONS(99),
    [anon_sym_ATif] = ACTIONS(101),
    [anon_sym_ATifdef] = ACTIONS(103),
    [anon_sym_ATifndef] = ACTIONS(103),
    [anon_sym_ATendif] = ACTIONS(105),
    [anon_sym_ATelse] = ACTIONS(105),
    [anon_sym_ATpragma] = ACTIONS(107),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(2)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1307),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(129),
    [anon_sym_LBRACK] = ACTIONS(129),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(129),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(129),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(129),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(3)] = {
    [sym_decl] = STATE(8),
    [sym_module_decl] = STATE(300),
    [sym_export_decl] = STATE(300),
    [sym_global_decl] = STATE(300),
    [sym_option_decl] = STATE(300),
    [sym_const_decl] = STATE(300),
    [sym_redef_decl] = STATE(300),
    [sym_redef_enum_decl] = STATE(300),
    [sym_redef_record_decl] = STATE(300),
    [sym_type_decl] = STATE(300),
    [sym_func_decl] = STATE(300),
    [sym_stmt] = STATE(79),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_func_hdr] = STATE(1844),
    [sym_func] = STATE(1850),
    [sym_hook] = STATE(1850),
    [sym_event] = STATE(1850),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(301),
    [sym_pragma] = STATE(296),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat1] = STATE(8),
    [aux_sym_source_file_repeat2] = STATE(79),
    [ts_builtin_sym_end] = ACTIONS(137),
    [anon_sym_module] = ACTIONS(9),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_export] = ACTIONS(13),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_global] = ACTIONS(17),
    [anon_sym_option] = ACTIONS(19),
    [anon_sym_const] = ACTIONS(21),
    [anon_sym_redef] = ACTIONS(23),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_type] = ACTIONS(29),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(33),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(59),
    [anon_sym_hook] = ACTIONS(61),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(91),
    [anon_sym_ATload] = ACTIONS(93),
    [anon_sym_ATload_DASHsigs] = ACTIONS(95),
    [anon_sym_ATload_DASHplugin] = ACTIONS(97),
    [anon_sym_ATunload] = ACTIONS(95),
    [anon_sym_ATprefixes] = ACTIONS(99),
    [anon_sym_ATif] = ACTIONS(101),
    [anon_sym_ATifdef] = ACTIONS(103),
    [anon_sym_ATifndef] = ACTIONS(103),
    [anon_sym_ATendif] = ACTIONS(105),
    [anon_sym_ATelse] = ACTIONS(105),
    [anon_sym_ATpragma] = ACTIONS(107),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(4)] = {
    [ts_builtin_sym_end] = ACTIONS(139),
    [anon_sym_module] = ACTIONS(141),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_export] = ACTIONS(141),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_global] = ACTIONS(141),
    [anon_sym_option] = ACTIONS(141),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_redef] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_type] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(139),
    [anon_sym_AMPdeprecated] = ACTIONS(139),
    [anon_sym_AMPerror_handler] = ACTIONS(139),
    [anon_sym_AMPis_assigned] = ACTIONS(139),
    [anon_sym_AMPis_used] = ACTIONS(139),
    [anon_sym_AMPlog] = ACTIONS(139),
    [anon_sym_AMPoptional] = ACTIONS(139),
    [anon_sym_AMPordered] = ACTIONS(139),
    [anon_sym_AMPraw_output] = ACTIONS(139),
    [anon_sym_AMPredef] = ACTIONS(139),
    [anon_sym_AMPadd_func] = ACTIONS(139),
    [anon_sym_AMPbackend] = ACTIONS(139),
    [anon_sym_AMPbroker_store] = ACTIONS(139),
    [anon_sym_AMPcreate_expire] = ACTIONS(139),
    [anon_sym_AMPdefault] = ACTIONS(139),
    [anon_sym_AMPdelete_func] = ACTIONS(139),
    [anon_sym_AMPexpire_func] = ACTIONS(139),
    [anon_sym_AMPgroup] = ACTIONS(139),
    [anon_sym_AMPon_change] = ACTIONS(139),
    [anon_sym_AMPpriority] = ACTIONS(139),
    [anon_sym_AMPread_expire] = ACTIONS(139),
    [anon_sym_AMPtype_column] = ACTIONS(139),
    [anon_sym_AMPwrite_expire] = ACTIONS(139),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(5)] = {
    [ts_builtin_sym_end] = ACTIONS(143),
    [anon_sym_module] = ACTIONS(145),
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_export] = ACTIONS(145),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_RBRACE] = ACTIONS(143),
    [anon_sym_global] = ACTIONS(145),
    [anon_sym_option] = ACTIONS(145),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_redef] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_type] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_COMMA] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(143),
    [anon_sym_AMPdeprecated] = ACTIONS(143),
    [anon_sym_AMPerror_handler] = ACTIONS(143),
    [anon_sym_AMPis_assigned] = ACTIONS(143),
    [anon_sym_AMPis_used] = ACTIONS(143),
    [anon_sym_AMPlog] = ACTIONS(143),
    [anon_sym_AMPoptional] = ACTIONS(143),
    [anon_sym_AMPordered] = ACTIONS(143),
    [anon_sym_AMPraw_output] = ACTIONS(143),
    [anon_sym_AMPredef] = ACTIONS(143),
    [anon_sym_AMPadd_func] = ACTIONS(143),
    [anon_sym_AMPbackend] = ACTIONS(143),
    [anon_sym_AMPbroker_store] = ACTIONS(143),
    [anon_sym_AMPcreate_expire] = ACTIONS(143),
    [anon_sym_AMPdefault] = ACTIONS(143),
    [anon_sym_AMPdelete_func] = ACTIONS(143),
    [anon_sym_AMPexpire_func] = ACTIONS(143),
    [anon_sym_AMPgroup] = ACTIONS(143),
    [anon_sym_AMPon_change] = ACTIONS(143),
    [anon_sym_AMPpriority] = ACTIONS(143),
    [anon_sym_AMPread_expire] = ACTIONS(143),
    [anon_sym_AMPtype_column] = ACTIONS(143),
    [anon_sym_AMPwrite_expire] = ACTIONS(143),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(6)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1307),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_COLON] = ACTIONS(129),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(129),
    [anon_sym_LBRACK] = ACTIONS(129),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(129),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(129),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(129),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(7)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_case] = ACTIONS(153),
    [anon_sym_default] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(8)] = {
    [sym_decl] = STATE(8),
    [sym_module_decl] = STATE(300),
    [sym_export_decl] = STATE(300),
    [sym_global_decl] = STATE(300),
    [sym_option_decl] = STATE(300),
    [sym_const_decl] = STATE(300),
    [sym_redef_decl] = STATE(300),
    [sym_redef_enum_decl] = STATE(300),
    [sym_redef_record_decl] = STATE(300),
    [sym_type_decl] = STATE(300),
    [sym_func_decl] = STATE(300),
    [sym_func_hdr] = STATE(1844),
    [sym_func] = STATE(1850),
    [sym_hook] = STATE(1850),
    [sym_event] = STATE(1850),
    [sym_preproc_directive] = STATE(300),
    [sym_pragma] = STATE(296),
    [aux_sym_source_file_repeat1] = STATE(8),
    [ts_builtin_sym_end] = ACTIONS(157),
    [anon_sym_module] = ACTIONS(159),
    [anon_sym_SEMI] = ACTIONS(157),
    [anon_sym_export] = ACTIONS(162),
    [anon_sym_LBRACE] = ACTIONS(157),
    [anon_sym_global] = ACTIONS(165),
    [anon_sym_option] = ACTIONS(168),
    [anon_sym_const] = ACTIONS(171),
    [anon_sym_redef] = ACTIONS(174),
    [anon_sym_enum] = ACTIONS(177),
    [anon_sym_record] = ACTIONS(177),
    [anon_sym_type] = ACTIONS(179),
    [anon_sym_print] = ACTIONS(177),
    [anon_sym_event] = ACTIONS(182),
    [anon_sym_if] = ACTIONS(177),
    [anon_sym_LPAREN] = ACTIONS(157),
    [anon_sym_switch] = ACTIONS(177),
    [anon_sym_for] = ACTIONS(177),
    [anon_sym_LBRACK] = ACTIONS(177),
    [anon_sym_while] = ACTIONS(177),
    [anon_sym_next] = ACTIONS(177),
    [anon_sym_break] = ACTIONS(177),
    [anon_sym_fallthrough] = ACTIONS(177),
    [anon_sym_return] = ACTIONS(177),
    [anon_sym_add] = ACTIONS(177),
    [anon_sym_delete] = ACTIONS(177),
    [anon_sym_local] = ACTIONS(177),
    [anon_sym_when] = ACTIONS(177),
    [anon_sym_assert] = ACTIONS(177),
    [anon_sym_function] = ACTIONS(185),
    [anon_sym_hook] = ACTIONS(188),
    [anon_sym_addr] = ACTIONS(177),
    [anon_sym_any] = ACTIONS(177),
    [anon_sym_bool] = ACTIONS(177),
    [anon_sym_count] = ACTIONS(177),
    [anon_sym_double] = ACTIONS(177),
    [anon_sym_file] = ACTIONS(177),
    [anon_sym_int] = ACTIONS(177),
    [anon_sym_interval] = ACTIONS(177),
    [anon_sym_list] = ACTIONS(177),
    [anon_sym_pattern] = ACTIONS(177),
    [anon_sym_port] = ACTIONS(177),
    [anon_sym_string] = ACTIONS(177),
    [anon_sym_subnet] = ACTIONS(177),
    [anon_sym_time] = ACTIONS(177),
    [anon_sym_opaque] = ACTIONS(177),
    [anon_sym_set] = ACTIONS(177),
    [anon_sym_table] = ACTIONS(177),
    [anon_sym_union] = ACTIONS(177),
    [anon_sym_vector] = ACTIONS(177),
    [anon_sym_DOLLAR] = ACTIONS(157),
    [anon_sym_PIPE] = ACTIONS(157),
    [anon_sym_PLUS_PLUS] = ACTIONS(157),
    [anon_sym_DASH_DASH] = ACTIONS(157),
    [anon_sym_BANG] = ACTIONS(157),
    [anon_sym_TILDE] = ACTIONS(157),
    [anon_sym_DASH] = ACTIONS(177),
    [anon_sym_PLUS] = ACTIONS(177),
    [anon_sym_copy] = ACTIONS(177),
    [anon_sym_schedule] = ACTIONS(177),
    [anon_sym_T] = ACTIONS(177),
    [anon_sym_F] = ACTIONS(177),
    [anon_sym_ATdeprecated] = ACTIONS(191),
    [anon_sym_ATload] = ACTIONS(194),
    [anon_sym_ATload_DASHsigs] = ACTIONS(197),
    [anon_sym_ATload_DASHplugin] = ACTIONS(200),
    [anon_sym_ATunload] = ACTIONS(197),
    [anon_sym_ATprefixes] = ACTIONS(203),
    [anon_sym_ATif] = ACTIONS(206),
    [anon_sym_ATifdef] = ACTIONS(209),
    [anon_sym_ATifndef] = ACTIONS(209),
    [anon_sym_ATendif] = ACTIONS(212),
    [anon_sym_ATelse] = ACTIONS(212),
    [anon_sym_ATpragma] = ACTIONS(215),
    [anon_sym_ATDIR] = ACTIONS(157),
    [anon_sym_ATFILENAME] = ACTIONS(157),
    [sym_id] = ACTIONS(177),
    [sym_pattern] = ACTIONS(157),
    [sym_ipv4] = ACTIONS(177),
    [sym_ipv6] = ACTIONS(157),
    [sym_port] = ACTIONS(157),
    [sym_integer] = ACTIONS(177),
    [sym_floatp] = ACTIONS(177),
    [sym_hex] = ACTIONS(177),
    [sym_hostname] = ACTIONS(177),
    [aux_sym_string_token1] = ACTIONS(157),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(9)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_case] = ACTIONS(153),
    [anon_sym_default] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(10)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_case] = ACTIONS(153),
    [anon_sym_default] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(11)] = {
    [ts_builtin_sym_end] = ACTIONS(151),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(12)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(13)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_case] = ACTIONS(153),
    [anon_sym_default] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(14)] = {
    [ts_builtin_sym_end] = ACTIONS(151),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(15)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(149),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_COMMA] = ACTIONS(149),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(16)] = {
    [ts_builtin_sym_end] = ACTIONS(151),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(17)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(18)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(19)] = {
    [ts_builtin_sym_end] = ACTIONS(151),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(20)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_in] = ACTIONS(155),
    [anon_sym_LBRACK] = ACTIONS(155),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_as] = ACTIONS(155),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(155),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(155),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(21)] = {
    [sym_stmt] = STATE(38),
    [sym_stmt_list] = STATE(1946),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(38),
    [anon_sym_SEMI] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(220),
    [anon_sym_RBRACE] = ACTIONS(222),
    [anon_sym_const] = ACTIONS(224),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(226),
    [anon_sym_event] = ACTIONS(228),
    [anon_sym_if] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(234),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(236),
    [anon_sym_next] = ACTIONS(238),
    [anon_sym_break] = ACTIONS(238),
    [anon_sym_fallthrough] = ACTIONS(238),
    [anon_sym_return] = ACTIONS(240),
    [anon_sym_add] = ACTIONS(242),
    [anon_sym_delete] = ACTIONS(242),
    [anon_sym_local] = ACTIONS(244),
    [anon_sym_when] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(248),
    [anon_sym_case] = ACTIONS(250),
    [anon_sym_default] = ACTIONS(250),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(252),
    [anon_sym_ATload] = ACTIONS(254),
    [anon_sym_ATload_DASHsigs] = ACTIONS(256),
    [anon_sym_ATload_DASHplugin] = ACTIONS(258),
    [anon_sym_ATunload] = ACTIONS(256),
    [anon_sym_ATprefixes] = ACTIONS(260),
    [anon_sym_ATif] = ACTIONS(262),
    [anon_sym_ATifdef] = ACTIONS(264),
    [anon_sym_ATifndef] = ACTIONS(264),
    [anon_sym_ATendif] = ACTIONS(266),
    [anon_sym_ATelse] = ACTIONS(266),
    [anon_sym_ATpragma] = ACTIONS(268),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(22)] = {
    [sym_stmt] = STATE(38),
    [sym_stmt_list] = STATE(1980),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(38),
    [anon_sym_SEMI] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(220),
    [anon_sym_RBRACE] = ACTIONS(270),
    [anon_sym_const] = ACTIONS(224),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(226),
    [anon_sym_event] = ACTIONS(228),
    [anon_sym_if] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(234),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(236),
    [anon_sym_next] = ACTIONS(238),
    [anon_sym_break] = ACTIONS(238),
    [anon_sym_fallthrough] = ACTIONS(238),
    [anon_sym_return] = ACTIONS(240),
    [anon_sym_add] = ACTIONS(242),
    [anon_sym_delete] = ACTIONS(242),
    [anon_sym_local] = ACTIONS(244),
    [anon_sym_when] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(248),
    [anon_sym_case] = ACTIONS(272),
    [anon_sym_default] = ACTIONS(272),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(252),
    [anon_sym_ATload] = ACTIONS(254),
    [anon_sym_ATload_DASHsigs] = ACTIONS(256),
    [anon_sym_ATload_DASHplugin] = ACTIONS(258),
    [anon_sym_ATunload] = ACTIONS(256),
    [anon_sym_ATprefixes] = ACTIONS(260),
    [anon_sym_ATif] = ACTIONS(262),
    [anon_sym_ATifdef] = ACTIONS(264),
    [anon_sym_ATifndef] = ACTIONS(264),
    [anon_sym_ATendif] = ACTIONS(266),
    [anon_sym_ATelse] = ACTIONS(266),
    [anon_sym_ATpragma] = ACTIONS(268),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(23)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2248),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(278),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(24)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2248),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(324),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(25)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2704),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(326),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(26)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2218),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(328),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(27)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2858),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(330),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(28)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2530),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(332),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(29)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2813),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(334),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(30)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2240),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(336),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(31)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2314),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(338),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(32)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2379),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(340),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(33)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2467),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(342),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(34)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2594),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(344),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(35)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2668),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1335),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(276),
    [anon_sym_RBRACE] = ACTIONS(346),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(36)] = {
    [anon_sym_SEMI] = ACTIONS(348),
    [anon_sym_LBRACE] = ACTIONS(348),
    [anon_sym_RBRACE] = ACTIONS(348),
    [anon_sym_enum] = ACTIONS(350),
    [anon_sym_PLUS_EQ] = ACTIONS(348),
    [anon_sym_record] = ACTIONS(350),
    [anon_sym_DASH_EQ] = ACTIONS(348),
    [anon_sym_LPAREN] = ACTIONS(348),
    [anon_sym_RPAREN] = ACTIONS(348),
    [anon_sym_COMMA] = ACTIONS(348),
    [anon_sym_LBRACK] = ACTIONS(350),
    [anon_sym_RBRACK] = ACTIONS(348),
    [anon_sym_local] = ACTIONS(350),
    [anon_sym_EQ] = ACTIONS(348),
    [anon_sym_function] = ACTIONS(350),
    [anon_sym_hook] = ACTIONS(350),
    [anon_sym_addr] = ACTIONS(350),
    [anon_sym_any] = ACTIONS(350),
    [anon_sym_bool] = ACTIONS(350),
    [anon_sym_count] = ACTIONS(350),
    [anon_sym_double] = ACTIONS(350),
    [anon_sym_file] = ACTIONS(350),
    [anon_sym_int] = ACTIONS(350),
    [anon_sym_interval] = ACTIONS(350),
    [anon_sym_list] = ACTIONS(350),
    [anon_sym_pattern] = ACTIONS(350),
    [anon_sym_port] = ACTIONS(350),
    [anon_sym_string] = ACTIONS(350),
    [anon_sym_subnet] = ACTIONS(350),
    [anon_sym_time] = ACTIONS(350),
    [anon_sym_opaque] = ACTIONS(350),
    [anon_sym_set] = ACTIONS(350),
    [anon_sym_table] = ACTIONS(350),
    [anon_sym_union] = ACTIONS(350),
    [anon_sym_vector] = ACTIONS(350),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(348),
    [anon_sym_AMPdeprecated] = ACTIONS(348),
    [anon_sym_AMPerror_handler] = ACTIONS(348),
    [anon_sym_AMPis_assigned] = ACTIONS(348),
    [anon_sym_AMPis_used] = ACTIONS(348),
    [anon_sym_AMPlog] = ACTIONS(348),
    [anon_sym_AMPoptional] = ACTIONS(348),
    [anon_sym_AMPordered] = ACTIONS(348),
    [anon_sym_AMPraw_output] = ACTIONS(348),
    [anon_sym_AMPredef] = ACTIONS(348),
    [anon_sym_AMPadd_func] = ACTIONS(348),
    [anon_sym_AMPbackend] = ACTIONS(348),
    [anon_sym_AMPbroker_store] = ACTIONS(348),
    [anon_sym_AMPcreate_expire] = ACTIONS(348),
    [anon_sym_AMPdefault] = ACTIONS(348),
    [anon_sym_AMPdelete_func] = ACTIONS(348),
    [anon_sym_AMPexpire_func] = ACTIONS(348),
    [anon_sym_AMPgroup] = ACTIONS(348),
    [anon_sym_AMPon_change] = ACTIONS(348),
    [anon_sym_AMPpriority] = ACTIONS(348),
    [anon_sym_AMPread_expire] = ACTIONS(348),
    [anon_sym_AMPtype_column] = ACTIONS(348),
    [anon_sym_AMPwrite_expire] = ACTIONS(348),
    [anon_sym_DOLLAR] = ACTIONS(348),
    [anon_sym_PIPE] = ACTIONS(348),
    [anon_sym_PLUS_PLUS] = ACTIONS(348),
    [anon_sym_DASH_DASH] = ACTIONS(348),
    [anon_sym_BANG] = ACTIONS(348),
    [anon_sym_TILDE] = ACTIONS(348),
    [anon_sym_DASH] = ACTIONS(350),
    [anon_sym_PLUS] = ACTIONS(350),
    [anon_sym_copy] = ACTIONS(350),
    [anon_sym_schedule] = ACTIONS(350),
    [anon_sym_T] = ACTIONS(350),
    [anon_sym_F] = ACTIONS(350),
    [anon_sym_ATdeprecated] = ACTIONS(348),
    [anon_sym_ATload] = ACTIONS(350),
    [anon_sym_ATload_DASHsigs] = ACTIONS(348),
    [anon_sym_ATload_DASHplugin] = ACTIONS(348),
    [anon_sym_ATunload] = ACTIONS(348),
    [anon_sym_ATprefixes] = ACTIONS(348),
    [anon_sym_ATif] = ACTIONS(350),
    [anon_sym_ATifdef] = ACTIONS(348),
    [anon_sym_ATifndef] = ACTIONS(348),
    [anon_sym_ATendif] = ACTIONS(348),
    [anon_sym_ATelse] = ACTIONS(348),
    [anon_sym_ATpragma] = ACTIONS(348),
    [anon_sym_ATDIR] = ACTIONS(348),
    [anon_sym_ATFILENAME] = ACTIONS(348),
    [sym_id] = ACTIONS(350),
    [sym_pattern] = ACTIONS(348),
    [sym_ipv4] = ACTIONS(350),
    [sym_ipv6] = ACTIONS(348),
    [sym_port] = ACTIONS(348),
    [sym_integer] = ACTIONS(350),
    [sym_floatp] = ACTIONS(350),
    [sym_hex] = ACTIONS(350),
    [sym_hostname] = ACTIONS(350),
    [aux_sym_string_token1] = ACTIONS(348),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(37)] = {
    [anon_sym_SEMI] = ACTIONS(352),
    [anon_sym_LBRACE] = ACTIONS(352),
    [anon_sym_RBRACE] = ACTIONS(352),
    [anon_sym_enum] = ACTIONS(354),
    [anon_sym_PLUS_EQ] = ACTIONS(352),
    [anon_sym_record] = ACTIONS(354),
    [anon_sym_DASH_EQ] = ACTIONS(352),
    [anon_sym_LPAREN] = ACTIONS(352),
    [anon_sym_RPAREN] = ACTIONS(352),
    [anon_sym_COMMA] = ACTIONS(352),
    [anon_sym_LBRACK] = ACTIONS(354),
    [anon_sym_RBRACK] = ACTIONS(352),
    [anon_sym_local] = ACTIONS(354),
    [anon_sym_EQ] = ACTIONS(352),
    [anon_sym_function] = ACTIONS(354),
    [anon_sym_hook] = ACTIONS(354),
    [anon_sym_addr] = ACTIONS(354),
    [anon_sym_any] = ACTIONS(354),
    [anon_sym_bool] = ACTIONS(354),
    [anon_sym_count] = ACTIONS(354),
    [anon_sym_double] = ACTIONS(354),
    [anon_sym_file] = ACTIONS(354),
    [anon_sym_int] = ACTIONS(354),
    [anon_sym_interval] = ACTIONS(354),
    [anon_sym_list] = ACTIONS(354),
    [anon_sym_pattern] = ACTIONS(354),
    [anon_sym_port] = ACTIONS(354),
    [anon_sym_string] = ACTIONS(354),
    [anon_sym_subnet] = ACTIONS(354),
    [anon_sym_time] = ACTIONS(354),
    [anon_sym_opaque] = ACTIONS(354),
    [anon_sym_set] = ACTIONS(354),
    [anon_sym_table] = ACTIONS(354),
    [anon_sym_union] = ACTIONS(354),
    [anon_sym_vector] = ACTIONS(354),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(352),
    [anon_sym_AMPdeprecated] = ACTIONS(352),
    [anon_sym_AMPerror_handler] = ACTIONS(352),
    [anon_sym_AMPis_assigned] = ACTIONS(352),
    [anon_sym_AMPis_used] = ACTIONS(352),
    [anon_sym_AMPlog] = ACTIONS(352),
    [anon_sym_AMPoptional] = ACTIONS(352),
    [anon_sym_AMPordered] = ACTIONS(352),
    [anon_sym_AMPraw_output] = ACTIONS(352),
    [anon_sym_AMPredef] = ACTIONS(352),
    [anon_sym_AMPadd_func] = ACTIONS(352),
    [anon_sym_AMPbackend] = ACTIONS(352),
    [anon_sym_AMPbroker_store] = ACTIONS(352),
    [anon_sym_AMPcreate_expire] = ACTIONS(352),
    [anon_sym_AMPdefault] = ACTIONS(352),
    [anon_sym_AMPdelete_func] = ACTIONS(352),
    [anon_sym_AMPexpire_func] = ACTIONS(352),
    [anon_sym_AMPgroup] = ACTIONS(352),
    [anon_sym_AMPon_change] = ACTIONS(352),
    [anon_sym_AMPpriority] = ACTIONS(352),
    [anon_sym_AMPread_expire] = ACTIONS(352),
    [anon_sym_AMPtype_column] = ACTIONS(352),
    [anon_sym_AMPwrite_expire] = ACTIONS(352),
    [anon_sym_DOLLAR] = ACTIONS(352),
    [anon_sym_PIPE] = ACTIONS(352),
    [anon_sym_PLUS_PLUS] = ACTIONS(352),
    [anon_sym_DASH_DASH] = ACTIONS(352),
    [anon_sym_BANG] = ACTIONS(352),
    [anon_sym_TILDE] = ACTIONS(352),
    [anon_sym_DASH] = ACTIONS(354),
    [anon_sym_PLUS] = ACTIONS(354),
    [anon_sym_copy] = ACTIONS(354),
    [anon_sym_schedule] = ACTIONS(354),
    [anon_sym_T] = ACTIONS(354),
    [anon_sym_F] = ACTIONS(354),
    [anon_sym_ATdeprecated] = ACTIONS(352),
    [anon_sym_ATload] = ACTIONS(354),
    [anon_sym_ATload_DASHsigs] = ACTIONS(352),
    [anon_sym_ATload_DASHplugin] = ACTIONS(352),
    [anon_sym_ATunload] = ACTIONS(352),
    [anon_sym_ATprefixes] = ACTIONS(352),
    [anon_sym_ATif] = ACTIONS(354),
    [anon_sym_ATifdef] = ACTIONS(352),
    [anon_sym_ATifndef] = ACTIONS(352),
    [anon_sym_ATendif] = ACTIONS(352),
    [anon_sym_ATelse] = ACTIONS(352),
    [anon_sym_ATpragma] = ACTIONS(352),
    [anon_sym_ATDIR] = ACTIONS(352),
    [anon_sym_ATFILENAME] = ACTIONS(352),
    [sym_id] = ACTIONS(354),
    [sym_pattern] = ACTIONS(352),
    [sym_ipv4] = ACTIONS(354),
    [sym_ipv6] = ACTIONS(352),
    [sym_port] = ACTIONS(352),
    [sym_integer] = ACTIONS(354),
    [sym_floatp] = ACTIONS(354),
    [sym_hex] = ACTIONS(354),
    [sym_hostname] = ACTIONS(354),
    [aux_sym_string_token1] = ACTIONS(352),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(38)] = {
    [sym_stmt] = STATE(39),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(39),
    [anon_sym_SEMI] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(220),
    [anon_sym_RBRACE] = ACTIONS(356),
    [anon_sym_const] = ACTIONS(224),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(226),
    [anon_sym_event] = ACTIONS(228),
    [anon_sym_if] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(234),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(236),
    [anon_sym_next] = ACTIONS(238),
    [anon_sym_break] = ACTIONS(238),
    [anon_sym_fallthrough] = ACTIONS(238),
    [anon_sym_return] = ACTIONS(240),
    [anon_sym_add] = ACTIONS(242),
    [anon_sym_delete] = ACTIONS(242),
    [anon_sym_local] = ACTIONS(244),
    [anon_sym_when] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(248),
    [anon_sym_case] = ACTIONS(358),
    [anon_sym_default] = ACTIONS(358),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(252),
    [anon_sym_ATload] = ACTIONS(254),
    [anon_sym_ATload_DASHsigs] = ACTIONS(256),
    [anon_sym_ATload_DASHplugin] = ACTIONS(258),
    [anon_sym_ATunload] = ACTIONS(256),
    [anon_sym_ATprefixes] = ACTIONS(260),
    [anon_sym_ATif] = ACTIONS(262),
    [anon_sym_ATifdef] = ACTIONS(264),
    [anon_sym_ATifndef] = ACTIONS(264),
    [anon_sym_ATendif] = ACTIONS(266),
    [anon_sym_ATelse] = ACTIONS(266),
    [anon_sym_ATpragma] = ACTIONS(268),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(39)] = {
    [sym_stmt] = STATE(39),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(39),
    [anon_sym_SEMI] = ACTIONS(360),
    [anon_sym_LBRACE] = ACTIONS(363),
    [anon_sym_RBRACE] = ACTIONS(366),
    [anon_sym_const] = ACTIONS(368),
    [anon_sym_enum] = ACTIONS(371),
    [anon_sym_record] = ACTIONS(374),
    [anon_sym_print] = ACTIONS(377),
    [anon_sym_event] = ACTIONS(380),
    [anon_sym_if] = ACTIONS(383),
    [anon_sym_LPAREN] = ACTIONS(386),
    [anon_sym_switch] = ACTIONS(389),
    [anon_sym_for] = ACTIONS(392),
    [anon_sym_LBRACK] = ACTIONS(395),
    [anon_sym_while] = ACTIONS(398),
    [anon_sym_next] = ACTIONS(401),
    [anon_sym_break] = ACTIONS(401),
    [anon_sym_fallthrough] = ACTIONS(401),
    [anon_sym_return] = ACTIONS(404),
    [anon_sym_add] = ACTIONS(407),
    [anon_sym_delete] = ACTIONS(407),
    [anon_sym_local] = ACTIONS(410),
    [anon_sym_when] = ACTIONS(413),
    [anon_sym_assert] = ACTIONS(416),
    [anon_sym_case] = ACTIONS(419),
    [anon_sym_default] = ACTIONS(419),
    [anon_sym_function] = ACTIONS(421),
    [anon_sym_hook] = ACTIONS(424),
    [anon_sym_addr] = ACTIONS(427),
    [anon_sym_any] = ACTIONS(427),
    [anon_sym_bool] = ACTIONS(427),
    [anon_sym_count] = ACTIONS(427),
    [anon_sym_double] = ACTIONS(427),
    [anon_sym_file] = ACTIONS(430),
    [anon_sym_int] = ACTIONS(427),
    [anon_sym_interval] = ACTIONS(427),
    [anon_sym_list] = ACTIONS(430),
    [anon_sym_pattern] = ACTIONS(427),
    [anon_sym_port] = ACTIONS(427),
    [anon_sym_string] = ACTIONS(427),
    [anon_sym_subnet] = ACTIONS(427),
    [anon_sym_time] = ACTIONS(427),
    [anon_sym_opaque] = ACTIONS(433),
    [anon_sym_set] = ACTIONS(436),
    [anon_sym_table] = ACTIONS(439),
    [anon_sym_union] = ACTIONS(442),
    [anon_sym_vector] = ACTIONS(445),
    [anon_sym_DOLLAR] = ACTIONS(448),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_PLUS_PLUS] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(454),
    [anon_sym_BANG] = ACTIONS(454),
    [anon_sym_TILDE] = ACTIONS(454),
    [anon_sym_DASH] = ACTIONS(457),
    [anon_sym_PLUS] = ACTIONS(457),
    [anon_sym_copy] = ACTIONS(460),
    [anon_sym_schedule] = ACTIONS(463),
    [anon_sym_T] = ACTIONS(466),
    [anon_sym_F] = ACTIONS(466),
    [anon_sym_ATdeprecated] = ACTIONS(469),
    [anon_sym_ATload] = ACTIONS(472),
    [anon_sym_ATload_DASHsigs] = ACTIONS(475),
    [anon_sym_ATload_DASHplugin] = ACTIONS(478),
    [anon_sym_ATunload] = ACTIONS(475),
    [anon_sym_ATprefixes] = ACTIONS(481),
    [anon_sym_ATif] = ACTIONS(484),
    [anon_sym_ATifdef] = ACTIONS(487),
    [anon_sym_ATifndef] = ACTIONS(487),
    [anon_sym_ATendif] = ACTIONS(490),
    [anon_sym_ATelse] = ACTIONS(490),
    [anon_sym_ATpragma] = ACTIONS(493),
    [anon_sym_ATDIR] = ACTIONS(496),
    [anon_sym_ATFILENAME] = ACTIONS(496),
    [sym_id] = ACTIONS(499),
    [sym_pattern] = ACTIONS(502),
    [sym_ipv4] = ACTIONS(505),
    [sym_ipv6] = ACTIONS(508),
    [sym_port] = ACTIONS(511),
    [sym_integer] = ACTIONS(514),
    [sym_floatp] = ACTIONS(517),
    [sym_hex] = ACTIONS(466),
    [sym_hostname] = ACTIONS(466),
    [aux_sym_string_token1] = ACTIONS(520),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(40)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2660),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(525),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(41)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2672),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(527),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(42)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2418),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(529),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(43)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2758),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(531),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(44)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2787),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(533),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(45)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2793),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(535),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(46)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2286),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(537),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(47)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2480),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(539),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(48)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2488),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(541),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(49)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2496),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(543),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(50)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2775),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(545),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(51)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2777),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(547),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(52)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2786),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(549),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(53)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2222),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(551),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(54)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2224),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(553),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(55)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2670),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(555),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(56)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2288),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(557),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(57)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2290),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(559),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(58)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2292),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(561),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(59)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2367),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(563),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(60)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2369),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(565),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(61)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2371),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(567),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(62)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2441),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(569),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(63)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2447),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(571),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(64)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2453),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(573),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(65)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2273),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(575),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(66)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2553),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(577),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(67)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2563),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(579),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(68)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2567),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(581),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(69)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2293),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(583),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(70)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2656),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(585),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(71)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2658),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(587),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(72)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2331),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(589),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(73)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2706),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(591),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(74)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2708),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(593),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(75)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2710),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(595),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(76)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2414),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(597),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(77)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2664),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(599),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(78)] = {
    [sym_stmt] = STATE(84),
    [sym_stmt_list] = STATE(2227),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(84),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(601),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(79)] = {
    [sym_stmt] = STATE(85),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(740),
    [sym_pragma] = STATE(729),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(85),
    [ts_builtin_sym_end] = ACTIONS(603),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(605),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(607),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(609),
    [anon_sym_ATload] = ACTIONS(611),
    [anon_sym_ATload_DASHsigs] = ACTIONS(613),
    [anon_sym_ATload_DASHplugin] = ACTIONS(615),
    [anon_sym_ATunload] = ACTIONS(613),
    [anon_sym_ATprefixes] = ACTIONS(617),
    [anon_sym_ATif] = ACTIONS(619),
    [anon_sym_ATifdef] = ACTIONS(621),
    [anon_sym_ATifndef] = ACTIONS(621),
    [anon_sym_ATendif] = ACTIONS(623),
    [anon_sym_ATelse] = ACTIONS(623),
    [anon_sym_ATpragma] = ACTIONS(625),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(80)] = {
    [anon_sym_SEMI] = ACTIONS(627),
    [anon_sym_LBRACE] = ACTIONS(627),
    [anon_sym_enum] = ACTIONS(629),
    [anon_sym_PLUS_EQ] = ACTIONS(627),
    [anon_sym_record] = ACTIONS(629),
    [anon_sym_DASH_EQ] = ACTIONS(627),
    [anon_sym_LPAREN] = ACTIONS(627),
    [anon_sym_RPAREN] = ACTIONS(627),
    [anon_sym_COMMA] = ACTIONS(627),
    [anon_sym_LBRACK] = ACTIONS(629),
    [anon_sym_local] = ACTIONS(629),
    [anon_sym_EQ] = ACTIONS(627),
    [anon_sym_function] = ACTIONS(629),
    [anon_sym_hook] = ACTIONS(629),
    [anon_sym_addr] = ACTIONS(629),
    [anon_sym_any] = ACTIONS(629),
    [anon_sym_bool] = ACTIONS(629),
    [anon_sym_count] = ACTIONS(629),
    [anon_sym_double] = ACTIONS(629),
    [anon_sym_file] = ACTIONS(629),
    [anon_sym_int] = ACTIONS(629),
    [anon_sym_interval] = ACTIONS(629),
    [anon_sym_list] = ACTIONS(629),
    [anon_sym_pattern] = ACTIONS(629),
    [anon_sym_port] = ACTIONS(629),
    [anon_sym_string] = ACTIONS(629),
    [anon_sym_subnet] = ACTIONS(629),
    [anon_sym_time] = ACTIONS(629),
    [anon_sym_opaque] = ACTIONS(629),
    [anon_sym_set] = ACTIONS(629),
    [anon_sym_table] = ACTIONS(629),
    [anon_sym_union] = ACTIONS(629),
    [anon_sym_vector] = ACTIONS(629),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(627),
    [anon_sym_AMPdeprecated] = ACTIONS(627),
    [anon_sym_AMPerror_handler] = ACTIONS(627),
    [anon_sym_AMPis_assigned] = ACTIONS(627),
    [anon_sym_AMPis_used] = ACTIONS(627),
    [anon_sym_AMPlog] = ACTIONS(627),
    [anon_sym_AMPoptional] = ACTIONS(627),
    [anon_sym_AMPordered] = ACTIONS(627),
    [anon_sym_AMPraw_output] = ACTIONS(627),
    [anon_sym_AMPredef] = ACTIONS(627),
    [anon_sym_AMPadd_func] = ACTIONS(627),
    [anon_sym_AMPbackend] = ACTIONS(627),
    [anon_sym_AMPbroker_store] = ACTIONS(627),
    [anon_sym_AMPcreate_expire] = ACTIONS(627),
    [anon_sym_AMPdefault] = ACTIONS(627),
    [anon_sym_AMPdelete_func] = ACTIONS(627),
    [anon_sym_AMPexpire_func] = ACTIONS(627),
    [anon_sym_AMPgroup] = ACTIONS(627),
    [anon_sym_AMPon_change] = ACTIONS(627),
    [anon_sym_AMPpriority] = ACTIONS(627),
    [anon_sym_AMPread_expire] = ACTIONS(627),
    [anon_sym_AMPtype_column] = ACTIONS(627),
    [anon_sym_AMPwrite_expire] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(627),
    [anon_sym_PIPE] = ACTIONS(627),
    [anon_sym_PLUS_PLUS] = ACTIONS(627),
    [anon_sym_DASH_DASH] = ACTIONS(627),
    [anon_sym_BANG] = ACTIONS(627),
    [anon_sym_TILDE] = ACTIONS(627),
    [anon_sym_DASH] = ACTIONS(629),
    [anon_sym_PLUS] = ACTIONS(629),
    [anon_sym_copy] = ACTIONS(629),
    [anon_sym_schedule] = ACTIONS(629),
    [anon_sym_T] = ACTIONS(629),
    [anon_sym_F] = ACTIONS(629),
    [anon_sym_ATdeprecated] = ACTIONS(627),
    [anon_sym_ATload] = ACTIONS(629),
    [anon_sym_ATload_DASHsigs] = ACTIONS(627),
    [anon_sym_ATload_DASHplugin] = ACTIONS(627),
    [anon_sym_ATunload] = ACTIONS(627),
    [anon_sym_ATprefixes] = ACTIONS(627),
    [anon_sym_ATif] = ACTIONS(629),
    [anon_sym_ATifdef] = ACTIONS(627),
    [anon_sym_ATifndef] = ACTIONS(627),
    [anon_sym_ATendif] = ACTIONS(627),
    [anon_sym_ATelse] = ACTIONS(627),
    [anon_sym_ATpragma] = ACTIONS(627),
    [anon_sym_ATDIR] = ACTIONS(627),
    [anon_sym_ATFILENAME] = ACTIONS(627),
    [sym_id] = ACTIONS(629),
    [sym_pattern] = ACTIONS(627),
    [sym_ipv4] = ACTIONS(629),
    [sym_ipv6] = ACTIONS(627),
    [sym_port] = ACTIONS(627),
    [sym_integer] = ACTIONS(629),
    [sym_floatp] = ACTIONS(629),
    [sym_hex] = ACTIONS(629),
    [sym_hostname] = ACTIONS(629),
    [aux_sym_string_token1] = ACTIONS(627),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(81)] = {
    [sym_stmt] = STATE(85),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(740),
    [sym_pragma] = STATE(729),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(85),
    [ts_builtin_sym_end] = ACTIONS(137),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(605),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(607),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(609),
    [anon_sym_ATload] = ACTIONS(611),
    [anon_sym_ATload_DASHsigs] = ACTIONS(613),
    [anon_sym_ATload_DASHplugin] = ACTIONS(615),
    [anon_sym_ATunload] = ACTIONS(613),
    [anon_sym_ATprefixes] = ACTIONS(617),
    [anon_sym_ATif] = ACTIONS(619),
    [anon_sym_ATifdef] = ACTIONS(621),
    [anon_sym_ATifndef] = ACTIONS(621),
    [anon_sym_ATendif] = ACTIONS(623),
    [anon_sym_ATelse] = ACTIONS(623),
    [anon_sym_ATpragma] = ACTIONS(625),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(82)] = {
    [sym_stmt] = STATE(82),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(82),
    [anon_sym_SEMI] = ACTIONS(631),
    [anon_sym_LBRACE] = ACTIONS(634),
    [anon_sym_RBRACE] = ACTIONS(366),
    [anon_sym_const] = ACTIONS(637),
    [anon_sym_enum] = ACTIONS(371),
    [anon_sym_record] = ACTIONS(374),
    [anon_sym_print] = ACTIONS(640),
    [anon_sym_event] = ACTIONS(643),
    [anon_sym_if] = ACTIONS(646),
    [anon_sym_LPAREN] = ACTIONS(386),
    [anon_sym_switch] = ACTIONS(649),
    [anon_sym_for] = ACTIONS(652),
    [anon_sym_LBRACK] = ACTIONS(395),
    [anon_sym_while] = ACTIONS(655),
    [anon_sym_next] = ACTIONS(658),
    [anon_sym_break] = ACTIONS(658),
    [anon_sym_fallthrough] = ACTIONS(658),
    [anon_sym_return] = ACTIONS(661),
    [anon_sym_add] = ACTIONS(664),
    [anon_sym_delete] = ACTIONS(664),
    [anon_sym_local] = ACTIONS(667),
    [anon_sym_when] = ACTIONS(670),
    [anon_sym_assert] = ACTIONS(673),
    [anon_sym_function] = ACTIONS(421),
    [anon_sym_hook] = ACTIONS(424),
    [anon_sym_addr] = ACTIONS(427),
    [anon_sym_any] = ACTIONS(427),
    [anon_sym_bool] = ACTIONS(427),
    [anon_sym_count] = ACTIONS(427),
    [anon_sym_double] = ACTIONS(427),
    [anon_sym_file] = ACTIONS(430),
    [anon_sym_int] = ACTIONS(427),
    [anon_sym_interval] = ACTIONS(427),
    [anon_sym_list] = ACTIONS(430),
    [anon_sym_pattern] = ACTIONS(427),
    [anon_sym_port] = ACTIONS(427),
    [anon_sym_string] = ACTIONS(427),
    [anon_sym_subnet] = ACTIONS(427),
    [anon_sym_time] = ACTIONS(427),
    [anon_sym_opaque] = ACTIONS(433),
    [anon_sym_set] = ACTIONS(436),
    [anon_sym_table] = ACTIONS(439),
    [anon_sym_union] = ACTIONS(442),
    [anon_sym_vector] = ACTIONS(445),
    [anon_sym_DOLLAR] = ACTIONS(448),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_PLUS_PLUS] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(454),
    [anon_sym_BANG] = ACTIONS(454),
    [anon_sym_TILDE] = ACTIONS(454),
    [anon_sym_DASH] = ACTIONS(457),
    [anon_sym_PLUS] = ACTIONS(457),
    [anon_sym_copy] = ACTIONS(460),
    [anon_sym_schedule] = ACTIONS(463),
    [anon_sym_T] = ACTIONS(466),
    [anon_sym_F] = ACTIONS(466),
    [anon_sym_ATdeprecated] = ACTIONS(676),
    [anon_sym_ATload] = ACTIONS(679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(682),
    [anon_sym_ATload_DASHplugin] = ACTIONS(685),
    [anon_sym_ATunload] = ACTIONS(682),
    [anon_sym_ATprefixes] = ACTIONS(688),
    [anon_sym_ATif] = ACTIONS(691),
    [anon_sym_ATifdef] = ACTIONS(694),
    [anon_sym_ATifndef] = ACTIONS(694),
    [anon_sym_ATendif] = ACTIONS(697),
    [anon_sym_ATelse] = ACTIONS(697),
    [anon_sym_ATpragma] = ACTIONS(700),
    [anon_sym_ATDIR] = ACTIONS(496),
    [anon_sym_ATFILENAME] = ACTIONS(496),
    [sym_id] = ACTIONS(499),
    [sym_pattern] = ACTIONS(502),
    [sym_ipv4] = ACTIONS(505),
    [sym_ipv6] = ACTIONS(508),
    [sym_port] = ACTIONS(511),
    [sym_integer] = ACTIONS(514),
    [sym_floatp] = ACTIONS(517),
    [sym_hex] = ACTIONS(466),
    [sym_hostname] = ACTIONS(466),
    [aux_sym_string_token1] = ACTIONS(520),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(83)] = {
    [anon_sym_SEMI] = ACTIONS(703),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_enum] = ACTIONS(705),
    [anon_sym_PLUS_EQ] = ACTIONS(703),
    [anon_sym_record] = ACTIONS(705),
    [anon_sym_DASH_EQ] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(703),
    [anon_sym_RPAREN] = ACTIONS(703),
    [anon_sym_COMMA] = ACTIONS(703),
    [anon_sym_LBRACK] = ACTIONS(705),
    [anon_sym_local] = ACTIONS(705),
    [anon_sym_EQ] = ACTIONS(703),
    [anon_sym_function] = ACTIONS(705),
    [anon_sym_hook] = ACTIONS(705),
    [anon_sym_addr] = ACTIONS(705),
    [anon_sym_any] = ACTIONS(705),
    [anon_sym_bool] = ACTIONS(705),
    [anon_sym_count] = ACTIONS(705),
    [anon_sym_double] = ACTIONS(705),
    [anon_sym_file] = ACTIONS(705),
    [anon_sym_int] = ACTIONS(705),
    [anon_sym_interval] = ACTIONS(705),
    [anon_sym_list] = ACTIONS(705),
    [anon_sym_pattern] = ACTIONS(705),
    [anon_sym_port] = ACTIONS(705),
    [anon_sym_string] = ACTIONS(705),
    [anon_sym_subnet] = ACTIONS(705),
    [anon_sym_time] = ACTIONS(705),
    [anon_sym_opaque] = ACTIONS(705),
    [anon_sym_set] = ACTIONS(705),
    [anon_sym_table] = ACTIONS(705),
    [anon_sym_union] = ACTIONS(705),
    [anon_sym_vector] = ACTIONS(705),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(703),
    [anon_sym_AMPdeprecated] = ACTIONS(703),
    [anon_sym_AMPerror_handler] = ACTIONS(703),
    [anon_sym_AMPis_assigned] = ACTIONS(703),
    [anon_sym_AMPis_used] = ACTIONS(703),
    [anon_sym_AMPlog] = ACTIONS(703),
    [anon_sym_AMPoptional] = ACTIONS(703),
    [anon_sym_AMPordered] = ACTIONS(703),
    [anon_sym_AMPraw_output] = ACTIONS(703),
    [anon_sym_AMPredef] = ACTIONS(703),
    [anon_sym_AMPadd_func] = ACTIONS(703),
    [anon_sym_AMPbackend] = ACTIONS(703),
    [anon_sym_AMPbroker_store] = ACTIONS(703),
    [anon_sym_AMPcreate_expire] = ACTIONS(703),
    [anon_sym_AMPdefault] = ACTIONS(703),
    [anon_sym_AMPdelete_func] = ACTIONS(703),
    [anon_sym_AMPexpire_func] = ACTIONS(703),
    [anon_sym_AMPgroup] = ACTIONS(703),
    [anon_sym_AMPon_change] = ACTIONS(703),
    [anon_sym_AMPpriority] = ACTIONS(703),
    [anon_sym_AMPread_expire] = ACTIONS(703),
    [anon_sym_AMPtype_column] = ACTIONS(703),
    [anon_sym_AMPwrite_expire] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(703),
    [anon_sym_PIPE] = ACTIONS(703),
    [anon_sym_PLUS_PLUS] = ACTIONS(703),
    [anon_sym_DASH_DASH] = ACTIONS(703),
    [anon_sym_BANG] = ACTIONS(703),
    [anon_sym_TILDE] = ACTIONS(703),
    [anon_sym_DASH] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(705),
    [anon_sym_copy] = ACTIONS(705),
    [anon_sym_schedule] = ACTIONS(705),
    [anon_sym_T] = ACTIONS(705),
    [anon_sym_F] = ACTIONS(705),
    [anon_sym_ATdeprecated] = ACTIONS(703),
    [anon_sym_ATload] = ACTIONS(705),
    [anon_sym_ATload_DASHsigs] = ACTIONS(703),
    [anon_sym_ATload_DASHplugin] = ACTIONS(703),
    [anon_sym_ATunload] = ACTIONS(703),
    [anon_sym_ATprefixes] = ACTIONS(703),
    [anon_sym_ATif] = ACTIONS(705),
    [anon_sym_ATifdef] = ACTIONS(703),
    [anon_sym_ATifndef] = ACTIONS(703),
    [anon_sym_ATendif] = ACTIONS(703),
    [anon_sym_ATelse] = ACTIONS(703),
    [anon_sym_ATpragma] = ACTIONS(703),
    [anon_sym_ATDIR] = ACTIONS(703),
    [anon_sym_ATFILENAME] = ACTIONS(703),
    [sym_id] = ACTIONS(705),
    [sym_pattern] = ACTIONS(703),
    [sym_ipv4] = ACTIONS(705),
    [sym_ipv6] = ACTIONS(703),
    [sym_port] = ACTIONS(703),
    [sym_integer] = ACTIONS(705),
    [sym_floatp] = ACTIONS(705),
    [sym_hex] = ACTIONS(705),
    [sym_hostname] = ACTIONS(705),
    [aux_sym_string_token1] = ACTIONS(703),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(84)] = {
    [sym_stmt] = STATE(82),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(82),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_RBRACE] = ACTIONS(356),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(85)] = {
    [sym_stmt] = STATE(85),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(740),
    [sym_pragma] = STATE(729),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_source_file_repeat2] = STATE(85),
    [ts_builtin_sym_end] = ACTIONS(366),
    [anon_sym_SEMI] = ACTIONS(707),
    [anon_sym_LBRACE] = ACTIONS(710),
    [anon_sym_const] = ACTIONS(713),
    [anon_sym_enum] = ACTIONS(371),
    [anon_sym_record] = ACTIONS(374),
    [anon_sym_print] = ACTIONS(716),
    [anon_sym_event] = ACTIONS(719),
    [anon_sym_if] = ACTIONS(722),
    [anon_sym_LPAREN] = ACTIONS(386),
    [anon_sym_switch] = ACTIONS(725),
    [anon_sym_for] = ACTIONS(728),
    [anon_sym_LBRACK] = ACTIONS(395),
    [anon_sym_while] = ACTIONS(731),
    [anon_sym_next] = ACTIONS(734),
    [anon_sym_break] = ACTIONS(734),
    [anon_sym_fallthrough] = ACTIONS(734),
    [anon_sym_return] = ACTIONS(737),
    [anon_sym_add] = ACTIONS(740),
    [anon_sym_delete] = ACTIONS(740),
    [anon_sym_local] = ACTIONS(743),
    [anon_sym_when] = ACTIONS(746),
    [anon_sym_assert] = ACTIONS(749),
    [anon_sym_function] = ACTIONS(421),
    [anon_sym_hook] = ACTIONS(424),
    [anon_sym_addr] = ACTIONS(427),
    [anon_sym_any] = ACTIONS(427),
    [anon_sym_bool] = ACTIONS(427),
    [anon_sym_count] = ACTIONS(427),
    [anon_sym_double] = ACTIONS(427),
    [anon_sym_file] = ACTIONS(430),
    [anon_sym_int] = ACTIONS(427),
    [anon_sym_interval] = ACTIONS(427),
    [anon_sym_list] = ACTIONS(430),
    [anon_sym_pattern] = ACTIONS(427),
    [anon_sym_port] = ACTIONS(427),
    [anon_sym_string] = ACTIONS(427),
    [anon_sym_subnet] = ACTIONS(427),
    [anon_sym_time] = ACTIONS(427),
    [anon_sym_opaque] = ACTIONS(433),
    [anon_sym_set] = ACTIONS(436),
    [anon_sym_table] = ACTIONS(439),
    [anon_sym_union] = ACTIONS(442),
    [anon_sym_vector] = ACTIONS(445),
    [anon_sym_DOLLAR] = ACTIONS(448),
    [anon_sym_PIPE] = ACTIONS(451),
    [anon_sym_PLUS_PLUS] = ACTIONS(454),
    [anon_sym_DASH_DASH] = ACTIONS(454),
    [anon_sym_BANG] = ACTIONS(454),
    [anon_sym_TILDE] = ACTIONS(454),
    [anon_sym_DASH] = ACTIONS(457),
    [anon_sym_PLUS] = ACTIONS(457),
    [anon_sym_copy] = ACTIONS(460),
    [anon_sym_schedule] = ACTIONS(463),
    [anon_sym_T] = ACTIONS(466),
    [anon_sym_F] = ACTIONS(466),
    [anon_sym_ATdeprecated] = ACTIONS(752),
    [anon_sym_ATload] = ACTIONS(755),
    [anon_sym_ATload_DASHsigs] = ACTIONS(758),
    [anon_sym_ATload_DASHplugin] = ACTIONS(761),
    [anon_sym_ATunload] = ACTIONS(758),
    [anon_sym_ATprefixes] = ACTIONS(764),
    [anon_sym_ATif] = ACTIONS(767),
    [anon_sym_ATifdef] = ACTIONS(770),
    [anon_sym_ATifndef] = ACTIONS(770),
    [anon_sym_ATendif] = ACTIONS(773),
    [anon_sym_ATelse] = ACTIONS(773),
    [anon_sym_ATpragma] = ACTIONS(776),
    [anon_sym_ATDIR] = ACTIONS(496),
    [anon_sym_ATFILENAME] = ACTIONS(496),
    [sym_id] = ACTIONS(499),
    [sym_pattern] = ACTIONS(502),
    [sym_ipv4] = ACTIONS(505),
    [sym_ipv6] = ACTIONS(508),
    [sym_port] = ACTIONS(511),
    [sym_integer] = ACTIONS(514),
    [sym_floatp] = ACTIONS(517),
    [sym_hex] = ACTIONS(466),
    [sym_hostname] = ACTIONS(466),
    [aux_sym_string_token1] = ACTIONS(520),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(86)] = {
    [anon_sym_SEMI] = ACTIONS(779),
    [anon_sym_LBRACE] = ACTIONS(779),
    [anon_sym_enum] = ACTIONS(781),
    [anon_sym_PLUS_EQ] = ACTIONS(779),
    [anon_sym_record] = ACTIONS(781),
    [anon_sym_DASH_EQ] = ACTIONS(779),
    [anon_sym_LPAREN] = ACTIONS(779),
    [anon_sym_RPAREN] = ACTIONS(779),
    [anon_sym_COMMA] = ACTIONS(779),
    [anon_sym_LBRACK] = ACTIONS(781),
    [anon_sym_local] = ACTIONS(781),
    [anon_sym_EQ] = ACTIONS(779),
    [anon_sym_function] = ACTIONS(781),
    [anon_sym_hook] = ACTIONS(781),
    [anon_sym_addr] = ACTIONS(781),
    [anon_sym_any] = ACTIONS(781),
    [anon_sym_bool] = ACTIONS(781),
    [anon_sym_count] = ACTIONS(781),
    [anon_sym_double] = ACTIONS(781),
    [anon_sym_file] = ACTIONS(781),
    [anon_sym_int] = ACTIONS(781),
    [anon_sym_interval] = ACTIONS(781),
    [anon_sym_list] = ACTIONS(781),
    [anon_sym_pattern] = ACTIONS(781),
    [anon_sym_port] = ACTIONS(781),
    [anon_sym_string] = ACTIONS(781),
    [anon_sym_subnet] = ACTIONS(781),
    [anon_sym_time] = ACTIONS(781),
    [anon_sym_opaque] = ACTIONS(781),
    [anon_sym_set] = ACTIONS(781),
    [anon_sym_table] = ACTIONS(781),
    [anon_sym_union] = ACTIONS(781),
    [anon_sym_vector] = ACTIONS(781),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(779),
    [anon_sym_AMPdeprecated] = ACTIONS(779),
    [anon_sym_AMPerror_handler] = ACTIONS(779),
    [anon_sym_AMPis_assigned] = ACTIONS(779),
    [anon_sym_AMPis_used] = ACTIONS(779),
    [anon_sym_AMPlog] = ACTIONS(779),
    [anon_sym_AMPoptional] = ACTIONS(779),
    [anon_sym_AMPordered] = ACTIONS(779),
    [anon_sym_AMPraw_output] = ACTIONS(779),
    [anon_sym_AMPredef] = ACTIONS(779),
    [anon_sym_AMPadd_func] = ACTIONS(779),
    [anon_sym_AMPbackend] = ACTIONS(779),
    [anon_sym_AMPbroker_store] = ACTIONS(779),
    [anon_sym_AMPcreate_expire] = ACTIONS(779),
    [anon_sym_AMPdefault] = ACTIONS(779),
    [anon_sym_AMPdelete_func] = ACTIONS(779),
    [anon_sym_AMPexpire_func] = ACTIONS(779),
    [anon_sym_AMPgroup] = ACTIONS(779),
    [anon_sym_AMPon_change] = ACTIONS(779),
    [anon_sym_AMPpriority] = ACTIONS(779),
    [anon_sym_AMPread_expire] = ACTIONS(779),
    [anon_sym_AMPtype_column] = ACTIONS(779),
    [anon_sym_AMPwrite_expire] = ACTIONS(779),
    [anon_sym_DOLLAR] = ACTIONS(779),
    [anon_sym_PIPE] = ACTIONS(779),
    [anon_sym_PLUS_PLUS] = ACTIONS(779),
    [anon_sym_DASH_DASH] = ACTIONS(779),
    [anon_sym_BANG] = ACTIONS(779),
    [anon_sym_TILDE] = ACTIONS(779),
    [anon_sym_DASH] = ACTIONS(781),
    [anon_sym_PLUS] = ACTIONS(781),
    [anon_sym_copy] = ACTIONS(781),
    [anon_sym_schedule] = ACTIONS(781),
    [anon_sym_T] = ACTIONS(781),
    [anon_sym_F] = ACTIONS(781),
    [anon_sym_ATdeprecated] = ACTIONS(779),
    [anon_sym_ATload] = ACTIONS(781),
    [anon_sym_ATload_DASHsigs] = ACTIONS(779),
    [anon_sym_ATload_DASHplugin] = ACTIONS(779),
    [anon_sym_ATunload] = ACTIONS(779),
    [anon_sym_ATprefixes] = ACTIONS(779),
    [anon_sym_ATif] = ACTIONS(781),
    [anon_sym_ATifdef] = ACTIONS(779),
    [anon_sym_ATifndef] = ACTIONS(779),
    [anon_sym_ATendif] = ACTIONS(779),
    [anon_sym_ATelse] = ACTIONS(779),
    [anon_sym_ATpragma] = ACTIONS(779),
    [anon_sym_ATDIR] = ACTIONS(779),
    [anon_sym_ATFILENAME] = ACTIONS(779),
    [sym_id] = ACTIONS(781),
    [sym_pattern] = ACTIONS(779),
    [sym_ipv4] = ACTIONS(781),
    [sym_ipv6] = ACTIONS(779),
    [sym_port] = ACTIONS(779),
    [sym_integer] = ACTIONS(781),
    [sym_floatp] = ACTIONS(781),
    [sym_hex] = ACTIONS(781),
    [sym_hostname] = ACTIONS(781),
    [aux_sym_string_token1] = ACTIONS(779),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(87)] = {
    [anon_sym_SEMI] = ACTIONS(783),
    [anon_sym_LBRACE] = ACTIONS(783),
    [anon_sym_enum] = ACTIONS(785),
    [anon_sym_PLUS_EQ] = ACTIONS(783),
    [anon_sym_record] = ACTIONS(785),
    [anon_sym_DASH_EQ] = ACTIONS(783),
    [anon_sym_LPAREN] = ACTIONS(783),
    [anon_sym_RPAREN] = ACTIONS(783),
    [anon_sym_COMMA] = ACTIONS(783),
    [anon_sym_LBRACK] = ACTIONS(785),
    [anon_sym_local] = ACTIONS(785),
    [anon_sym_EQ] = ACTIONS(783),
    [anon_sym_function] = ACTIONS(785),
    [anon_sym_hook] = ACTIONS(785),
    [anon_sym_addr] = ACTIONS(785),
    [anon_sym_any] = ACTIONS(785),
    [anon_sym_bool] = ACTIONS(785),
    [anon_sym_count] = ACTIONS(785),
    [anon_sym_double] = ACTIONS(785),
    [anon_sym_file] = ACTIONS(785),
    [anon_sym_int] = ACTIONS(785),
    [anon_sym_interval] = ACTIONS(785),
    [anon_sym_list] = ACTIONS(785),
    [anon_sym_pattern] = ACTIONS(785),
    [anon_sym_port] = ACTIONS(785),
    [anon_sym_string] = ACTIONS(785),
    [anon_sym_subnet] = ACTIONS(785),
    [anon_sym_time] = ACTIONS(785),
    [anon_sym_opaque] = ACTIONS(785),
    [anon_sym_set] = ACTIONS(785),
    [anon_sym_table] = ACTIONS(785),
    [anon_sym_union] = ACTIONS(785),
    [anon_sym_vector] = ACTIONS(785),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(783),
    [anon_sym_AMPdeprecated] = ACTIONS(783),
    [anon_sym_AMPerror_handler] = ACTIONS(783),
    [anon_sym_AMPis_assigned] = ACTIONS(783),
    [anon_sym_AMPis_used] = ACTIONS(783),
    [anon_sym_AMPlog] = ACTIONS(783),
    [anon_sym_AMPoptional] = ACTIONS(783),
    [anon_sym_AMPordered] = ACTIONS(783),
    [anon_sym_AMPraw_output] = ACTIONS(783),
    [anon_sym_AMPredef] = ACTIONS(783),
    [anon_sym_AMPadd_func] = ACTIONS(783),
    [anon_sym_AMPbackend] = ACTIONS(783),
    [anon_sym_AMPbroker_store] = ACTIONS(783),
    [anon_sym_AMPcreate_expire] = ACTIONS(783),
    [anon_sym_AMPdefault] = ACTIONS(783),
    [anon_sym_AMPdelete_func] = ACTIONS(783),
    [anon_sym_AMPexpire_func] = ACTIONS(783),
    [anon_sym_AMPgroup] = ACTIONS(783),
    [anon_sym_AMPon_change] = ACTIONS(783),
    [anon_sym_AMPpriority] = ACTIONS(783),
    [anon_sym_AMPread_expire] = ACTIONS(783),
    [anon_sym_AMPtype_column] = ACTIONS(783),
    [anon_sym_AMPwrite_expire] = ACTIONS(783),
    [anon_sym_DOLLAR] = ACTIONS(783),
    [anon_sym_PIPE] = ACTIONS(783),
    [anon_sym_PLUS_PLUS] = ACTIONS(783),
    [anon_sym_DASH_DASH] = ACTIONS(783),
    [anon_sym_BANG] = ACTIONS(783),
    [anon_sym_TILDE] = ACTIONS(783),
    [anon_sym_DASH] = ACTIONS(785),
    [anon_sym_PLUS] = ACTIONS(785),
    [anon_sym_copy] = ACTIONS(785),
    [anon_sym_schedule] = ACTIONS(785),
    [anon_sym_T] = ACTIONS(785),
    [anon_sym_F] = ACTIONS(785),
    [anon_sym_ATdeprecated] = ACTIONS(783),
    [anon_sym_ATload] = ACTIONS(785),
    [anon_sym_ATload_DASHsigs] = ACTIONS(783),
    [anon_sym_ATload_DASHplugin] = ACTIONS(783),
    [anon_sym_ATunload] = ACTIONS(783),
    [anon_sym_ATprefixes] = ACTIONS(783),
    [anon_sym_ATif] = ACTIONS(785),
    [anon_sym_ATifdef] = ACTIONS(783),
    [anon_sym_ATifndef] = ACTIONS(783),
    [anon_sym_ATendif] = ACTIONS(783),
    [anon_sym_ATelse] = ACTIONS(783),
    [anon_sym_ATpragma] = ACTIONS(783),
    [anon_sym_ATDIR] = ACTIONS(783),
    [anon_sym_ATFILENAME] = ACTIONS(783),
    [sym_id] = ACTIONS(785),
    [sym_pattern] = ACTIONS(783),
    [sym_ipv4] = ACTIONS(785),
    [sym_ipv6] = ACTIONS(783),
    [sym_port] = ACTIONS(783),
    [sym_integer] = ACTIONS(785),
    [sym_floatp] = ACTIONS(785),
    [sym_hex] = ACTIONS(785),
    [sym_hostname] = ACTIONS(785),
    [aux_sym_string_token1] = ACTIONS(783),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(88)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1707),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2300),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(787),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(791),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(89)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1667),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2219),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(861),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(863),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(90)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1645),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2333),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(865),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(867),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(91)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1663),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2338),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(871),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(873),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(92)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1717),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2430),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(875),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(877),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(93)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1746),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2503),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(879),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(881),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(94)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1724),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2547),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(883),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(885),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(95)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1644),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2624),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(887),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(889),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(96)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1715),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2394),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(891),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(893),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(97)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1734),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2413),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(895),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(897),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(98)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1726),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2605),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(899),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(901),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(99)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1729),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2648),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(903),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(905),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(100)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1739),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2474),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(907),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(909),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(101)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1723),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2908),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(911),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(913),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(102)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1662),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2493),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(915),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(917),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(103)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1665),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2499),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(919),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(921),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(104)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1668),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2277),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(923),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(925),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(105)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1732),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2734),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(927),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(929),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(106)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1753),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2860),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(931),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(933),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(107)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1769),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2872),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(935),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(937),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(108)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1737),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2620),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(939),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(941),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(109)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1740),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2625),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(943),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(945),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(110)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1670),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2485),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(947),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(949),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(111)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1735),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2820),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(951),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(953),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(112)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1694),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2342),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(955),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(957),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(113)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1695),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2348),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(959),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(961),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(114)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1788),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2681),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(963),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(965),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(115)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1794),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2686),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(967),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(969),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(116)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1700),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2257),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(971),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(973),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(117)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1653),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2263),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(975),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(977),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(118)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1697),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2356),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(979),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(981),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(119)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1705),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2375),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(983),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(985),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(120)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1704),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2255),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(987),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_COLON] = ACTIONS(989),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(869),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(121)] = {
    [sym_stmt] = STATE(554),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(122)] = {
    [sym_stmt] = STATE(428),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1489),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2557),
    [sym_preproc_directive] = STATE(414),
    [sym_pragma] = STATE(402),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1039),
    [anon_sym_LBRACE] = ACTIONS(1041),
    [anon_sym_const] = ACTIONS(1043),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1045),
    [anon_sym_event] = ACTIONS(1047),
    [anon_sym_if] = ACTIONS(1049),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1051),
    [anon_sym_for] = ACTIONS(1053),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1055),
    [anon_sym_next] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_fallthrough] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1059),
    [anon_sym_add] = ACTIONS(1061),
    [anon_sym_delete] = ACTIONS(1061),
    [anon_sym_local] = ACTIONS(1063),
    [anon_sym_when] = ACTIONS(1065),
    [anon_sym_assert] = ACTIONS(1067),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1069),
    [anon_sym_ATload] = ACTIONS(1071),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1073),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1075),
    [anon_sym_ATunload] = ACTIONS(1073),
    [anon_sym_ATprefixes] = ACTIONS(1077),
    [anon_sym_ATif] = ACTIONS(1079),
    [anon_sym_ATifdef] = ACTIONS(1081),
    [anon_sym_ATifndef] = ACTIONS(1081),
    [anon_sym_ATendif] = ACTIONS(1083),
    [anon_sym_ATelse] = ACTIONS(1083),
    [anon_sym_ATpragma] = ACTIONS(1085),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(123)] = {
    [sym_stmt] = STATE(431),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1489),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2557),
    [sym_preproc_directive] = STATE(414),
    [sym_pragma] = STATE(402),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1039),
    [anon_sym_LBRACE] = ACTIONS(1041),
    [anon_sym_const] = ACTIONS(1043),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1045),
    [anon_sym_event] = ACTIONS(1047),
    [anon_sym_if] = ACTIONS(1049),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1051),
    [anon_sym_for] = ACTIONS(1053),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1055),
    [anon_sym_next] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_fallthrough] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1059),
    [anon_sym_add] = ACTIONS(1061),
    [anon_sym_delete] = ACTIONS(1061),
    [anon_sym_local] = ACTIONS(1063),
    [anon_sym_when] = ACTIONS(1065),
    [anon_sym_assert] = ACTIONS(1067),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1069),
    [anon_sym_ATload] = ACTIONS(1071),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1073),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1075),
    [anon_sym_ATunload] = ACTIONS(1073),
    [anon_sym_ATprefixes] = ACTIONS(1077),
    [anon_sym_ATif] = ACTIONS(1079),
    [anon_sym_ATifdef] = ACTIONS(1081),
    [anon_sym_ATifndef] = ACTIONS(1081),
    [anon_sym_ATendif] = ACTIONS(1083),
    [anon_sym_ATelse] = ACTIONS(1083),
    [anon_sym_ATpragma] = ACTIONS(1085),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(124)] = {
    [sym_stmt] = STATE(434),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1489),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2557),
    [sym_preproc_directive] = STATE(414),
    [sym_pragma] = STATE(402),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1039),
    [anon_sym_LBRACE] = ACTIONS(1041),
    [anon_sym_const] = ACTIONS(1043),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1045),
    [anon_sym_event] = ACTIONS(1047),
    [anon_sym_if] = ACTIONS(1049),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1051),
    [anon_sym_for] = ACTIONS(1053),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1055),
    [anon_sym_next] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_fallthrough] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1059),
    [anon_sym_add] = ACTIONS(1061),
    [anon_sym_delete] = ACTIONS(1061),
    [anon_sym_local] = ACTIONS(1063),
    [anon_sym_when] = ACTIONS(1065),
    [anon_sym_assert] = ACTIONS(1067),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1069),
    [anon_sym_ATload] = ACTIONS(1071),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1073),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1075),
    [anon_sym_ATunload] = ACTIONS(1073),
    [anon_sym_ATprefixes] = ACTIONS(1077),
    [anon_sym_ATif] = ACTIONS(1079),
    [anon_sym_ATifdef] = ACTIONS(1081),
    [anon_sym_ATifndef] = ACTIONS(1081),
    [anon_sym_ATendif] = ACTIONS(1083),
    [anon_sym_ATelse] = ACTIONS(1083),
    [anon_sym_ATpragma] = ACTIONS(1085),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(125)] = {
    [sym_stmt] = STATE(437),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1489),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2557),
    [sym_preproc_directive] = STATE(414),
    [sym_pragma] = STATE(402),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1039),
    [anon_sym_LBRACE] = ACTIONS(1041),
    [anon_sym_const] = ACTIONS(1043),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1045),
    [anon_sym_event] = ACTIONS(1047),
    [anon_sym_if] = ACTIONS(1049),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1051),
    [anon_sym_for] = ACTIONS(1053),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1055),
    [anon_sym_next] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_fallthrough] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1059),
    [anon_sym_add] = ACTIONS(1061),
    [anon_sym_delete] = ACTIONS(1061),
    [anon_sym_local] = ACTIONS(1063),
    [anon_sym_when] = ACTIONS(1065),
    [anon_sym_assert] = ACTIONS(1067),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1069),
    [anon_sym_ATload] = ACTIONS(1071),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1073),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1075),
    [anon_sym_ATunload] = ACTIONS(1073),
    [anon_sym_ATprefixes] = ACTIONS(1077),
    [anon_sym_ATif] = ACTIONS(1079),
    [anon_sym_ATifdef] = ACTIONS(1081),
    [anon_sym_ATifndef] = ACTIONS(1081),
    [anon_sym_ATendif] = ACTIONS(1083),
    [anon_sym_ATelse] = ACTIONS(1083),
    [anon_sym_ATpragma] = ACTIONS(1085),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(126)] = {
    [sym_stmt] = STATE(442),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1489),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2557),
    [sym_preproc_directive] = STATE(414),
    [sym_pragma] = STATE(402),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1039),
    [anon_sym_LBRACE] = ACTIONS(1041),
    [anon_sym_const] = ACTIONS(1043),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1045),
    [anon_sym_event] = ACTIONS(1047),
    [anon_sym_if] = ACTIONS(1049),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1051),
    [anon_sym_for] = ACTIONS(1053),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1055),
    [anon_sym_next] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_fallthrough] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1059),
    [anon_sym_add] = ACTIONS(1061),
    [anon_sym_delete] = ACTIONS(1061),
    [anon_sym_local] = ACTIONS(1063),
    [anon_sym_when] = ACTIONS(1065),
    [anon_sym_assert] = ACTIONS(1067),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1069),
    [anon_sym_ATload] = ACTIONS(1071),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1073),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1075),
    [anon_sym_ATunload] = ACTIONS(1073),
    [anon_sym_ATprefixes] = ACTIONS(1077),
    [anon_sym_ATif] = ACTIONS(1079),
    [anon_sym_ATifdef] = ACTIONS(1081),
    [anon_sym_ATifndef] = ACTIONS(1081),
    [anon_sym_ATendif] = ACTIONS(1083),
    [anon_sym_ATelse] = ACTIONS(1083),
    [anon_sym_ATpragma] = ACTIONS(1085),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(127)] = {
    [sym_stmt] = STATE(753),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(740),
    [sym_pragma] = STATE(729),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(605),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(607),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(609),
    [anon_sym_ATload] = ACTIONS(611),
    [anon_sym_ATload_DASHsigs] = ACTIONS(613),
    [anon_sym_ATload_DASHplugin] = ACTIONS(615),
    [anon_sym_ATunload] = ACTIONS(613),
    [anon_sym_ATprefixes] = ACTIONS(617),
    [anon_sym_ATif] = ACTIONS(619),
    [anon_sym_ATifdef] = ACTIONS(621),
    [anon_sym_ATifndef] = ACTIONS(621),
    [anon_sym_ATendif] = ACTIONS(623),
    [anon_sym_ATelse] = ACTIONS(623),
    [anon_sym_ATpragma] = ACTIONS(625),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(128)] = {
    [sym_stmt] = STATE(386),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(129)] = {
    [sym_stmt] = STATE(390),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(130)] = {
    [sym_stmt] = STATE(391),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(131)] = {
    [sym_stmt] = STATE(393),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(132)] = {
    [sym_stmt] = STATE(395),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(133)] = {
    [sym_stmt] = STATE(397),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(134)] = {
    [sym_stmt] = STATE(399),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(135)] = {
    [sym_stmt] = STATE(754),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(740),
    [sym_pragma] = STATE(729),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(605),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(607),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(609),
    [anon_sym_ATload] = ACTIONS(611),
    [anon_sym_ATload_DASHsigs] = ACTIONS(613),
    [anon_sym_ATload_DASHplugin] = ACTIONS(615),
    [anon_sym_ATunload] = ACTIONS(613),
    [anon_sym_ATprefixes] = ACTIONS(617),
    [anon_sym_ATif] = ACTIONS(619),
    [anon_sym_ATifdef] = ACTIONS(621),
    [anon_sym_ATifndef] = ACTIONS(621),
    [anon_sym_ATendif] = ACTIONS(623),
    [anon_sym_ATelse] = ACTIONS(623),
    [anon_sym_ATpragma] = ACTIONS(625),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(136)] = {
    [sym_stmt] = STATE(353),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(137)] = {
    [sym_stmt] = STATE(357),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(138)] = {
    [sym_stmt] = STATE(358),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(139)] = {
    [sym_stmt] = STATE(360),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(140)] = {
    [sym_stmt] = STATE(362),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(141)] = {
    [sym_stmt] = STATE(364),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(142)] = {
    [sym_stmt] = STATE(366),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(143)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1760),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2479),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1183),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(144)] = {
    [sym_stmt] = STATE(592),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(145)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1767),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2232),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1233),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(146)] = {
    [sym_stmt] = STATE(710),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(147)] = {
    [sym_stmt] = STATE(653),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(148)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1754),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2661),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1235),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(149)] = {
    [sym_stmt] = STATE(716),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(150)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1749),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2522),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1237),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(151)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1750),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2538),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1239),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(152)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1755),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2548),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1241),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(153)] = {
    [sym_stmt] = STATE(646),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1537),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2472),
    [sym_preproc_directive] = STATE(624),
    [sym_pragma] = STATE(620),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_const] = ACTIONS(1247),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1249),
    [anon_sym_event] = ACTIONS(1251),
    [anon_sym_if] = ACTIONS(1253),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1255),
    [anon_sym_for] = ACTIONS(1257),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1259),
    [anon_sym_next] = ACTIONS(1261),
    [anon_sym_break] = ACTIONS(1261),
    [anon_sym_fallthrough] = ACTIONS(1261),
    [anon_sym_return] = ACTIONS(1263),
    [anon_sym_add] = ACTIONS(1265),
    [anon_sym_delete] = ACTIONS(1265),
    [anon_sym_local] = ACTIONS(1267),
    [anon_sym_when] = ACTIONS(1269),
    [anon_sym_assert] = ACTIONS(1271),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1273),
    [anon_sym_ATload] = ACTIONS(1275),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1277),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1279),
    [anon_sym_ATunload] = ACTIONS(1277),
    [anon_sym_ATprefixes] = ACTIONS(1281),
    [anon_sym_ATif] = ACTIONS(1283),
    [anon_sym_ATifdef] = ACTIONS(1285),
    [anon_sym_ATifndef] = ACTIONS(1285),
    [anon_sym_ATendif] = ACTIONS(1287),
    [anon_sym_ATelse] = ACTIONS(1287),
    [anon_sym_ATpragma] = ACTIONS(1289),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(154)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1761),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2578),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1291),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(155)] = {
    [sym_stmt] = STATE(647),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(156)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1774),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2617),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1341),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(157)] = {
    [sym_stmt] = STATE(650),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(158)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1777),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2637),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1343),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(159)] = {
    [sym_stmt] = STATE(651),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(160)] = {
    [sym_stmt] = STATE(717),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(161)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1708),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2688),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1345),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(162)] = {
    [sym_stmt] = STATE(721),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(163)] = {
    [sym_stmt] = STATE(723),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(164)] = {
    [sym_stmt] = STATE(725),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(165)] = {
    [sym_stmt] = STATE(727),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1409),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2311),
    [sym_preproc_directive] = STATE(752),
    [sym_pragma] = STATE(711),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(274),
    [anon_sym_LBRACE] = ACTIONS(523),
    [anon_sym_const] = ACTIONS(280),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(282),
    [anon_sym_event] = ACTIONS(284),
    [anon_sym_if] = ACTIONS(286),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(288),
    [anon_sym_for] = ACTIONS(290),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(292),
    [anon_sym_next] = ACTIONS(294),
    [anon_sym_break] = ACTIONS(294),
    [anon_sym_fallthrough] = ACTIONS(294),
    [anon_sym_return] = ACTIONS(296),
    [anon_sym_add] = ACTIONS(298),
    [anon_sym_delete] = ACTIONS(298),
    [anon_sym_local] = ACTIONS(300),
    [anon_sym_when] = ACTIONS(302),
    [anon_sym_assert] = ACTIONS(304),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(306),
    [anon_sym_ATload] = ACTIONS(308),
    [anon_sym_ATload_DASHsigs] = ACTIONS(310),
    [anon_sym_ATload_DASHplugin] = ACTIONS(312),
    [anon_sym_ATunload] = ACTIONS(310),
    [anon_sym_ATprefixes] = ACTIONS(314),
    [anon_sym_ATif] = ACTIONS(316),
    [anon_sym_ATifdef] = ACTIONS(318),
    [anon_sym_ATifndef] = ACTIONS(318),
    [anon_sym_ATendif] = ACTIONS(320),
    [anon_sym_ATelse] = ACTIONS(320),
    [anon_sym_ATpragma] = ACTIONS(322),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(166)] = {
    [sym_stmt] = STATE(722),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(740),
    [sym_pragma] = STATE(729),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(605),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(607),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(609),
    [anon_sym_ATload] = ACTIONS(611),
    [anon_sym_ATload_DASHsigs] = ACTIONS(613),
    [anon_sym_ATload_DASHplugin] = ACTIONS(615),
    [anon_sym_ATunload] = ACTIONS(613),
    [anon_sym_ATprefixes] = ACTIONS(617),
    [anon_sym_ATif] = ACTIONS(619),
    [anon_sym_ATifdef] = ACTIONS(621),
    [anon_sym_ATifndef] = ACTIONS(621),
    [anon_sym_ATendif] = ACTIONS(623),
    [anon_sym_ATelse] = ACTIONS(623),
    [anon_sym_ATpragma] = ACTIONS(625),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(167)] = {
    [sym_stmt] = STATE(553),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(168)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1688),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2494),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1347),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(169)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1673),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2679),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1349),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(170)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1691),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2544),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1351),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(171)] = {
    [sym_stmt] = STATE(555),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(172)] = {
    [sym_stmt] = STATE(556),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(173)] = {
    [sym_stmt] = STATE(751),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(740),
    [sym_pragma] = STATE(729),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(605),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(607),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(609),
    [anon_sym_ATload] = ACTIONS(611),
    [anon_sym_ATload_DASHsigs] = ACTIONS(613),
    [anon_sym_ATload_DASHplugin] = ACTIONS(615),
    [anon_sym_ATunload] = ACTIONS(613),
    [anon_sym_ATprefixes] = ACTIONS(617),
    [anon_sym_ATif] = ACTIONS(619),
    [anon_sym_ATifdef] = ACTIONS(621),
    [anon_sym_ATifndef] = ACTIONS(621),
    [anon_sym_ATendif] = ACTIONS(623),
    [anon_sym_ATelse] = ACTIONS(623),
    [anon_sym_ATpragma] = ACTIONS(625),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(174)] = {
    [sym_stmt] = STATE(669),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1483),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2411),
    [sym_preproc_directive] = STATE(659),
    [sym_pragma] = STATE(619),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_const] = ACTIONS(1357),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1359),
    [anon_sym_event] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1365),
    [anon_sym_for] = ACTIONS(1367),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1369),
    [anon_sym_next] = ACTIONS(1371),
    [anon_sym_break] = ACTIONS(1371),
    [anon_sym_fallthrough] = ACTIONS(1371),
    [anon_sym_return] = ACTIONS(1373),
    [anon_sym_add] = ACTIONS(1375),
    [anon_sym_delete] = ACTIONS(1375),
    [anon_sym_local] = ACTIONS(1377),
    [anon_sym_when] = ACTIONS(1379),
    [anon_sym_assert] = ACTIONS(1381),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1383),
    [anon_sym_ATload] = ACTIONS(1385),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1387),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1389),
    [anon_sym_ATunload] = ACTIONS(1387),
    [anon_sym_ATprefixes] = ACTIONS(1391),
    [anon_sym_ATif] = ACTIONS(1393),
    [anon_sym_ATifdef] = ACTIONS(1395),
    [anon_sym_ATifndef] = ACTIONS(1395),
    [anon_sym_ATendif] = ACTIONS(1397),
    [anon_sym_ATelse] = ACTIONS(1397),
    [anon_sym_ATpragma] = ACTIONS(1399),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(175)] = {
    [sym_stmt] = STATE(674),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1483),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2411),
    [sym_preproc_directive] = STATE(659),
    [sym_pragma] = STATE(619),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_const] = ACTIONS(1357),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1359),
    [anon_sym_event] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1365),
    [anon_sym_for] = ACTIONS(1367),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1369),
    [anon_sym_next] = ACTIONS(1371),
    [anon_sym_break] = ACTIONS(1371),
    [anon_sym_fallthrough] = ACTIONS(1371),
    [anon_sym_return] = ACTIONS(1373),
    [anon_sym_add] = ACTIONS(1375),
    [anon_sym_delete] = ACTIONS(1375),
    [anon_sym_local] = ACTIONS(1377),
    [anon_sym_when] = ACTIONS(1379),
    [anon_sym_assert] = ACTIONS(1381),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1383),
    [anon_sym_ATload] = ACTIONS(1385),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1387),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1389),
    [anon_sym_ATunload] = ACTIONS(1387),
    [anon_sym_ATprefixes] = ACTIONS(1391),
    [anon_sym_ATif] = ACTIONS(1393),
    [anon_sym_ATifdef] = ACTIONS(1395),
    [anon_sym_ATifndef] = ACTIONS(1395),
    [anon_sym_ATendif] = ACTIONS(1397),
    [anon_sym_ATelse] = ACTIONS(1397),
    [anon_sym_ATpragma] = ACTIONS(1399),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(176)] = {
    [sym_stmt] = STATE(675),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1483),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2411),
    [sym_preproc_directive] = STATE(659),
    [sym_pragma] = STATE(619),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_const] = ACTIONS(1357),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1359),
    [anon_sym_event] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1365),
    [anon_sym_for] = ACTIONS(1367),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1369),
    [anon_sym_next] = ACTIONS(1371),
    [anon_sym_break] = ACTIONS(1371),
    [anon_sym_fallthrough] = ACTIONS(1371),
    [anon_sym_return] = ACTIONS(1373),
    [anon_sym_add] = ACTIONS(1375),
    [anon_sym_delete] = ACTIONS(1375),
    [anon_sym_local] = ACTIONS(1377),
    [anon_sym_when] = ACTIONS(1379),
    [anon_sym_assert] = ACTIONS(1381),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1383),
    [anon_sym_ATload] = ACTIONS(1385),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1387),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1389),
    [anon_sym_ATunload] = ACTIONS(1387),
    [anon_sym_ATprefixes] = ACTIONS(1391),
    [anon_sym_ATif] = ACTIONS(1393),
    [anon_sym_ATifdef] = ACTIONS(1395),
    [anon_sym_ATifndef] = ACTIONS(1395),
    [anon_sym_ATendif] = ACTIONS(1397),
    [anon_sym_ATelse] = ACTIONS(1397),
    [anon_sym_ATpragma] = ACTIONS(1399),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(177)] = {
    [sym_stmt] = STATE(692),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1483),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2411),
    [sym_preproc_directive] = STATE(659),
    [sym_pragma] = STATE(619),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_const] = ACTIONS(1357),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1359),
    [anon_sym_event] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1365),
    [anon_sym_for] = ACTIONS(1367),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1369),
    [anon_sym_next] = ACTIONS(1371),
    [anon_sym_break] = ACTIONS(1371),
    [anon_sym_fallthrough] = ACTIONS(1371),
    [anon_sym_return] = ACTIONS(1373),
    [anon_sym_add] = ACTIONS(1375),
    [anon_sym_delete] = ACTIONS(1375),
    [anon_sym_local] = ACTIONS(1377),
    [anon_sym_when] = ACTIONS(1379),
    [anon_sym_assert] = ACTIONS(1381),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1383),
    [anon_sym_ATload] = ACTIONS(1385),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1387),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1389),
    [anon_sym_ATunload] = ACTIONS(1387),
    [anon_sym_ATprefixes] = ACTIONS(1391),
    [anon_sym_ATif] = ACTIONS(1393),
    [anon_sym_ATifdef] = ACTIONS(1395),
    [anon_sym_ATifndef] = ACTIONS(1395),
    [anon_sym_ATendif] = ACTIONS(1397),
    [anon_sym_ATelse] = ACTIONS(1397),
    [anon_sym_ATpragma] = ACTIONS(1399),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(178)] = {
    [sym_stmt] = STATE(694),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1483),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2411),
    [sym_preproc_directive] = STATE(659),
    [sym_pragma] = STATE(619),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_const] = ACTIONS(1357),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1359),
    [anon_sym_event] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1365),
    [anon_sym_for] = ACTIONS(1367),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1369),
    [anon_sym_next] = ACTIONS(1371),
    [anon_sym_break] = ACTIONS(1371),
    [anon_sym_fallthrough] = ACTIONS(1371),
    [anon_sym_return] = ACTIONS(1373),
    [anon_sym_add] = ACTIONS(1375),
    [anon_sym_delete] = ACTIONS(1375),
    [anon_sym_local] = ACTIONS(1377),
    [anon_sym_when] = ACTIONS(1379),
    [anon_sym_assert] = ACTIONS(1381),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1383),
    [anon_sym_ATload] = ACTIONS(1385),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1387),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1389),
    [anon_sym_ATunload] = ACTIONS(1387),
    [anon_sym_ATprefixes] = ACTIONS(1391),
    [anon_sym_ATif] = ACTIONS(1393),
    [anon_sym_ATifdef] = ACTIONS(1395),
    [anon_sym_ATifndef] = ACTIONS(1395),
    [anon_sym_ATendif] = ACTIONS(1397),
    [anon_sym_ATelse] = ACTIONS(1397),
    [anon_sym_ATpragma] = ACTIONS(1399),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(179)] = {
    [sym_stmt] = STATE(639),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1537),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2472),
    [sym_preproc_directive] = STATE(624),
    [sym_pragma] = STATE(620),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_const] = ACTIONS(1247),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1249),
    [anon_sym_event] = ACTIONS(1251),
    [anon_sym_if] = ACTIONS(1253),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1255),
    [anon_sym_for] = ACTIONS(1257),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1259),
    [anon_sym_next] = ACTIONS(1261),
    [anon_sym_break] = ACTIONS(1261),
    [anon_sym_fallthrough] = ACTIONS(1261),
    [anon_sym_return] = ACTIONS(1263),
    [anon_sym_add] = ACTIONS(1265),
    [anon_sym_delete] = ACTIONS(1265),
    [anon_sym_local] = ACTIONS(1267),
    [anon_sym_when] = ACTIONS(1269),
    [anon_sym_assert] = ACTIONS(1271),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1273),
    [anon_sym_ATload] = ACTIONS(1275),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1277),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1279),
    [anon_sym_ATunload] = ACTIONS(1277),
    [anon_sym_ATprefixes] = ACTIONS(1281),
    [anon_sym_ATif] = ACTIONS(1283),
    [anon_sym_ATifdef] = ACTIONS(1285),
    [anon_sym_ATifndef] = ACTIONS(1285),
    [anon_sym_ATendif] = ACTIONS(1287),
    [anon_sym_ATelse] = ACTIONS(1287),
    [anon_sym_ATpragma] = ACTIONS(1289),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(180)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1711),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2392),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1401),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(181)] = {
    [sym_stmt] = STATE(515),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(182)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1712),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2415),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1451),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(183)] = {
    [sym_stmt] = STATE(520),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(184)] = {
    [sym_stmt] = STATE(484),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(185)] = {
    [sym_stmt] = STATE(696),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1483),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2411),
    [sym_preproc_directive] = STATE(659),
    [sym_pragma] = STATE(619),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_const] = ACTIONS(1357),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1359),
    [anon_sym_event] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1365),
    [anon_sym_for] = ACTIONS(1367),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1369),
    [anon_sym_next] = ACTIONS(1371),
    [anon_sym_break] = ACTIONS(1371),
    [anon_sym_fallthrough] = ACTIONS(1371),
    [anon_sym_return] = ACTIONS(1373),
    [anon_sym_add] = ACTIONS(1375),
    [anon_sym_delete] = ACTIONS(1375),
    [anon_sym_local] = ACTIONS(1377),
    [anon_sym_when] = ACTIONS(1379),
    [anon_sym_assert] = ACTIONS(1381),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1383),
    [anon_sym_ATload] = ACTIONS(1385),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1387),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1389),
    [anon_sym_ATunload] = ACTIONS(1387),
    [anon_sym_ATprefixes] = ACTIONS(1391),
    [anon_sym_ATif] = ACTIONS(1393),
    [anon_sym_ATifdef] = ACTIONS(1395),
    [anon_sym_ATifndef] = ACTIONS(1395),
    [anon_sym_ATendif] = ACTIONS(1397),
    [anon_sym_ATelse] = ACTIONS(1397),
    [anon_sym_ATpragma] = ACTIONS(1399),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(186)] = {
    [sym_stmt] = STATE(698),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1483),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2411),
    [sym_preproc_directive] = STATE(659),
    [sym_pragma] = STATE(619),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_const] = ACTIONS(1357),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1359),
    [anon_sym_event] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1365),
    [anon_sym_for] = ACTIONS(1367),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1369),
    [anon_sym_next] = ACTIONS(1371),
    [anon_sym_break] = ACTIONS(1371),
    [anon_sym_fallthrough] = ACTIONS(1371),
    [anon_sym_return] = ACTIONS(1373),
    [anon_sym_add] = ACTIONS(1375),
    [anon_sym_delete] = ACTIONS(1375),
    [anon_sym_local] = ACTIONS(1377),
    [anon_sym_when] = ACTIONS(1379),
    [anon_sym_assert] = ACTIONS(1381),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1383),
    [anon_sym_ATload] = ACTIONS(1385),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1387),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1389),
    [anon_sym_ATunload] = ACTIONS(1387),
    [anon_sym_ATprefixes] = ACTIONS(1391),
    [anon_sym_ATif] = ACTIONS(1393),
    [anon_sym_ATifdef] = ACTIONS(1395),
    [anon_sym_ATifndef] = ACTIONS(1395),
    [anon_sym_ATendif] = ACTIONS(1397),
    [anon_sym_ATelse] = ACTIONS(1397),
    [anon_sym_ATpragma] = ACTIONS(1399),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(187)] = {
    [sym_stmt] = STATE(607),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(188)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1676),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2685),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1453),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(189)] = {
    [sym_stmt] = STATE(623),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(190)] = {
    [sym_stmt] = STATE(655),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(191)] = {
    [sym_stmt] = STATE(548),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(192)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1733),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2742),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1455),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(193)] = {
    [sym_stmt] = STATE(406),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(194)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1799),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2753),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1457),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(195)] = {
    [sym_stmt] = STATE(430),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(196)] = {
    [sym_stmt] = STATE(448),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(197)] = {
    [sym_stmt] = STATE(683),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(198)] = {
    [sym_stmt] = STATE(582),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(199)] = {
    [sym_stmt] = STATE(597),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(200)] = {
    [sym_stmt] = STATE(600),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(201)] = {
    [sym_stmt] = STATE(609),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(202)] = {
    [sym_stmt] = STATE(733),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(740),
    [sym_pragma] = STATE(729),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(605),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(607),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(609),
    [anon_sym_ATload] = ACTIONS(611),
    [anon_sym_ATload_DASHsigs] = ACTIONS(613),
    [anon_sym_ATload_DASHplugin] = ACTIONS(615),
    [anon_sym_ATunload] = ACTIONS(613),
    [anon_sym_ATprefixes] = ACTIONS(617),
    [anon_sym_ATif] = ACTIONS(619),
    [anon_sym_ATifdef] = ACTIONS(621),
    [anon_sym_ATifndef] = ACTIONS(621),
    [anon_sym_ATendif] = ACTIONS(623),
    [anon_sym_ATelse] = ACTIONS(623),
    [anon_sym_ATpragma] = ACTIONS(625),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(203)] = {
    [sym_stmt] = STATE(405),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1489),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2557),
    [sym_preproc_directive] = STATE(414),
    [sym_pragma] = STATE(402),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1039),
    [anon_sym_LBRACE] = ACTIONS(1041),
    [anon_sym_const] = ACTIONS(1043),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1045),
    [anon_sym_event] = ACTIONS(1047),
    [anon_sym_if] = ACTIONS(1049),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1051),
    [anon_sym_for] = ACTIONS(1053),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1055),
    [anon_sym_next] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_fallthrough] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1059),
    [anon_sym_add] = ACTIONS(1061),
    [anon_sym_delete] = ACTIONS(1061),
    [anon_sym_local] = ACTIONS(1063),
    [anon_sym_when] = ACTIONS(1065),
    [anon_sym_assert] = ACTIONS(1067),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1069),
    [anon_sym_ATload] = ACTIONS(1071),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1073),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1075),
    [anon_sym_ATunload] = ACTIONS(1073),
    [anon_sym_ATprefixes] = ACTIONS(1077),
    [anon_sym_ATif] = ACTIONS(1079),
    [anon_sym_ATifdef] = ACTIONS(1081),
    [anon_sym_ATifndef] = ACTIONS(1081),
    [anon_sym_ATendif] = ACTIONS(1083),
    [anon_sym_ATelse] = ACTIONS(1083),
    [anon_sym_ATpragma] = ACTIONS(1085),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(204)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1782),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2898),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1459),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(205)] = {
    [sym_stmt] = STATE(342),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(206)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1783),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2903),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1461),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(207)] = {
    [sym_stmt] = STATE(340),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(208)] = {
    [sym_stmt] = STATE(343),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(209)] = {
    [sym_stmt] = STATE(645),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1537),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2472),
    [sym_preproc_directive] = STATE(624),
    [sym_pragma] = STATE(620),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_const] = ACTIONS(1247),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1249),
    [anon_sym_event] = ACTIONS(1251),
    [anon_sym_if] = ACTIONS(1253),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1255),
    [anon_sym_for] = ACTIONS(1257),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1259),
    [anon_sym_next] = ACTIONS(1261),
    [anon_sym_break] = ACTIONS(1261),
    [anon_sym_fallthrough] = ACTIONS(1261),
    [anon_sym_return] = ACTIONS(1263),
    [anon_sym_add] = ACTIONS(1265),
    [anon_sym_delete] = ACTIONS(1265),
    [anon_sym_local] = ACTIONS(1267),
    [anon_sym_when] = ACTIONS(1269),
    [anon_sym_assert] = ACTIONS(1271),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1273),
    [anon_sym_ATload] = ACTIONS(1275),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1277),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1279),
    [anon_sym_ATunload] = ACTIONS(1277),
    [anon_sym_ATprefixes] = ACTIONS(1281),
    [anon_sym_ATif] = ACTIONS(1283),
    [anon_sym_ATifdef] = ACTIONS(1285),
    [anon_sym_ATifndef] = ACTIONS(1285),
    [anon_sym_ATendif] = ACTIONS(1287),
    [anon_sym_ATelse] = ACTIONS(1287),
    [anon_sym_ATpragma] = ACTIONS(1289),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(210)] = {
    [sym_stmt] = STATE(670),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1537),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2472),
    [sym_preproc_directive] = STATE(624),
    [sym_pragma] = STATE(620),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_const] = ACTIONS(1247),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1249),
    [anon_sym_event] = ACTIONS(1251),
    [anon_sym_if] = ACTIONS(1253),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1255),
    [anon_sym_for] = ACTIONS(1257),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1259),
    [anon_sym_next] = ACTIONS(1261),
    [anon_sym_break] = ACTIONS(1261),
    [anon_sym_fallthrough] = ACTIONS(1261),
    [anon_sym_return] = ACTIONS(1263),
    [anon_sym_add] = ACTIONS(1265),
    [anon_sym_delete] = ACTIONS(1265),
    [anon_sym_local] = ACTIONS(1267),
    [anon_sym_when] = ACTIONS(1269),
    [anon_sym_assert] = ACTIONS(1271),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1273),
    [anon_sym_ATload] = ACTIONS(1275),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1277),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1279),
    [anon_sym_ATunload] = ACTIONS(1277),
    [anon_sym_ATprefixes] = ACTIONS(1281),
    [anon_sym_ATif] = ACTIONS(1283),
    [anon_sym_ATifdef] = ACTIONS(1285),
    [anon_sym_ATifndef] = ACTIONS(1285),
    [anon_sym_ATendif] = ACTIONS(1287),
    [anon_sym_ATelse] = ACTIONS(1287),
    [anon_sym_ATpragma] = ACTIONS(1289),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(211)] = {
    [sym_stmt] = STATE(427),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1489),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2557),
    [sym_preproc_directive] = STATE(414),
    [sym_pragma] = STATE(402),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1039),
    [anon_sym_LBRACE] = ACTIONS(1041),
    [anon_sym_const] = ACTIONS(1043),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1045),
    [anon_sym_event] = ACTIONS(1047),
    [anon_sym_if] = ACTIONS(1049),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1051),
    [anon_sym_for] = ACTIONS(1053),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1055),
    [anon_sym_next] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_fallthrough] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1059),
    [anon_sym_add] = ACTIONS(1061),
    [anon_sym_delete] = ACTIONS(1061),
    [anon_sym_local] = ACTIONS(1063),
    [anon_sym_when] = ACTIONS(1065),
    [anon_sym_assert] = ACTIONS(1067),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1069),
    [anon_sym_ATload] = ACTIONS(1071),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1073),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1075),
    [anon_sym_ATunload] = ACTIONS(1073),
    [anon_sym_ATprefixes] = ACTIONS(1077),
    [anon_sym_ATif] = ACTIONS(1079),
    [anon_sym_ATifdef] = ACTIONS(1081),
    [anon_sym_ATifndef] = ACTIONS(1081),
    [anon_sym_ATendif] = ACTIONS(1083),
    [anon_sym_ATelse] = ACTIONS(1083),
    [anon_sym_ATpragma] = ACTIONS(1085),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(212)] = {
    [sym_stmt] = STATE(687),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1537),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2472),
    [sym_preproc_directive] = STATE(624),
    [sym_pragma] = STATE(620),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_const] = ACTIONS(1247),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1249),
    [anon_sym_event] = ACTIONS(1251),
    [anon_sym_if] = ACTIONS(1253),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1255),
    [anon_sym_for] = ACTIONS(1257),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1259),
    [anon_sym_next] = ACTIONS(1261),
    [anon_sym_break] = ACTIONS(1261),
    [anon_sym_fallthrough] = ACTIONS(1261),
    [anon_sym_return] = ACTIONS(1263),
    [anon_sym_add] = ACTIONS(1265),
    [anon_sym_delete] = ACTIONS(1265),
    [anon_sym_local] = ACTIONS(1267),
    [anon_sym_when] = ACTIONS(1269),
    [anon_sym_assert] = ACTIONS(1271),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1273),
    [anon_sym_ATload] = ACTIONS(1275),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1277),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1279),
    [anon_sym_ATunload] = ACTIONS(1277),
    [anon_sym_ATprefixes] = ACTIONS(1281),
    [anon_sym_ATif] = ACTIONS(1283),
    [anon_sym_ATifdef] = ACTIONS(1285),
    [anon_sym_ATifndef] = ACTIONS(1285),
    [anon_sym_ATendif] = ACTIONS(1287),
    [anon_sym_ATelse] = ACTIONS(1287),
    [anon_sym_ATpragma] = ACTIONS(1289),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(213)] = {
    [sym_stmt] = STATE(642),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1537),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2472),
    [sym_preproc_directive] = STATE(624),
    [sym_pragma] = STATE(620),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_const] = ACTIONS(1247),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1249),
    [anon_sym_event] = ACTIONS(1251),
    [anon_sym_if] = ACTIONS(1253),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1255),
    [anon_sym_for] = ACTIONS(1257),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1259),
    [anon_sym_next] = ACTIONS(1261),
    [anon_sym_break] = ACTIONS(1261),
    [anon_sym_fallthrough] = ACTIONS(1261),
    [anon_sym_return] = ACTIONS(1263),
    [anon_sym_add] = ACTIONS(1265),
    [anon_sym_delete] = ACTIONS(1265),
    [anon_sym_local] = ACTIONS(1267),
    [anon_sym_when] = ACTIONS(1269),
    [anon_sym_assert] = ACTIONS(1271),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1273),
    [anon_sym_ATload] = ACTIONS(1275),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1277),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1279),
    [anon_sym_ATunload] = ACTIONS(1277),
    [anon_sym_ATprefixes] = ACTIONS(1281),
    [anon_sym_ATif] = ACTIONS(1283),
    [anon_sym_ATifdef] = ACTIONS(1285),
    [anon_sym_ATifndef] = ACTIONS(1285),
    [anon_sym_ATendif] = ACTIONS(1287),
    [anon_sym_ATelse] = ACTIONS(1287),
    [anon_sym_ATpragma] = ACTIONS(1289),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(214)] = {
    [sym_stmt] = STATE(573),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1537),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2472),
    [sym_preproc_directive] = STATE(624),
    [sym_pragma] = STATE(620),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_const] = ACTIONS(1247),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1249),
    [anon_sym_event] = ACTIONS(1251),
    [anon_sym_if] = ACTIONS(1253),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1255),
    [anon_sym_for] = ACTIONS(1257),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1259),
    [anon_sym_next] = ACTIONS(1261),
    [anon_sym_break] = ACTIONS(1261),
    [anon_sym_fallthrough] = ACTIONS(1261),
    [anon_sym_return] = ACTIONS(1263),
    [anon_sym_add] = ACTIONS(1265),
    [anon_sym_delete] = ACTIONS(1265),
    [anon_sym_local] = ACTIONS(1267),
    [anon_sym_when] = ACTIONS(1269),
    [anon_sym_assert] = ACTIONS(1271),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1273),
    [anon_sym_ATload] = ACTIONS(1275),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1277),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1279),
    [anon_sym_ATunload] = ACTIONS(1277),
    [anon_sym_ATprefixes] = ACTIONS(1281),
    [anon_sym_ATif] = ACTIONS(1283),
    [anon_sym_ATifdef] = ACTIONS(1285),
    [anon_sym_ATifndef] = ACTIONS(1285),
    [anon_sym_ATendif] = ACTIONS(1287),
    [anon_sym_ATelse] = ACTIONS(1287),
    [anon_sym_ATpragma] = ACTIONS(1289),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(215)] = {
    [sym_stmt] = STATE(538),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(216)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1684),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2272),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1463),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(217)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1647),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2275),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1465),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(218)] = {
    [sym_stmt] = STATE(578),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1537),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2472),
    [sym_preproc_directive] = STATE(624),
    [sym_pragma] = STATE(620),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_const] = ACTIONS(1247),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1249),
    [anon_sym_event] = ACTIONS(1251),
    [anon_sym_if] = ACTIONS(1253),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1255),
    [anon_sym_for] = ACTIONS(1257),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1259),
    [anon_sym_next] = ACTIONS(1261),
    [anon_sym_break] = ACTIONS(1261),
    [anon_sym_fallthrough] = ACTIONS(1261),
    [anon_sym_return] = ACTIONS(1263),
    [anon_sym_add] = ACTIONS(1265),
    [anon_sym_delete] = ACTIONS(1265),
    [anon_sym_local] = ACTIONS(1267),
    [anon_sym_when] = ACTIONS(1269),
    [anon_sym_assert] = ACTIONS(1271),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1273),
    [anon_sym_ATload] = ACTIONS(1275),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1277),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1279),
    [anon_sym_ATunload] = ACTIONS(1277),
    [anon_sym_ATprefixes] = ACTIONS(1281),
    [anon_sym_ATif] = ACTIONS(1283),
    [anon_sym_ATifdef] = ACTIONS(1285),
    [anon_sym_ATifndef] = ACTIONS(1285),
    [anon_sym_ATendif] = ACTIONS(1287),
    [anon_sym_ATelse] = ACTIONS(1287),
    [anon_sym_ATpragma] = ACTIONS(1289),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(219)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1682),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2712),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1467),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(220)] = {
    [sym_stmt] = STATE(596),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(221)] = {
    [sym_stmt] = STATE(603),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(222)] = {
    [sym_stmt] = STATE(604),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(223)] = {
    [sym_stmt] = STATE(608),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(224)] = {
    [sym_stmt] = STATE(539),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(225)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1672),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2354),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1469),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(226)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1674),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2358),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1471),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(227)] = {
    [sym_stmt] = STATE(612),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(228)] = {
    [sym_stmt] = STATE(614),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(229)] = {
    [sym_stmt] = STATE(617),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(230)] = {
    [sym_stmt] = STATE(743),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(740),
    [sym_pragma] = STATE(729),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(605),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(607),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(609),
    [anon_sym_ATload] = ACTIONS(611),
    [anon_sym_ATload_DASHsigs] = ACTIONS(613),
    [anon_sym_ATload_DASHplugin] = ACTIONS(615),
    [anon_sym_ATunload] = ACTIONS(613),
    [anon_sym_ATprefixes] = ACTIONS(617),
    [anon_sym_ATif] = ACTIONS(619),
    [anon_sym_ATifdef] = ACTIONS(621),
    [anon_sym_ATifndef] = ACTIONS(621),
    [anon_sym_ATendif] = ACTIONS(623),
    [anon_sym_ATelse] = ACTIONS(623),
    [anon_sym_ATpragma] = ACTIONS(625),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(231)] = {
    [sym_stmt] = STATE(457),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(220),
    [anon_sym_const] = ACTIONS(224),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(226),
    [anon_sym_event] = ACTIONS(228),
    [anon_sym_if] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(234),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(236),
    [anon_sym_next] = ACTIONS(238),
    [anon_sym_break] = ACTIONS(238),
    [anon_sym_fallthrough] = ACTIONS(238),
    [anon_sym_return] = ACTIONS(240),
    [anon_sym_add] = ACTIONS(242),
    [anon_sym_delete] = ACTIONS(242),
    [anon_sym_local] = ACTIONS(244),
    [anon_sym_when] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(248),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(252),
    [anon_sym_ATload] = ACTIONS(254),
    [anon_sym_ATload_DASHsigs] = ACTIONS(256),
    [anon_sym_ATload_DASHplugin] = ACTIONS(258),
    [anon_sym_ATunload] = ACTIONS(256),
    [anon_sym_ATprefixes] = ACTIONS(260),
    [anon_sym_ATif] = ACTIONS(262),
    [anon_sym_ATifdef] = ACTIONS(264),
    [anon_sym_ATifndef] = ACTIONS(264),
    [anon_sym_ATendif] = ACTIONS(266),
    [anon_sym_ATelse] = ACTIONS(266),
    [anon_sym_ATpragma] = ACTIONS(268),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(232)] = {
    [sym_stmt] = STATE(563),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(220),
    [anon_sym_const] = ACTIONS(224),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(226),
    [anon_sym_event] = ACTIONS(228),
    [anon_sym_if] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(234),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(236),
    [anon_sym_next] = ACTIONS(238),
    [anon_sym_break] = ACTIONS(238),
    [anon_sym_fallthrough] = ACTIONS(238),
    [anon_sym_return] = ACTIONS(240),
    [anon_sym_add] = ACTIONS(242),
    [anon_sym_delete] = ACTIONS(242),
    [anon_sym_local] = ACTIONS(244),
    [anon_sym_when] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(248),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(252),
    [anon_sym_ATload] = ACTIONS(254),
    [anon_sym_ATload_DASHsigs] = ACTIONS(256),
    [anon_sym_ATload_DASHplugin] = ACTIONS(258),
    [anon_sym_ATunload] = ACTIONS(256),
    [anon_sym_ATprefixes] = ACTIONS(260),
    [anon_sym_ATif] = ACTIONS(262),
    [anon_sym_ATifdef] = ACTIONS(264),
    [anon_sym_ATifndef] = ACTIONS(264),
    [anon_sym_ATendif] = ACTIONS(266),
    [anon_sym_ATelse] = ACTIONS(266),
    [anon_sym_ATpragma] = ACTIONS(268),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(233)] = {
    [sym_stmt] = STATE(449),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1489),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2557),
    [sym_preproc_directive] = STATE(414),
    [sym_pragma] = STATE(402),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1039),
    [anon_sym_LBRACE] = ACTIONS(1041),
    [anon_sym_const] = ACTIONS(1043),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1045),
    [anon_sym_event] = ACTIONS(1047),
    [anon_sym_if] = ACTIONS(1049),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1051),
    [anon_sym_for] = ACTIONS(1053),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1055),
    [anon_sym_next] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_fallthrough] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1059),
    [anon_sym_add] = ACTIONS(1061),
    [anon_sym_delete] = ACTIONS(1061),
    [anon_sym_local] = ACTIONS(1063),
    [anon_sym_when] = ACTIONS(1065),
    [anon_sym_assert] = ACTIONS(1067),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1069),
    [anon_sym_ATload] = ACTIONS(1071),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1073),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1075),
    [anon_sym_ATunload] = ACTIONS(1073),
    [anon_sym_ATprefixes] = ACTIONS(1077),
    [anon_sym_ATif] = ACTIONS(1079),
    [anon_sym_ATifdef] = ACTIONS(1081),
    [anon_sym_ATifndef] = ACTIONS(1081),
    [anon_sym_ATendif] = ACTIONS(1083),
    [anon_sym_ATelse] = ACTIONS(1083),
    [anon_sym_ATpragma] = ACTIONS(1085),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(234)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1791),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2431),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1473),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(235)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1793),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2433),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1475),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(236)] = {
    [sym_stmt] = STATE(566),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(220),
    [anon_sym_const] = ACTIONS(224),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(226),
    [anon_sym_event] = ACTIONS(228),
    [anon_sym_if] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(234),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(236),
    [anon_sym_next] = ACTIONS(238),
    [anon_sym_break] = ACTIONS(238),
    [anon_sym_fallthrough] = ACTIONS(238),
    [anon_sym_return] = ACTIONS(240),
    [anon_sym_add] = ACTIONS(242),
    [anon_sym_delete] = ACTIONS(242),
    [anon_sym_local] = ACTIONS(244),
    [anon_sym_when] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(248),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(252),
    [anon_sym_ATload] = ACTIONS(254),
    [anon_sym_ATload_DASHsigs] = ACTIONS(256),
    [anon_sym_ATload_DASHplugin] = ACTIONS(258),
    [anon_sym_ATunload] = ACTIONS(256),
    [anon_sym_ATprefixes] = ACTIONS(260),
    [anon_sym_ATif] = ACTIONS(262),
    [anon_sym_ATifdef] = ACTIONS(264),
    [anon_sym_ATifndef] = ACTIONS(264),
    [anon_sym_ATendif] = ACTIONS(266),
    [anon_sym_ATelse] = ACTIONS(266),
    [anon_sym_ATpragma] = ACTIONS(268),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(237)] = {
    [sym_stmt] = STATE(475),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(220),
    [anon_sym_const] = ACTIONS(224),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(226),
    [anon_sym_event] = ACTIONS(228),
    [anon_sym_if] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(234),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(236),
    [anon_sym_next] = ACTIONS(238),
    [anon_sym_break] = ACTIONS(238),
    [anon_sym_fallthrough] = ACTIONS(238),
    [anon_sym_return] = ACTIONS(240),
    [anon_sym_add] = ACTIONS(242),
    [anon_sym_delete] = ACTIONS(242),
    [anon_sym_local] = ACTIONS(244),
    [anon_sym_when] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(248),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(252),
    [anon_sym_ATload] = ACTIONS(254),
    [anon_sym_ATload_DASHsigs] = ACTIONS(256),
    [anon_sym_ATload_DASHplugin] = ACTIONS(258),
    [anon_sym_ATunload] = ACTIONS(256),
    [anon_sym_ATprefixes] = ACTIONS(260),
    [anon_sym_ATif] = ACTIONS(262),
    [anon_sym_ATifdef] = ACTIONS(264),
    [anon_sym_ATifndef] = ACTIONS(264),
    [anon_sym_ATendif] = ACTIONS(266),
    [anon_sym_ATelse] = ACTIONS(266),
    [anon_sym_ATpragma] = ACTIONS(268),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(238)] = {
    [sym_stmt] = STATE(492),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(220),
    [anon_sym_const] = ACTIONS(224),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(226),
    [anon_sym_event] = ACTIONS(228),
    [anon_sym_if] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(234),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(236),
    [anon_sym_next] = ACTIONS(238),
    [anon_sym_break] = ACTIONS(238),
    [anon_sym_fallthrough] = ACTIONS(238),
    [anon_sym_return] = ACTIONS(240),
    [anon_sym_add] = ACTIONS(242),
    [anon_sym_delete] = ACTIONS(242),
    [anon_sym_local] = ACTIONS(244),
    [anon_sym_when] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(248),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(252),
    [anon_sym_ATload] = ACTIONS(254),
    [anon_sym_ATload_DASHsigs] = ACTIONS(256),
    [anon_sym_ATload_DASHplugin] = ACTIONS(258),
    [anon_sym_ATunload] = ACTIONS(256),
    [anon_sym_ATprefixes] = ACTIONS(260),
    [anon_sym_ATif] = ACTIONS(262),
    [anon_sym_ATifdef] = ACTIONS(264),
    [anon_sym_ATifndef] = ACTIONS(264),
    [anon_sym_ATendif] = ACTIONS(266),
    [anon_sym_ATelse] = ACTIONS(266),
    [anon_sym_ATpragma] = ACTIONS(268),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(239)] = {
    [sym_stmt] = STATE(501),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(220),
    [anon_sym_const] = ACTIONS(224),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(226),
    [anon_sym_event] = ACTIONS(228),
    [anon_sym_if] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(234),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(236),
    [anon_sym_next] = ACTIONS(238),
    [anon_sym_break] = ACTIONS(238),
    [anon_sym_fallthrough] = ACTIONS(238),
    [anon_sym_return] = ACTIONS(240),
    [anon_sym_add] = ACTIONS(242),
    [anon_sym_delete] = ACTIONS(242),
    [anon_sym_local] = ACTIONS(244),
    [anon_sym_when] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(248),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(252),
    [anon_sym_ATload] = ACTIONS(254),
    [anon_sym_ATload_DASHsigs] = ACTIONS(256),
    [anon_sym_ATload_DASHplugin] = ACTIONS(258),
    [anon_sym_ATunload] = ACTIONS(256),
    [anon_sym_ATprefixes] = ACTIONS(260),
    [anon_sym_ATif] = ACTIONS(262),
    [anon_sym_ATifdef] = ACTIONS(264),
    [anon_sym_ATifndef] = ACTIONS(264),
    [anon_sym_ATendif] = ACTIONS(266),
    [anon_sym_ATelse] = ACTIONS(266),
    [anon_sym_ATpragma] = ACTIONS(268),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(240)] = {
    [sym_stmt] = STATE(504),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1592),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2512),
    [sym_preproc_directive] = STATE(535),
    [sym_pragma] = STATE(466),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(218),
    [anon_sym_LBRACE] = ACTIONS(220),
    [anon_sym_const] = ACTIONS(224),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(226),
    [anon_sym_event] = ACTIONS(228),
    [anon_sym_if] = ACTIONS(230),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(232),
    [anon_sym_for] = ACTIONS(234),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(236),
    [anon_sym_next] = ACTIONS(238),
    [anon_sym_break] = ACTIONS(238),
    [anon_sym_fallthrough] = ACTIONS(238),
    [anon_sym_return] = ACTIONS(240),
    [anon_sym_add] = ACTIONS(242),
    [anon_sym_delete] = ACTIONS(242),
    [anon_sym_local] = ACTIONS(244),
    [anon_sym_when] = ACTIONS(246),
    [anon_sym_assert] = ACTIONS(248),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(252),
    [anon_sym_ATload] = ACTIONS(254),
    [anon_sym_ATload_DASHsigs] = ACTIONS(256),
    [anon_sym_ATload_DASHplugin] = ACTIONS(258),
    [anon_sym_ATunload] = ACTIONS(256),
    [anon_sym_ATprefixes] = ACTIONS(260),
    [anon_sym_ATif] = ACTIONS(262),
    [anon_sym_ATifdef] = ACTIONS(264),
    [anon_sym_ATifndef] = ACTIONS(264),
    [anon_sym_ATendif] = ACTIONS(266),
    [anon_sym_ATelse] = ACTIONS(266),
    [anon_sym_ATpragma] = ACTIONS(268),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(241)] = {
    [sym_stmt] = STATE(688),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1483),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2411),
    [sym_preproc_directive] = STATE(659),
    [sym_pragma] = STATE(619),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_const] = ACTIONS(1357),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1359),
    [anon_sym_event] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1365),
    [anon_sym_for] = ACTIONS(1367),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1369),
    [anon_sym_next] = ACTIONS(1371),
    [anon_sym_break] = ACTIONS(1371),
    [anon_sym_fallthrough] = ACTIONS(1371),
    [anon_sym_return] = ACTIONS(1373),
    [anon_sym_add] = ACTIONS(1375),
    [anon_sym_delete] = ACTIONS(1375),
    [anon_sym_local] = ACTIONS(1377),
    [anon_sym_when] = ACTIONS(1379),
    [anon_sym_assert] = ACTIONS(1381),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1383),
    [anon_sym_ATload] = ACTIONS(1385),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1387),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1389),
    [anon_sym_ATunload] = ACTIONS(1387),
    [anon_sym_ATprefixes] = ACTIONS(1391),
    [anon_sym_ATif] = ACTIONS(1393),
    [anon_sym_ATifdef] = ACTIONS(1395),
    [anon_sym_ATifndef] = ACTIONS(1395),
    [anon_sym_ATendif] = ACTIONS(1397),
    [anon_sym_ATelse] = ACTIONS(1397),
    [anon_sym_ATpragma] = ACTIONS(1399),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(242)] = {
    [sym_stmt] = STATE(341),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(243)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1671),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2523),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1477),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(244)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1675),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2533),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1479),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(245)] = {
    [sym_stmt] = STATE(523),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(246)] = {
    [sym_stmt] = STATE(531),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(247)] = {
    [sym_stmt] = STATE(532),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(248)] = {
    [sym_stmt] = STATE(541),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(249)] = {
    [sym_stmt] = STATE(567),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(250)] = {
    [sym_stmt] = STATE(458),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(251)] = {
    [sym_stmt] = STATE(379),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(252)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1747),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2640),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1481),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(253)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1748),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2644),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1483),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(254)] = {
    [sym_stmt] = STATE(461),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(255)] = {
    [sym_stmt] = STATE(755),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1509),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2432),
    [sym_preproc_directive] = STATE(740),
    [sym_pragma] = STATE(729),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(11),
    [anon_sym_LBRACE] = ACTIONS(15),
    [anon_sym_const] = ACTIONS(605),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(31),
    [anon_sym_event] = ACTIONS(607),
    [anon_sym_if] = ACTIONS(35),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(39),
    [anon_sym_for] = ACTIONS(41),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(45),
    [anon_sym_next] = ACTIONS(47),
    [anon_sym_break] = ACTIONS(47),
    [anon_sym_fallthrough] = ACTIONS(47),
    [anon_sym_return] = ACTIONS(49),
    [anon_sym_add] = ACTIONS(51),
    [anon_sym_delete] = ACTIONS(51),
    [anon_sym_local] = ACTIONS(53),
    [anon_sym_when] = ACTIONS(55),
    [anon_sym_assert] = ACTIONS(57),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(609),
    [anon_sym_ATload] = ACTIONS(611),
    [anon_sym_ATload_DASHsigs] = ACTIONS(613),
    [anon_sym_ATload_DASHplugin] = ACTIONS(615),
    [anon_sym_ATunload] = ACTIONS(613),
    [anon_sym_ATprefixes] = ACTIONS(617),
    [anon_sym_ATif] = ACTIONS(619),
    [anon_sym_ATifdef] = ACTIONS(621),
    [anon_sym_ATifndef] = ACTIONS(621),
    [anon_sym_ATendif] = ACTIONS(623),
    [anon_sym_ATelse] = ACTIONS(623),
    [anon_sym_ATpragma] = ACTIONS(625),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(256)] = {
    [sym_stmt] = STATE(482),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(257)] = {
    [sym_stmt] = STATE(487),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(258)] = {
    [sym_stmt] = STATE(488),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(259)] = {
    [sym_stmt] = STATE(491),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(260)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1757),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2696),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1485),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(261)] = {
    [sym__simple_type] = STATE(777),
    [sym_initializer] = STATE(1643),
    [sym_init_class] = STATE(891),
    [sym_attr_list] = STATE(2698),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1247),
    [sym_constant] = STATE(773),
    [sym_string_directive] = STATE(812),
    [sym_subnet] = STATE(769),
    [sym_interval] = STATE(769),
    [sym_string] = STATE(769),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [anon_sym_SEMI] = ACTIONS(1487),
    [anon_sym_LBRACE] = ACTIONS(789),
    [anon_sym_enum] = ACTIONS(793),
    [anon_sym_PLUS_EQ] = ACTIONS(795),
    [anon_sym_record] = ACTIONS(797),
    [anon_sym_DASH_EQ] = ACTIONS(795),
    [anon_sym_LPAREN] = ACTIONS(799),
    [anon_sym_LBRACK] = ACTIONS(801),
    [anon_sym_local] = ACTIONS(803),
    [anon_sym_EQ] = ACTIONS(795),
    [anon_sym_function] = ACTIONS(805),
    [anon_sym_hook] = ACTIONS(807),
    [anon_sym_addr] = ACTIONS(809),
    [anon_sym_any] = ACTIONS(809),
    [anon_sym_bool] = ACTIONS(809),
    [anon_sym_count] = ACTIONS(809),
    [anon_sym_double] = ACTIONS(809),
    [anon_sym_file] = ACTIONS(811),
    [anon_sym_int] = ACTIONS(809),
    [anon_sym_interval] = ACTIONS(809),
    [anon_sym_list] = ACTIONS(811),
    [anon_sym_pattern] = ACTIONS(809),
    [anon_sym_port] = ACTIONS(809),
    [anon_sym_string] = ACTIONS(809),
    [anon_sym_subnet] = ACTIONS(809),
    [anon_sym_time] = ACTIONS(809),
    [anon_sym_opaque] = ACTIONS(813),
    [anon_sym_set] = ACTIONS(815),
    [anon_sym_table] = ACTIONS(817),
    [anon_sym_union] = ACTIONS(819),
    [anon_sym_vector] = ACTIONS(821),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(829),
    [anon_sym_PIPE] = ACTIONS(831),
    [anon_sym_PLUS_PLUS] = ACTIONS(833),
    [anon_sym_DASH_DASH] = ACTIONS(833),
    [anon_sym_BANG] = ACTIONS(833),
    [anon_sym_TILDE] = ACTIONS(833),
    [anon_sym_DASH] = ACTIONS(835),
    [anon_sym_PLUS] = ACTIONS(835),
    [anon_sym_copy] = ACTIONS(837),
    [anon_sym_schedule] = ACTIONS(839),
    [anon_sym_T] = ACTIONS(841),
    [anon_sym_F] = ACTIONS(841),
    [anon_sym_ATDIR] = ACTIONS(843),
    [anon_sym_ATFILENAME] = ACTIONS(843),
    [sym_id] = ACTIONS(845),
    [sym_pattern] = ACTIONS(847),
    [sym_ipv4] = ACTIONS(849),
    [sym_ipv6] = ACTIONS(851),
    [sym_port] = ACTIONS(853),
    [sym_integer] = ACTIONS(855),
    [sym_floatp] = ACTIONS(857),
    [sym_hex] = ACTIONS(841),
    [sym_hostname] = ACTIONS(841),
    [aux_sym_string_token1] = ACTIONS(859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(262)] = {
    [sym_stmt] = STATE(494),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(263)] = {
    [sym_stmt] = STATE(496),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(264)] = {
    [sym_stmt] = STATE(499),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(265)] = {
    [sym_stmt] = STATE(637),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1483),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2411),
    [sym_preproc_directive] = STATE(659),
    [sym_pragma] = STATE(619),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1353),
    [anon_sym_LBRACE] = ACTIONS(1355),
    [anon_sym_const] = ACTIONS(1357),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1359),
    [anon_sym_event] = ACTIONS(1361),
    [anon_sym_if] = ACTIONS(1363),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1365),
    [anon_sym_for] = ACTIONS(1367),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1369),
    [anon_sym_next] = ACTIONS(1371),
    [anon_sym_break] = ACTIONS(1371),
    [anon_sym_fallthrough] = ACTIONS(1371),
    [anon_sym_return] = ACTIONS(1373),
    [anon_sym_add] = ACTIONS(1375),
    [anon_sym_delete] = ACTIONS(1375),
    [anon_sym_local] = ACTIONS(1377),
    [anon_sym_when] = ACTIONS(1379),
    [anon_sym_assert] = ACTIONS(1381),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1383),
    [anon_sym_ATload] = ACTIONS(1385),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1387),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1389),
    [anon_sym_ATunload] = ACTIONS(1387),
    [anon_sym_ATprefixes] = ACTIONS(1391),
    [anon_sym_ATif] = ACTIONS(1393),
    [anon_sym_ATifdef] = ACTIONS(1395),
    [anon_sym_ATifndef] = ACTIONS(1395),
    [anon_sym_ATendif] = ACTIONS(1397),
    [anon_sym_ATelse] = ACTIONS(1397),
    [anon_sym_ATpragma] = ACTIONS(1399),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(266)] = {
    [sym_stmt] = STATE(456),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1489),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2557),
    [sym_preproc_directive] = STATE(414),
    [sym_pragma] = STATE(402),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1039),
    [anon_sym_LBRACE] = ACTIONS(1041),
    [anon_sym_const] = ACTIONS(1043),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1045),
    [anon_sym_event] = ACTIONS(1047),
    [anon_sym_if] = ACTIONS(1049),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1051),
    [anon_sym_for] = ACTIONS(1053),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1055),
    [anon_sym_next] = ACTIONS(1057),
    [anon_sym_break] = ACTIONS(1057),
    [anon_sym_fallthrough] = ACTIONS(1057),
    [anon_sym_return] = ACTIONS(1059),
    [anon_sym_add] = ACTIONS(1061),
    [anon_sym_delete] = ACTIONS(1061),
    [anon_sym_local] = ACTIONS(1063),
    [anon_sym_when] = ACTIONS(1065),
    [anon_sym_assert] = ACTIONS(1067),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1069),
    [anon_sym_ATload] = ACTIONS(1071),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1073),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1075),
    [anon_sym_ATunload] = ACTIONS(1073),
    [anon_sym_ATprefixes] = ACTIONS(1077),
    [anon_sym_ATif] = ACTIONS(1079),
    [anon_sym_ATifdef] = ACTIONS(1081),
    [anon_sym_ATifndef] = ACTIONS(1081),
    [anon_sym_ATendif] = ACTIONS(1083),
    [anon_sym_ATelse] = ACTIONS(1083),
    [anon_sym_ATpragma] = ACTIONS(1085),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(267)] = {
    [sym_stmt] = STATE(679),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(268)] = {
    [sym_stmt] = STATE(680),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(269)] = {
    [sym_stmt] = STATE(681),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1553),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2492),
    [sym_preproc_directive] = STATE(583),
    [sym_pragma] = STATE(686),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1293),
    [anon_sym_LBRACE] = ACTIONS(1295),
    [anon_sym_const] = ACTIONS(1297),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1299),
    [anon_sym_event] = ACTIONS(1301),
    [anon_sym_if] = ACTIONS(1303),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1305),
    [anon_sym_for] = ACTIONS(1307),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1309),
    [anon_sym_next] = ACTIONS(1311),
    [anon_sym_break] = ACTIONS(1311),
    [anon_sym_fallthrough] = ACTIONS(1311),
    [anon_sym_return] = ACTIONS(1313),
    [anon_sym_add] = ACTIONS(1315),
    [anon_sym_delete] = ACTIONS(1315),
    [anon_sym_local] = ACTIONS(1317),
    [anon_sym_when] = ACTIONS(1319),
    [anon_sym_assert] = ACTIONS(1321),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1323),
    [anon_sym_ATload] = ACTIONS(1325),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1327),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1329),
    [anon_sym_ATunload] = ACTIONS(1327),
    [anon_sym_ATprefixes] = ACTIONS(1331),
    [anon_sym_ATif] = ACTIONS(1333),
    [anon_sym_ATifdef] = ACTIONS(1335),
    [anon_sym_ATifndef] = ACTIONS(1335),
    [anon_sym_ATendif] = ACTIONS(1337),
    [anon_sym_ATelse] = ACTIONS(1337),
    [anon_sym_ATpragma] = ACTIONS(1339),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(270)] = {
    [sym_stmt] = STATE(557),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(271)] = {
    [sym_stmt] = STATE(558),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(272)] = {
    [sym_stmt] = STATE(559),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1357),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2527),
    [sym_preproc_directive] = STATE(510),
    [sym_pragma] = STATE(502),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(991),
    [anon_sym_LBRACE] = ACTIONS(993),
    [anon_sym_const] = ACTIONS(995),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(997),
    [anon_sym_event] = ACTIONS(999),
    [anon_sym_if] = ACTIONS(1001),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1003),
    [anon_sym_for] = ACTIONS(1005),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1007),
    [anon_sym_next] = ACTIONS(1009),
    [anon_sym_break] = ACTIONS(1009),
    [anon_sym_fallthrough] = ACTIONS(1009),
    [anon_sym_return] = ACTIONS(1011),
    [anon_sym_add] = ACTIONS(1013),
    [anon_sym_delete] = ACTIONS(1013),
    [anon_sym_local] = ACTIONS(1015),
    [anon_sym_when] = ACTIONS(1017),
    [anon_sym_assert] = ACTIONS(1019),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1021),
    [anon_sym_ATload] = ACTIONS(1023),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1025),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1027),
    [anon_sym_ATunload] = ACTIONS(1025),
    [anon_sym_ATprefixes] = ACTIONS(1029),
    [anon_sym_ATif] = ACTIONS(1031),
    [anon_sym_ATifdef] = ACTIONS(1033),
    [anon_sym_ATifndef] = ACTIONS(1033),
    [anon_sym_ATendif] = ACTIONS(1035),
    [anon_sym_ATelse] = ACTIONS(1035),
    [anon_sym_ATpragma] = ACTIONS(1037),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(273)] = {
    [sym_stmt] = STATE(560),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(274)] = {
    [sym_stmt] = STATE(561),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(275)] = {
    [sym_stmt] = STATE(562),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1414),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2542),
    [sym_preproc_directive] = STATE(470),
    [sym_pragma] = STATE(565),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1403),
    [anon_sym_LBRACE] = ACTIONS(1405),
    [anon_sym_const] = ACTIONS(1407),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1409),
    [anon_sym_event] = ACTIONS(1411),
    [anon_sym_if] = ACTIONS(1413),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1415),
    [anon_sym_for] = ACTIONS(1417),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1419),
    [anon_sym_next] = ACTIONS(1421),
    [anon_sym_break] = ACTIONS(1421),
    [anon_sym_fallthrough] = ACTIONS(1421),
    [anon_sym_return] = ACTIONS(1423),
    [anon_sym_add] = ACTIONS(1425),
    [anon_sym_delete] = ACTIONS(1425),
    [anon_sym_local] = ACTIONS(1427),
    [anon_sym_when] = ACTIONS(1429),
    [anon_sym_assert] = ACTIONS(1431),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1433),
    [anon_sym_ATload] = ACTIONS(1435),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1437),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1439),
    [anon_sym_ATunload] = ACTIONS(1437),
    [anon_sym_ATprefixes] = ACTIONS(1441),
    [anon_sym_ATif] = ACTIONS(1443),
    [anon_sym_ATifdef] = ACTIONS(1445),
    [anon_sym_ATifndef] = ACTIONS(1445),
    [anon_sym_ATendif] = ACTIONS(1447),
    [anon_sym_ATelse] = ACTIONS(1447),
    [anon_sym_ATpragma] = ACTIONS(1449),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(276)] = {
    [sym_stmt] = STATE(451),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(277)] = {
    [sym_stmt] = STATE(452),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(278)] = {
    [sym_stmt] = STATE(453),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1532),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2572),
    [sym_preproc_directive] = STATE(447),
    [sym_pragma] = STATE(432),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1087),
    [anon_sym_LBRACE] = ACTIONS(1089),
    [anon_sym_const] = ACTIONS(1091),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1093),
    [anon_sym_event] = ACTIONS(1095),
    [anon_sym_if] = ACTIONS(1097),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1099),
    [anon_sym_for] = ACTIONS(1101),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1103),
    [anon_sym_next] = ACTIONS(1105),
    [anon_sym_break] = ACTIONS(1105),
    [anon_sym_fallthrough] = ACTIONS(1105),
    [anon_sym_return] = ACTIONS(1107),
    [anon_sym_add] = ACTIONS(1109),
    [anon_sym_delete] = ACTIONS(1109),
    [anon_sym_local] = ACTIONS(1111),
    [anon_sym_when] = ACTIONS(1113),
    [anon_sym_assert] = ACTIONS(1115),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1117),
    [anon_sym_ATload] = ACTIONS(1119),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1121),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1123),
    [anon_sym_ATunload] = ACTIONS(1121),
    [anon_sym_ATprefixes] = ACTIONS(1125),
    [anon_sym_ATif] = ACTIONS(1127),
    [anon_sym_ATifdef] = ACTIONS(1129),
    [anon_sym_ATifndef] = ACTIONS(1129),
    [anon_sym_ATendif] = ACTIONS(1131),
    [anon_sym_ATelse] = ACTIONS(1131),
    [anon_sym_ATpragma] = ACTIONS(1133),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(279)] = {
    [sym_stmt] = STATE(380),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(280)] = {
    [sym_stmt] = STATE(381),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(281)] = {
    [sym_stmt] = STATE(382),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1565),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2587),
    [sym_preproc_directive] = STATE(345),
    [sym_pragma] = STATE(372),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1135),
    [anon_sym_LBRACE] = ACTIONS(1137),
    [anon_sym_const] = ACTIONS(1139),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1141),
    [anon_sym_event] = ACTIONS(1143),
    [anon_sym_if] = ACTIONS(1145),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1147),
    [anon_sym_for] = ACTIONS(1149),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1151),
    [anon_sym_next] = ACTIONS(1153),
    [anon_sym_break] = ACTIONS(1153),
    [anon_sym_fallthrough] = ACTIONS(1153),
    [anon_sym_return] = ACTIONS(1155),
    [anon_sym_add] = ACTIONS(1157),
    [anon_sym_delete] = ACTIONS(1157),
    [anon_sym_local] = ACTIONS(1159),
    [anon_sym_when] = ACTIONS(1161),
    [anon_sym_assert] = ACTIONS(1163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1165),
    [anon_sym_ATload] = ACTIONS(1167),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1169),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1171),
    [anon_sym_ATunload] = ACTIONS(1169),
    [anon_sym_ATprefixes] = ACTIONS(1173),
    [anon_sym_ATif] = ACTIONS(1175),
    [anon_sym_ATifdef] = ACTIONS(1177),
    [anon_sym_ATifndef] = ACTIONS(1177),
    [anon_sym_ATendif] = ACTIONS(1179),
    [anon_sym_ATelse] = ACTIONS(1179),
    [anon_sym_ATpragma] = ACTIONS(1181),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(282)] = {
    [sym_stmt] = STATE(676),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(283)] = {
    [sym_stmt] = STATE(677),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(284)] = {
    [sym_stmt] = STATE(678),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1521),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2452),
    [sym_preproc_directive] = STATE(689),
    [sym_pragma] = STATE(581),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1185),
    [anon_sym_LBRACE] = ACTIONS(1187),
    [anon_sym_const] = ACTIONS(1189),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1191),
    [anon_sym_event] = ACTIONS(1193),
    [anon_sym_if] = ACTIONS(1195),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1197),
    [anon_sym_for] = ACTIONS(1199),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1201),
    [anon_sym_next] = ACTIONS(1203),
    [anon_sym_break] = ACTIONS(1203),
    [anon_sym_fallthrough] = ACTIONS(1203),
    [anon_sym_return] = ACTIONS(1205),
    [anon_sym_add] = ACTIONS(1207),
    [anon_sym_delete] = ACTIONS(1207),
    [anon_sym_local] = ACTIONS(1209),
    [anon_sym_when] = ACTIONS(1211),
    [anon_sym_assert] = ACTIONS(1213),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1215),
    [anon_sym_ATload] = ACTIONS(1217),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1219),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1221),
    [anon_sym_ATunload] = ACTIONS(1219),
    [anon_sym_ATprefixes] = ACTIONS(1223),
    [anon_sym_ATif] = ACTIONS(1225),
    [anon_sym_ATifdef] = ACTIONS(1227),
    [anon_sym_ATifndef] = ACTIONS(1227),
    [anon_sym_ATendif] = ACTIONS(1229),
    [anon_sym_ATelse] = ACTIONS(1229),
    [anon_sym_ATpragma] = ACTIONS(1231),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(285)] = {
    [sym_stmt] = STATE(682),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1537),
    [sym_constant] = STATE(1273),
    [sym_index_slice] = STATE(2472),
    [sym_preproc_directive] = STATE(624),
    [sym_pragma] = STATE(620),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(1243),
    [anon_sym_LBRACE] = ACTIONS(1245),
    [anon_sym_const] = ACTIONS(1247),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_print] = ACTIONS(1249),
    [anon_sym_event] = ACTIONS(1251),
    [anon_sym_if] = ACTIONS(1253),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_switch] = ACTIONS(1255),
    [anon_sym_for] = ACTIONS(1257),
    [anon_sym_LBRACK] = ACTIONS(43),
    [anon_sym_while] = ACTIONS(1259),
    [anon_sym_next] = ACTIONS(1261),
    [anon_sym_break] = ACTIONS(1261),
    [anon_sym_fallthrough] = ACTIONS(1261),
    [anon_sym_return] = ACTIONS(1263),
    [anon_sym_add] = ACTIONS(1265),
    [anon_sym_delete] = ACTIONS(1265),
    [anon_sym_local] = ACTIONS(1267),
    [anon_sym_when] = ACTIONS(1269),
    [anon_sym_assert] = ACTIONS(1271),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATdeprecated] = ACTIONS(1273),
    [anon_sym_ATload] = ACTIONS(1275),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1277),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1279),
    [anon_sym_ATunload] = ACTIONS(1277),
    [anon_sym_ATprefixes] = ACTIONS(1281),
    [anon_sym_ATif] = ACTIONS(1283),
    [anon_sym_ATifdef] = ACTIONS(1285),
    [anon_sym_ATifndef] = ACTIONS(1285),
    [anon_sym_ATendif] = ACTIONS(1287),
    [anon_sym_ATelse] = ACTIONS(1287),
    [anon_sym_ATpragma] = ACTIONS(1289),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(286)] = {
    [sym__simple_type] = STATE(1305),
    [sym_attr_list] = STATE(2726),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_RBRACE] = ACTIONS(1489),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(287)] = {
    [sym__simple_type] = STATE(1305),
    [sym_attr_list] = STATE(2383),
    [sym_attr] = STATE(1603),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_attr_list_repeat1] = STATE(1603),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_RBRACE] = ACTIONS(1489),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(823),
    [anon_sym_AMPdeprecated] = ACTIONS(825),
    [anon_sym_AMPerror_handler] = ACTIONS(823),
    [anon_sym_AMPis_assigned] = ACTIONS(823),
    [anon_sym_AMPis_used] = ACTIONS(823),
    [anon_sym_AMPlog] = ACTIONS(823),
    [anon_sym_AMPoptional] = ACTIONS(823),
    [anon_sym_AMPordered] = ACTIONS(823),
    [anon_sym_AMPraw_output] = ACTIONS(823),
    [anon_sym_AMPredef] = ACTIONS(823),
    [anon_sym_AMPadd_func] = ACTIONS(827),
    [anon_sym_AMPbackend] = ACTIONS(827),
    [anon_sym_AMPbroker_store] = ACTIONS(827),
    [anon_sym_AMPcreate_expire] = ACTIONS(827),
    [anon_sym_AMPdefault] = ACTIONS(827),
    [anon_sym_AMPdelete_func] = ACTIONS(827),
    [anon_sym_AMPexpire_func] = ACTIONS(827),
    [anon_sym_AMPgroup] = ACTIONS(827),
    [anon_sym_AMPon_change] = ACTIONS(827),
    [anon_sym_AMPpriority] = ACTIONS(827),
    [anon_sym_AMPread_expire] = ACTIONS(827),
    [anon_sym_AMPtype_column] = ACTIONS(827),
    [anon_sym_AMPwrite_expire] = ACTIONS(827),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(288)] = {
    [ts_builtin_sym_end] = ACTIONS(1493),
    [anon_sym_module] = ACTIONS(1495),
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_export] = ACTIONS(1495),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_global] = ACTIONS(1495),
    [anon_sym_option] = ACTIONS(1495),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_redef] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_type] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1497),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(289)] = {
    [ts_builtin_sym_end] = ACTIONS(1499),
    [anon_sym_module] = ACTIONS(1501),
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_export] = ACTIONS(1501),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_global] = ACTIONS(1501),
    [anon_sym_option] = ACTIONS(1501),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_redef] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_type] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1503),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(290)] = {
    [ts_builtin_sym_end] = ACTIONS(1505),
    [anon_sym_module] = ACTIONS(1507),
    [anon_sym_SEMI] = ACTIONS(1505),
    [anon_sym_export] = ACTIONS(1507),
    [anon_sym_LBRACE] = ACTIONS(1505),
    [anon_sym_global] = ACTIONS(1507),
    [anon_sym_option] = ACTIONS(1507),
    [anon_sym_const] = ACTIONS(1507),
    [anon_sym_redef] = ACTIONS(1507),
    [anon_sym_enum] = ACTIONS(1507),
    [anon_sym_record] = ACTIONS(1507),
    [anon_sym_type] = ACTIONS(1507),
    [anon_sym_print] = ACTIONS(1507),
    [anon_sym_event] = ACTIONS(1507),
    [anon_sym_if] = ACTIONS(1507),
    [anon_sym_LPAREN] = ACTIONS(1505),
    [anon_sym_switch] = ACTIONS(1507),
    [anon_sym_for] = ACTIONS(1507),
    [anon_sym_LBRACK] = ACTIONS(1507),
    [anon_sym_while] = ACTIONS(1507),
    [anon_sym_next] = ACTIONS(1507),
    [anon_sym_break] = ACTIONS(1507),
    [anon_sym_fallthrough] = ACTIONS(1507),
    [anon_sym_return] = ACTIONS(1507),
    [anon_sym_add] = ACTIONS(1507),
    [anon_sym_delete] = ACTIONS(1507),
    [anon_sym_local] = ACTIONS(1507),
    [anon_sym_when] = ACTIONS(1507),
    [anon_sym_assert] = ACTIONS(1507),
    [anon_sym_function] = ACTIONS(1507),
    [anon_sym_hook] = ACTIONS(1507),
    [anon_sym_addr] = ACTIONS(1507),
    [anon_sym_any] = ACTIONS(1507),
    [anon_sym_bool] = ACTIONS(1507),
    [anon_sym_count] = ACTIONS(1507),
    [anon_sym_double] = ACTIONS(1507),
    [anon_sym_file] = ACTIONS(1507),
    [anon_sym_int] = ACTIONS(1507),
    [anon_sym_interval] = ACTIONS(1507),
    [anon_sym_list] = ACTIONS(1507),
    [anon_sym_pattern] = ACTIONS(1507),
    [anon_sym_port] = ACTIONS(1507),
    [anon_sym_string] = ACTIONS(1507),
    [anon_sym_subnet] = ACTIONS(1507),
    [anon_sym_time] = ACTIONS(1507),
    [anon_sym_opaque] = ACTIONS(1507),
    [anon_sym_set] = ACTIONS(1507),
    [anon_sym_table] = ACTIONS(1507),
    [anon_sym_union] = ACTIONS(1507),
    [anon_sym_vector] = ACTIONS(1507),
    [anon_sym_DOLLAR] = ACTIONS(1505),
    [anon_sym_PIPE] = ACTIONS(1505),
    [anon_sym_PLUS_PLUS] = ACTIONS(1505),
    [anon_sym_DASH_DASH] = ACTIONS(1505),
    [anon_sym_BANG] = ACTIONS(1505),
    [anon_sym_TILDE] = ACTIONS(1505),
    [anon_sym_DASH] = ACTIONS(1507),
    [anon_sym_PLUS] = ACTIONS(1507),
    [anon_sym_copy] = ACTIONS(1507),
    [anon_sym_schedule] = ACTIONS(1507),
    [anon_sym_T] = ACTIONS(1507),
    [anon_sym_F] = ACTIONS(1507),
    [anon_sym_ATdeprecated] = ACTIONS(1505),
    [anon_sym_ATload] = ACTIONS(1507),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1505),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1505),
    [anon_sym_ATunload] = ACTIONS(1505),
    [anon_sym_ATprefixes] = ACTIONS(1505),
    [anon_sym_ATif] = ACTIONS(1507),
    [anon_sym_ATifdef] = ACTIONS(1505),
    [anon_sym_ATifndef] = ACTIONS(1505),
    [anon_sym_ATendif] = ACTIONS(1505),
    [anon_sym_ATelse] = ACTIONS(1505),
    [anon_sym_ATpragma] = ACTIONS(1505),
    [anon_sym_ATDIR] = ACTIONS(1505),
    [anon_sym_ATFILENAME] = ACTIONS(1505),
    [sym_id] = ACTIONS(1507),
    [sym_pattern] = ACTIONS(1505),
    [sym_ipv4] = ACTIONS(1507),
    [sym_ipv6] = ACTIONS(1505),
    [sym_port] = ACTIONS(1505),
    [sym_integer] = ACTIONS(1507),
    [sym_floatp] = ACTIONS(1507),
    [sym_hex] = ACTIONS(1507),
    [sym_hostname] = ACTIONS(1507),
    [aux_sym_string_token1] = ACTIONS(1505),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(291)] = {
    [ts_builtin_sym_end] = ACTIONS(1509),
    [anon_sym_module] = ACTIONS(1511),
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_export] = ACTIONS(1511),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_global] = ACTIONS(1511),
    [anon_sym_option] = ACTIONS(1511),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_redef] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_type] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(292)] = {
    [ts_builtin_sym_end] = ACTIONS(1513),
    [anon_sym_module] = ACTIONS(1515),
    [anon_sym_SEMI] = ACTIONS(1513),
    [anon_sym_export] = ACTIONS(1515),
    [anon_sym_LBRACE] = ACTIONS(1513),
    [anon_sym_global] = ACTIONS(1515),
    [anon_sym_option] = ACTIONS(1515),
    [anon_sym_const] = ACTIONS(1515),
    [anon_sym_redef] = ACTIONS(1515),
    [anon_sym_enum] = ACTIONS(1515),
    [anon_sym_record] = ACTIONS(1515),
    [anon_sym_type] = ACTIONS(1515),
    [anon_sym_print] = ACTIONS(1515),
    [anon_sym_event] = ACTIONS(1515),
    [anon_sym_if] = ACTIONS(1515),
    [anon_sym_LPAREN] = ACTIONS(1513),
    [anon_sym_switch] = ACTIONS(1515),
    [anon_sym_for] = ACTIONS(1515),
    [anon_sym_LBRACK] = ACTIONS(1515),
    [anon_sym_while] = ACTIONS(1515),
    [anon_sym_next] = ACTIONS(1515),
    [anon_sym_break] = ACTIONS(1515),
    [anon_sym_fallthrough] = ACTIONS(1515),
    [anon_sym_return] = ACTIONS(1515),
    [anon_sym_add] = ACTIONS(1515),
    [anon_sym_delete] = ACTIONS(1515),
    [anon_sym_local] = ACTIONS(1515),
    [anon_sym_when] = ACTIONS(1515),
    [anon_sym_assert] = ACTIONS(1515),
    [anon_sym_function] = ACTIONS(1515),
    [anon_sym_hook] = ACTIONS(1515),
    [anon_sym_addr] = ACTIONS(1515),
    [anon_sym_any] = ACTIONS(1515),
    [anon_sym_bool] = ACTIONS(1515),
    [anon_sym_count] = ACTIONS(1515),
    [anon_sym_double] = ACTIONS(1515),
    [anon_sym_file] = ACTIONS(1515),
    [anon_sym_int] = ACTIONS(1515),
    [anon_sym_interval] = ACTIONS(1515),
    [anon_sym_list] = ACTIONS(1515),
    [anon_sym_pattern] = ACTIONS(1515),
    [anon_sym_port] = ACTIONS(1515),
    [anon_sym_string] = ACTIONS(1515),
    [anon_sym_subnet] = ACTIONS(1515),
    [anon_sym_time] = ACTIONS(1515),
    [anon_sym_opaque] = ACTIONS(1515),
    [anon_sym_set] = ACTIONS(1515),
    [anon_sym_table] = ACTIONS(1515),
    [anon_sym_union] = ACTIONS(1515),
    [anon_sym_vector] = ACTIONS(1515),
    [anon_sym_DOLLAR] = ACTIONS(1513),
    [anon_sym_PIPE] = ACTIONS(1513),
    [anon_sym_PLUS_PLUS] = ACTIONS(1513),
    [anon_sym_DASH_DASH] = ACTIONS(1513),
    [anon_sym_BANG] = ACTIONS(1513),
    [anon_sym_TILDE] = ACTIONS(1513),
    [anon_sym_DASH] = ACTIONS(1515),
    [anon_sym_PLUS] = ACTIONS(1515),
    [anon_sym_copy] = ACTIONS(1515),
    [anon_sym_schedule] = ACTIONS(1515),
    [anon_sym_T] = ACTIONS(1515),
    [anon_sym_F] = ACTIONS(1515),
    [anon_sym_ATdeprecated] = ACTIONS(1513),
    [anon_sym_ATload] = ACTIONS(1515),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1513),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1513),
    [anon_sym_ATunload] = ACTIONS(1513),
    [anon_sym_ATprefixes] = ACTIONS(1513),
    [anon_sym_ATif] = ACTIONS(1515),
    [anon_sym_ATifdef] = ACTIONS(1513),
    [anon_sym_ATifndef] = ACTIONS(1513),
    [anon_sym_ATendif] = ACTIONS(1513),
    [anon_sym_ATelse] = ACTIONS(1513),
    [anon_sym_ATpragma] = ACTIONS(1513),
    [anon_sym_ATDIR] = ACTIONS(1513),
    [anon_sym_ATFILENAME] = ACTIONS(1513),
    [sym_id] = ACTIONS(1515),
    [sym_pattern] = ACTIONS(1513),
    [sym_ipv4] = ACTIONS(1515),
    [sym_ipv6] = ACTIONS(1513),
    [sym_port] = ACTIONS(1513),
    [sym_integer] = ACTIONS(1515),
    [sym_floatp] = ACTIONS(1515),
    [sym_hex] = ACTIONS(1515),
    [sym_hostname] = ACTIONS(1515),
    [aux_sym_string_token1] = ACTIONS(1513),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(293)] = {
    [ts_builtin_sym_end] = ACTIONS(1517),
    [anon_sym_module] = ACTIONS(1519),
    [anon_sym_SEMI] = ACTIONS(1517),
    [anon_sym_export] = ACTIONS(1519),
    [anon_sym_LBRACE] = ACTIONS(1517),
    [anon_sym_global] = ACTIONS(1519),
    [anon_sym_option] = ACTIONS(1519),
    [anon_sym_const] = ACTIONS(1519),
    [anon_sym_redef] = ACTIONS(1519),
    [anon_sym_enum] = ACTIONS(1519),
    [anon_sym_record] = ACTIONS(1519),
    [anon_sym_type] = ACTIONS(1519),
    [anon_sym_print] = ACTIONS(1519),
    [anon_sym_event] = ACTIONS(1519),
    [anon_sym_if] = ACTIONS(1519),
    [anon_sym_LPAREN] = ACTIONS(1517),
    [anon_sym_switch] = ACTIONS(1519),
    [anon_sym_for] = ACTIONS(1519),
    [anon_sym_LBRACK] = ACTIONS(1519),
    [anon_sym_while] = ACTIONS(1519),
    [anon_sym_next] = ACTIONS(1519),
    [anon_sym_break] = ACTIONS(1519),
    [anon_sym_fallthrough] = ACTIONS(1519),
    [anon_sym_return] = ACTIONS(1519),
    [anon_sym_add] = ACTIONS(1519),
    [anon_sym_delete] = ACTIONS(1519),
    [anon_sym_local] = ACTIONS(1519),
    [anon_sym_when] = ACTIONS(1519),
    [anon_sym_assert] = ACTIONS(1519),
    [anon_sym_function] = ACTIONS(1519),
    [anon_sym_hook] = ACTIONS(1519),
    [anon_sym_addr] = ACTIONS(1519),
    [anon_sym_any] = ACTIONS(1519),
    [anon_sym_bool] = ACTIONS(1519),
    [anon_sym_count] = ACTIONS(1519),
    [anon_sym_double] = ACTIONS(1519),
    [anon_sym_file] = ACTIONS(1519),
    [anon_sym_int] = ACTIONS(1519),
    [anon_sym_interval] = ACTIONS(1519),
    [anon_sym_list] = ACTIONS(1519),
    [anon_sym_pattern] = ACTIONS(1519),
    [anon_sym_port] = ACTIONS(1519),
    [anon_sym_string] = ACTIONS(1519),
    [anon_sym_subnet] = ACTIONS(1519),
    [anon_sym_time] = ACTIONS(1519),
    [anon_sym_opaque] = ACTIONS(1519),
    [anon_sym_set] = ACTIONS(1519),
    [anon_sym_table] = ACTIONS(1519),
    [anon_sym_union] = ACTIONS(1519),
    [anon_sym_vector] = ACTIONS(1519),
    [anon_sym_DOLLAR] = ACTIONS(1517),
    [anon_sym_PIPE] = ACTIONS(1517),
    [anon_sym_PLUS_PLUS] = ACTIONS(1517),
    [anon_sym_DASH_DASH] = ACTIONS(1517),
    [anon_sym_BANG] = ACTIONS(1517),
    [anon_sym_TILDE] = ACTIONS(1517),
    [anon_sym_DASH] = ACTIONS(1519),
    [anon_sym_PLUS] = ACTIONS(1519),
    [anon_sym_copy] = ACTIONS(1519),
    [anon_sym_schedule] = ACTIONS(1519),
    [anon_sym_T] = ACTIONS(1519),
    [anon_sym_F] = ACTIONS(1519),
    [anon_sym_ATdeprecated] = ACTIONS(1517),
    [anon_sym_ATload] = ACTIONS(1519),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1517),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1517),
    [anon_sym_ATunload] = ACTIONS(1517),
    [anon_sym_ATprefixes] = ACTIONS(1517),
    [anon_sym_ATif] = ACTIONS(1519),
    [anon_sym_ATifdef] = ACTIONS(1517),
    [anon_sym_ATifndef] = ACTIONS(1517),
    [anon_sym_ATendif] = ACTIONS(1517),
    [anon_sym_ATelse] = ACTIONS(1517),
    [anon_sym_ATpragma] = ACTIONS(1517),
    [anon_sym_ATDIR] = ACTIONS(1517),
    [anon_sym_ATFILENAME] = ACTIONS(1517),
    [sym_id] = ACTIONS(1519),
    [sym_pattern] = ACTIONS(1517),
    [sym_ipv4] = ACTIONS(1519),
    [sym_ipv6] = ACTIONS(1517),
    [sym_port] = ACTIONS(1517),
    [sym_integer] = ACTIONS(1519),
    [sym_floatp] = ACTIONS(1519),
    [sym_hex] = ACTIONS(1519),
    [sym_hostname] = ACTIONS(1519),
    [aux_sym_string_token1] = ACTIONS(1517),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(294)] = {
    [ts_builtin_sym_end] = ACTIONS(1521),
    [anon_sym_module] = ACTIONS(1523),
    [anon_sym_SEMI] = ACTIONS(1521),
    [anon_sym_export] = ACTIONS(1523),
    [anon_sym_LBRACE] = ACTIONS(1521),
    [anon_sym_global] = ACTIONS(1523),
    [anon_sym_option] = ACTIONS(1523),
    [anon_sym_const] = ACTIONS(1523),
    [anon_sym_redef] = ACTIONS(1523),
    [anon_sym_enum] = ACTIONS(1523),
    [anon_sym_record] = ACTIONS(1523),
    [anon_sym_type] = ACTIONS(1523),
    [anon_sym_print] = ACTIONS(1523),
    [anon_sym_event] = ACTIONS(1523),
    [anon_sym_if] = ACTIONS(1523),
    [anon_sym_LPAREN] = ACTIONS(1521),
    [anon_sym_switch] = ACTIONS(1523),
    [anon_sym_for] = ACTIONS(1523),
    [anon_sym_LBRACK] = ACTIONS(1523),
    [anon_sym_while] = ACTIONS(1523),
    [anon_sym_next] = ACTIONS(1523),
    [anon_sym_break] = ACTIONS(1523),
    [anon_sym_fallthrough] = ACTIONS(1523),
    [anon_sym_return] = ACTIONS(1523),
    [anon_sym_add] = ACTIONS(1523),
    [anon_sym_delete] = ACTIONS(1523),
    [anon_sym_local] = ACTIONS(1523),
    [anon_sym_when] = ACTIONS(1523),
    [anon_sym_assert] = ACTIONS(1523),
    [anon_sym_function] = ACTIONS(1523),
    [anon_sym_hook] = ACTIONS(1523),
    [anon_sym_addr] = ACTIONS(1523),
    [anon_sym_any] = ACTIONS(1523),
    [anon_sym_bool] = ACTIONS(1523),
    [anon_sym_count] = ACTIONS(1523),
    [anon_sym_double] = ACTIONS(1523),
    [anon_sym_file] = ACTIONS(1523),
    [anon_sym_int] = ACTIONS(1523),
    [anon_sym_interval] = ACTIONS(1523),
    [anon_sym_list] = ACTIONS(1523),
    [anon_sym_pattern] = ACTIONS(1523),
    [anon_sym_port] = ACTIONS(1523),
    [anon_sym_string] = ACTIONS(1523),
    [anon_sym_subnet] = ACTIONS(1523),
    [anon_sym_time] = ACTIONS(1523),
    [anon_sym_opaque] = ACTIONS(1523),
    [anon_sym_set] = ACTIONS(1523),
    [anon_sym_table] = ACTIONS(1523),
    [anon_sym_union] = ACTIONS(1523),
    [anon_sym_vector] = ACTIONS(1523),
    [anon_sym_DOLLAR] = ACTIONS(1521),
    [anon_sym_PIPE] = ACTIONS(1521),
    [anon_sym_PLUS_PLUS] = ACTIONS(1521),
    [anon_sym_DASH_DASH] = ACTIONS(1521),
    [anon_sym_BANG] = ACTIONS(1521),
    [anon_sym_TILDE] = ACTIONS(1521),
    [anon_sym_DASH] = ACTIONS(1523),
    [anon_sym_PLUS] = ACTIONS(1523),
    [anon_sym_copy] = ACTIONS(1523),
    [anon_sym_schedule] = ACTIONS(1523),
    [anon_sym_T] = ACTIONS(1523),
    [anon_sym_F] = ACTIONS(1523),
    [anon_sym_ATdeprecated] = ACTIONS(1521),
    [anon_sym_ATload] = ACTIONS(1523),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1521),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1521),
    [anon_sym_ATunload] = ACTIONS(1521),
    [anon_sym_ATprefixes] = ACTIONS(1521),
    [anon_sym_ATif] = ACTIONS(1523),
    [anon_sym_ATifdef] = ACTIONS(1521),
    [anon_sym_ATifndef] = ACTIONS(1521),
    [anon_sym_ATendif] = ACTIONS(1521),
    [anon_sym_ATelse] = ACTIONS(1521),
    [anon_sym_ATpragma] = ACTIONS(1521),
    [anon_sym_ATDIR] = ACTIONS(1521),
    [anon_sym_ATFILENAME] = ACTIONS(1521),
    [sym_id] = ACTIONS(1523),
    [sym_pattern] = ACTIONS(1521),
    [sym_ipv4] = ACTIONS(1523),
    [sym_ipv6] = ACTIONS(1521),
    [sym_port] = ACTIONS(1521),
    [sym_integer] = ACTIONS(1523),
    [sym_floatp] = ACTIONS(1523),
    [sym_hex] = ACTIONS(1523),
    [sym_hostname] = ACTIONS(1523),
    [aux_sym_string_token1] = ACTIONS(1521),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(295)] = {
    [ts_builtin_sym_end] = ACTIONS(1525),
    [anon_sym_module] = ACTIONS(1527),
    [anon_sym_SEMI] = ACTIONS(1525),
    [anon_sym_export] = ACTIONS(1527),
    [anon_sym_LBRACE] = ACTIONS(1525),
    [anon_sym_global] = ACTIONS(1527),
    [anon_sym_option] = ACTIONS(1527),
    [anon_sym_const] = ACTIONS(1527),
    [anon_sym_redef] = ACTIONS(1527),
    [anon_sym_enum] = ACTIONS(1527),
    [anon_sym_record] = ACTIONS(1527),
    [anon_sym_type] = ACTIONS(1527),
    [anon_sym_print] = ACTIONS(1527),
    [anon_sym_event] = ACTIONS(1527),
    [anon_sym_if] = ACTIONS(1527),
    [anon_sym_LPAREN] = ACTIONS(1525),
    [anon_sym_switch] = ACTIONS(1527),
    [anon_sym_for] = ACTIONS(1527),
    [anon_sym_LBRACK] = ACTIONS(1527),
    [anon_sym_while] = ACTIONS(1527),
    [anon_sym_next] = ACTIONS(1527),
    [anon_sym_break] = ACTIONS(1527),
    [anon_sym_fallthrough] = ACTIONS(1527),
    [anon_sym_return] = ACTIONS(1527),
    [anon_sym_add] = ACTIONS(1527),
    [anon_sym_delete] = ACTIONS(1527),
    [anon_sym_local] = ACTIONS(1527),
    [anon_sym_when] = ACTIONS(1527),
    [anon_sym_assert] = ACTIONS(1527),
    [anon_sym_function] = ACTIONS(1527),
    [anon_sym_hook] = ACTIONS(1527),
    [anon_sym_addr] = ACTIONS(1527),
    [anon_sym_any] = ACTIONS(1527),
    [anon_sym_bool] = ACTIONS(1527),
    [anon_sym_count] = ACTIONS(1527),
    [anon_sym_double] = ACTIONS(1527),
    [anon_sym_file] = ACTIONS(1527),
    [anon_sym_int] = ACTIONS(1527),
    [anon_sym_interval] = ACTIONS(1527),
    [anon_sym_list] = ACTIONS(1527),
    [anon_sym_pattern] = ACTIONS(1527),
    [anon_sym_port] = ACTIONS(1527),
    [anon_sym_string] = ACTIONS(1527),
    [anon_sym_subnet] = ACTIONS(1527),
    [anon_sym_time] = ACTIONS(1527),
    [anon_sym_opaque] = ACTIONS(1527),
    [anon_sym_set] = ACTIONS(1527),
    [anon_sym_table] = ACTIONS(1527),
    [anon_sym_union] = ACTIONS(1527),
    [anon_sym_vector] = ACTIONS(1527),
    [anon_sym_DOLLAR] = ACTIONS(1525),
    [anon_sym_PIPE] = ACTIONS(1525),
    [anon_sym_PLUS_PLUS] = ACTIONS(1525),
    [anon_sym_DASH_DASH] = ACTIONS(1525),
    [anon_sym_BANG] = ACTIONS(1525),
    [anon_sym_TILDE] = ACTIONS(1525),
    [anon_sym_DASH] = ACTIONS(1527),
    [anon_sym_PLUS] = ACTIONS(1527),
    [anon_sym_copy] = ACTIONS(1527),
    [anon_sym_schedule] = ACTIONS(1527),
    [anon_sym_T] = ACTIONS(1527),
    [anon_sym_F] = ACTIONS(1527),
    [anon_sym_ATdeprecated] = ACTIONS(1525),
    [anon_sym_ATload] = ACTIONS(1527),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1525),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1525),
    [anon_sym_ATunload] = ACTIONS(1525),
    [anon_sym_ATprefixes] = ACTIONS(1525),
    [anon_sym_ATif] = ACTIONS(1527),
    [anon_sym_ATifdef] = ACTIONS(1525),
    [anon_sym_ATifndef] = ACTIONS(1525),
    [anon_sym_ATendif] = ACTIONS(1525),
    [anon_sym_ATelse] = ACTIONS(1525),
    [anon_sym_ATpragma] = ACTIONS(1525),
    [anon_sym_ATDIR] = ACTIONS(1525),
    [anon_sym_ATFILENAME] = ACTIONS(1525),
    [sym_id] = ACTIONS(1527),
    [sym_pattern] = ACTIONS(1525),
    [sym_ipv4] = ACTIONS(1527),
    [sym_ipv6] = ACTIONS(1525),
    [sym_port] = ACTIONS(1525),
    [sym_integer] = ACTIONS(1527),
    [sym_floatp] = ACTIONS(1527),
    [sym_hex] = ACTIONS(1527),
    [sym_hostname] = ACTIONS(1527),
    [aux_sym_string_token1] = ACTIONS(1525),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(296)] = {
    [ts_builtin_sym_end] = ACTIONS(1529),
    [anon_sym_module] = ACTIONS(1531),
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_export] = ACTIONS(1531),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_global] = ACTIONS(1531),
    [anon_sym_option] = ACTIONS(1531),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_redef] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_type] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(297)] = {
    [ts_builtin_sym_end] = ACTIONS(1533),
    [anon_sym_module] = ACTIONS(1535),
    [anon_sym_SEMI] = ACTIONS(1533),
    [anon_sym_export] = ACTIONS(1535),
    [anon_sym_LBRACE] = ACTIONS(1533),
    [anon_sym_global] = ACTIONS(1535),
    [anon_sym_option] = ACTIONS(1535),
    [anon_sym_const] = ACTIONS(1535),
    [anon_sym_redef] = ACTIONS(1535),
    [anon_sym_enum] = ACTIONS(1535),
    [anon_sym_record] = ACTIONS(1535),
    [anon_sym_type] = ACTIONS(1535),
    [anon_sym_print] = ACTIONS(1535),
    [anon_sym_event] = ACTIONS(1535),
    [anon_sym_if] = ACTIONS(1535),
    [anon_sym_LPAREN] = ACTIONS(1533),
    [anon_sym_switch] = ACTIONS(1535),
    [anon_sym_for] = ACTIONS(1535),
    [anon_sym_LBRACK] = ACTIONS(1535),
    [anon_sym_while] = ACTIONS(1535),
    [anon_sym_next] = ACTIONS(1535),
    [anon_sym_break] = ACTIONS(1535),
    [anon_sym_fallthrough] = ACTIONS(1535),
    [anon_sym_return] = ACTIONS(1535),
    [anon_sym_add] = ACTIONS(1535),
    [anon_sym_delete] = ACTIONS(1535),
    [anon_sym_local] = ACTIONS(1535),
    [anon_sym_when] = ACTIONS(1535),
    [anon_sym_assert] = ACTIONS(1535),
    [anon_sym_function] = ACTIONS(1535),
    [anon_sym_hook] = ACTIONS(1535),
    [anon_sym_addr] = ACTIONS(1535),
    [anon_sym_any] = ACTIONS(1535),
    [anon_sym_bool] = ACTIONS(1535),
    [anon_sym_count] = ACTIONS(1535),
    [anon_sym_double] = ACTIONS(1535),
    [anon_sym_file] = ACTIONS(1535),
    [anon_sym_int] = ACTIONS(1535),
    [anon_sym_interval] = ACTIONS(1535),
    [anon_sym_list] = ACTIONS(1535),
    [anon_sym_pattern] = ACTIONS(1535),
    [anon_sym_port] = ACTIONS(1535),
    [anon_sym_string] = ACTIONS(1535),
    [anon_sym_subnet] = ACTIONS(1535),
    [anon_sym_time] = ACTIONS(1535),
    [anon_sym_opaque] = ACTIONS(1535),
    [anon_sym_set] = ACTIONS(1535),
    [anon_sym_table] = ACTIONS(1535),
    [anon_sym_union] = ACTIONS(1535),
    [anon_sym_vector] = ACTIONS(1535),
    [anon_sym_DOLLAR] = ACTIONS(1533),
    [anon_sym_PIPE] = ACTIONS(1533),
    [anon_sym_PLUS_PLUS] = ACTIONS(1533),
    [anon_sym_DASH_DASH] = ACTIONS(1533),
    [anon_sym_BANG] = ACTIONS(1533),
    [anon_sym_TILDE] = ACTIONS(1533),
    [anon_sym_DASH] = ACTIONS(1535),
    [anon_sym_PLUS] = ACTIONS(1535),
    [anon_sym_copy] = ACTIONS(1535),
    [anon_sym_schedule] = ACTIONS(1535),
    [anon_sym_T] = ACTIONS(1535),
    [anon_sym_F] = ACTIONS(1535),
    [anon_sym_ATdeprecated] = ACTIONS(1533),
    [anon_sym_ATload] = ACTIONS(1535),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1533),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1533),
    [anon_sym_ATunload] = ACTIONS(1533),
    [anon_sym_ATprefixes] = ACTIONS(1533),
    [anon_sym_ATif] = ACTIONS(1535),
    [anon_sym_ATifdef] = ACTIONS(1533),
    [anon_sym_ATifndef] = ACTIONS(1533),
    [anon_sym_ATendif] = ACTIONS(1533),
    [anon_sym_ATelse] = ACTIONS(1533),
    [anon_sym_ATpragma] = ACTIONS(1533),
    [anon_sym_ATDIR] = ACTIONS(1533),
    [anon_sym_ATFILENAME] = ACTIONS(1533),
    [sym_id] = ACTIONS(1535),
    [sym_pattern] = ACTIONS(1533),
    [sym_ipv4] = ACTIONS(1535),
    [sym_ipv6] = ACTIONS(1533),
    [sym_port] = ACTIONS(1533),
    [sym_integer] = ACTIONS(1535),
    [sym_floatp] = ACTIONS(1535),
    [sym_hex] = ACTIONS(1535),
    [sym_hostname] = ACTIONS(1535),
    [aux_sym_string_token1] = ACTIONS(1533),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(298)] = {
    [ts_builtin_sym_end] = ACTIONS(1537),
    [anon_sym_module] = ACTIONS(1539),
    [anon_sym_SEMI] = ACTIONS(1537),
    [anon_sym_export] = ACTIONS(1539),
    [anon_sym_LBRACE] = ACTIONS(1537),
    [anon_sym_global] = ACTIONS(1539),
    [anon_sym_option] = ACTIONS(1539),
    [anon_sym_const] = ACTIONS(1539),
    [anon_sym_redef] = ACTIONS(1539),
    [anon_sym_enum] = ACTIONS(1539),
    [anon_sym_record] = ACTIONS(1539),
    [anon_sym_type] = ACTIONS(1539),
    [anon_sym_print] = ACTIONS(1539),
    [anon_sym_event] = ACTIONS(1539),
    [anon_sym_if] = ACTIONS(1539),
    [anon_sym_LPAREN] = ACTIONS(1537),
    [anon_sym_switch] = ACTIONS(1539),
    [anon_sym_for] = ACTIONS(1539),
    [anon_sym_LBRACK] = ACTIONS(1539),
    [anon_sym_while] = ACTIONS(1539),
    [anon_sym_next] = ACTIONS(1539),
    [anon_sym_break] = ACTIONS(1539),
    [anon_sym_fallthrough] = ACTIONS(1539),
    [anon_sym_return] = ACTIONS(1539),
    [anon_sym_add] = ACTIONS(1539),
    [anon_sym_delete] = ACTIONS(1539),
    [anon_sym_local] = ACTIONS(1539),
    [anon_sym_when] = ACTIONS(1539),
    [anon_sym_assert] = ACTIONS(1539),
    [anon_sym_function] = ACTIONS(1539),
    [anon_sym_hook] = ACTIONS(1539),
    [anon_sym_addr] = ACTIONS(1539),
    [anon_sym_any] = ACTIONS(1539),
    [anon_sym_bool] = ACTIONS(1539),
    [anon_sym_count] = ACTIONS(1539),
    [anon_sym_double] = ACTIONS(1539),
    [anon_sym_file] = ACTIONS(1539),
    [anon_sym_int] = ACTIONS(1539),
    [anon_sym_interval] = ACTIONS(1539),
    [anon_sym_list] = ACTIONS(1539),
    [anon_sym_pattern] = ACTIONS(1539),
    [anon_sym_port] = ACTIONS(1539),
    [anon_sym_string] = ACTIONS(1539),
    [anon_sym_subnet] = ACTIONS(1539),
    [anon_sym_time] = ACTIONS(1539),
    [anon_sym_opaque] = ACTIONS(1539),
    [anon_sym_set] = ACTIONS(1539),
    [anon_sym_table] = ACTIONS(1539),
    [anon_sym_union] = ACTIONS(1539),
    [anon_sym_vector] = ACTIONS(1539),
    [anon_sym_DOLLAR] = ACTIONS(1537),
    [anon_sym_PIPE] = ACTIONS(1537),
    [anon_sym_PLUS_PLUS] = ACTIONS(1537),
    [anon_sym_DASH_DASH] = ACTIONS(1537),
    [anon_sym_BANG] = ACTIONS(1537),
    [anon_sym_TILDE] = ACTIONS(1537),
    [anon_sym_DASH] = ACTIONS(1539),
    [anon_sym_PLUS] = ACTIONS(1539),
    [anon_sym_copy] = ACTIONS(1539),
    [anon_sym_schedule] = ACTIONS(1539),
    [anon_sym_T] = ACTIONS(1539),
    [anon_sym_F] = ACTIONS(1539),
    [anon_sym_ATdeprecated] = ACTIONS(1537),
    [anon_sym_ATload] = ACTIONS(1539),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1537),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1537),
    [anon_sym_ATunload] = ACTIONS(1537),
    [anon_sym_ATprefixes] = ACTIONS(1537),
    [anon_sym_ATif] = ACTIONS(1539),
    [anon_sym_ATifdef] = ACTIONS(1537),
    [anon_sym_ATifndef] = ACTIONS(1537),
    [anon_sym_ATendif] = ACTIONS(1537),
    [anon_sym_ATelse] = ACTIONS(1537),
    [anon_sym_ATpragma] = ACTIONS(1537),
    [anon_sym_ATDIR] = ACTIONS(1537),
    [anon_sym_ATFILENAME] = ACTIONS(1537),
    [sym_id] = ACTIONS(1539),
    [sym_pattern] = ACTIONS(1537),
    [sym_ipv4] = ACTIONS(1539),
    [sym_ipv6] = ACTIONS(1537),
    [sym_port] = ACTIONS(1537),
    [sym_integer] = ACTIONS(1539),
    [sym_floatp] = ACTIONS(1539),
    [sym_hex] = ACTIONS(1539),
    [sym_hostname] = ACTIONS(1539),
    [aux_sym_string_token1] = ACTIONS(1537),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(299)] = {
    [ts_builtin_sym_end] = ACTIONS(1541),
    [anon_sym_module] = ACTIONS(1543),
    [anon_sym_SEMI] = ACTIONS(1541),
    [anon_sym_export] = ACTIONS(1543),
    [anon_sym_LBRACE] = ACTIONS(1541),
    [anon_sym_global] = ACTIONS(1543),
    [anon_sym_option] = ACTIONS(1543),
    [anon_sym_const] = ACTIONS(1543),
    [anon_sym_redef] = ACTIONS(1543),
    [anon_sym_enum] = ACTIONS(1543),
    [anon_sym_record] = ACTIONS(1543),
    [anon_sym_type] = ACTIONS(1543),
    [anon_sym_print] = ACTIONS(1543),
    [anon_sym_event] = ACTIONS(1543),
    [anon_sym_if] = ACTIONS(1543),
    [anon_sym_LPAREN] = ACTIONS(1541),
    [anon_sym_switch] = ACTIONS(1543),
    [anon_sym_for] = ACTIONS(1543),
    [anon_sym_LBRACK] = ACTIONS(1543),
    [anon_sym_while] = ACTIONS(1543),
    [anon_sym_next] = ACTIONS(1543),
    [anon_sym_break] = ACTIONS(1543),
    [anon_sym_fallthrough] = ACTIONS(1543),
    [anon_sym_return] = ACTIONS(1543),
    [anon_sym_add] = ACTIONS(1543),
    [anon_sym_delete] = ACTIONS(1543),
    [anon_sym_local] = ACTIONS(1543),
    [anon_sym_when] = ACTIONS(1543),
    [anon_sym_assert] = ACTIONS(1543),
    [anon_sym_function] = ACTIONS(1543),
    [anon_sym_hook] = ACTIONS(1543),
    [anon_sym_addr] = ACTIONS(1543),
    [anon_sym_any] = ACTIONS(1543),
    [anon_sym_bool] = ACTIONS(1543),
    [anon_sym_count] = ACTIONS(1543),
    [anon_sym_double] = ACTIONS(1543),
    [anon_sym_file] = ACTIONS(1543),
    [anon_sym_int] = ACTIONS(1543),
    [anon_sym_interval] = ACTIONS(1543),
    [anon_sym_list] = ACTIONS(1543),
    [anon_sym_pattern] = ACTIONS(1543),
    [anon_sym_port] = ACTIONS(1543),
    [anon_sym_string] = ACTIONS(1543),
    [anon_sym_subnet] = ACTIONS(1543),
    [anon_sym_time] = ACTIONS(1543),
    [anon_sym_opaque] = ACTIONS(1543),
    [anon_sym_set] = ACTIONS(1543),
    [anon_sym_table] = ACTIONS(1543),
    [anon_sym_union] = ACTIONS(1543),
    [anon_sym_vector] = ACTIONS(1543),
    [anon_sym_DOLLAR] = ACTIONS(1541),
    [anon_sym_PIPE] = ACTIONS(1541),
    [anon_sym_PLUS_PLUS] = ACTIONS(1541),
    [anon_sym_DASH_DASH] = ACTIONS(1541),
    [anon_sym_BANG] = ACTIONS(1541),
    [anon_sym_TILDE] = ACTIONS(1541),
    [anon_sym_DASH] = ACTIONS(1543),
    [anon_sym_PLUS] = ACTIONS(1543),
    [anon_sym_copy] = ACTIONS(1543),
    [anon_sym_schedule] = ACTIONS(1543),
    [anon_sym_T] = ACTIONS(1543),
    [anon_sym_F] = ACTIONS(1543),
    [anon_sym_ATdeprecated] = ACTIONS(1541),
    [anon_sym_ATload] = ACTIONS(1543),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1541),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1541),
    [anon_sym_ATunload] = ACTIONS(1541),
    [anon_sym_ATprefixes] = ACTIONS(1541),
    [anon_sym_ATif] = ACTIONS(1543),
    [anon_sym_ATifdef] = ACTIONS(1541),
    [anon_sym_ATifndef] = ACTIONS(1541),
    [anon_sym_ATendif] = ACTIONS(1541),
    [anon_sym_ATelse] = ACTIONS(1541),
    [anon_sym_ATpragma] = ACTIONS(1541),
    [anon_sym_ATDIR] = ACTIONS(1541),
    [anon_sym_ATFILENAME] = ACTIONS(1541),
    [sym_id] = ACTIONS(1543),
    [sym_pattern] = ACTIONS(1541),
    [sym_ipv4] = ACTIONS(1543),
    [sym_ipv6] = ACTIONS(1541),
    [sym_port] = ACTIONS(1541),
    [sym_integer] = ACTIONS(1543),
    [sym_floatp] = ACTIONS(1543),
    [sym_hex] = ACTIONS(1543),
    [sym_hostname] = ACTIONS(1543),
    [aux_sym_string_token1] = ACTIONS(1541),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(300)] = {
    [ts_builtin_sym_end] = ACTIONS(1545),
    [anon_sym_module] = ACTIONS(1547),
    [anon_sym_SEMI] = ACTIONS(1545),
    [anon_sym_export] = ACTIONS(1547),
    [anon_sym_LBRACE] = ACTIONS(1545),
    [anon_sym_global] = ACTIONS(1547),
    [anon_sym_option] = ACTIONS(1547),
    [anon_sym_const] = ACTIONS(1547),
    [anon_sym_redef] = ACTIONS(1547),
    [anon_sym_enum] = ACTIONS(1547),
    [anon_sym_record] = ACTIONS(1547),
    [anon_sym_type] = ACTIONS(1547),
    [anon_sym_print] = ACTIONS(1547),
    [anon_sym_event] = ACTIONS(1547),
    [anon_sym_if] = ACTIONS(1547),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_switch] = ACTIONS(1547),
    [anon_sym_for] = ACTIONS(1547),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_while] = ACTIONS(1547),
    [anon_sym_next] = ACTIONS(1547),
    [anon_sym_break] = ACTIONS(1547),
    [anon_sym_fallthrough] = ACTIONS(1547),
    [anon_sym_return] = ACTIONS(1547),
    [anon_sym_add] = ACTIONS(1547),
    [anon_sym_delete] = ACTIONS(1547),
    [anon_sym_local] = ACTIONS(1547),
    [anon_sym_when] = ACTIONS(1547),
    [anon_sym_assert] = ACTIONS(1547),
    [anon_sym_function] = ACTIONS(1547),
    [anon_sym_hook] = ACTIONS(1547),
    [anon_sym_addr] = ACTIONS(1547),
    [anon_sym_any] = ACTIONS(1547),
    [anon_sym_bool] = ACTIONS(1547),
    [anon_sym_count] = ACTIONS(1547),
    [anon_sym_double] = ACTIONS(1547),
    [anon_sym_file] = ACTIONS(1547),
    [anon_sym_int] = ACTIONS(1547),
    [anon_sym_interval] = ACTIONS(1547),
    [anon_sym_list] = ACTIONS(1547),
    [anon_sym_pattern] = ACTIONS(1547),
    [anon_sym_port] = ACTIONS(1547),
    [anon_sym_string] = ACTIONS(1547),
    [anon_sym_subnet] = ACTIONS(1547),
    [anon_sym_time] = ACTIONS(1547),
    [anon_sym_opaque] = ACTIONS(1547),
    [anon_sym_set] = ACTIONS(1547),
    [anon_sym_table] = ACTIONS(1547),
    [anon_sym_union] = ACTIONS(1547),
    [anon_sym_vector] = ACTIONS(1547),
    [anon_sym_DOLLAR] = ACTIONS(1545),
    [anon_sym_PIPE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_DASH] = ACTIONS(1547),
    [anon_sym_PLUS] = ACTIONS(1547),
    [anon_sym_copy] = ACTIONS(1547),
    [anon_sym_schedule] = ACTIONS(1547),
    [anon_sym_T] = ACTIONS(1547),
    [anon_sym_F] = ACTIONS(1547),
    [anon_sym_ATdeprecated] = ACTIONS(1545),
    [anon_sym_ATload] = ACTIONS(1547),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1545),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1545),
    [anon_sym_ATunload] = ACTIONS(1545),
    [anon_sym_ATprefixes] = ACTIONS(1545),
    [anon_sym_ATif] = ACTIONS(1547),
    [anon_sym_ATifdef] = ACTIONS(1545),
    [anon_sym_ATifndef] = ACTIONS(1545),
    [anon_sym_ATendif] = ACTIONS(1545),
    [anon_sym_ATelse] = ACTIONS(1545),
    [anon_sym_ATpragma] = ACTIONS(1545),
    [anon_sym_ATDIR] = ACTIONS(1545),
    [anon_sym_ATFILENAME] = ACTIONS(1545),
    [sym_id] = ACTIONS(1547),
    [sym_pattern] = ACTIONS(1545),
    [sym_ipv4] = ACTIONS(1547),
    [sym_ipv6] = ACTIONS(1545),
    [sym_port] = ACTIONS(1545),
    [sym_integer] = ACTIONS(1547),
    [sym_floatp] = ACTIONS(1547),
    [sym_hex] = ACTIONS(1547),
    [sym_hostname] = ACTIONS(1547),
    [aux_sym_string_token1] = ACTIONS(1545),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(301)] = {
    [ts_builtin_sym_end] = ACTIONS(1545),
    [anon_sym_module] = ACTIONS(1547),
    [anon_sym_SEMI] = ACTIONS(1545),
    [anon_sym_export] = ACTIONS(1547),
    [anon_sym_LBRACE] = ACTIONS(1545),
    [anon_sym_global] = ACTIONS(1547),
    [anon_sym_option] = ACTIONS(1547),
    [anon_sym_const] = ACTIONS(1547),
    [anon_sym_redef] = ACTIONS(1547),
    [anon_sym_enum] = ACTIONS(1547),
    [anon_sym_record] = ACTIONS(1547),
    [anon_sym_type] = ACTIONS(1547),
    [anon_sym_print] = ACTIONS(1547),
    [anon_sym_event] = ACTIONS(1547),
    [anon_sym_if] = ACTIONS(1547),
    [anon_sym_LPAREN] = ACTIONS(1545),
    [anon_sym_switch] = ACTIONS(1547),
    [anon_sym_for] = ACTIONS(1547),
    [anon_sym_LBRACK] = ACTIONS(1547),
    [anon_sym_while] = ACTIONS(1547),
    [anon_sym_next] = ACTIONS(1547),
    [anon_sym_break] = ACTIONS(1547),
    [anon_sym_fallthrough] = ACTIONS(1547),
    [anon_sym_return] = ACTIONS(1547),
    [anon_sym_add] = ACTIONS(1547),
    [anon_sym_delete] = ACTIONS(1547),
    [anon_sym_local] = ACTIONS(1547),
    [anon_sym_when] = ACTIONS(1547),
    [anon_sym_assert] = ACTIONS(1547),
    [anon_sym_function] = ACTIONS(1547),
    [anon_sym_hook] = ACTIONS(1547),
    [anon_sym_addr] = ACTIONS(1547),
    [anon_sym_any] = ACTIONS(1547),
    [anon_sym_bool] = ACTIONS(1547),
    [anon_sym_count] = ACTIONS(1547),
    [anon_sym_double] = ACTIONS(1547),
    [anon_sym_file] = ACTIONS(1547),
    [anon_sym_int] = ACTIONS(1547),
    [anon_sym_interval] = ACTIONS(1547),
    [anon_sym_list] = ACTIONS(1547),
    [anon_sym_pattern] = ACTIONS(1547),
    [anon_sym_port] = ACTIONS(1547),
    [anon_sym_string] = ACTIONS(1547),
    [anon_sym_subnet] = ACTIONS(1547),
    [anon_sym_time] = ACTIONS(1547),
    [anon_sym_opaque] = ACTIONS(1547),
    [anon_sym_set] = ACTIONS(1547),
    [anon_sym_table] = ACTIONS(1547),
    [anon_sym_union] = ACTIONS(1547),
    [anon_sym_vector] = ACTIONS(1547),
    [anon_sym_DOLLAR] = ACTIONS(1545),
    [anon_sym_PIPE] = ACTIONS(1545),
    [anon_sym_PLUS_PLUS] = ACTIONS(1545),
    [anon_sym_DASH_DASH] = ACTIONS(1545),
    [anon_sym_BANG] = ACTIONS(1545),
    [anon_sym_TILDE] = ACTIONS(1545),
    [anon_sym_DASH] = ACTIONS(1547),
    [anon_sym_PLUS] = ACTIONS(1547),
    [anon_sym_copy] = ACTIONS(1547),
    [anon_sym_schedule] = ACTIONS(1547),
    [anon_sym_T] = ACTIONS(1547),
    [anon_sym_F] = ACTIONS(1547),
    [anon_sym_ATdeprecated] = ACTIONS(1545),
    [anon_sym_ATload] = ACTIONS(1547),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1545),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1545),
    [anon_sym_ATunload] = ACTIONS(1545),
    [anon_sym_ATprefixes] = ACTIONS(1545),
    [anon_sym_ATif] = ACTIONS(1547),
    [anon_sym_ATifdef] = ACTIONS(1545),
    [anon_sym_ATifndef] = ACTIONS(1545),
    [anon_sym_ATendif] = ACTIONS(1545),
    [anon_sym_ATelse] = ACTIONS(1545),
    [anon_sym_ATpragma] = ACTIONS(1545),
    [anon_sym_ATDIR] = ACTIONS(1545),
    [anon_sym_ATFILENAME] = ACTIONS(1545),
    [sym_id] = ACTIONS(1547),
    [sym_pattern] = ACTIONS(1545),
    [sym_ipv4] = ACTIONS(1547),
    [sym_ipv6] = ACTIONS(1545),
    [sym_port] = ACTIONS(1545),
    [sym_integer] = ACTIONS(1547),
    [sym_floatp] = ACTIONS(1547),
    [sym_hex] = ACTIONS(1547),
    [sym_hostname] = ACTIONS(1547),
    [aux_sym_string_token1] = ACTIONS(1545),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(302)] = {
    [ts_builtin_sym_end] = ACTIONS(1499),
    [anon_sym_module] = ACTIONS(1501),
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_export] = ACTIONS(1501),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_global] = ACTIONS(1501),
    [anon_sym_option] = ACTIONS(1501),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_redef] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_type] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(303)] = {
    [ts_builtin_sym_end] = ACTIONS(1549),
    [anon_sym_module] = ACTIONS(1551),
    [anon_sym_SEMI] = ACTIONS(1549),
    [anon_sym_export] = ACTIONS(1551),
    [anon_sym_LBRACE] = ACTIONS(1549),
    [anon_sym_global] = ACTIONS(1551),
    [anon_sym_option] = ACTIONS(1551),
    [anon_sym_const] = ACTIONS(1551),
    [anon_sym_redef] = ACTIONS(1551),
    [anon_sym_enum] = ACTIONS(1551),
    [anon_sym_record] = ACTIONS(1551),
    [anon_sym_type] = ACTIONS(1551),
    [anon_sym_print] = ACTIONS(1551),
    [anon_sym_event] = ACTIONS(1551),
    [anon_sym_if] = ACTIONS(1551),
    [anon_sym_LPAREN] = ACTIONS(1549),
    [anon_sym_switch] = ACTIONS(1551),
    [anon_sym_for] = ACTIONS(1551),
    [anon_sym_LBRACK] = ACTIONS(1551),
    [anon_sym_while] = ACTIONS(1551),
    [anon_sym_next] = ACTIONS(1551),
    [anon_sym_break] = ACTIONS(1551),
    [anon_sym_fallthrough] = ACTIONS(1551),
    [anon_sym_return] = ACTIONS(1551),
    [anon_sym_add] = ACTIONS(1551),
    [anon_sym_delete] = ACTIONS(1551),
    [anon_sym_local] = ACTIONS(1551),
    [anon_sym_when] = ACTIONS(1551),
    [anon_sym_assert] = ACTIONS(1551),
    [anon_sym_function] = ACTIONS(1551),
    [anon_sym_hook] = ACTIONS(1551),
    [anon_sym_addr] = ACTIONS(1551),
    [anon_sym_any] = ACTIONS(1551),
    [anon_sym_bool] = ACTIONS(1551),
    [anon_sym_count] = ACTIONS(1551),
    [anon_sym_double] = ACTIONS(1551),
    [anon_sym_file] = ACTIONS(1551),
    [anon_sym_int] = ACTIONS(1551),
    [anon_sym_interval] = ACTIONS(1551),
    [anon_sym_list] = ACTIONS(1551),
    [anon_sym_pattern] = ACTIONS(1551),
    [anon_sym_port] = ACTIONS(1551),
    [anon_sym_string] = ACTIONS(1551),
    [anon_sym_subnet] = ACTIONS(1551),
    [anon_sym_time] = ACTIONS(1551),
    [anon_sym_opaque] = ACTIONS(1551),
    [anon_sym_set] = ACTIONS(1551),
    [anon_sym_table] = ACTIONS(1551),
    [anon_sym_union] = ACTIONS(1551),
    [anon_sym_vector] = ACTIONS(1551),
    [anon_sym_DOLLAR] = ACTIONS(1549),
    [anon_sym_PIPE] = ACTIONS(1549),
    [anon_sym_PLUS_PLUS] = ACTIONS(1549),
    [anon_sym_DASH_DASH] = ACTIONS(1549),
    [anon_sym_BANG] = ACTIONS(1549),
    [anon_sym_TILDE] = ACTIONS(1549),
    [anon_sym_DASH] = ACTIONS(1551),
    [anon_sym_PLUS] = ACTIONS(1551),
    [anon_sym_copy] = ACTIONS(1551),
    [anon_sym_schedule] = ACTIONS(1551),
    [anon_sym_T] = ACTIONS(1551),
    [anon_sym_F] = ACTIONS(1551),
    [anon_sym_ATdeprecated] = ACTIONS(1549),
    [anon_sym_ATload] = ACTIONS(1551),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1549),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1549),
    [anon_sym_ATunload] = ACTIONS(1549),
    [anon_sym_ATprefixes] = ACTIONS(1549),
    [anon_sym_ATif] = ACTIONS(1551),
    [anon_sym_ATifdef] = ACTIONS(1549),
    [anon_sym_ATifndef] = ACTIONS(1549),
    [anon_sym_ATendif] = ACTIONS(1549),
    [anon_sym_ATelse] = ACTIONS(1549),
    [anon_sym_ATpragma] = ACTIONS(1549),
    [anon_sym_ATDIR] = ACTIONS(1549),
    [anon_sym_ATFILENAME] = ACTIONS(1549),
    [sym_id] = ACTIONS(1551),
    [sym_pattern] = ACTIONS(1549),
    [sym_ipv4] = ACTIONS(1551),
    [sym_ipv6] = ACTIONS(1549),
    [sym_port] = ACTIONS(1549),
    [sym_integer] = ACTIONS(1551),
    [sym_floatp] = ACTIONS(1551),
    [sym_hex] = ACTIONS(1551),
    [sym_hostname] = ACTIONS(1551),
    [aux_sym_string_token1] = ACTIONS(1549),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(304)] = {
    [ts_builtin_sym_end] = ACTIONS(1553),
    [anon_sym_module] = ACTIONS(1555),
    [anon_sym_SEMI] = ACTIONS(1553),
    [anon_sym_export] = ACTIONS(1555),
    [anon_sym_LBRACE] = ACTIONS(1553),
    [anon_sym_global] = ACTIONS(1555),
    [anon_sym_option] = ACTIONS(1555),
    [anon_sym_const] = ACTIONS(1555),
    [anon_sym_redef] = ACTIONS(1555),
    [anon_sym_enum] = ACTIONS(1555),
    [anon_sym_record] = ACTIONS(1555),
    [anon_sym_type] = ACTIONS(1555),
    [anon_sym_print] = ACTIONS(1555),
    [anon_sym_event] = ACTIONS(1555),
    [anon_sym_if] = ACTIONS(1555),
    [anon_sym_LPAREN] = ACTIONS(1553),
    [anon_sym_switch] = ACTIONS(1555),
    [anon_sym_for] = ACTIONS(1555),
    [anon_sym_LBRACK] = ACTIONS(1555),
    [anon_sym_while] = ACTIONS(1555),
    [anon_sym_next] = ACTIONS(1555),
    [anon_sym_break] = ACTIONS(1555),
    [anon_sym_fallthrough] = ACTIONS(1555),
    [anon_sym_return] = ACTIONS(1555),
    [anon_sym_add] = ACTIONS(1555),
    [anon_sym_delete] = ACTIONS(1555),
    [anon_sym_local] = ACTIONS(1555),
    [anon_sym_when] = ACTIONS(1555),
    [anon_sym_assert] = ACTIONS(1555),
    [anon_sym_function] = ACTIONS(1555),
    [anon_sym_hook] = ACTIONS(1555),
    [anon_sym_addr] = ACTIONS(1555),
    [anon_sym_any] = ACTIONS(1555),
    [anon_sym_bool] = ACTIONS(1555),
    [anon_sym_count] = ACTIONS(1555),
    [anon_sym_double] = ACTIONS(1555),
    [anon_sym_file] = ACTIONS(1555),
    [anon_sym_int] = ACTIONS(1555),
    [anon_sym_interval] = ACTIONS(1555),
    [anon_sym_list] = ACTIONS(1555),
    [anon_sym_pattern] = ACTIONS(1555),
    [anon_sym_port] = ACTIONS(1555),
    [anon_sym_string] = ACTIONS(1555),
    [anon_sym_subnet] = ACTIONS(1555),
    [anon_sym_time] = ACTIONS(1555),
    [anon_sym_opaque] = ACTIONS(1555),
    [anon_sym_set] = ACTIONS(1555),
    [anon_sym_table] = ACTIONS(1555),
    [anon_sym_union] = ACTIONS(1555),
    [anon_sym_vector] = ACTIONS(1555),
    [anon_sym_DOLLAR] = ACTIONS(1553),
    [anon_sym_PIPE] = ACTIONS(1553),
    [anon_sym_PLUS_PLUS] = ACTIONS(1553),
    [anon_sym_DASH_DASH] = ACTIONS(1553),
    [anon_sym_BANG] = ACTIONS(1553),
    [anon_sym_TILDE] = ACTIONS(1553),
    [anon_sym_DASH] = ACTIONS(1555),
    [anon_sym_PLUS] = ACTIONS(1555),
    [anon_sym_copy] = ACTIONS(1555),
    [anon_sym_schedule] = ACTIONS(1555),
    [anon_sym_T] = ACTIONS(1555),
    [anon_sym_F] = ACTIONS(1555),
    [anon_sym_ATdeprecated] = ACTIONS(1553),
    [anon_sym_ATload] = ACTIONS(1555),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1553),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1553),
    [anon_sym_ATunload] = ACTIONS(1553),
    [anon_sym_ATprefixes] = ACTIONS(1553),
    [anon_sym_ATif] = ACTIONS(1555),
    [anon_sym_ATifdef] = ACTIONS(1553),
    [anon_sym_ATifndef] = ACTIONS(1553),
    [anon_sym_ATendif] = ACTIONS(1553),
    [anon_sym_ATelse] = ACTIONS(1553),
    [anon_sym_ATpragma] = ACTIONS(1553),
    [anon_sym_ATDIR] = ACTIONS(1553),
    [anon_sym_ATFILENAME] = ACTIONS(1553),
    [sym_id] = ACTIONS(1555),
    [sym_pattern] = ACTIONS(1553),
    [sym_ipv4] = ACTIONS(1555),
    [sym_ipv6] = ACTIONS(1553),
    [sym_port] = ACTIONS(1553),
    [sym_integer] = ACTIONS(1555),
    [sym_floatp] = ACTIONS(1555),
    [sym_hex] = ACTIONS(1555),
    [sym_hostname] = ACTIONS(1555),
    [aux_sym_string_token1] = ACTIONS(1553),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(305)] = {
    [ts_builtin_sym_end] = ACTIONS(1557),
    [anon_sym_module] = ACTIONS(1559),
    [anon_sym_SEMI] = ACTIONS(1557),
    [anon_sym_export] = ACTIONS(1559),
    [anon_sym_LBRACE] = ACTIONS(1557),
    [anon_sym_global] = ACTIONS(1559),
    [anon_sym_option] = ACTIONS(1559),
    [anon_sym_const] = ACTIONS(1559),
    [anon_sym_redef] = ACTIONS(1559),
    [anon_sym_enum] = ACTIONS(1559),
    [anon_sym_record] = ACTIONS(1559),
    [anon_sym_type] = ACTIONS(1559),
    [anon_sym_print] = ACTIONS(1559),
    [anon_sym_event] = ACTIONS(1559),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_LPAREN] = ACTIONS(1557),
    [anon_sym_switch] = ACTIONS(1559),
    [anon_sym_for] = ACTIONS(1559),
    [anon_sym_LBRACK] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1559),
    [anon_sym_next] = ACTIONS(1559),
    [anon_sym_break] = ACTIONS(1559),
    [anon_sym_fallthrough] = ACTIONS(1559),
    [anon_sym_return] = ACTIONS(1559),
    [anon_sym_add] = ACTIONS(1559),
    [anon_sym_delete] = ACTIONS(1559),
    [anon_sym_local] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(1559),
    [anon_sym_assert] = ACTIONS(1559),
    [anon_sym_function] = ACTIONS(1559),
    [anon_sym_hook] = ACTIONS(1559),
    [anon_sym_addr] = ACTIONS(1559),
    [anon_sym_any] = ACTIONS(1559),
    [anon_sym_bool] = ACTIONS(1559),
    [anon_sym_count] = ACTIONS(1559),
    [anon_sym_double] = ACTIONS(1559),
    [anon_sym_file] = ACTIONS(1559),
    [anon_sym_int] = ACTIONS(1559),
    [anon_sym_interval] = ACTIONS(1559),
    [anon_sym_list] = ACTIONS(1559),
    [anon_sym_pattern] = ACTIONS(1559),
    [anon_sym_port] = ACTIONS(1559),
    [anon_sym_string] = ACTIONS(1559),
    [anon_sym_subnet] = ACTIONS(1559),
    [anon_sym_time] = ACTIONS(1559),
    [anon_sym_opaque] = ACTIONS(1559),
    [anon_sym_set] = ACTIONS(1559),
    [anon_sym_table] = ACTIONS(1559),
    [anon_sym_union] = ACTIONS(1559),
    [anon_sym_vector] = ACTIONS(1559),
    [anon_sym_DOLLAR] = ACTIONS(1557),
    [anon_sym_PIPE] = ACTIONS(1557),
    [anon_sym_PLUS_PLUS] = ACTIONS(1557),
    [anon_sym_DASH_DASH] = ACTIONS(1557),
    [anon_sym_BANG] = ACTIONS(1557),
    [anon_sym_TILDE] = ACTIONS(1557),
    [anon_sym_DASH] = ACTIONS(1559),
    [anon_sym_PLUS] = ACTIONS(1559),
    [anon_sym_copy] = ACTIONS(1559),
    [anon_sym_schedule] = ACTIONS(1559),
    [anon_sym_T] = ACTIONS(1559),
    [anon_sym_F] = ACTIONS(1559),
    [anon_sym_ATdeprecated] = ACTIONS(1557),
    [anon_sym_ATload] = ACTIONS(1559),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1557),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1557),
    [anon_sym_ATunload] = ACTIONS(1557),
    [anon_sym_ATprefixes] = ACTIONS(1557),
    [anon_sym_ATif] = ACTIONS(1559),
    [anon_sym_ATifdef] = ACTIONS(1557),
    [anon_sym_ATifndef] = ACTIONS(1557),
    [anon_sym_ATendif] = ACTIONS(1557),
    [anon_sym_ATelse] = ACTIONS(1557),
    [anon_sym_ATpragma] = ACTIONS(1557),
    [anon_sym_ATDIR] = ACTIONS(1557),
    [anon_sym_ATFILENAME] = ACTIONS(1557),
    [sym_id] = ACTIONS(1559),
    [sym_pattern] = ACTIONS(1557),
    [sym_ipv4] = ACTIONS(1559),
    [sym_ipv6] = ACTIONS(1557),
    [sym_port] = ACTIONS(1557),
    [sym_integer] = ACTIONS(1559),
    [sym_floatp] = ACTIONS(1559),
    [sym_hex] = ACTIONS(1559),
    [sym_hostname] = ACTIONS(1559),
    [aux_sym_string_token1] = ACTIONS(1557),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(306)] = {
    [ts_builtin_sym_end] = ACTIONS(1561),
    [anon_sym_module] = ACTIONS(1563),
    [anon_sym_SEMI] = ACTIONS(1561),
    [anon_sym_export] = ACTIONS(1563),
    [anon_sym_LBRACE] = ACTIONS(1561),
    [anon_sym_global] = ACTIONS(1563),
    [anon_sym_option] = ACTIONS(1563),
    [anon_sym_const] = ACTIONS(1563),
    [anon_sym_redef] = ACTIONS(1563),
    [anon_sym_enum] = ACTIONS(1563),
    [anon_sym_record] = ACTIONS(1563),
    [anon_sym_type] = ACTIONS(1563),
    [anon_sym_print] = ACTIONS(1563),
    [anon_sym_event] = ACTIONS(1563),
    [anon_sym_if] = ACTIONS(1563),
    [anon_sym_LPAREN] = ACTIONS(1561),
    [anon_sym_switch] = ACTIONS(1563),
    [anon_sym_for] = ACTIONS(1563),
    [anon_sym_LBRACK] = ACTIONS(1563),
    [anon_sym_while] = ACTIONS(1563),
    [anon_sym_next] = ACTIONS(1563),
    [anon_sym_break] = ACTIONS(1563),
    [anon_sym_fallthrough] = ACTIONS(1563),
    [anon_sym_return] = ACTIONS(1563),
    [anon_sym_add] = ACTIONS(1563),
    [anon_sym_delete] = ACTIONS(1563),
    [anon_sym_local] = ACTIONS(1563),
    [anon_sym_when] = ACTIONS(1563),
    [anon_sym_assert] = ACTIONS(1563),
    [anon_sym_function] = ACTIONS(1563),
    [anon_sym_hook] = ACTIONS(1563),
    [anon_sym_addr] = ACTIONS(1563),
    [anon_sym_any] = ACTIONS(1563),
    [anon_sym_bool] = ACTIONS(1563),
    [anon_sym_count] = ACTIONS(1563),
    [anon_sym_double] = ACTIONS(1563),
    [anon_sym_file] = ACTIONS(1563),
    [anon_sym_int] = ACTIONS(1563),
    [anon_sym_interval] = ACTIONS(1563),
    [anon_sym_list] = ACTIONS(1563),
    [anon_sym_pattern] = ACTIONS(1563),
    [anon_sym_port] = ACTIONS(1563),
    [anon_sym_string] = ACTIONS(1563),
    [anon_sym_subnet] = ACTIONS(1563),
    [anon_sym_time] = ACTIONS(1563),
    [anon_sym_opaque] = ACTIONS(1563),
    [anon_sym_set] = ACTIONS(1563),
    [anon_sym_table] = ACTIONS(1563),
    [anon_sym_union] = ACTIONS(1563),
    [anon_sym_vector] = ACTIONS(1563),
    [anon_sym_DOLLAR] = ACTIONS(1561),
    [anon_sym_PIPE] = ACTIONS(1561),
    [anon_sym_PLUS_PLUS] = ACTIONS(1561),
    [anon_sym_DASH_DASH] = ACTIONS(1561),
    [anon_sym_BANG] = ACTIONS(1561),
    [anon_sym_TILDE] = ACTIONS(1561),
    [anon_sym_DASH] = ACTIONS(1563),
    [anon_sym_PLUS] = ACTIONS(1563),
    [anon_sym_copy] = ACTIONS(1563),
    [anon_sym_schedule] = ACTIONS(1563),
    [anon_sym_T] = ACTIONS(1563),
    [anon_sym_F] = ACTIONS(1563),
    [anon_sym_ATdeprecated] = ACTIONS(1561),
    [anon_sym_ATload] = ACTIONS(1563),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1561),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1561),
    [anon_sym_ATunload] = ACTIONS(1561),
    [anon_sym_ATprefixes] = ACTIONS(1561),
    [anon_sym_ATif] = ACTIONS(1563),
    [anon_sym_ATifdef] = ACTIONS(1561),
    [anon_sym_ATifndef] = ACTIONS(1561),
    [anon_sym_ATendif] = ACTIONS(1561),
    [anon_sym_ATelse] = ACTIONS(1561),
    [anon_sym_ATpragma] = ACTIONS(1561),
    [anon_sym_ATDIR] = ACTIONS(1561),
    [anon_sym_ATFILENAME] = ACTIONS(1561),
    [sym_id] = ACTIONS(1563),
    [sym_pattern] = ACTIONS(1561),
    [sym_ipv4] = ACTIONS(1563),
    [sym_ipv6] = ACTIONS(1561),
    [sym_port] = ACTIONS(1561),
    [sym_integer] = ACTIONS(1563),
    [sym_floatp] = ACTIONS(1563),
    [sym_hex] = ACTIONS(1563),
    [sym_hostname] = ACTIONS(1563),
    [aux_sym_string_token1] = ACTIONS(1561),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(307)] = {
    [ts_builtin_sym_end] = ACTIONS(1565),
    [anon_sym_module] = ACTIONS(1567),
    [anon_sym_SEMI] = ACTIONS(1565),
    [anon_sym_export] = ACTIONS(1567),
    [anon_sym_LBRACE] = ACTIONS(1565),
    [anon_sym_global] = ACTIONS(1567),
    [anon_sym_option] = ACTIONS(1567),
    [anon_sym_const] = ACTIONS(1567),
    [anon_sym_redef] = ACTIONS(1567),
    [anon_sym_enum] = ACTIONS(1567),
    [anon_sym_record] = ACTIONS(1567),
    [anon_sym_type] = ACTIONS(1567),
    [anon_sym_print] = ACTIONS(1567),
    [anon_sym_event] = ACTIONS(1567),
    [anon_sym_if] = ACTIONS(1567),
    [anon_sym_LPAREN] = ACTIONS(1565),
    [anon_sym_switch] = ACTIONS(1567),
    [anon_sym_for] = ACTIONS(1567),
    [anon_sym_LBRACK] = ACTIONS(1567),
    [anon_sym_while] = ACTIONS(1567),
    [anon_sym_next] = ACTIONS(1567),
    [anon_sym_break] = ACTIONS(1567),
    [anon_sym_fallthrough] = ACTIONS(1567),
    [anon_sym_return] = ACTIONS(1567),
    [anon_sym_add] = ACTIONS(1567),
    [anon_sym_delete] = ACTIONS(1567),
    [anon_sym_local] = ACTIONS(1567),
    [anon_sym_when] = ACTIONS(1567),
    [anon_sym_assert] = ACTIONS(1567),
    [anon_sym_function] = ACTIONS(1567),
    [anon_sym_hook] = ACTIONS(1567),
    [anon_sym_addr] = ACTIONS(1567),
    [anon_sym_any] = ACTIONS(1567),
    [anon_sym_bool] = ACTIONS(1567),
    [anon_sym_count] = ACTIONS(1567),
    [anon_sym_double] = ACTIONS(1567),
    [anon_sym_file] = ACTIONS(1567),
    [anon_sym_int] = ACTIONS(1567),
    [anon_sym_interval] = ACTIONS(1567),
    [anon_sym_list] = ACTIONS(1567),
    [anon_sym_pattern] = ACTIONS(1567),
    [anon_sym_port] = ACTIONS(1567),
    [anon_sym_string] = ACTIONS(1567),
    [anon_sym_subnet] = ACTIONS(1567),
    [anon_sym_time] = ACTIONS(1567),
    [anon_sym_opaque] = ACTIONS(1567),
    [anon_sym_set] = ACTIONS(1567),
    [anon_sym_table] = ACTIONS(1567),
    [anon_sym_union] = ACTIONS(1567),
    [anon_sym_vector] = ACTIONS(1567),
    [anon_sym_DOLLAR] = ACTIONS(1565),
    [anon_sym_PIPE] = ACTIONS(1565),
    [anon_sym_PLUS_PLUS] = ACTIONS(1565),
    [anon_sym_DASH_DASH] = ACTIONS(1565),
    [anon_sym_BANG] = ACTIONS(1565),
    [anon_sym_TILDE] = ACTIONS(1565),
    [anon_sym_DASH] = ACTIONS(1567),
    [anon_sym_PLUS] = ACTIONS(1567),
    [anon_sym_copy] = ACTIONS(1567),
    [anon_sym_schedule] = ACTIONS(1567),
    [anon_sym_T] = ACTIONS(1567),
    [anon_sym_F] = ACTIONS(1567),
    [anon_sym_ATdeprecated] = ACTIONS(1565),
    [anon_sym_ATload] = ACTIONS(1567),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1565),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1565),
    [anon_sym_ATunload] = ACTIONS(1565),
    [anon_sym_ATprefixes] = ACTIONS(1565),
    [anon_sym_ATif] = ACTIONS(1567),
    [anon_sym_ATifdef] = ACTIONS(1565),
    [anon_sym_ATifndef] = ACTIONS(1565),
    [anon_sym_ATendif] = ACTIONS(1565),
    [anon_sym_ATelse] = ACTIONS(1565),
    [anon_sym_ATpragma] = ACTIONS(1565),
    [anon_sym_ATDIR] = ACTIONS(1565),
    [anon_sym_ATFILENAME] = ACTIONS(1565),
    [sym_id] = ACTIONS(1567),
    [sym_pattern] = ACTIONS(1565),
    [sym_ipv4] = ACTIONS(1567),
    [sym_ipv6] = ACTIONS(1565),
    [sym_port] = ACTIONS(1565),
    [sym_integer] = ACTIONS(1567),
    [sym_floatp] = ACTIONS(1567),
    [sym_hex] = ACTIONS(1567),
    [sym_hostname] = ACTIONS(1567),
    [aux_sym_string_token1] = ACTIONS(1565),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(308)] = {
    [ts_builtin_sym_end] = ACTIONS(1569),
    [anon_sym_module] = ACTIONS(1571),
    [anon_sym_SEMI] = ACTIONS(1569),
    [anon_sym_export] = ACTIONS(1571),
    [anon_sym_LBRACE] = ACTIONS(1569),
    [anon_sym_global] = ACTIONS(1571),
    [anon_sym_option] = ACTIONS(1571),
    [anon_sym_const] = ACTIONS(1571),
    [anon_sym_redef] = ACTIONS(1571),
    [anon_sym_enum] = ACTIONS(1571),
    [anon_sym_record] = ACTIONS(1571),
    [anon_sym_type] = ACTIONS(1571),
    [anon_sym_print] = ACTIONS(1571),
    [anon_sym_event] = ACTIONS(1571),
    [anon_sym_if] = ACTIONS(1571),
    [anon_sym_LPAREN] = ACTIONS(1569),
    [anon_sym_switch] = ACTIONS(1571),
    [anon_sym_for] = ACTIONS(1571),
    [anon_sym_LBRACK] = ACTIONS(1571),
    [anon_sym_while] = ACTIONS(1571),
    [anon_sym_next] = ACTIONS(1571),
    [anon_sym_break] = ACTIONS(1571),
    [anon_sym_fallthrough] = ACTIONS(1571),
    [anon_sym_return] = ACTIONS(1571),
    [anon_sym_add] = ACTIONS(1571),
    [anon_sym_delete] = ACTIONS(1571),
    [anon_sym_local] = ACTIONS(1571),
    [anon_sym_when] = ACTIONS(1571),
    [anon_sym_assert] = ACTIONS(1571),
    [anon_sym_function] = ACTIONS(1571),
    [anon_sym_hook] = ACTIONS(1571),
    [anon_sym_addr] = ACTIONS(1571),
    [anon_sym_any] = ACTIONS(1571),
    [anon_sym_bool] = ACTIONS(1571),
    [anon_sym_count] = ACTIONS(1571),
    [anon_sym_double] = ACTIONS(1571),
    [anon_sym_file] = ACTIONS(1571),
    [anon_sym_int] = ACTIONS(1571),
    [anon_sym_interval] = ACTIONS(1571),
    [anon_sym_list] = ACTIONS(1571),
    [anon_sym_pattern] = ACTIONS(1571),
    [anon_sym_port] = ACTIONS(1571),
    [anon_sym_string] = ACTIONS(1571),
    [anon_sym_subnet] = ACTIONS(1571),
    [anon_sym_time] = ACTIONS(1571),
    [anon_sym_opaque] = ACTIONS(1571),
    [anon_sym_set] = ACTIONS(1571),
    [anon_sym_table] = ACTIONS(1571),
    [anon_sym_union] = ACTIONS(1571),
    [anon_sym_vector] = ACTIONS(1571),
    [anon_sym_DOLLAR] = ACTIONS(1569),
    [anon_sym_PIPE] = ACTIONS(1569),
    [anon_sym_PLUS_PLUS] = ACTIONS(1569),
    [anon_sym_DASH_DASH] = ACTIONS(1569),
    [anon_sym_BANG] = ACTIONS(1569),
    [anon_sym_TILDE] = ACTIONS(1569),
    [anon_sym_DASH] = ACTIONS(1571),
    [anon_sym_PLUS] = ACTIONS(1571),
    [anon_sym_copy] = ACTIONS(1571),
    [anon_sym_schedule] = ACTIONS(1571),
    [anon_sym_T] = ACTIONS(1571),
    [anon_sym_F] = ACTIONS(1571),
    [anon_sym_ATdeprecated] = ACTIONS(1569),
    [anon_sym_ATload] = ACTIONS(1571),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1569),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1569),
    [anon_sym_ATunload] = ACTIONS(1569),
    [anon_sym_ATprefixes] = ACTIONS(1569),
    [anon_sym_ATif] = ACTIONS(1571),
    [anon_sym_ATifdef] = ACTIONS(1569),
    [anon_sym_ATifndef] = ACTIONS(1569),
    [anon_sym_ATendif] = ACTIONS(1569),
    [anon_sym_ATelse] = ACTIONS(1569),
    [anon_sym_ATpragma] = ACTIONS(1569),
    [anon_sym_ATDIR] = ACTIONS(1569),
    [anon_sym_ATFILENAME] = ACTIONS(1569),
    [sym_id] = ACTIONS(1571),
    [sym_pattern] = ACTIONS(1569),
    [sym_ipv4] = ACTIONS(1571),
    [sym_ipv6] = ACTIONS(1569),
    [sym_port] = ACTIONS(1569),
    [sym_integer] = ACTIONS(1571),
    [sym_floatp] = ACTIONS(1571),
    [sym_hex] = ACTIONS(1571),
    [sym_hostname] = ACTIONS(1571),
    [aux_sym_string_token1] = ACTIONS(1569),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(309)] = {
    [ts_builtin_sym_end] = ACTIONS(1573),
    [anon_sym_module] = ACTIONS(1575),
    [anon_sym_SEMI] = ACTIONS(1573),
    [anon_sym_export] = ACTIONS(1575),
    [anon_sym_LBRACE] = ACTIONS(1573),
    [anon_sym_global] = ACTIONS(1575),
    [anon_sym_option] = ACTIONS(1575),
    [anon_sym_const] = ACTIONS(1575),
    [anon_sym_redef] = ACTIONS(1575),
    [anon_sym_enum] = ACTIONS(1575),
    [anon_sym_record] = ACTIONS(1575),
    [anon_sym_type] = ACTIONS(1575),
    [anon_sym_print] = ACTIONS(1575),
    [anon_sym_event] = ACTIONS(1575),
    [anon_sym_if] = ACTIONS(1575),
    [anon_sym_LPAREN] = ACTIONS(1573),
    [anon_sym_switch] = ACTIONS(1575),
    [anon_sym_for] = ACTIONS(1575),
    [anon_sym_LBRACK] = ACTIONS(1575),
    [anon_sym_while] = ACTIONS(1575),
    [anon_sym_next] = ACTIONS(1575),
    [anon_sym_break] = ACTIONS(1575),
    [anon_sym_fallthrough] = ACTIONS(1575),
    [anon_sym_return] = ACTIONS(1575),
    [anon_sym_add] = ACTIONS(1575),
    [anon_sym_delete] = ACTIONS(1575),
    [anon_sym_local] = ACTIONS(1575),
    [anon_sym_when] = ACTIONS(1575),
    [anon_sym_assert] = ACTIONS(1575),
    [anon_sym_function] = ACTIONS(1575),
    [anon_sym_hook] = ACTIONS(1575),
    [anon_sym_addr] = ACTIONS(1575),
    [anon_sym_any] = ACTIONS(1575),
    [anon_sym_bool] = ACTIONS(1575),
    [anon_sym_count] = ACTIONS(1575),
    [anon_sym_double] = ACTIONS(1575),
    [anon_sym_file] = ACTIONS(1575),
    [anon_sym_int] = ACTIONS(1575),
    [anon_sym_interval] = ACTIONS(1575),
    [anon_sym_list] = ACTIONS(1575),
    [anon_sym_pattern] = ACTIONS(1575),
    [anon_sym_port] = ACTIONS(1575),
    [anon_sym_string] = ACTIONS(1575),
    [anon_sym_subnet] = ACTIONS(1575),
    [anon_sym_time] = ACTIONS(1575),
    [anon_sym_opaque] = ACTIONS(1575),
    [anon_sym_set] = ACTIONS(1575),
    [anon_sym_table] = ACTIONS(1575),
    [anon_sym_union] = ACTIONS(1575),
    [anon_sym_vector] = ACTIONS(1575),
    [anon_sym_DOLLAR] = ACTIONS(1573),
    [anon_sym_PIPE] = ACTIONS(1573),
    [anon_sym_PLUS_PLUS] = ACTIONS(1573),
    [anon_sym_DASH_DASH] = ACTIONS(1573),
    [anon_sym_BANG] = ACTIONS(1573),
    [anon_sym_TILDE] = ACTIONS(1573),
    [anon_sym_DASH] = ACTIONS(1575),
    [anon_sym_PLUS] = ACTIONS(1575),
    [anon_sym_copy] = ACTIONS(1575),
    [anon_sym_schedule] = ACTIONS(1575),
    [anon_sym_T] = ACTIONS(1575),
    [anon_sym_F] = ACTIONS(1575),
    [anon_sym_ATdeprecated] = ACTIONS(1573),
    [anon_sym_ATload] = ACTIONS(1575),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1573),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1573),
    [anon_sym_ATunload] = ACTIONS(1573),
    [anon_sym_ATprefixes] = ACTIONS(1573),
    [anon_sym_ATif] = ACTIONS(1575),
    [anon_sym_ATifdef] = ACTIONS(1573),
    [anon_sym_ATifndef] = ACTIONS(1573),
    [anon_sym_ATendif] = ACTIONS(1573),
    [anon_sym_ATelse] = ACTIONS(1573),
    [anon_sym_ATpragma] = ACTIONS(1573),
    [anon_sym_ATDIR] = ACTIONS(1573),
    [anon_sym_ATFILENAME] = ACTIONS(1573),
    [sym_id] = ACTIONS(1575),
    [sym_pattern] = ACTIONS(1573),
    [sym_ipv4] = ACTIONS(1575),
    [sym_ipv6] = ACTIONS(1573),
    [sym_port] = ACTIONS(1573),
    [sym_integer] = ACTIONS(1575),
    [sym_floatp] = ACTIONS(1575),
    [sym_hex] = ACTIONS(1575),
    [sym_hostname] = ACTIONS(1575),
    [aux_sym_string_token1] = ACTIONS(1573),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(310)] = {
    [ts_builtin_sym_end] = ACTIONS(1577),
    [anon_sym_module] = ACTIONS(1579),
    [anon_sym_SEMI] = ACTIONS(1577),
    [anon_sym_export] = ACTIONS(1579),
    [anon_sym_LBRACE] = ACTIONS(1577),
    [anon_sym_global] = ACTIONS(1579),
    [anon_sym_option] = ACTIONS(1579),
    [anon_sym_const] = ACTIONS(1579),
    [anon_sym_redef] = ACTIONS(1579),
    [anon_sym_enum] = ACTIONS(1579),
    [anon_sym_record] = ACTIONS(1579),
    [anon_sym_type] = ACTIONS(1579),
    [anon_sym_print] = ACTIONS(1579),
    [anon_sym_event] = ACTIONS(1579),
    [anon_sym_if] = ACTIONS(1579),
    [anon_sym_LPAREN] = ACTIONS(1577),
    [anon_sym_switch] = ACTIONS(1579),
    [anon_sym_for] = ACTIONS(1579),
    [anon_sym_LBRACK] = ACTIONS(1579),
    [anon_sym_while] = ACTIONS(1579),
    [anon_sym_next] = ACTIONS(1579),
    [anon_sym_break] = ACTIONS(1579),
    [anon_sym_fallthrough] = ACTIONS(1579),
    [anon_sym_return] = ACTIONS(1579),
    [anon_sym_add] = ACTIONS(1579),
    [anon_sym_delete] = ACTIONS(1579),
    [anon_sym_local] = ACTIONS(1579),
    [anon_sym_when] = ACTIONS(1579),
    [anon_sym_assert] = ACTIONS(1579),
    [anon_sym_function] = ACTIONS(1579),
    [anon_sym_hook] = ACTIONS(1579),
    [anon_sym_addr] = ACTIONS(1579),
    [anon_sym_any] = ACTIONS(1579),
    [anon_sym_bool] = ACTIONS(1579),
    [anon_sym_count] = ACTIONS(1579),
    [anon_sym_double] = ACTIONS(1579),
    [anon_sym_file] = ACTIONS(1579),
    [anon_sym_int] = ACTIONS(1579),
    [anon_sym_interval] = ACTIONS(1579),
    [anon_sym_list] = ACTIONS(1579),
    [anon_sym_pattern] = ACTIONS(1579),
    [anon_sym_port] = ACTIONS(1579),
    [anon_sym_string] = ACTIONS(1579),
    [anon_sym_subnet] = ACTIONS(1579),
    [anon_sym_time] = ACTIONS(1579),
    [anon_sym_opaque] = ACTIONS(1579),
    [anon_sym_set] = ACTIONS(1579),
    [anon_sym_table] = ACTIONS(1579),
    [anon_sym_union] = ACTIONS(1579),
    [anon_sym_vector] = ACTIONS(1579),
    [anon_sym_DOLLAR] = ACTIONS(1577),
    [anon_sym_PIPE] = ACTIONS(1577),
    [anon_sym_PLUS_PLUS] = ACTIONS(1577),
    [anon_sym_DASH_DASH] = ACTIONS(1577),
    [anon_sym_BANG] = ACTIONS(1577),
    [anon_sym_TILDE] = ACTIONS(1577),
    [anon_sym_DASH] = ACTIONS(1579),
    [anon_sym_PLUS] = ACTIONS(1579),
    [anon_sym_copy] = ACTIONS(1579),
    [anon_sym_schedule] = ACTIONS(1579),
    [anon_sym_T] = ACTIONS(1579),
    [anon_sym_F] = ACTIONS(1579),
    [anon_sym_ATdeprecated] = ACTIONS(1577),
    [anon_sym_ATload] = ACTIONS(1579),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1577),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1577),
    [anon_sym_ATunload] = ACTIONS(1577),
    [anon_sym_ATprefixes] = ACTIONS(1577),
    [anon_sym_ATif] = ACTIONS(1579),
    [anon_sym_ATifdef] = ACTIONS(1577),
    [anon_sym_ATifndef] = ACTIONS(1577),
    [anon_sym_ATendif] = ACTIONS(1577),
    [anon_sym_ATelse] = ACTIONS(1577),
    [anon_sym_ATpragma] = ACTIONS(1577),
    [anon_sym_ATDIR] = ACTIONS(1577),
    [anon_sym_ATFILENAME] = ACTIONS(1577),
    [sym_id] = ACTIONS(1579),
    [sym_pattern] = ACTIONS(1577),
    [sym_ipv4] = ACTIONS(1579),
    [sym_ipv6] = ACTIONS(1577),
    [sym_port] = ACTIONS(1577),
    [sym_integer] = ACTIONS(1579),
    [sym_floatp] = ACTIONS(1579),
    [sym_hex] = ACTIONS(1579),
    [sym_hostname] = ACTIONS(1579),
    [aux_sym_string_token1] = ACTIONS(1577),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(311)] = {
    [ts_builtin_sym_end] = ACTIONS(1581),
    [anon_sym_module] = ACTIONS(1583),
    [anon_sym_SEMI] = ACTIONS(1581),
    [anon_sym_export] = ACTIONS(1583),
    [anon_sym_LBRACE] = ACTIONS(1581),
    [anon_sym_global] = ACTIONS(1583),
    [anon_sym_option] = ACTIONS(1583),
    [anon_sym_const] = ACTIONS(1583),
    [anon_sym_redef] = ACTIONS(1583),
    [anon_sym_enum] = ACTIONS(1583),
    [anon_sym_record] = ACTIONS(1583),
    [anon_sym_type] = ACTIONS(1583),
    [anon_sym_print] = ACTIONS(1583),
    [anon_sym_event] = ACTIONS(1583),
    [anon_sym_if] = ACTIONS(1583),
    [anon_sym_LPAREN] = ACTIONS(1581),
    [anon_sym_switch] = ACTIONS(1583),
    [anon_sym_for] = ACTIONS(1583),
    [anon_sym_LBRACK] = ACTIONS(1583),
    [anon_sym_while] = ACTIONS(1583),
    [anon_sym_next] = ACTIONS(1583),
    [anon_sym_break] = ACTIONS(1583),
    [anon_sym_fallthrough] = ACTIONS(1583),
    [anon_sym_return] = ACTIONS(1583),
    [anon_sym_add] = ACTIONS(1583),
    [anon_sym_delete] = ACTIONS(1583),
    [anon_sym_local] = ACTIONS(1583),
    [anon_sym_when] = ACTIONS(1583),
    [anon_sym_assert] = ACTIONS(1583),
    [anon_sym_function] = ACTIONS(1583),
    [anon_sym_hook] = ACTIONS(1583),
    [anon_sym_addr] = ACTIONS(1583),
    [anon_sym_any] = ACTIONS(1583),
    [anon_sym_bool] = ACTIONS(1583),
    [anon_sym_count] = ACTIONS(1583),
    [anon_sym_double] = ACTIONS(1583),
    [anon_sym_file] = ACTIONS(1583),
    [anon_sym_int] = ACTIONS(1583),
    [anon_sym_interval] = ACTIONS(1583),
    [anon_sym_list] = ACTIONS(1583),
    [anon_sym_pattern] = ACTIONS(1583),
    [anon_sym_port] = ACTIONS(1583),
    [anon_sym_string] = ACTIONS(1583),
    [anon_sym_subnet] = ACTIONS(1583),
    [anon_sym_time] = ACTIONS(1583),
    [anon_sym_opaque] = ACTIONS(1583),
    [anon_sym_set] = ACTIONS(1583),
    [anon_sym_table] = ACTIONS(1583),
    [anon_sym_union] = ACTIONS(1583),
    [anon_sym_vector] = ACTIONS(1583),
    [anon_sym_DOLLAR] = ACTIONS(1581),
    [anon_sym_PIPE] = ACTIONS(1581),
    [anon_sym_PLUS_PLUS] = ACTIONS(1581),
    [anon_sym_DASH_DASH] = ACTIONS(1581),
    [anon_sym_BANG] = ACTIONS(1581),
    [anon_sym_TILDE] = ACTIONS(1581),
    [anon_sym_DASH] = ACTIONS(1583),
    [anon_sym_PLUS] = ACTIONS(1583),
    [anon_sym_copy] = ACTIONS(1583),
    [anon_sym_schedule] = ACTIONS(1583),
    [anon_sym_T] = ACTIONS(1583),
    [anon_sym_F] = ACTIONS(1583),
    [anon_sym_ATdeprecated] = ACTIONS(1581),
    [anon_sym_ATload] = ACTIONS(1583),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1581),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1581),
    [anon_sym_ATunload] = ACTIONS(1581),
    [anon_sym_ATprefixes] = ACTIONS(1581),
    [anon_sym_ATif] = ACTIONS(1583),
    [anon_sym_ATifdef] = ACTIONS(1581),
    [anon_sym_ATifndef] = ACTIONS(1581),
    [anon_sym_ATendif] = ACTIONS(1581),
    [anon_sym_ATelse] = ACTIONS(1581),
    [anon_sym_ATpragma] = ACTIONS(1581),
    [anon_sym_ATDIR] = ACTIONS(1581),
    [anon_sym_ATFILENAME] = ACTIONS(1581),
    [sym_id] = ACTIONS(1583),
    [sym_pattern] = ACTIONS(1581),
    [sym_ipv4] = ACTIONS(1583),
    [sym_ipv6] = ACTIONS(1581),
    [sym_port] = ACTIONS(1581),
    [sym_integer] = ACTIONS(1583),
    [sym_floatp] = ACTIONS(1583),
    [sym_hex] = ACTIONS(1583),
    [sym_hostname] = ACTIONS(1583),
    [aux_sym_string_token1] = ACTIONS(1581),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(312)] = {
    [ts_builtin_sym_end] = ACTIONS(1585),
    [anon_sym_module] = ACTIONS(1587),
    [anon_sym_SEMI] = ACTIONS(1585),
    [anon_sym_export] = ACTIONS(1587),
    [anon_sym_LBRACE] = ACTIONS(1585),
    [anon_sym_global] = ACTIONS(1587),
    [anon_sym_option] = ACTIONS(1587),
    [anon_sym_const] = ACTIONS(1587),
    [anon_sym_redef] = ACTIONS(1587),
    [anon_sym_enum] = ACTIONS(1587),
    [anon_sym_record] = ACTIONS(1587),
    [anon_sym_type] = ACTIONS(1587),
    [anon_sym_print] = ACTIONS(1587),
    [anon_sym_event] = ACTIONS(1587),
    [anon_sym_if] = ACTIONS(1587),
    [anon_sym_LPAREN] = ACTIONS(1585),
    [anon_sym_switch] = ACTIONS(1587),
    [anon_sym_for] = ACTIONS(1587),
    [anon_sym_LBRACK] = ACTIONS(1587),
    [anon_sym_while] = ACTIONS(1587),
    [anon_sym_next] = ACTIONS(1587),
    [anon_sym_break] = ACTIONS(1587),
    [anon_sym_fallthrough] = ACTIONS(1587),
    [anon_sym_return] = ACTIONS(1587),
    [anon_sym_add] = ACTIONS(1587),
    [anon_sym_delete] = ACTIONS(1587),
    [anon_sym_local] = ACTIONS(1587),
    [anon_sym_when] = ACTIONS(1587),
    [anon_sym_assert] = ACTIONS(1587),
    [anon_sym_function] = ACTIONS(1587),
    [anon_sym_hook] = ACTIONS(1587),
    [anon_sym_addr] = ACTIONS(1587),
    [anon_sym_any] = ACTIONS(1587),
    [anon_sym_bool] = ACTIONS(1587),
    [anon_sym_count] = ACTIONS(1587),
    [anon_sym_double] = ACTIONS(1587),
    [anon_sym_file] = ACTIONS(1587),
    [anon_sym_int] = ACTIONS(1587),
    [anon_sym_interval] = ACTIONS(1587),
    [anon_sym_list] = ACTIONS(1587),
    [anon_sym_pattern] = ACTIONS(1587),
    [anon_sym_port] = ACTIONS(1587),
    [anon_sym_string] = ACTIONS(1587),
    [anon_sym_subnet] = ACTIONS(1587),
    [anon_sym_time] = ACTIONS(1587),
    [anon_sym_opaque] = ACTIONS(1587),
    [anon_sym_set] = ACTIONS(1587),
    [anon_sym_table] = ACTIONS(1587),
    [anon_sym_union] = ACTIONS(1587),
    [anon_sym_vector] = ACTIONS(1587),
    [anon_sym_DOLLAR] = ACTIONS(1585),
    [anon_sym_PIPE] = ACTIONS(1585),
    [anon_sym_PLUS_PLUS] = ACTIONS(1585),
    [anon_sym_DASH_DASH] = ACTIONS(1585),
    [anon_sym_BANG] = ACTIONS(1585),
    [anon_sym_TILDE] = ACTIONS(1585),
    [anon_sym_DASH] = ACTIONS(1587),
    [anon_sym_PLUS] = ACTIONS(1587),
    [anon_sym_copy] = ACTIONS(1587),
    [anon_sym_schedule] = ACTIONS(1587),
    [anon_sym_T] = ACTIONS(1587),
    [anon_sym_F] = ACTIONS(1587),
    [anon_sym_ATdeprecated] = ACTIONS(1585),
    [anon_sym_ATload] = ACTIONS(1587),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1585),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1585),
    [anon_sym_ATunload] = ACTIONS(1585),
    [anon_sym_ATprefixes] = ACTIONS(1585),
    [anon_sym_ATif] = ACTIONS(1587),
    [anon_sym_ATifdef] = ACTIONS(1585),
    [anon_sym_ATifndef] = ACTIONS(1585),
    [anon_sym_ATendif] = ACTIONS(1585),
    [anon_sym_ATelse] = ACTIONS(1585),
    [anon_sym_ATpragma] = ACTIONS(1585),
    [anon_sym_ATDIR] = ACTIONS(1585),
    [anon_sym_ATFILENAME] = ACTIONS(1585),
    [sym_id] = ACTIONS(1587),
    [sym_pattern] = ACTIONS(1585),
    [sym_ipv4] = ACTIONS(1587),
    [sym_ipv6] = ACTIONS(1585),
    [sym_port] = ACTIONS(1585),
    [sym_integer] = ACTIONS(1587),
    [sym_floatp] = ACTIONS(1587),
    [sym_hex] = ACTIONS(1587),
    [sym_hostname] = ACTIONS(1587),
    [aux_sym_string_token1] = ACTIONS(1585),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(313)] = {
    [ts_builtin_sym_end] = ACTIONS(1589),
    [anon_sym_module] = ACTIONS(1591),
    [anon_sym_SEMI] = ACTIONS(1589),
    [anon_sym_export] = ACTIONS(1591),
    [anon_sym_LBRACE] = ACTIONS(1589),
    [anon_sym_global] = ACTIONS(1591),
    [anon_sym_option] = ACTIONS(1591),
    [anon_sym_const] = ACTIONS(1591),
    [anon_sym_redef] = ACTIONS(1591),
    [anon_sym_enum] = ACTIONS(1591),
    [anon_sym_record] = ACTIONS(1591),
    [anon_sym_type] = ACTIONS(1591),
    [anon_sym_print] = ACTIONS(1591),
    [anon_sym_event] = ACTIONS(1591),
    [anon_sym_if] = ACTIONS(1591),
    [anon_sym_LPAREN] = ACTIONS(1589),
    [anon_sym_switch] = ACTIONS(1591),
    [anon_sym_for] = ACTIONS(1591),
    [anon_sym_LBRACK] = ACTIONS(1591),
    [anon_sym_while] = ACTIONS(1591),
    [anon_sym_next] = ACTIONS(1591),
    [anon_sym_break] = ACTIONS(1591),
    [anon_sym_fallthrough] = ACTIONS(1591),
    [anon_sym_return] = ACTIONS(1591),
    [anon_sym_add] = ACTIONS(1591),
    [anon_sym_delete] = ACTIONS(1591),
    [anon_sym_local] = ACTIONS(1591),
    [anon_sym_when] = ACTIONS(1591),
    [anon_sym_assert] = ACTIONS(1591),
    [anon_sym_function] = ACTIONS(1591),
    [anon_sym_hook] = ACTIONS(1591),
    [anon_sym_addr] = ACTIONS(1591),
    [anon_sym_any] = ACTIONS(1591),
    [anon_sym_bool] = ACTIONS(1591),
    [anon_sym_count] = ACTIONS(1591),
    [anon_sym_double] = ACTIONS(1591),
    [anon_sym_file] = ACTIONS(1591),
    [anon_sym_int] = ACTIONS(1591),
    [anon_sym_interval] = ACTIONS(1591),
    [anon_sym_list] = ACTIONS(1591),
    [anon_sym_pattern] = ACTIONS(1591),
    [anon_sym_port] = ACTIONS(1591),
    [anon_sym_string] = ACTIONS(1591),
    [anon_sym_subnet] = ACTIONS(1591),
    [anon_sym_time] = ACTIONS(1591),
    [anon_sym_opaque] = ACTIONS(1591),
    [anon_sym_set] = ACTIONS(1591),
    [anon_sym_table] = ACTIONS(1591),
    [anon_sym_union] = ACTIONS(1591),
    [anon_sym_vector] = ACTIONS(1591),
    [anon_sym_DOLLAR] = ACTIONS(1589),
    [anon_sym_PIPE] = ACTIONS(1589),
    [anon_sym_PLUS_PLUS] = ACTIONS(1589),
    [anon_sym_DASH_DASH] = ACTIONS(1589),
    [anon_sym_BANG] = ACTIONS(1589),
    [anon_sym_TILDE] = ACTIONS(1589),
    [anon_sym_DASH] = ACTIONS(1591),
    [anon_sym_PLUS] = ACTIONS(1591),
    [anon_sym_copy] = ACTIONS(1591),
    [anon_sym_schedule] = ACTIONS(1591),
    [anon_sym_T] = ACTIONS(1591),
    [anon_sym_F] = ACTIONS(1591),
    [anon_sym_ATdeprecated] = ACTIONS(1589),
    [anon_sym_ATload] = ACTIONS(1591),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1589),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1589),
    [anon_sym_ATunload] = ACTIONS(1589),
    [anon_sym_ATprefixes] = ACTIONS(1589),
    [anon_sym_ATif] = ACTIONS(1591),
    [anon_sym_ATifdef] = ACTIONS(1589),
    [anon_sym_ATifndef] = ACTIONS(1589),
    [anon_sym_ATendif] = ACTIONS(1589),
    [anon_sym_ATelse] = ACTIONS(1589),
    [anon_sym_ATpragma] = ACTIONS(1589),
    [anon_sym_ATDIR] = ACTIONS(1589),
    [anon_sym_ATFILENAME] = ACTIONS(1589),
    [sym_id] = ACTIONS(1591),
    [sym_pattern] = ACTIONS(1589),
    [sym_ipv4] = ACTIONS(1591),
    [sym_ipv6] = ACTIONS(1589),
    [sym_port] = ACTIONS(1589),
    [sym_integer] = ACTIONS(1591),
    [sym_floatp] = ACTIONS(1591),
    [sym_hex] = ACTIONS(1591),
    [sym_hostname] = ACTIONS(1591),
    [aux_sym_string_token1] = ACTIONS(1589),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(314)] = {
    [ts_builtin_sym_end] = ACTIONS(1593),
    [anon_sym_module] = ACTIONS(1595),
    [anon_sym_SEMI] = ACTIONS(1593),
    [anon_sym_export] = ACTIONS(1595),
    [anon_sym_LBRACE] = ACTIONS(1593),
    [anon_sym_global] = ACTIONS(1595),
    [anon_sym_option] = ACTIONS(1595),
    [anon_sym_const] = ACTIONS(1595),
    [anon_sym_redef] = ACTIONS(1595),
    [anon_sym_enum] = ACTIONS(1595),
    [anon_sym_record] = ACTIONS(1595),
    [anon_sym_type] = ACTIONS(1595),
    [anon_sym_print] = ACTIONS(1595),
    [anon_sym_event] = ACTIONS(1595),
    [anon_sym_if] = ACTIONS(1595),
    [anon_sym_LPAREN] = ACTIONS(1593),
    [anon_sym_switch] = ACTIONS(1595),
    [anon_sym_for] = ACTIONS(1595),
    [anon_sym_LBRACK] = ACTIONS(1595),
    [anon_sym_while] = ACTIONS(1595),
    [anon_sym_next] = ACTIONS(1595),
    [anon_sym_break] = ACTIONS(1595),
    [anon_sym_fallthrough] = ACTIONS(1595),
    [anon_sym_return] = ACTIONS(1595),
    [anon_sym_add] = ACTIONS(1595),
    [anon_sym_delete] = ACTIONS(1595),
    [anon_sym_local] = ACTIONS(1595),
    [anon_sym_when] = ACTIONS(1595),
    [anon_sym_assert] = ACTIONS(1595),
    [anon_sym_function] = ACTIONS(1595),
    [anon_sym_hook] = ACTIONS(1595),
    [anon_sym_addr] = ACTIONS(1595),
    [anon_sym_any] = ACTIONS(1595),
    [anon_sym_bool] = ACTIONS(1595),
    [anon_sym_count] = ACTIONS(1595),
    [anon_sym_double] = ACTIONS(1595),
    [anon_sym_file] = ACTIONS(1595),
    [anon_sym_int] = ACTIONS(1595),
    [anon_sym_interval] = ACTIONS(1595),
    [anon_sym_list] = ACTIONS(1595),
    [anon_sym_pattern] = ACTIONS(1595),
    [anon_sym_port] = ACTIONS(1595),
    [anon_sym_string] = ACTIONS(1595),
    [anon_sym_subnet] = ACTIONS(1595),
    [anon_sym_time] = ACTIONS(1595),
    [anon_sym_opaque] = ACTIONS(1595),
    [anon_sym_set] = ACTIONS(1595),
    [anon_sym_table] = ACTIONS(1595),
    [anon_sym_union] = ACTIONS(1595),
    [anon_sym_vector] = ACTIONS(1595),
    [anon_sym_DOLLAR] = ACTIONS(1593),
    [anon_sym_PIPE] = ACTIONS(1593),
    [anon_sym_PLUS_PLUS] = ACTIONS(1593),
    [anon_sym_DASH_DASH] = ACTIONS(1593),
    [anon_sym_BANG] = ACTIONS(1593),
    [anon_sym_TILDE] = ACTIONS(1593),
    [anon_sym_DASH] = ACTIONS(1595),
    [anon_sym_PLUS] = ACTIONS(1595),
    [anon_sym_copy] = ACTIONS(1595),
    [anon_sym_schedule] = ACTIONS(1595),
    [anon_sym_T] = ACTIONS(1595),
    [anon_sym_F] = ACTIONS(1595),
    [anon_sym_ATdeprecated] = ACTIONS(1593),
    [anon_sym_ATload] = ACTIONS(1595),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1593),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1593),
    [anon_sym_ATunload] = ACTIONS(1593),
    [anon_sym_ATprefixes] = ACTIONS(1593),
    [anon_sym_ATif] = ACTIONS(1595),
    [anon_sym_ATifdef] = ACTIONS(1593),
    [anon_sym_ATifndef] = ACTIONS(1593),
    [anon_sym_ATendif] = ACTIONS(1593),
    [anon_sym_ATelse] = ACTIONS(1593),
    [anon_sym_ATpragma] = ACTIONS(1593),
    [anon_sym_ATDIR] = ACTIONS(1593),
    [anon_sym_ATFILENAME] = ACTIONS(1593),
    [sym_id] = ACTIONS(1595),
    [sym_pattern] = ACTIONS(1593),
    [sym_ipv4] = ACTIONS(1595),
    [sym_ipv6] = ACTIONS(1593),
    [sym_port] = ACTIONS(1593),
    [sym_integer] = ACTIONS(1595),
    [sym_floatp] = ACTIONS(1595),
    [sym_hex] = ACTIONS(1595),
    [sym_hostname] = ACTIONS(1595),
    [aux_sym_string_token1] = ACTIONS(1593),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(315)] = {
    [ts_builtin_sym_end] = ACTIONS(1597),
    [anon_sym_module] = ACTIONS(1599),
    [anon_sym_SEMI] = ACTIONS(1597),
    [anon_sym_export] = ACTIONS(1599),
    [anon_sym_LBRACE] = ACTIONS(1597),
    [anon_sym_global] = ACTIONS(1599),
    [anon_sym_option] = ACTIONS(1599),
    [anon_sym_const] = ACTIONS(1599),
    [anon_sym_redef] = ACTIONS(1599),
    [anon_sym_enum] = ACTIONS(1599),
    [anon_sym_record] = ACTIONS(1599),
    [anon_sym_type] = ACTIONS(1599),
    [anon_sym_print] = ACTIONS(1599),
    [anon_sym_event] = ACTIONS(1599),
    [anon_sym_if] = ACTIONS(1599),
    [anon_sym_LPAREN] = ACTIONS(1597),
    [anon_sym_switch] = ACTIONS(1599),
    [anon_sym_for] = ACTIONS(1599),
    [anon_sym_LBRACK] = ACTIONS(1599),
    [anon_sym_while] = ACTIONS(1599),
    [anon_sym_next] = ACTIONS(1599),
    [anon_sym_break] = ACTIONS(1599),
    [anon_sym_fallthrough] = ACTIONS(1599),
    [anon_sym_return] = ACTIONS(1599),
    [anon_sym_add] = ACTIONS(1599),
    [anon_sym_delete] = ACTIONS(1599),
    [anon_sym_local] = ACTIONS(1599),
    [anon_sym_when] = ACTIONS(1599),
    [anon_sym_assert] = ACTIONS(1599),
    [anon_sym_function] = ACTIONS(1599),
    [anon_sym_hook] = ACTIONS(1599),
    [anon_sym_addr] = ACTIONS(1599),
    [anon_sym_any] = ACTIONS(1599),
    [anon_sym_bool] = ACTIONS(1599),
    [anon_sym_count] = ACTIONS(1599),
    [anon_sym_double] = ACTIONS(1599),
    [anon_sym_file] = ACTIONS(1599),
    [anon_sym_int] = ACTIONS(1599),
    [anon_sym_interval] = ACTIONS(1599),
    [anon_sym_list] = ACTIONS(1599),
    [anon_sym_pattern] = ACTIONS(1599),
    [anon_sym_port] = ACTIONS(1599),
    [anon_sym_string] = ACTIONS(1599),
    [anon_sym_subnet] = ACTIONS(1599),
    [anon_sym_time] = ACTIONS(1599),
    [anon_sym_opaque] = ACTIONS(1599),
    [anon_sym_set] = ACTIONS(1599),
    [anon_sym_table] = ACTIONS(1599),
    [anon_sym_union] = ACTIONS(1599),
    [anon_sym_vector] = ACTIONS(1599),
    [anon_sym_DOLLAR] = ACTIONS(1597),
    [anon_sym_PIPE] = ACTIONS(1597),
    [anon_sym_PLUS_PLUS] = ACTIONS(1597),
    [anon_sym_DASH_DASH] = ACTIONS(1597),
    [anon_sym_BANG] = ACTIONS(1597),
    [anon_sym_TILDE] = ACTIONS(1597),
    [anon_sym_DASH] = ACTIONS(1599),
    [anon_sym_PLUS] = ACTIONS(1599),
    [anon_sym_copy] = ACTIONS(1599),
    [anon_sym_schedule] = ACTIONS(1599),
    [anon_sym_T] = ACTIONS(1599),
    [anon_sym_F] = ACTIONS(1599),
    [anon_sym_ATdeprecated] = ACTIONS(1597),
    [anon_sym_ATload] = ACTIONS(1599),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1597),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1597),
    [anon_sym_ATunload] = ACTIONS(1597),
    [anon_sym_ATprefixes] = ACTIONS(1597),
    [anon_sym_ATif] = ACTIONS(1599),
    [anon_sym_ATifdef] = ACTIONS(1597),
    [anon_sym_ATifndef] = ACTIONS(1597),
    [anon_sym_ATendif] = ACTIONS(1597),
    [anon_sym_ATelse] = ACTIONS(1597),
    [anon_sym_ATpragma] = ACTIONS(1597),
    [anon_sym_ATDIR] = ACTIONS(1597),
    [anon_sym_ATFILENAME] = ACTIONS(1597),
    [sym_id] = ACTIONS(1599),
    [sym_pattern] = ACTIONS(1597),
    [sym_ipv4] = ACTIONS(1599),
    [sym_ipv6] = ACTIONS(1597),
    [sym_port] = ACTIONS(1597),
    [sym_integer] = ACTIONS(1599),
    [sym_floatp] = ACTIONS(1599),
    [sym_hex] = ACTIONS(1599),
    [sym_hostname] = ACTIONS(1599),
    [aux_sym_string_token1] = ACTIONS(1597),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(316)] = {
    [ts_builtin_sym_end] = ACTIONS(1601),
    [anon_sym_module] = ACTIONS(1603),
    [anon_sym_SEMI] = ACTIONS(1601),
    [anon_sym_export] = ACTIONS(1603),
    [anon_sym_LBRACE] = ACTIONS(1601),
    [anon_sym_global] = ACTIONS(1603),
    [anon_sym_option] = ACTIONS(1603),
    [anon_sym_const] = ACTIONS(1603),
    [anon_sym_redef] = ACTIONS(1603),
    [anon_sym_enum] = ACTIONS(1603),
    [anon_sym_record] = ACTIONS(1603),
    [anon_sym_type] = ACTIONS(1603),
    [anon_sym_print] = ACTIONS(1603),
    [anon_sym_event] = ACTIONS(1603),
    [anon_sym_if] = ACTIONS(1603),
    [anon_sym_LPAREN] = ACTIONS(1601),
    [anon_sym_switch] = ACTIONS(1603),
    [anon_sym_for] = ACTIONS(1603),
    [anon_sym_LBRACK] = ACTIONS(1603),
    [anon_sym_while] = ACTIONS(1603),
    [anon_sym_next] = ACTIONS(1603),
    [anon_sym_break] = ACTIONS(1603),
    [anon_sym_fallthrough] = ACTIONS(1603),
    [anon_sym_return] = ACTIONS(1603),
    [anon_sym_add] = ACTIONS(1603),
    [anon_sym_delete] = ACTIONS(1603),
    [anon_sym_local] = ACTIONS(1603),
    [anon_sym_when] = ACTIONS(1603),
    [anon_sym_assert] = ACTIONS(1603),
    [anon_sym_function] = ACTIONS(1603),
    [anon_sym_hook] = ACTIONS(1603),
    [anon_sym_addr] = ACTIONS(1603),
    [anon_sym_any] = ACTIONS(1603),
    [anon_sym_bool] = ACTIONS(1603),
    [anon_sym_count] = ACTIONS(1603),
    [anon_sym_double] = ACTIONS(1603),
    [anon_sym_file] = ACTIONS(1603),
    [anon_sym_int] = ACTIONS(1603),
    [anon_sym_interval] = ACTIONS(1603),
    [anon_sym_list] = ACTIONS(1603),
    [anon_sym_pattern] = ACTIONS(1603),
    [anon_sym_port] = ACTIONS(1603),
    [anon_sym_string] = ACTIONS(1603),
    [anon_sym_subnet] = ACTIONS(1603),
    [anon_sym_time] = ACTIONS(1603),
    [anon_sym_opaque] = ACTIONS(1603),
    [anon_sym_set] = ACTIONS(1603),
    [anon_sym_table] = ACTIONS(1603),
    [anon_sym_union] = ACTIONS(1603),
    [anon_sym_vector] = ACTIONS(1603),
    [anon_sym_DOLLAR] = ACTIONS(1601),
    [anon_sym_PIPE] = ACTIONS(1601),
    [anon_sym_PLUS_PLUS] = ACTIONS(1601),
    [anon_sym_DASH_DASH] = ACTIONS(1601),
    [anon_sym_BANG] = ACTIONS(1601),
    [anon_sym_TILDE] = ACTIONS(1601),
    [anon_sym_DASH] = ACTIONS(1603),
    [anon_sym_PLUS] = ACTIONS(1603),
    [anon_sym_copy] = ACTIONS(1603),
    [anon_sym_schedule] = ACTIONS(1603),
    [anon_sym_T] = ACTIONS(1603),
    [anon_sym_F] = ACTIONS(1603),
    [anon_sym_ATdeprecated] = ACTIONS(1601),
    [anon_sym_ATload] = ACTIONS(1603),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1601),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1601),
    [anon_sym_ATunload] = ACTIONS(1601),
    [anon_sym_ATprefixes] = ACTIONS(1601),
    [anon_sym_ATif] = ACTIONS(1603),
    [anon_sym_ATifdef] = ACTIONS(1601),
    [anon_sym_ATifndef] = ACTIONS(1601),
    [anon_sym_ATendif] = ACTIONS(1601),
    [anon_sym_ATelse] = ACTIONS(1601),
    [anon_sym_ATpragma] = ACTIONS(1601),
    [anon_sym_ATDIR] = ACTIONS(1601),
    [anon_sym_ATFILENAME] = ACTIONS(1601),
    [sym_id] = ACTIONS(1603),
    [sym_pattern] = ACTIONS(1601),
    [sym_ipv4] = ACTIONS(1603),
    [sym_ipv6] = ACTIONS(1601),
    [sym_port] = ACTIONS(1601),
    [sym_integer] = ACTIONS(1603),
    [sym_floatp] = ACTIONS(1603),
    [sym_hex] = ACTIONS(1603),
    [sym_hostname] = ACTIONS(1603),
    [aux_sym_string_token1] = ACTIONS(1601),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(317)] = {
    [ts_builtin_sym_end] = ACTIONS(1605),
    [anon_sym_module] = ACTIONS(1607),
    [anon_sym_SEMI] = ACTIONS(1605),
    [anon_sym_export] = ACTIONS(1607),
    [anon_sym_LBRACE] = ACTIONS(1605),
    [anon_sym_global] = ACTIONS(1607),
    [anon_sym_option] = ACTIONS(1607),
    [anon_sym_const] = ACTIONS(1607),
    [anon_sym_redef] = ACTIONS(1607),
    [anon_sym_enum] = ACTIONS(1607),
    [anon_sym_record] = ACTIONS(1607),
    [anon_sym_type] = ACTIONS(1607),
    [anon_sym_print] = ACTIONS(1607),
    [anon_sym_event] = ACTIONS(1607),
    [anon_sym_if] = ACTIONS(1607),
    [anon_sym_LPAREN] = ACTIONS(1605),
    [anon_sym_switch] = ACTIONS(1607),
    [anon_sym_for] = ACTIONS(1607),
    [anon_sym_LBRACK] = ACTIONS(1607),
    [anon_sym_while] = ACTIONS(1607),
    [anon_sym_next] = ACTIONS(1607),
    [anon_sym_break] = ACTIONS(1607),
    [anon_sym_fallthrough] = ACTIONS(1607),
    [anon_sym_return] = ACTIONS(1607),
    [anon_sym_add] = ACTIONS(1607),
    [anon_sym_delete] = ACTIONS(1607),
    [anon_sym_local] = ACTIONS(1607),
    [anon_sym_when] = ACTIONS(1607),
    [anon_sym_assert] = ACTIONS(1607),
    [anon_sym_function] = ACTIONS(1607),
    [anon_sym_hook] = ACTIONS(1607),
    [anon_sym_addr] = ACTIONS(1607),
    [anon_sym_any] = ACTIONS(1607),
    [anon_sym_bool] = ACTIONS(1607),
    [anon_sym_count] = ACTIONS(1607),
    [anon_sym_double] = ACTIONS(1607),
    [anon_sym_file] = ACTIONS(1607),
    [anon_sym_int] = ACTIONS(1607),
    [anon_sym_interval] = ACTIONS(1607),
    [anon_sym_list] = ACTIONS(1607),
    [anon_sym_pattern] = ACTIONS(1607),
    [anon_sym_port] = ACTIONS(1607),
    [anon_sym_string] = ACTIONS(1607),
    [anon_sym_subnet] = ACTIONS(1607),
    [anon_sym_time] = ACTIONS(1607),
    [anon_sym_opaque] = ACTIONS(1607),
    [anon_sym_set] = ACTIONS(1607),
    [anon_sym_table] = ACTIONS(1607),
    [anon_sym_union] = ACTIONS(1607),
    [anon_sym_vector] = ACTIONS(1607),
    [anon_sym_DOLLAR] = ACTIONS(1605),
    [anon_sym_PIPE] = ACTIONS(1605),
    [anon_sym_PLUS_PLUS] = ACTIONS(1605),
    [anon_sym_DASH_DASH] = ACTIONS(1605),
    [anon_sym_BANG] = ACTIONS(1605),
    [anon_sym_TILDE] = ACTIONS(1605),
    [anon_sym_DASH] = ACTIONS(1607),
    [anon_sym_PLUS] = ACTIONS(1607),
    [anon_sym_copy] = ACTIONS(1607),
    [anon_sym_schedule] = ACTIONS(1607),
    [anon_sym_T] = ACTIONS(1607),
    [anon_sym_F] = ACTIONS(1607),
    [anon_sym_ATdeprecated] = ACTIONS(1605),
    [anon_sym_ATload] = ACTIONS(1607),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1605),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1605),
    [anon_sym_ATunload] = ACTIONS(1605),
    [anon_sym_ATprefixes] = ACTIONS(1605),
    [anon_sym_ATif] = ACTIONS(1607),
    [anon_sym_ATifdef] = ACTIONS(1605),
    [anon_sym_ATifndef] = ACTIONS(1605),
    [anon_sym_ATendif] = ACTIONS(1605),
    [anon_sym_ATelse] = ACTIONS(1605),
    [anon_sym_ATpragma] = ACTIONS(1605),
    [anon_sym_ATDIR] = ACTIONS(1605),
    [anon_sym_ATFILENAME] = ACTIONS(1605),
    [sym_id] = ACTIONS(1607),
    [sym_pattern] = ACTIONS(1605),
    [sym_ipv4] = ACTIONS(1607),
    [sym_ipv6] = ACTIONS(1605),
    [sym_port] = ACTIONS(1605),
    [sym_integer] = ACTIONS(1607),
    [sym_floatp] = ACTIONS(1607),
    [sym_hex] = ACTIONS(1607),
    [sym_hostname] = ACTIONS(1607),
    [aux_sym_string_token1] = ACTIONS(1605),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(318)] = {
    [ts_builtin_sym_end] = ACTIONS(1609),
    [anon_sym_module] = ACTIONS(1611),
    [anon_sym_SEMI] = ACTIONS(1609),
    [anon_sym_export] = ACTIONS(1611),
    [anon_sym_LBRACE] = ACTIONS(1609),
    [anon_sym_global] = ACTIONS(1611),
    [anon_sym_option] = ACTIONS(1611),
    [anon_sym_const] = ACTIONS(1611),
    [anon_sym_redef] = ACTIONS(1611),
    [anon_sym_enum] = ACTIONS(1611),
    [anon_sym_record] = ACTIONS(1611),
    [anon_sym_type] = ACTIONS(1611),
    [anon_sym_print] = ACTIONS(1611),
    [anon_sym_event] = ACTIONS(1611),
    [anon_sym_if] = ACTIONS(1611),
    [anon_sym_LPAREN] = ACTIONS(1609),
    [anon_sym_switch] = ACTIONS(1611),
    [anon_sym_for] = ACTIONS(1611),
    [anon_sym_LBRACK] = ACTIONS(1611),
    [anon_sym_while] = ACTIONS(1611),
    [anon_sym_next] = ACTIONS(1611),
    [anon_sym_break] = ACTIONS(1611),
    [anon_sym_fallthrough] = ACTIONS(1611),
    [anon_sym_return] = ACTIONS(1611),
    [anon_sym_add] = ACTIONS(1611),
    [anon_sym_delete] = ACTIONS(1611),
    [anon_sym_local] = ACTIONS(1611),
    [anon_sym_when] = ACTIONS(1611),
    [anon_sym_assert] = ACTIONS(1611),
    [anon_sym_function] = ACTIONS(1611),
    [anon_sym_hook] = ACTIONS(1611),
    [anon_sym_addr] = ACTIONS(1611),
    [anon_sym_any] = ACTIONS(1611),
    [anon_sym_bool] = ACTIONS(1611),
    [anon_sym_count] = ACTIONS(1611),
    [anon_sym_double] = ACTIONS(1611),
    [anon_sym_file] = ACTIONS(1611),
    [anon_sym_int] = ACTIONS(1611),
    [anon_sym_interval] = ACTIONS(1611),
    [anon_sym_list] = ACTIONS(1611),
    [anon_sym_pattern] = ACTIONS(1611),
    [anon_sym_port] = ACTIONS(1611),
    [anon_sym_string] = ACTIONS(1611),
    [anon_sym_subnet] = ACTIONS(1611),
    [anon_sym_time] = ACTIONS(1611),
    [anon_sym_opaque] = ACTIONS(1611),
    [anon_sym_set] = ACTIONS(1611),
    [anon_sym_table] = ACTIONS(1611),
    [anon_sym_union] = ACTIONS(1611),
    [anon_sym_vector] = ACTIONS(1611),
    [anon_sym_DOLLAR] = ACTIONS(1609),
    [anon_sym_PIPE] = ACTIONS(1609),
    [anon_sym_PLUS_PLUS] = ACTIONS(1609),
    [anon_sym_DASH_DASH] = ACTIONS(1609),
    [anon_sym_BANG] = ACTIONS(1609),
    [anon_sym_TILDE] = ACTIONS(1609),
    [anon_sym_DASH] = ACTIONS(1611),
    [anon_sym_PLUS] = ACTIONS(1611),
    [anon_sym_copy] = ACTIONS(1611),
    [anon_sym_schedule] = ACTIONS(1611),
    [anon_sym_T] = ACTIONS(1611),
    [anon_sym_F] = ACTIONS(1611),
    [anon_sym_ATdeprecated] = ACTIONS(1609),
    [anon_sym_ATload] = ACTIONS(1611),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1609),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1609),
    [anon_sym_ATunload] = ACTIONS(1609),
    [anon_sym_ATprefixes] = ACTIONS(1609),
    [anon_sym_ATif] = ACTIONS(1611),
    [anon_sym_ATifdef] = ACTIONS(1609),
    [anon_sym_ATifndef] = ACTIONS(1609),
    [anon_sym_ATendif] = ACTIONS(1609),
    [anon_sym_ATelse] = ACTIONS(1609),
    [anon_sym_ATpragma] = ACTIONS(1609),
    [anon_sym_ATDIR] = ACTIONS(1609),
    [anon_sym_ATFILENAME] = ACTIONS(1609),
    [sym_id] = ACTIONS(1611),
    [sym_pattern] = ACTIONS(1609),
    [sym_ipv4] = ACTIONS(1611),
    [sym_ipv6] = ACTIONS(1609),
    [sym_port] = ACTIONS(1609),
    [sym_integer] = ACTIONS(1611),
    [sym_floatp] = ACTIONS(1611),
    [sym_hex] = ACTIONS(1611),
    [sym_hostname] = ACTIONS(1611),
    [aux_sym_string_token1] = ACTIONS(1609),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(319)] = {
    [ts_builtin_sym_end] = ACTIONS(1613),
    [anon_sym_module] = ACTIONS(1615),
    [anon_sym_SEMI] = ACTIONS(1613),
    [anon_sym_export] = ACTIONS(1615),
    [anon_sym_LBRACE] = ACTIONS(1613),
    [anon_sym_global] = ACTIONS(1615),
    [anon_sym_option] = ACTIONS(1615),
    [anon_sym_const] = ACTIONS(1615),
    [anon_sym_redef] = ACTIONS(1615),
    [anon_sym_enum] = ACTIONS(1615),
    [anon_sym_record] = ACTIONS(1615),
    [anon_sym_type] = ACTIONS(1615),
    [anon_sym_print] = ACTIONS(1615),
    [anon_sym_event] = ACTIONS(1615),
    [anon_sym_if] = ACTIONS(1615),
    [anon_sym_LPAREN] = ACTIONS(1613),
    [anon_sym_switch] = ACTIONS(1615),
    [anon_sym_for] = ACTIONS(1615),
    [anon_sym_LBRACK] = ACTIONS(1615),
    [anon_sym_while] = ACTIONS(1615),
    [anon_sym_next] = ACTIONS(1615),
    [anon_sym_break] = ACTIONS(1615),
    [anon_sym_fallthrough] = ACTIONS(1615),
    [anon_sym_return] = ACTIONS(1615),
    [anon_sym_add] = ACTIONS(1615),
    [anon_sym_delete] = ACTIONS(1615),
    [anon_sym_local] = ACTIONS(1615),
    [anon_sym_when] = ACTIONS(1615),
    [anon_sym_assert] = ACTIONS(1615),
    [anon_sym_function] = ACTIONS(1615),
    [anon_sym_hook] = ACTIONS(1615),
    [anon_sym_addr] = ACTIONS(1615),
    [anon_sym_any] = ACTIONS(1615),
    [anon_sym_bool] = ACTIONS(1615),
    [anon_sym_count] = ACTIONS(1615),
    [anon_sym_double] = ACTIONS(1615),
    [anon_sym_file] = ACTIONS(1615),
    [anon_sym_int] = ACTIONS(1615),
    [anon_sym_interval] = ACTIONS(1615),
    [anon_sym_list] = ACTIONS(1615),
    [anon_sym_pattern] = ACTIONS(1615),
    [anon_sym_port] = ACTIONS(1615),
    [anon_sym_string] = ACTIONS(1615),
    [anon_sym_subnet] = ACTIONS(1615),
    [anon_sym_time] = ACTIONS(1615),
    [anon_sym_opaque] = ACTIONS(1615),
    [anon_sym_set] = ACTIONS(1615),
    [anon_sym_table] = ACTIONS(1615),
    [anon_sym_union] = ACTIONS(1615),
    [anon_sym_vector] = ACTIONS(1615),
    [anon_sym_DOLLAR] = ACTIONS(1613),
    [anon_sym_PIPE] = ACTIONS(1613),
    [anon_sym_PLUS_PLUS] = ACTIONS(1613),
    [anon_sym_DASH_DASH] = ACTIONS(1613),
    [anon_sym_BANG] = ACTIONS(1613),
    [anon_sym_TILDE] = ACTIONS(1613),
    [anon_sym_DASH] = ACTIONS(1615),
    [anon_sym_PLUS] = ACTIONS(1615),
    [anon_sym_copy] = ACTIONS(1615),
    [anon_sym_schedule] = ACTIONS(1615),
    [anon_sym_T] = ACTIONS(1615),
    [anon_sym_F] = ACTIONS(1615),
    [anon_sym_ATdeprecated] = ACTIONS(1613),
    [anon_sym_ATload] = ACTIONS(1615),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1613),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1613),
    [anon_sym_ATunload] = ACTIONS(1613),
    [anon_sym_ATprefixes] = ACTIONS(1613),
    [anon_sym_ATif] = ACTIONS(1615),
    [anon_sym_ATifdef] = ACTIONS(1613),
    [anon_sym_ATifndef] = ACTIONS(1613),
    [anon_sym_ATendif] = ACTIONS(1613),
    [anon_sym_ATelse] = ACTIONS(1613),
    [anon_sym_ATpragma] = ACTIONS(1613),
    [anon_sym_ATDIR] = ACTIONS(1613),
    [anon_sym_ATFILENAME] = ACTIONS(1613),
    [sym_id] = ACTIONS(1615),
    [sym_pattern] = ACTIONS(1613),
    [sym_ipv4] = ACTIONS(1615),
    [sym_ipv6] = ACTIONS(1613),
    [sym_port] = ACTIONS(1613),
    [sym_integer] = ACTIONS(1615),
    [sym_floatp] = ACTIONS(1615),
    [sym_hex] = ACTIONS(1615),
    [sym_hostname] = ACTIONS(1615),
    [aux_sym_string_token1] = ACTIONS(1613),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(320)] = {
    [ts_builtin_sym_end] = ACTIONS(1617),
    [anon_sym_module] = ACTIONS(1619),
    [anon_sym_SEMI] = ACTIONS(1617),
    [anon_sym_export] = ACTIONS(1619),
    [anon_sym_LBRACE] = ACTIONS(1617),
    [anon_sym_global] = ACTIONS(1619),
    [anon_sym_option] = ACTIONS(1619),
    [anon_sym_const] = ACTIONS(1619),
    [anon_sym_redef] = ACTIONS(1619),
    [anon_sym_enum] = ACTIONS(1619),
    [anon_sym_record] = ACTIONS(1619),
    [anon_sym_type] = ACTIONS(1619),
    [anon_sym_print] = ACTIONS(1619),
    [anon_sym_event] = ACTIONS(1619),
    [anon_sym_if] = ACTIONS(1619),
    [anon_sym_LPAREN] = ACTIONS(1617),
    [anon_sym_switch] = ACTIONS(1619),
    [anon_sym_for] = ACTIONS(1619),
    [anon_sym_LBRACK] = ACTIONS(1619),
    [anon_sym_while] = ACTIONS(1619),
    [anon_sym_next] = ACTIONS(1619),
    [anon_sym_break] = ACTIONS(1619),
    [anon_sym_fallthrough] = ACTIONS(1619),
    [anon_sym_return] = ACTIONS(1619),
    [anon_sym_add] = ACTIONS(1619),
    [anon_sym_delete] = ACTIONS(1619),
    [anon_sym_local] = ACTIONS(1619),
    [anon_sym_when] = ACTIONS(1619),
    [anon_sym_assert] = ACTIONS(1619),
    [anon_sym_function] = ACTIONS(1619),
    [anon_sym_hook] = ACTIONS(1619),
    [anon_sym_addr] = ACTIONS(1619),
    [anon_sym_any] = ACTIONS(1619),
    [anon_sym_bool] = ACTIONS(1619),
    [anon_sym_count] = ACTIONS(1619),
    [anon_sym_double] = ACTIONS(1619),
    [anon_sym_file] = ACTIONS(1619),
    [anon_sym_int] = ACTIONS(1619),
    [anon_sym_interval] = ACTIONS(1619),
    [anon_sym_list] = ACTIONS(1619),
    [anon_sym_pattern] = ACTIONS(1619),
    [anon_sym_port] = ACTIONS(1619),
    [anon_sym_string] = ACTIONS(1619),
    [anon_sym_subnet] = ACTIONS(1619),
    [anon_sym_time] = ACTIONS(1619),
    [anon_sym_opaque] = ACTIONS(1619),
    [anon_sym_set] = ACTIONS(1619),
    [anon_sym_table] = ACTIONS(1619),
    [anon_sym_union] = ACTIONS(1619),
    [anon_sym_vector] = ACTIONS(1619),
    [anon_sym_DOLLAR] = ACTIONS(1617),
    [anon_sym_PIPE] = ACTIONS(1617),
    [anon_sym_PLUS_PLUS] = ACTIONS(1617),
    [anon_sym_DASH_DASH] = ACTIONS(1617),
    [anon_sym_BANG] = ACTIONS(1617),
    [anon_sym_TILDE] = ACTIONS(1617),
    [anon_sym_DASH] = ACTIONS(1619),
    [anon_sym_PLUS] = ACTIONS(1619),
    [anon_sym_copy] = ACTIONS(1619),
    [anon_sym_schedule] = ACTIONS(1619),
    [anon_sym_T] = ACTIONS(1619),
    [anon_sym_F] = ACTIONS(1619),
    [anon_sym_ATdeprecated] = ACTIONS(1617),
    [anon_sym_ATload] = ACTIONS(1619),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1617),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1617),
    [anon_sym_ATunload] = ACTIONS(1617),
    [anon_sym_ATprefixes] = ACTIONS(1617),
    [anon_sym_ATif] = ACTIONS(1619),
    [anon_sym_ATifdef] = ACTIONS(1617),
    [anon_sym_ATifndef] = ACTIONS(1617),
    [anon_sym_ATendif] = ACTIONS(1617),
    [anon_sym_ATelse] = ACTIONS(1617),
    [anon_sym_ATpragma] = ACTIONS(1617),
    [anon_sym_ATDIR] = ACTIONS(1617),
    [anon_sym_ATFILENAME] = ACTIONS(1617),
    [sym_id] = ACTIONS(1619),
    [sym_pattern] = ACTIONS(1617),
    [sym_ipv4] = ACTIONS(1619),
    [sym_ipv6] = ACTIONS(1617),
    [sym_port] = ACTIONS(1617),
    [sym_integer] = ACTIONS(1619),
    [sym_floatp] = ACTIONS(1619),
    [sym_hex] = ACTIONS(1619),
    [sym_hostname] = ACTIONS(1619),
    [aux_sym_string_token1] = ACTIONS(1617),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(321)] = {
    [ts_builtin_sym_end] = ACTIONS(1621),
    [anon_sym_module] = ACTIONS(1623),
    [anon_sym_SEMI] = ACTIONS(1621),
    [anon_sym_export] = ACTIONS(1623),
    [anon_sym_LBRACE] = ACTIONS(1621),
    [anon_sym_global] = ACTIONS(1623),
    [anon_sym_option] = ACTIONS(1623),
    [anon_sym_const] = ACTIONS(1623),
    [anon_sym_redef] = ACTIONS(1623),
    [anon_sym_enum] = ACTIONS(1623),
    [anon_sym_record] = ACTIONS(1623),
    [anon_sym_type] = ACTIONS(1623),
    [anon_sym_print] = ACTIONS(1623),
    [anon_sym_event] = ACTIONS(1623),
    [anon_sym_if] = ACTIONS(1623),
    [anon_sym_LPAREN] = ACTIONS(1621),
    [anon_sym_switch] = ACTIONS(1623),
    [anon_sym_for] = ACTIONS(1623),
    [anon_sym_LBRACK] = ACTIONS(1623),
    [anon_sym_while] = ACTIONS(1623),
    [anon_sym_next] = ACTIONS(1623),
    [anon_sym_break] = ACTIONS(1623),
    [anon_sym_fallthrough] = ACTIONS(1623),
    [anon_sym_return] = ACTIONS(1623),
    [anon_sym_add] = ACTIONS(1623),
    [anon_sym_delete] = ACTIONS(1623),
    [anon_sym_local] = ACTIONS(1623),
    [anon_sym_when] = ACTIONS(1623),
    [anon_sym_assert] = ACTIONS(1623),
    [anon_sym_function] = ACTIONS(1623),
    [anon_sym_hook] = ACTIONS(1623),
    [anon_sym_addr] = ACTIONS(1623),
    [anon_sym_any] = ACTIONS(1623),
    [anon_sym_bool] = ACTIONS(1623),
    [anon_sym_count] = ACTIONS(1623),
    [anon_sym_double] = ACTIONS(1623),
    [anon_sym_file] = ACTIONS(1623),
    [anon_sym_int] = ACTIONS(1623),
    [anon_sym_interval] = ACTIONS(1623),
    [anon_sym_list] = ACTIONS(1623),
    [anon_sym_pattern] = ACTIONS(1623),
    [anon_sym_port] = ACTIONS(1623),
    [anon_sym_string] = ACTIONS(1623),
    [anon_sym_subnet] = ACTIONS(1623),
    [anon_sym_time] = ACTIONS(1623),
    [anon_sym_opaque] = ACTIONS(1623),
    [anon_sym_set] = ACTIONS(1623),
    [anon_sym_table] = ACTIONS(1623),
    [anon_sym_union] = ACTIONS(1623),
    [anon_sym_vector] = ACTIONS(1623),
    [anon_sym_DOLLAR] = ACTIONS(1621),
    [anon_sym_PIPE] = ACTIONS(1621),
    [anon_sym_PLUS_PLUS] = ACTIONS(1621),
    [anon_sym_DASH_DASH] = ACTIONS(1621),
    [anon_sym_BANG] = ACTIONS(1621),
    [anon_sym_TILDE] = ACTIONS(1621),
    [anon_sym_DASH] = ACTIONS(1623),
    [anon_sym_PLUS] = ACTIONS(1623),
    [anon_sym_copy] = ACTIONS(1623),
    [anon_sym_schedule] = ACTIONS(1623),
    [anon_sym_T] = ACTIONS(1623),
    [anon_sym_F] = ACTIONS(1623),
    [anon_sym_ATdeprecated] = ACTIONS(1621),
    [anon_sym_ATload] = ACTIONS(1623),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1621),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1621),
    [anon_sym_ATunload] = ACTIONS(1621),
    [anon_sym_ATprefixes] = ACTIONS(1621),
    [anon_sym_ATif] = ACTIONS(1623),
    [anon_sym_ATifdef] = ACTIONS(1621),
    [anon_sym_ATifndef] = ACTIONS(1621),
    [anon_sym_ATendif] = ACTIONS(1621),
    [anon_sym_ATelse] = ACTIONS(1621),
    [anon_sym_ATpragma] = ACTIONS(1621),
    [anon_sym_ATDIR] = ACTIONS(1621),
    [anon_sym_ATFILENAME] = ACTIONS(1621),
    [sym_id] = ACTIONS(1623),
    [sym_pattern] = ACTIONS(1621),
    [sym_ipv4] = ACTIONS(1623),
    [sym_ipv6] = ACTIONS(1621),
    [sym_port] = ACTIONS(1621),
    [sym_integer] = ACTIONS(1623),
    [sym_floatp] = ACTIONS(1623),
    [sym_hex] = ACTIONS(1623),
    [sym_hostname] = ACTIONS(1623),
    [aux_sym_string_token1] = ACTIONS(1621),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(322)] = {
    [ts_builtin_sym_end] = ACTIONS(1493),
    [anon_sym_module] = ACTIONS(1495),
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_export] = ACTIONS(1495),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_global] = ACTIONS(1495),
    [anon_sym_option] = ACTIONS(1495),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_redef] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_type] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(323)] = {
    [ts_builtin_sym_end] = ACTIONS(1625),
    [anon_sym_module] = ACTIONS(1627),
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_export] = ACTIONS(1627),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_global] = ACTIONS(1627),
    [anon_sym_option] = ACTIONS(1627),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_redef] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_type] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(324)] = {
    [ts_builtin_sym_end] = ACTIONS(1629),
    [anon_sym_module] = ACTIONS(1631),
    [anon_sym_SEMI] = ACTIONS(1629),
    [anon_sym_export] = ACTIONS(1631),
    [anon_sym_LBRACE] = ACTIONS(1629),
    [anon_sym_global] = ACTIONS(1631),
    [anon_sym_option] = ACTIONS(1631),
    [anon_sym_const] = ACTIONS(1631),
    [anon_sym_redef] = ACTIONS(1631),
    [anon_sym_enum] = ACTIONS(1631),
    [anon_sym_record] = ACTIONS(1631),
    [anon_sym_type] = ACTIONS(1631),
    [anon_sym_print] = ACTIONS(1631),
    [anon_sym_event] = ACTIONS(1631),
    [anon_sym_if] = ACTIONS(1631),
    [anon_sym_LPAREN] = ACTIONS(1629),
    [anon_sym_switch] = ACTIONS(1631),
    [anon_sym_for] = ACTIONS(1631),
    [anon_sym_LBRACK] = ACTIONS(1631),
    [anon_sym_while] = ACTIONS(1631),
    [anon_sym_next] = ACTIONS(1631),
    [anon_sym_break] = ACTIONS(1631),
    [anon_sym_fallthrough] = ACTIONS(1631),
    [anon_sym_return] = ACTIONS(1631),
    [anon_sym_add] = ACTIONS(1631),
    [anon_sym_delete] = ACTIONS(1631),
    [anon_sym_local] = ACTIONS(1631),
    [anon_sym_when] = ACTIONS(1631),
    [anon_sym_assert] = ACTIONS(1631),
    [anon_sym_function] = ACTIONS(1631),
    [anon_sym_hook] = ACTIONS(1631),
    [anon_sym_addr] = ACTIONS(1631),
    [anon_sym_any] = ACTIONS(1631),
    [anon_sym_bool] = ACTIONS(1631),
    [anon_sym_count] = ACTIONS(1631),
    [anon_sym_double] = ACTIONS(1631),
    [anon_sym_file] = ACTIONS(1631),
    [anon_sym_int] = ACTIONS(1631),
    [anon_sym_interval] = ACTIONS(1631),
    [anon_sym_list] = ACTIONS(1631),
    [anon_sym_pattern] = ACTIONS(1631),
    [anon_sym_port] = ACTIONS(1631),
    [anon_sym_string] = ACTIONS(1631),
    [anon_sym_subnet] = ACTIONS(1631),
    [anon_sym_time] = ACTIONS(1631),
    [anon_sym_opaque] = ACTIONS(1631),
    [anon_sym_set] = ACTIONS(1631),
    [anon_sym_table] = ACTIONS(1631),
    [anon_sym_union] = ACTIONS(1631),
    [anon_sym_vector] = ACTIONS(1631),
    [anon_sym_DOLLAR] = ACTIONS(1629),
    [anon_sym_PIPE] = ACTIONS(1629),
    [anon_sym_PLUS_PLUS] = ACTIONS(1629),
    [anon_sym_DASH_DASH] = ACTIONS(1629),
    [anon_sym_BANG] = ACTIONS(1629),
    [anon_sym_TILDE] = ACTIONS(1629),
    [anon_sym_DASH] = ACTIONS(1631),
    [anon_sym_PLUS] = ACTIONS(1631),
    [anon_sym_copy] = ACTIONS(1631),
    [anon_sym_schedule] = ACTIONS(1631),
    [anon_sym_T] = ACTIONS(1631),
    [anon_sym_F] = ACTIONS(1631),
    [anon_sym_ATdeprecated] = ACTIONS(1629),
    [anon_sym_ATload] = ACTIONS(1631),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1629),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1629),
    [anon_sym_ATunload] = ACTIONS(1629),
    [anon_sym_ATprefixes] = ACTIONS(1629),
    [anon_sym_ATif] = ACTIONS(1631),
    [anon_sym_ATifdef] = ACTIONS(1629),
    [anon_sym_ATifndef] = ACTIONS(1629),
    [anon_sym_ATendif] = ACTIONS(1629),
    [anon_sym_ATelse] = ACTIONS(1629),
    [anon_sym_ATpragma] = ACTIONS(1629),
    [anon_sym_ATDIR] = ACTIONS(1629),
    [anon_sym_ATFILENAME] = ACTIONS(1629),
    [sym_id] = ACTIONS(1631),
    [sym_pattern] = ACTIONS(1629),
    [sym_ipv4] = ACTIONS(1631),
    [sym_ipv6] = ACTIONS(1629),
    [sym_port] = ACTIONS(1629),
    [sym_integer] = ACTIONS(1631),
    [sym_floatp] = ACTIONS(1631),
    [sym_hex] = ACTIONS(1631),
    [sym_hostname] = ACTIONS(1631),
    [aux_sym_string_token1] = ACTIONS(1629),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(325)] = {
    [ts_builtin_sym_end] = ACTIONS(1617),
    [anon_sym_module] = ACTIONS(1619),
    [anon_sym_SEMI] = ACTIONS(1617),
    [anon_sym_export] = ACTIONS(1619),
    [anon_sym_LBRACE] = ACTIONS(1617),
    [anon_sym_global] = ACTIONS(1619),
    [anon_sym_option] = ACTIONS(1619),
    [anon_sym_const] = ACTIONS(1619),
    [anon_sym_redef] = ACTIONS(1619),
    [anon_sym_enum] = ACTIONS(1619),
    [anon_sym_record] = ACTIONS(1619),
    [anon_sym_type] = ACTIONS(1619),
    [anon_sym_print] = ACTIONS(1619),
    [anon_sym_event] = ACTIONS(1619),
    [anon_sym_if] = ACTIONS(1619),
    [anon_sym_LPAREN] = ACTIONS(1617),
    [anon_sym_switch] = ACTIONS(1619),
    [anon_sym_for] = ACTIONS(1619),
    [anon_sym_LBRACK] = ACTIONS(1619),
    [anon_sym_while] = ACTIONS(1619),
    [anon_sym_next] = ACTIONS(1619),
    [anon_sym_break] = ACTIONS(1619),
    [anon_sym_fallthrough] = ACTIONS(1619),
    [anon_sym_return] = ACTIONS(1619),
    [anon_sym_add] = ACTIONS(1619),
    [anon_sym_delete] = ACTIONS(1619),
    [anon_sym_local] = ACTIONS(1619),
    [anon_sym_when] = ACTIONS(1619),
    [anon_sym_assert] = ACTIONS(1619),
    [anon_sym_function] = ACTIONS(1619),
    [anon_sym_hook] = ACTIONS(1619),
    [anon_sym_addr] = ACTIONS(1619),
    [anon_sym_any] = ACTIONS(1619),
    [anon_sym_bool] = ACTIONS(1619),
    [anon_sym_count] = ACTIONS(1619),
    [anon_sym_double] = ACTIONS(1619),
    [anon_sym_file] = ACTIONS(1619),
    [anon_sym_int] = ACTIONS(1619),
    [anon_sym_interval] = ACTIONS(1619),
    [anon_sym_list] = ACTIONS(1619),
    [anon_sym_pattern] = ACTIONS(1619),
    [anon_sym_port] = ACTIONS(1619),
    [anon_sym_string] = ACTIONS(1619),
    [anon_sym_subnet] = ACTIONS(1619),
    [anon_sym_time] = ACTIONS(1619),
    [anon_sym_opaque] = ACTIONS(1619),
    [anon_sym_set] = ACTIONS(1619),
    [anon_sym_table] = ACTIONS(1619),
    [anon_sym_union] = ACTIONS(1619),
    [anon_sym_vector] = ACTIONS(1619),
    [anon_sym_DOLLAR] = ACTIONS(1617),
    [anon_sym_PIPE] = ACTIONS(1617),
    [anon_sym_PLUS_PLUS] = ACTIONS(1617),
    [anon_sym_DASH_DASH] = ACTIONS(1617),
    [anon_sym_BANG] = ACTIONS(1617),
    [anon_sym_TILDE] = ACTIONS(1617),
    [anon_sym_DASH] = ACTIONS(1619),
    [anon_sym_PLUS] = ACTIONS(1619),
    [anon_sym_copy] = ACTIONS(1619),
    [anon_sym_schedule] = ACTIONS(1619),
    [anon_sym_T] = ACTIONS(1619),
    [anon_sym_F] = ACTIONS(1619),
    [anon_sym_ATdeprecated] = ACTIONS(1617),
    [anon_sym_ATload] = ACTIONS(1619),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1617),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1617),
    [anon_sym_ATunload] = ACTIONS(1617),
    [anon_sym_ATprefixes] = ACTIONS(1617),
    [anon_sym_ATif] = ACTIONS(1619),
    [anon_sym_ATifdef] = ACTIONS(1617),
    [anon_sym_ATifndef] = ACTIONS(1617),
    [anon_sym_ATendif] = ACTIONS(1617),
    [anon_sym_ATelse] = ACTIONS(1617),
    [anon_sym_ATpragma] = ACTIONS(1617),
    [anon_sym_ATDIR] = ACTIONS(1617),
    [anon_sym_ATFILENAME] = ACTIONS(1617),
    [sym_id] = ACTIONS(1619),
    [sym_pattern] = ACTIONS(1617),
    [sym_ipv4] = ACTIONS(1619),
    [sym_ipv6] = ACTIONS(1617),
    [sym_port] = ACTIONS(1617),
    [sym_integer] = ACTIONS(1619),
    [sym_floatp] = ACTIONS(1619),
    [sym_hex] = ACTIONS(1619),
    [sym_hostname] = ACTIONS(1619),
    [aux_sym_string_token1] = ACTIONS(1617),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(326)] = {
    [ts_builtin_sym_end] = ACTIONS(1633),
    [anon_sym_module] = ACTIONS(1635),
    [anon_sym_SEMI] = ACTIONS(1633),
    [anon_sym_export] = ACTIONS(1635),
    [anon_sym_LBRACE] = ACTIONS(1633),
    [anon_sym_global] = ACTIONS(1635),
    [anon_sym_option] = ACTIONS(1635),
    [anon_sym_const] = ACTIONS(1635),
    [anon_sym_redef] = ACTIONS(1635),
    [anon_sym_enum] = ACTIONS(1635),
    [anon_sym_record] = ACTIONS(1635),
    [anon_sym_type] = ACTIONS(1635),
    [anon_sym_print] = ACTIONS(1635),
    [anon_sym_event] = ACTIONS(1635),
    [anon_sym_if] = ACTIONS(1635),
    [anon_sym_LPAREN] = ACTIONS(1633),
    [anon_sym_switch] = ACTIONS(1635),
    [anon_sym_for] = ACTIONS(1635),
    [anon_sym_LBRACK] = ACTIONS(1635),
    [anon_sym_while] = ACTIONS(1635),
    [anon_sym_next] = ACTIONS(1635),
    [anon_sym_break] = ACTIONS(1635),
    [anon_sym_fallthrough] = ACTIONS(1635),
    [anon_sym_return] = ACTIONS(1635),
    [anon_sym_add] = ACTIONS(1635),
    [anon_sym_delete] = ACTIONS(1635),
    [anon_sym_local] = ACTIONS(1635),
    [anon_sym_when] = ACTIONS(1635),
    [anon_sym_assert] = ACTIONS(1635),
    [anon_sym_function] = ACTIONS(1635),
    [anon_sym_hook] = ACTIONS(1635),
    [anon_sym_addr] = ACTIONS(1635),
    [anon_sym_any] = ACTIONS(1635),
    [anon_sym_bool] = ACTIONS(1635),
    [anon_sym_count] = ACTIONS(1635),
    [anon_sym_double] = ACTIONS(1635),
    [anon_sym_file] = ACTIONS(1635),
    [anon_sym_int] = ACTIONS(1635),
    [anon_sym_interval] = ACTIONS(1635),
    [anon_sym_list] = ACTIONS(1635),
    [anon_sym_pattern] = ACTIONS(1635),
    [anon_sym_port] = ACTIONS(1635),
    [anon_sym_string] = ACTIONS(1635),
    [anon_sym_subnet] = ACTIONS(1635),
    [anon_sym_time] = ACTIONS(1635),
    [anon_sym_opaque] = ACTIONS(1635),
    [anon_sym_set] = ACTIONS(1635),
    [anon_sym_table] = ACTIONS(1635),
    [anon_sym_union] = ACTIONS(1635),
    [anon_sym_vector] = ACTIONS(1635),
    [anon_sym_DOLLAR] = ACTIONS(1633),
    [anon_sym_PIPE] = ACTIONS(1633),
    [anon_sym_PLUS_PLUS] = ACTIONS(1633),
    [anon_sym_DASH_DASH] = ACTIONS(1633),
    [anon_sym_BANG] = ACTIONS(1633),
    [anon_sym_TILDE] = ACTIONS(1633),
    [anon_sym_DASH] = ACTIONS(1635),
    [anon_sym_PLUS] = ACTIONS(1635),
    [anon_sym_copy] = ACTIONS(1635),
    [anon_sym_schedule] = ACTIONS(1635),
    [anon_sym_T] = ACTIONS(1635),
    [anon_sym_F] = ACTIONS(1635),
    [anon_sym_ATdeprecated] = ACTIONS(1633),
    [anon_sym_ATload] = ACTIONS(1635),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1633),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1633),
    [anon_sym_ATunload] = ACTIONS(1633),
    [anon_sym_ATprefixes] = ACTIONS(1633),
    [anon_sym_ATif] = ACTIONS(1635),
    [anon_sym_ATifdef] = ACTIONS(1633),
    [anon_sym_ATifndef] = ACTIONS(1633),
    [anon_sym_ATendif] = ACTIONS(1633),
    [anon_sym_ATelse] = ACTIONS(1633),
    [anon_sym_ATpragma] = ACTIONS(1633),
    [anon_sym_ATDIR] = ACTIONS(1633),
    [anon_sym_ATFILENAME] = ACTIONS(1633),
    [sym_id] = ACTIONS(1635),
    [sym_pattern] = ACTIONS(1633),
    [sym_ipv4] = ACTIONS(1635),
    [sym_ipv6] = ACTIONS(1633),
    [sym_port] = ACTIONS(1633),
    [sym_integer] = ACTIONS(1635),
    [sym_floatp] = ACTIONS(1635),
    [sym_hex] = ACTIONS(1635),
    [sym_hostname] = ACTIONS(1635),
    [aux_sym_string_token1] = ACTIONS(1633),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(327)] = {
    [ts_builtin_sym_end] = ACTIONS(1637),
    [anon_sym_module] = ACTIONS(1639),
    [anon_sym_SEMI] = ACTIONS(1637),
    [anon_sym_export] = ACTIONS(1639),
    [anon_sym_LBRACE] = ACTIONS(1637),
    [anon_sym_global] = ACTIONS(1639),
    [anon_sym_option] = ACTIONS(1639),
    [anon_sym_const] = ACTIONS(1639),
    [anon_sym_redef] = ACTIONS(1639),
    [anon_sym_enum] = ACTIONS(1639),
    [anon_sym_record] = ACTIONS(1639),
    [anon_sym_type] = ACTIONS(1639),
    [anon_sym_print] = ACTIONS(1639),
    [anon_sym_event] = ACTIONS(1639),
    [anon_sym_if] = ACTIONS(1639),
    [anon_sym_LPAREN] = ACTIONS(1637),
    [anon_sym_switch] = ACTIONS(1639),
    [anon_sym_for] = ACTIONS(1639),
    [anon_sym_LBRACK] = ACTIONS(1639),
    [anon_sym_while] = ACTIONS(1639),
    [anon_sym_next] = ACTIONS(1639),
    [anon_sym_break] = ACTIONS(1639),
    [anon_sym_fallthrough] = ACTIONS(1639),
    [anon_sym_return] = ACTIONS(1639),
    [anon_sym_add] = ACTIONS(1639),
    [anon_sym_delete] = ACTIONS(1639),
    [anon_sym_local] = ACTIONS(1639),
    [anon_sym_when] = ACTIONS(1639),
    [anon_sym_assert] = ACTIONS(1639),
    [anon_sym_function] = ACTIONS(1639),
    [anon_sym_hook] = ACTIONS(1639),
    [anon_sym_addr] = ACTIONS(1639),
    [anon_sym_any] = ACTIONS(1639),
    [anon_sym_bool] = ACTIONS(1639),
    [anon_sym_count] = ACTIONS(1639),
    [anon_sym_double] = ACTIONS(1639),
    [anon_sym_file] = ACTIONS(1639),
    [anon_sym_int] = ACTIONS(1639),
    [anon_sym_interval] = ACTIONS(1639),
    [anon_sym_list] = ACTIONS(1639),
    [anon_sym_pattern] = ACTIONS(1639),
    [anon_sym_port] = ACTIONS(1639),
    [anon_sym_string] = ACTIONS(1639),
    [anon_sym_subnet] = ACTIONS(1639),
    [anon_sym_time] = ACTIONS(1639),
    [anon_sym_opaque] = ACTIONS(1639),
    [anon_sym_set] = ACTIONS(1639),
    [anon_sym_table] = ACTIONS(1639),
    [anon_sym_union] = ACTIONS(1639),
    [anon_sym_vector] = ACTIONS(1639),
    [anon_sym_DOLLAR] = ACTIONS(1637),
    [anon_sym_PIPE] = ACTIONS(1637),
    [anon_sym_PLUS_PLUS] = ACTIONS(1637),
    [anon_sym_DASH_DASH] = ACTIONS(1637),
    [anon_sym_BANG] = ACTIONS(1637),
    [anon_sym_TILDE] = ACTIONS(1637),
    [anon_sym_DASH] = ACTIONS(1639),
    [anon_sym_PLUS] = ACTIONS(1639),
    [anon_sym_copy] = ACTIONS(1639),
    [anon_sym_schedule] = ACTIONS(1639),
    [anon_sym_T] = ACTIONS(1639),
    [anon_sym_F] = ACTIONS(1639),
    [anon_sym_ATdeprecated] = ACTIONS(1637),
    [anon_sym_ATload] = ACTIONS(1639),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1637),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1637),
    [anon_sym_ATunload] = ACTIONS(1637),
    [anon_sym_ATprefixes] = ACTIONS(1637),
    [anon_sym_ATif] = ACTIONS(1639),
    [anon_sym_ATifdef] = ACTIONS(1637),
    [anon_sym_ATifndef] = ACTIONS(1637),
    [anon_sym_ATendif] = ACTIONS(1637),
    [anon_sym_ATelse] = ACTIONS(1637),
    [anon_sym_ATpragma] = ACTIONS(1637),
    [anon_sym_ATDIR] = ACTIONS(1637),
    [anon_sym_ATFILENAME] = ACTIONS(1637),
    [sym_id] = ACTIONS(1639),
    [sym_pattern] = ACTIONS(1637),
    [sym_ipv4] = ACTIONS(1639),
    [sym_ipv6] = ACTIONS(1637),
    [sym_port] = ACTIONS(1637),
    [sym_integer] = ACTIONS(1639),
    [sym_floatp] = ACTIONS(1639),
    [sym_hex] = ACTIONS(1639),
    [sym_hostname] = ACTIONS(1639),
    [aux_sym_string_token1] = ACTIONS(1637),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(328)] = {
    [ts_builtin_sym_end] = ACTIONS(1525),
    [anon_sym_module] = ACTIONS(1527),
    [anon_sym_SEMI] = ACTIONS(1525),
    [anon_sym_export] = ACTIONS(1527),
    [anon_sym_LBRACE] = ACTIONS(1525),
    [anon_sym_global] = ACTIONS(1527),
    [anon_sym_option] = ACTIONS(1527),
    [anon_sym_const] = ACTIONS(1527),
    [anon_sym_redef] = ACTIONS(1527),
    [anon_sym_enum] = ACTIONS(1527),
    [anon_sym_record] = ACTIONS(1527),
    [anon_sym_type] = ACTIONS(1527),
    [anon_sym_print] = ACTIONS(1527),
    [anon_sym_event] = ACTIONS(1527),
    [anon_sym_if] = ACTIONS(1527),
    [anon_sym_LPAREN] = ACTIONS(1525),
    [anon_sym_switch] = ACTIONS(1527),
    [anon_sym_for] = ACTIONS(1527),
    [anon_sym_LBRACK] = ACTIONS(1527),
    [anon_sym_while] = ACTIONS(1527),
    [anon_sym_next] = ACTIONS(1527),
    [anon_sym_break] = ACTIONS(1527),
    [anon_sym_fallthrough] = ACTIONS(1527),
    [anon_sym_return] = ACTIONS(1527),
    [anon_sym_add] = ACTIONS(1527),
    [anon_sym_delete] = ACTIONS(1527),
    [anon_sym_local] = ACTIONS(1527),
    [anon_sym_when] = ACTIONS(1527),
    [anon_sym_assert] = ACTIONS(1527),
    [anon_sym_function] = ACTIONS(1527),
    [anon_sym_hook] = ACTIONS(1527),
    [anon_sym_addr] = ACTIONS(1527),
    [anon_sym_any] = ACTIONS(1527),
    [anon_sym_bool] = ACTIONS(1527),
    [anon_sym_count] = ACTIONS(1527),
    [anon_sym_double] = ACTIONS(1527),
    [anon_sym_file] = ACTIONS(1527),
    [anon_sym_int] = ACTIONS(1527),
    [anon_sym_interval] = ACTIONS(1527),
    [anon_sym_list] = ACTIONS(1527),
    [anon_sym_pattern] = ACTIONS(1527),
    [anon_sym_port] = ACTIONS(1527),
    [anon_sym_string] = ACTIONS(1527),
    [anon_sym_subnet] = ACTIONS(1527),
    [anon_sym_time] = ACTIONS(1527),
    [anon_sym_opaque] = ACTIONS(1527),
    [anon_sym_set] = ACTIONS(1527),
    [anon_sym_table] = ACTIONS(1527),
    [anon_sym_union] = ACTIONS(1527),
    [anon_sym_vector] = ACTIONS(1527),
    [anon_sym_DOLLAR] = ACTIONS(1525),
    [anon_sym_PIPE] = ACTIONS(1525),
    [anon_sym_PLUS_PLUS] = ACTIONS(1525),
    [anon_sym_DASH_DASH] = ACTIONS(1525),
    [anon_sym_BANG] = ACTIONS(1525),
    [anon_sym_TILDE] = ACTIONS(1525),
    [anon_sym_DASH] = ACTIONS(1527),
    [anon_sym_PLUS] = ACTIONS(1527),
    [anon_sym_copy] = ACTIONS(1527),
    [anon_sym_schedule] = ACTIONS(1527),
    [anon_sym_T] = ACTIONS(1527),
    [anon_sym_F] = ACTIONS(1527),
    [anon_sym_ATdeprecated] = ACTIONS(1525),
    [anon_sym_ATload] = ACTIONS(1527),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1525),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1525),
    [anon_sym_ATunload] = ACTIONS(1525),
    [anon_sym_ATprefixes] = ACTIONS(1525),
    [anon_sym_ATif] = ACTIONS(1527),
    [anon_sym_ATifdef] = ACTIONS(1525),
    [anon_sym_ATifndef] = ACTIONS(1525),
    [anon_sym_ATendif] = ACTIONS(1525),
    [anon_sym_ATelse] = ACTIONS(1525),
    [anon_sym_ATpragma] = ACTIONS(1525),
    [anon_sym_ATDIR] = ACTIONS(1525),
    [anon_sym_ATFILENAME] = ACTIONS(1525),
    [sym_id] = ACTIONS(1527),
    [sym_pattern] = ACTIONS(1525),
    [sym_ipv4] = ACTIONS(1527),
    [sym_ipv6] = ACTIONS(1525),
    [sym_port] = ACTIONS(1525),
    [sym_integer] = ACTIONS(1527),
    [sym_floatp] = ACTIONS(1527),
    [sym_hex] = ACTIONS(1527),
    [sym_hostname] = ACTIONS(1527),
    [aux_sym_string_token1] = ACTIONS(1525),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(329)] = {
    [ts_builtin_sym_end] = ACTIONS(1557),
    [anon_sym_module] = ACTIONS(1559),
    [anon_sym_SEMI] = ACTIONS(1557),
    [anon_sym_export] = ACTIONS(1559),
    [anon_sym_LBRACE] = ACTIONS(1557),
    [anon_sym_global] = ACTIONS(1559),
    [anon_sym_option] = ACTIONS(1559),
    [anon_sym_const] = ACTIONS(1559),
    [anon_sym_redef] = ACTIONS(1559),
    [anon_sym_enum] = ACTIONS(1559),
    [anon_sym_record] = ACTIONS(1559),
    [anon_sym_type] = ACTIONS(1559),
    [anon_sym_print] = ACTIONS(1559),
    [anon_sym_event] = ACTIONS(1559),
    [anon_sym_if] = ACTIONS(1559),
    [anon_sym_LPAREN] = ACTIONS(1557),
    [anon_sym_switch] = ACTIONS(1559),
    [anon_sym_for] = ACTIONS(1559),
    [anon_sym_LBRACK] = ACTIONS(1559),
    [anon_sym_while] = ACTIONS(1559),
    [anon_sym_next] = ACTIONS(1559),
    [anon_sym_break] = ACTIONS(1559),
    [anon_sym_fallthrough] = ACTIONS(1559),
    [anon_sym_return] = ACTIONS(1559),
    [anon_sym_add] = ACTIONS(1559),
    [anon_sym_delete] = ACTIONS(1559),
    [anon_sym_local] = ACTIONS(1559),
    [anon_sym_when] = ACTIONS(1559),
    [anon_sym_assert] = ACTIONS(1559),
    [anon_sym_function] = ACTIONS(1559),
    [anon_sym_hook] = ACTIONS(1559),
    [anon_sym_addr] = ACTIONS(1559),
    [anon_sym_any] = ACTIONS(1559),
    [anon_sym_bool] = ACTIONS(1559),
    [anon_sym_count] = ACTIONS(1559),
    [anon_sym_double] = ACTIONS(1559),
    [anon_sym_file] = ACTIONS(1559),
    [anon_sym_int] = ACTIONS(1559),
    [anon_sym_interval] = ACTIONS(1559),
    [anon_sym_list] = ACTIONS(1559),
    [anon_sym_pattern] = ACTIONS(1559),
    [anon_sym_port] = ACTIONS(1559),
    [anon_sym_string] = ACTIONS(1559),
    [anon_sym_subnet] = ACTIONS(1559),
    [anon_sym_time] = ACTIONS(1559),
    [anon_sym_opaque] = ACTIONS(1559),
    [anon_sym_set] = ACTIONS(1559),
    [anon_sym_table] = ACTIONS(1559),
    [anon_sym_union] = ACTIONS(1559),
    [anon_sym_vector] = ACTIONS(1559),
    [anon_sym_DOLLAR] = ACTIONS(1557),
    [anon_sym_PIPE] = ACTIONS(1557),
    [anon_sym_PLUS_PLUS] = ACTIONS(1557),
    [anon_sym_DASH_DASH] = ACTIONS(1557),
    [anon_sym_BANG] = ACTIONS(1557),
    [anon_sym_TILDE] = ACTIONS(1557),
    [anon_sym_DASH] = ACTIONS(1559),
    [anon_sym_PLUS] = ACTIONS(1559),
    [anon_sym_copy] = ACTIONS(1559),
    [anon_sym_schedule] = ACTIONS(1559),
    [anon_sym_T] = ACTIONS(1559),
    [anon_sym_F] = ACTIONS(1559),
    [anon_sym_ATdeprecated] = ACTIONS(1557),
    [anon_sym_ATload] = ACTIONS(1559),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1557),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1557),
    [anon_sym_ATunload] = ACTIONS(1557),
    [anon_sym_ATprefixes] = ACTIONS(1557),
    [anon_sym_ATif] = ACTIONS(1559),
    [anon_sym_ATifdef] = ACTIONS(1557),
    [anon_sym_ATifndef] = ACTIONS(1557),
    [anon_sym_ATendif] = ACTIONS(1557),
    [anon_sym_ATelse] = ACTIONS(1557),
    [anon_sym_ATpragma] = ACTIONS(1557),
    [anon_sym_ATDIR] = ACTIONS(1557),
    [anon_sym_ATFILENAME] = ACTIONS(1557),
    [sym_id] = ACTIONS(1559),
    [sym_pattern] = ACTIONS(1557),
    [sym_ipv4] = ACTIONS(1559),
    [sym_ipv6] = ACTIONS(1557),
    [sym_port] = ACTIONS(1557),
    [sym_integer] = ACTIONS(1559),
    [sym_floatp] = ACTIONS(1559),
    [sym_hex] = ACTIONS(1559),
    [sym_hostname] = ACTIONS(1559),
    [aux_sym_string_token1] = ACTIONS(1557),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(330)] = {
    [ts_builtin_sym_end] = ACTIONS(1585),
    [anon_sym_module] = ACTIONS(1587),
    [anon_sym_SEMI] = ACTIONS(1585),
    [anon_sym_export] = ACTIONS(1587),
    [anon_sym_LBRACE] = ACTIONS(1585),
    [anon_sym_global] = ACTIONS(1587),
    [anon_sym_option] = ACTIONS(1587),
    [anon_sym_const] = ACTIONS(1587),
    [anon_sym_redef] = ACTIONS(1587),
    [anon_sym_enum] = ACTIONS(1587),
    [anon_sym_record] = ACTIONS(1587),
    [anon_sym_type] = ACTIONS(1587),
    [anon_sym_print] = ACTIONS(1587),
    [anon_sym_event] = ACTIONS(1587),
    [anon_sym_if] = ACTIONS(1587),
    [anon_sym_LPAREN] = ACTIONS(1585),
    [anon_sym_switch] = ACTIONS(1587),
    [anon_sym_for] = ACTIONS(1587),
    [anon_sym_LBRACK] = ACTIONS(1587),
    [anon_sym_while] = ACTIONS(1587),
    [anon_sym_next] = ACTIONS(1587),
    [anon_sym_break] = ACTIONS(1587),
    [anon_sym_fallthrough] = ACTIONS(1587),
    [anon_sym_return] = ACTIONS(1587),
    [anon_sym_add] = ACTIONS(1587),
    [anon_sym_delete] = ACTIONS(1587),
    [anon_sym_local] = ACTIONS(1587),
    [anon_sym_when] = ACTIONS(1587),
    [anon_sym_assert] = ACTIONS(1587),
    [anon_sym_function] = ACTIONS(1587),
    [anon_sym_hook] = ACTIONS(1587),
    [anon_sym_addr] = ACTIONS(1587),
    [anon_sym_any] = ACTIONS(1587),
    [anon_sym_bool] = ACTIONS(1587),
    [anon_sym_count] = ACTIONS(1587),
    [anon_sym_double] = ACTIONS(1587),
    [anon_sym_file] = ACTIONS(1587),
    [anon_sym_int] = ACTIONS(1587),
    [anon_sym_interval] = ACTIONS(1587),
    [anon_sym_list] = ACTIONS(1587),
    [anon_sym_pattern] = ACTIONS(1587),
    [anon_sym_port] = ACTIONS(1587),
    [anon_sym_string] = ACTIONS(1587),
    [anon_sym_subnet] = ACTIONS(1587),
    [anon_sym_time] = ACTIONS(1587),
    [anon_sym_opaque] = ACTIONS(1587),
    [anon_sym_set] = ACTIONS(1587),
    [anon_sym_table] = ACTIONS(1587),
    [anon_sym_union] = ACTIONS(1587),
    [anon_sym_vector] = ACTIONS(1587),
    [anon_sym_DOLLAR] = ACTIONS(1585),
    [anon_sym_PIPE] = ACTIONS(1585),
    [anon_sym_PLUS_PLUS] = ACTIONS(1585),
    [anon_sym_DASH_DASH] = ACTIONS(1585),
    [anon_sym_BANG] = ACTIONS(1585),
    [anon_sym_TILDE] = ACTIONS(1585),
    [anon_sym_DASH] = ACTIONS(1587),
    [anon_sym_PLUS] = ACTIONS(1587),
    [anon_sym_copy] = ACTIONS(1587),
    [anon_sym_schedule] = ACTIONS(1587),
    [anon_sym_T] = ACTIONS(1587),
    [anon_sym_F] = ACTIONS(1587),
    [anon_sym_ATdeprecated] = ACTIONS(1585),
    [anon_sym_ATload] = ACTIONS(1587),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1585),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1585),
    [anon_sym_ATunload] = ACTIONS(1585),
    [anon_sym_ATprefixes] = ACTIONS(1585),
    [anon_sym_ATif] = ACTIONS(1587),
    [anon_sym_ATifdef] = ACTIONS(1585),
    [anon_sym_ATifndef] = ACTIONS(1585),
    [anon_sym_ATendif] = ACTIONS(1585),
    [anon_sym_ATelse] = ACTIONS(1585),
    [anon_sym_ATpragma] = ACTIONS(1585),
    [anon_sym_ATDIR] = ACTIONS(1585),
    [anon_sym_ATFILENAME] = ACTIONS(1585),
    [sym_id] = ACTIONS(1587),
    [sym_pattern] = ACTIONS(1585),
    [sym_ipv4] = ACTIONS(1587),
    [sym_ipv6] = ACTIONS(1585),
    [sym_port] = ACTIONS(1585),
    [sym_integer] = ACTIONS(1587),
    [sym_floatp] = ACTIONS(1587),
    [sym_hex] = ACTIONS(1587),
    [sym_hostname] = ACTIONS(1587),
    [aux_sym_string_token1] = ACTIONS(1585),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(331)] = {
    [ts_builtin_sym_end] = ACTIONS(1641),
    [anon_sym_module] = ACTIONS(1643),
    [anon_sym_SEMI] = ACTIONS(1641),
    [anon_sym_export] = ACTIONS(1643),
    [anon_sym_LBRACE] = ACTIONS(1641),
    [anon_sym_global] = ACTIONS(1643),
    [anon_sym_option] = ACTIONS(1643),
    [anon_sym_const] = ACTIONS(1643),
    [anon_sym_redef] = ACTIONS(1643),
    [anon_sym_enum] = ACTIONS(1643),
    [anon_sym_record] = ACTIONS(1643),
    [anon_sym_type] = ACTIONS(1643),
    [anon_sym_print] = ACTIONS(1643),
    [anon_sym_event] = ACTIONS(1643),
    [anon_sym_if] = ACTIONS(1643),
    [anon_sym_LPAREN] = ACTIONS(1641),
    [anon_sym_switch] = ACTIONS(1643),
    [anon_sym_for] = ACTIONS(1643),
    [anon_sym_LBRACK] = ACTIONS(1643),
    [anon_sym_while] = ACTIONS(1643),
    [anon_sym_next] = ACTIONS(1643),
    [anon_sym_break] = ACTIONS(1643),
    [anon_sym_fallthrough] = ACTIONS(1643),
    [anon_sym_return] = ACTIONS(1643),
    [anon_sym_add] = ACTIONS(1643),
    [anon_sym_delete] = ACTIONS(1643),
    [anon_sym_local] = ACTIONS(1643),
    [anon_sym_when] = ACTIONS(1643),
    [anon_sym_assert] = ACTIONS(1643),
    [anon_sym_function] = ACTIONS(1643),
    [anon_sym_hook] = ACTIONS(1643),
    [anon_sym_addr] = ACTIONS(1643),
    [anon_sym_any] = ACTIONS(1643),
    [anon_sym_bool] = ACTIONS(1643),
    [anon_sym_count] = ACTIONS(1643),
    [anon_sym_double] = ACTIONS(1643),
    [anon_sym_file] = ACTIONS(1643),
    [anon_sym_int] = ACTIONS(1643),
    [anon_sym_interval] = ACTIONS(1643),
    [anon_sym_list] = ACTIONS(1643),
    [anon_sym_pattern] = ACTIONS(1643),
    [anon_sym_port] = ACTIONS(1643),
    [anon_sym_string] = ACTIONS(1643),
    [anon_sym_subnet] = ACTIONS(1643),
    [anon_sym_time] = ACTIONS(1643),
    [anon_sym_opaque] = ACTIONS(1643),
    [anon_sym_set] = ACTIONS(1643),
    [anon_sym_table] = ACTIONS(1643),
    [anon_sym_union] = ACTIONS(1643),
    [anon_sym_vector] = ACTIONS(1643),
    [anon_sym_DOLLAR] = ACTIONS(1641),
    [anon_sym_PIPE] = ACTIONS(1641),
    [anon_sym_PLUS_PLUS] = ACTIONS(1641),
    [anon_sym_DASH_DASH] = ACTIONS(1641),
    [anon_sym_BANG] = ACTIONS(1641),
    [anon_sym_TILDE] = ACTIONS(1641),
    [anon_sym_DASH] = ACTIONS(1643),
    [anon_sym_PLUS] = ACTIONS(1643),
    [anon_sym_copy] = ACTIONS(1643),
    [anon_sym_schedule] = ACTIONS(1643),
    [anon_sym_T] = ACTIONS(1643),
    [anon_sym_F] = ACTIONS(1643),
    [anon_sym_ATdeprecated] = ACTIONS(1641),
    [anon_sym_ATload] = ACTIONS(1643),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1641),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1641),
    [anon_sym_ATunload] = ACTIONS(1641),
    [anon_sym_ATprefixes] = ACTIONS(1641),
    [anon_sym_ATif] = ACTIONS(1643),
    [anon_sym_ATifdef] = ACTIONS(1641),
    [anon_sym_ATifndef] = ACTIONS(1641),
    [anon_sym_ATendif] = ACTIONS(1641),
    [anon_sym_ATelse] = ACTIONS(1641),
    [anon_sym_ATpragma] = ACTIONS(1641),
    [anon_sym_ATDIR] = ACTIONS(1641),
    [anon_sym_ATFILENAME] = ACTIONS(1641),
    [sym_id] = ACTIONS(1643),
    [sym_pattern] = ACTIONS(1641),
    [sym_ipv4] = ACTIONS(1643),
    [sym_ipv6] = ACTIONS(1641),
    [sym_port] = ACTIONS(1641),
    [sym_integer] = ACTIONS(1643),
    [sym_floatp] = ACTIONS(1643),
    [sym_hex] = ACTIONS(1643),
    [sym_hostname] = ACTIONS(1643),
    [aux_sym_string_token1] = ACTIONS(1641),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(332)] = {
    [ts_builtin_sym_end] = ACTIONS(1645),
    [anon_sym_module] = ACTIONS(1647),
    [anon_sym_SEMI] = ACTIONS(1645),
    [anon_sym_export] = ACTIONS(1647),
    [anon_sym_LBRACE] = ACTIONS(1645),
    [anon_sym_global] = ACTIONS(1647),
    [anon_sym_option] = ACTIONS(1647),
    [anon_sym_const] = ACTIONS(1647),
    [anon_sym_redef] = ACTIONS(1647),
    [anon_sym_enum] = ACTIONS(1647),
    [anon_sym_record] = ACTIONS(1647),
    [anon_sym_type] = ACTIONS(1647),
    [anon_sym_print] = ACTIONS(1647),
    [anon_sym_event] = ACTIONS(1647),
    [anon_sym_if] = ACTIONS(1647),
    [anon_sym_LPAREN] = ACTIONS(1645),
    [anon_sym_switch] = ACTIONS(1647),
    [anon_sym_for] = ACTIONS(1647),
    [anon_sym_LBRACK] = ACTIONS(1647),
    [anon_sym_while] = ACTIONS(1647),
    [anon_sym_next] = ACTIONS(1647),
    [anon_sym_break] = ACTIONS(1647),
    [anon_sym_fallthrough] = ACTIONS(1647),
    [anon_sym_return] = ACTIONS(1647),
    [anon_sym_add] = ACTIONS(1647),
    [anon_sym_delete] = ACTIONS(1647),
    [anon_sym_local] = ACTIONS(1647),
    [anon_sym_when] = ACTIONS(1647),
    [anon_sym_assert] = ACTIONS(1647),
    [anon_sym_function] = ACTIONS(1647),
    [anon_sym_hook] = ACTIONS(1647),
    [anon_sym_addr] = ACTIONS(1647),
    [anon_sym_any] = ACTIONS(1647),
    [anon_sym_bool] = ACTIONS(1647),
    [anon_sym_count] = ACTIONS(1647),
    [anon_sym_double] = ACTIONS(1647),
    [anon_sym_file] = ACTIONS(1647),
    [anon_sym_int] = ACTIONS(1647),
    [anon_sym_interval] = ACTIONS(1647),
    [anon_sym_list] = ACTIONS(1647),
    [anon_sym_pattern] = ACTIONS(1647),
    [anon_sym_port] = ACTIONS(1647),
    [anon_sym_string] = ACTIONS(1647),
    [anon_sym_subnet] = ACTIONS(1647),
    [anon_sym_time] = ACTIONS(1647),
    [anon_sym_opaque] = ACTIONS(1647),
    [anon_sym_set] = ACTIONS(1647),
    [anon_sym_table] = ACTIONS(1647),
    [anon_sym_union] = ACTIONS(1647),
    [anon_sym_vector] = ACTIONS(1647),
    [anon_sym_DOLLAR] = ACTIONS(1645),
    [anon_sym_PIPE] = ACTIONS(1645),
    [anon_sym_PLUS_PLUS] = ACTIONS(1645),
    [anon_sym_DASH_DASH] = ACTIONS(1645),
    [anon_sym_BANG] = ACTIONS(1645),
    [anon_sym_TILDE] = ACTIONS(1645),
    [anon_sym_DASH] = ACTIONS(1647),
    [anon_sym_PLUS] = ACTIONS(1647),
    [anon_sym_copy] = ACTIONS(1647),
    [anon_sym_schedule] = ACTIONS(1647),
    [anon_sym_T] = ACTIONS(1647),
    [anon_sym_F] = ACTIONS(1647),
    [anon_sym_ATdeprecated] = ACTIONS(1645),
    [anon_sym_ATload] = ACTIONS(1647),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1645),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1645),
    [anon_sym_ATunload] = ACTIONS(1645),
    [anon_sym_ATprefixes] = ACTIONS(1645),
    [anon_sym_ATif] = ACTIONS(1647),
    [anon_sym_ATifdef] = ACTIONS(1645),
    [anon_sym_ATifndef] = ACTIONS(1645),
    [anon_sym_ATendif] = ACTIONS(1645),
    [anon_sym_ATelse] = ACTIONS(1645),
    [anon_sym_ATpragma] = ACTIONS(1645),
    [anon_sym_ATDIR] = ACTIONS(1645),
    [anon_sym_ATFILENAME] = ACTIONS(1645),
    [sym_id] = ACTIONS(1647),
    [sym_pattern] = ACTIONS(1645),
    [sym_ipv4] = ACTIONS(1647),
    [sym_ipv6] = ACTIONS(1645),
    [sym_port] = ACTIONS(1645),
    [sym_integer] = ACTIONS(1647),
    [sym_floatp] = ACTIONS(1647),
    [sym_hex] = ACTIONS(1647),
    [sym_hostname] = ACTIONS(1647),
    [aux_sym_string_token1] = ACTIONS(1645),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(333)] = {
    [ts_builtin_sym_end] = ACTIONS(1633),
    [anon_sym_module] = ACTIONS(1635),
    [anon_sym_SEMI] = ACTIONS(1633),
    [anon_sym_export] = ACTIONS(1635),
    [anon_sym_LBRACE] = ACTIONS(1633),
    [anon_sym_global] = ACTIONS(1635),
    [anon_sym_option] = ACTIONS(1635),
    [anon_sym_const] = ACTIONS(1635),
    [anon_sym_redef] = ACTIONS(1635),
    [anon_sym_enum] = ACTIONS(1635),
    [anon_sym_record] = ACTIONS(1635),
    [anon_sym_type] = ACTIONS(1635),
    [anon_sym_print] = ACTIONS(1635),
    [anon_sym_event] = ACTIONS(1635),
    [anon_sym_if] = ACTIONS(1635),
    [anon_sym_LPAREN] = ACTIONS(1633),
    [anon_sym_switch] = ACTIONS(1635),
    [anon_sym_for] = ACTIONS(1635),
    [anon_sym_LBRACK] = ACTIONS(1635),
    [anon_sym_while] = ACTIONS(1635),
    [anon_sym_next] = ACTIONS(1635),
    [anon_sym_break] = ACTIONS(1635),
    [anon_sym_fallthrough] = ACTIONS(1635),
    [anon_sym_return] = ACTIONS(1635),
    [anon_sym_add] = ACTIONS(1635),
    [anon_sym_delete] = ACTIONS(1635),
    [anon_sym_local] = ACTIONS(1635),
    [anon_sym_when] = ACTIONS(1635),
    [anon_sym_assert] = ACTIONS(1635),
    [anon_sym_function] = ACTIONS(1635),
    [anon_sym_hook] = ACTIONS(1635),
    [anon_sym_addr] = ACTIONS(1635),
    [anon_sym_any] = ACTIONS(1635),
    [anon_sym_bool] = ACTIONS(1635),
    [anon_sym_count] = ACTIONS(1635),
    [anon_sym_double] = ACTIONS(1635),
    [anon_sym_file] = ACTIONS(1635),
    [anon_sym_int] = ACTIONS(1635),
    [anon_sym_interval] = ACTIONS(1635),
    [anon_sym_list] = ACTIONS(1635),
    [anon_sym_pattern] = ACTIONS(1635),
    [anon_sym_port] = ACTIONS(1635),
    [anon_sym_string] = ACTIONS(1635),
    [anon_sym_subnet] = ACTIONS(1635),
    [anon_sym_time] = ACTIONS(1635),
    [anon_sym_opaque] = ACTIONS(1635),
    [anon_sym_set] = ACTIONS(1635),
    [anon_sym_table] = ACTIONS(1635),
    [anon_sym_union] = ACTIONS(1635),
    [anon_sym_vector] = ACTIONS(1635),
    [anon_sym_DOLLAR] = ACTIONS(1633),
    [anon_sym_PIPE] = ACTIONS(1633),
    [anon_sym_PLUS_PLUS] = ACTIONS(1633),
    [anon_sym_DASH_DASH] = ACTIONS(1633),
    [anon_sym_BANG] = ACTIONS(1633),
    [anon_sym_TILDE] = ACTIONS(1633),
    [anon_sym_DASH] = ACTIONS(1635),
    [anon_sym_PLUS] = ACTIONS(1635),
    [anon_sym_copy] = ACTIONS(1635),
    [anon_sym_schedule] = ACTIONS(1635),
    [anon_sym_T] = ACTIONS(1635),
    [anon_sym_F] = ACTIONS(1635),
    [anon_sym_ATdeprecated] = ACTIONS(1633),
    [anon_sym_ATload] = ACTIONS(1635),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1633),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1633),
    [anon_sym_ATunload] = ACTIONS(1633),
    [anon_sym_ATprefixes] = ACTIONS(1633),
    [anon_sym_ATif] = ACTIONS(1635),
    [anon_sym_ATifdef] = ACTIONS(1633),
    [anon_sym_ATifndef] = ACTIONS(1633),
    [anon_sym_ATendif] = ACTIONS(1633),
    [anon_sym_ATelse] = ACTIONS(1633),
    [anon_sym_ATpragma] = ACTIONS(1633),
    [anon_sym_ATDIR] = ACTIONS(1633),
    [anon_sym_ATFILENAME] = ACTIONS(1633),
    [sym_id] = ACTIONS(1635),
    [sym_pattern] = ACTIONS(1633),
    [sym_ipv4] = ACTIONS(1635),
    [sym_ipv6] = ACTIONS(1633),
    [sym_port] = ACTIONS(1633),
    [sym_integer] = ACTIONS(1635),
    [sym_floatp] = ACTIONS(1635),
    [sym_hex] = ACTIONS(1635),
    [sym_hostname] = ACTIONS(1635),
    [aux_sym_string_token1] = ACTIONS(1633),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(334)] = {
    [ts_builtin_sym_end] = ACTIONS(1649),
    [anon_sym_module] = ACTIONS(1651),
    [anon_sym_SEMI] = ACTIONS(1649),
    [anon_sym_export] = ACTIONS(1651),
    [anon_sym_LBRACE] = ACTIONS(1649),
    [anon_sym_global] = ACTIONS(1651),
    [anon_sym_option] = ACTIONS(1651),
    [anon_sym_const] = ACTIONS(1651),
    [anon_sym_redef] = ACTIONS(1651),
    [anon_sym_enum] = ACTIONS(1651),
    [anon_sym_record] = ACTIONS(1651),
    [anon_sym_type] = ACTIONS(1651),
    [anon_sym_print] = ACTIONS(1651),
    [anon_sym_event] = ACTIONS(1651),
    [anon_sym_if] = ACTIONS(1651),
    [anon_sym_LPAREN] = ACTIONS(1649),
    [anon_sym_switch] = ACTIONS(1651),
    [anon_sym_for] = ACTIONS(1651),
    [anon_sym_LBRACK] = ACTIONS(1651),
    [anon_sym_while] = ACTIONS(1651),
    [anon_sym_next] = ACTIONS(1651),
    [anon_sym_break] = ACTIONS(1651),
    [anon_sym_fallthrough] = ACTIONS(1651),
    [anon_sym_return] = ACTIONS(1651),
    [anon_sym_add] = ACTIONS(1651),
    [anon_sym_delete] = ACTIONS(1651),
    [anon_sym_local] = ACTIONS(1651),
    [anon_sym_when] = ACTIONS(1651),
    [anon_sym_assert] = ACTIONS(1651),
    [anon_sym_function] = ACTIONS(1651),
    [anon_sym_hook] = ACTIONS(1651),
    [anon_sym_addr] = ACTIONS(1651),
    [anon_sym_any] = ACTIONS(1651),
    [anon_sym_bool] = ACTIONS(1651),
    [anon_sym_count] = ACTIONS(1651),
    [anon_sym_double] = ACTIONS(1651),
    [anon_sym_file] = ACTIONS(1651),
    [anon_sym_int] = ACTIONS(1651),
    [anon_sym_interval] = ACTIONS(1651),
    [anon_sym_list] = ACTIONS(1651),
    [anon_sym_pattern] = ACTIONS(1651),
    [anon_sym_port] = ACTIONS(1651),
    [anon_sym_string] = ACTIONS(1651),
    [anon_sym_subnet] = ACTIONS(1651),
    [anon_sym_time] = ACTIONS(1651),
    [anon_sym_opaque] = ACTIONS(1651),
    [anon_sym_set] = ACTIONS(1651),
    [anon_sym_table] = ACTIONS(1651),
    [anon_sym_union] = ACTIONS(1651),
    [anon_sym_vector] = ACTIONS(1651),
    [anon_sym_DOLLAR] = ACTIONS(1649),
    [anon_sym_PIPE] = ACTIONS(1649),
    [anon_sym_PLUS_PLUS] = ACTIONS(1649),
    [anon_sym_DASH_DASH] = ACTIONS(1649),
    [anon_sym_BANG] = ACTIONS(1649),
    [anon_sym_TILDE] = ACTIONS(1649),
    [anon_sym_DASH] = ACTIONS(1651),
    [anon_sym_PLUS] = ACTIONS(1651),
    [anon_sym_copy] = ACTIONS(1651),
    [anon_sym_schedule] = ACTIONS(1651),
    [anon_sym_T] = ACTIONS(1651),
    [anon_sym_F] = ACTIONS(1651),
    [anon_sym_ATdeprecated] = ACTIONS(1649),
    [anon_sym_ATload] = ACTIONS(1651),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1649),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1649),
    [anon_sym_ATunload] = ACTIONS(1649),
    [anon_sym_ATprefixes] = ACTIONS(1649),
    [anon_sym_ATif] = ACTIONS(1651),
    [anon_sym_ATifdef] = ACTIONS(1649),
    [anon_sym_ATifndef] = ACTIONS(1649),
    [anon_sym_ATendif] = ACTIONS(1649),
    [anon_sym_ATelse] = ACTIONS(1649),
    [anon_sym_ATpragma] = ACTIONS(1649),
    [anon_sym_ATDIR] = ACTIONS(1649),
    [anon_sym_ATFILENAME] = ACTIONS(1649),
    [sym_id] = ACTIONS(1651),
    [sym_pattern] = ACTIONS(1649),
    [sym_ipv4] = ACTIONS(1651),
    [sym_ipv6] = ACTIONS(1649),
    [sym_port] = ACTIONS(1649),
    [sym_integer] = ACTIONS(1651),
    [sym_floatp] = ACTIONS(1651),
    [sym_hex] = ACTIONS(1651),
    [sym_hostname] = ACTIONS(1651),
    [aux_sym_string_token1] = ACTIONS(1649),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(335)] = {
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_else] = ACTIONS(141),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_timeout] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_case] = ACTIONS(141),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(336)] = {
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_RBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_else] = ACTIONS(145),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_timeout] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_case] = ACTIONS(145),
    [anon_sym_default] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(337)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1307),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_COLON] = ACTIONS(129),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(129),
    [anon_sym_LBRACK] = ACTIONS(129),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(129),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(129),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(129),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(338)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1653),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_case] = ACTIONS(1501),
    [anon_sym_default] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(339)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1655),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_case] = ACTIONS(1495),
    [anon_sym_default] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(340)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1661),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(341)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1667),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(342)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1669),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(343)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1675),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(344)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_case] = ACTIONS(1679),
    [anon_sym_default] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(345)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_case] = ACTIONS(1679),
    [anon_sym_default] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(346)] = {
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_case] = ACTIONS(153),
    [anon_sym_default] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(347)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1681),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_case] = ACTIONS(1501),
    [anon_sym_default] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(348)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_case] = ACTIONS(1685),
    [anon_sym_default] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(349)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1687),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_case] = ACTIONS(1495),
    [anon_sym_default] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(350)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_case] = ACTIONS(1685),
    [anon_sym_default] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(351)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_case] = ACTIONS(1691),
    [anon_sym_default] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(352)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_case] = ACTIONS(1691),
    [anon_sym_default] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(353)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(354)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(355)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(356)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(357)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(358)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(359)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(360)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_case] = ACTIONS(1695),
    [anon_sym_default] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(361)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_case] = ACTIONS(1695),
    [anon_sym_default] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(362)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(1699),
    [anon_sym_default] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(363)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(1699),
    [anon_sym_default] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(364)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_case] = ACTIONS(1703),
    [anon_sym_default] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(365)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_case] = ACTIONS(1703),
    [anon_sym_default] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(366)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_case] = ACTIONS(1707),
    [anon_sym_default] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(367)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_case] = ACTIONS(1707),
    [anon_sym_default] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(368)] = {
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_else] = ACTIONS(141),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_case] = ACTIONS(141),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(369)] = {
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_RBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_else] = ACTIONS(145),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_case] = ACTIONS(145),
    [anon_sym_default] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(370)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1709),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_case] = ACTIONS(1501),
    [anon_sym_default] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(371)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1711),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_case] = ACTIONS(1495),
    [anon_sym_default] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(372)] = {
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_RBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_else] = ACTIONS(1531),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_timeout] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_case] = ACTIONS(1531),
    [anon_sym_default] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(373)] = {
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_timeout] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_case] = ACTIONS(141),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(374)] = {
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_RBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_timeout] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_case] = ACTIONS(145),
    [anon_sym_default] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(375)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_case] = ACTIONS(1501),
    [anon_sym_default] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(376)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_case] = ACTIONS(1495),
    [anon_sym_default] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(377)] = {
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_RBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_else] = ACTIONS(1627),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_timeout] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_case] = ACTIONS(1627),
    [anon_sym_default] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(378)] = {
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_RBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_else] = ACTIONS(1511),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_timeout] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_case] = ACTIONS(1511),
    [anon_sym_default] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(379)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1713),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(380)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1715),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(381)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1717),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(382)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1719),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(383)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_case] = ACTIONS(1691),
    [anon_sym_default] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(384)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_case] = ACTIONS(1691),
    [anon_sym_default] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(385)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_case] = ACTIONS(1691),
    [anon_sym_default] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(386)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(387)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(388)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(389)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(390)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(391)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(392)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(393)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_case] = ACTIONS(1695),
    [anon_sym_default] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(394)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_case] = ACTIONS(1695),
    [anon_sym_default] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(395)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(1699),
    [anon_sym_default] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(396)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(1699),
    [anon_sym_default] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(397)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_case] = ACTIONS(1703),
    [anon_sym_default] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(398)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_case] = ACTIONS(1703),
    [anon_sym_default] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(399)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_case] = ACTIONS(1707),
    [anon_sym_default] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(400)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_case] = ACTIONS(1707),
    [anon_sym_default] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(401)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1721),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_case] = ACTIONS(1495),
    [anon_sym_default] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(402)] = {
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_RBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_else] = ACTIONS(1531),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_case] = ACTIONS(1531),
    [anon_sym_default] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(403)] = {
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_else] = ACTIONS(141),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_timeout] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(404)] = {
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_RBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_else] = ACTIONS(145),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_timeout] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(405)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1723),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(406)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1725),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(407)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1727),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_case] = ACTIONS(1501),
    [anon_sym_default] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(408)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_case] = ACTIONS(1501),
    [anon_sym_default] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(409)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_case] = ACTIONS(1679),
    [anon_sym_default] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(410)] = {
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_case] = ACTIONS(141),
    [anon_sym_default] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(411)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_case] = ACTIONS(1495),
    [anon_sym_default] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(412)] = {
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_RBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_else] = ACTIONS(1627),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_case] = ACTIONS(1627),
    [anon_sym_default] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(413)] = {
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_RBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_case] = ACTIONS(145),
    [anon_sym_default] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(414)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_case] = ACTIONS(1679),
    [anon_sym_default] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(415)] = {
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_RBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_else] = ACTIONS(1511),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_case] = ACTIONS(1511),
    [anon_sym_default] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(416)] = {
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_case] = ACTIONS(153),
    [anon_sym_default] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(417)] = {
    [ts_builtin_sym_end] = ACTIONS(1499),
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1729),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(418)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_case] = ACTIONS(1685),
    [anon_sym_default] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(419)] = {
    [ts_builtin_sym_end] = ACTIONS(1493),
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1731),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(420)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_case] = ACTIONS(1685),
    [anon_sym_default] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(421)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_case] = ACTIONS(1691),
    [anon_sym_default] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(422)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1733),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(423)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_case] = ACTIONS(1685),
    [anon_sym_default] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(424)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(425)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(426)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(427)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(428)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(429)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(430)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1735),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(431)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_case] = ACTIONS(1695),
    [anon_sym_default] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(432)] = {
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_RBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_timeout] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_case] = ACTIONS(1531),
    [anon_sym_default] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(433)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_case] = ACTIONS(1695),
    [anon_sym_default] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(434)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(1699),
    [anon_sym_default] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(435)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(1699),
    [anon_sym_default] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(436)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_case] = ACTIONS(1501),
    [anon_sym_default] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(437)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_case] = ACTIONS(1703),
    [anon_sym_default] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(438)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_case] = ACTIONS(1495),
    [anon_sym_default] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(439)] = {
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_RBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_timeout] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_case] = ACTIONS(1627),
    [anon_sym_default] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(440)] = {
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_RBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_timeout] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_case] = ACTIONS(1511),
    [anon_sym_default] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(441)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_case] = ACTIONS(1703),
    [anon_sym_default] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(442)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_case] = ACTIONS(1707),
    [anon_sym_default] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(443)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_case] = ACTIONS(1707),
    [anon_sym_default] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(444)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_case] = ACTIONS(1679),
    [anon_sym_default] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(445)] = {
    [ts_builtin_sym_end] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_else] = ACTIONS(141),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_timeout] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(446)] = {
    [ts_builtin_sym_end] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_else] = ACTIONS(145),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_timeout] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(447)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_case] = ACTIONS(1679),
    [anon_sym_default] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(448)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1737),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(449)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1739),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(450)] = {
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_case] = ACTIONS(153),
    [anon_sym_default] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(451)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1741),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(452)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1743),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(453)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1745),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(454)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1747),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(455)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_case] = ACTIONS(1685),
    [anon_sym_default] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(456)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(457)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(458)] = {
    [ts_builtin_sym_end] = ACTIONS(1701),
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(459)] = {
    [ts_builtin_sym_end] = ACTIONS(1701),
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(460)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(461)] = {
    [ts_builtin_sym_end] = ACTIONS(1705),
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(462)] = {
    [ts_builtin_sym_end] = ACTIONS(1705),
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(463)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(464)] = {
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_RBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_else] = ACTIONS(1627),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_timeout] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(465)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(466)] = {
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_RBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_case] = ACTIONS(1531),
    [anon_sym_default] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(467)] = {
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_RBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_else] = ACTIONS(1511),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_timeout] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(468)] = {
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_timeout] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(469)] = {
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_RBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_timeout] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(470)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(471)] = {
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(472)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(473)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_case] = ACTIONS(1501),
    [anon_sym_default] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(474)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(475)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_case] = ACTIONS(1695),
    [anon_sym_default] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(476)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_case] = ACTIONS(1495),
    [anon_sym_default] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(477)] = {
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_RBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_case] = ACTIONS(1627),
    [anon_sym_default] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(478)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(479)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(480)] = {
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_RBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_case] = ACTIONS(1511),
    [anon_sym_default] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(481)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(482)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(483)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(484)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1749),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(485)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(486)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(487)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(488)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(489)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(490)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_case] = ACTIONS(1695),
    [anon_sym_default] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(491)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(492)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(1699),
    [anon_sym_default] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(493)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(494)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(495)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(496)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(497)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_case] = ACTIONS(1699),
    [anon_sym_default] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(498)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(499)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(500)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(501)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_case] = ACTIONS(1703),
    [anon_sym_default] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(502)] = {
    [ts_builtin_sym_end] = ACTIONS(1529),
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_else] = ACTIONS(1531),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_timeout] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(503)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_case] = ACTIONS(1703),
    [anon_sym_default] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(504)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_case] = ACTIONS(1707),
    [anon_sym_default] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(505)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_case] = ACTIONS(1707),
    [anon_sym_default] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(506)] = {
    [ts_builtin_sym_end] = ACTIONS(1677),
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(507)] = {
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_else] = ACTIONS(141),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(508)] = {
    [ts_builtin_sym_end] = ACTIONS(1499),
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(509)] = {
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_RBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_else] = ACTIONS(145),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(510)] = {
    [ts_builtin_sym_end] = ACTIONS(1677),
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(511)] = {
    [ts_builtin_sym_end] = ACTIONS(1493),
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(512)] = {
    [ts_builtin_sym_end] = ACTIONS(1625),
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_else] = ACTIONS(1627),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_timeout] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(513)] = {
    [ts_builtin_sym_end] = ACTIONS(151),
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(514)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1751),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(515)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1753),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(516)] = {
    [ts_builtin_sym_end] = ACTIONS(1509),
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_else] = ACTIONS(1511),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_timeout] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(517)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(518)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1755),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(519)] = {
    [ts_builtin_sym_end] = ACTIONS(1683),
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(520)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1757),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(521)] = {
    [ts_builtin_sym_end] = ACTIONS(1689),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(522)] = {
    [ts_builtin_sym_end] = ACTIONS(1689),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(523)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(524)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(525)] = {
    [ts_builtin_sym_end] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_else] = ACTIONS(145),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(526)] = {
    [ts_builtin_sym_end] = ACTIONS(1499),
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1759),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(527)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_case] = ACTIONS(1679),
    [anon_sym_default] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(528)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(529)] = {
    [ts_builtin_sym_end] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_timeout] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(530)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(531)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(532)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(533)] = {
    [ts_builtin_sym_end] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_timeout] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(534)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(535)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_case] = ACTIONS(1679),
    [anon_sym_default] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(536)] = {
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_case] = ACTIONS(153),
    [anon_sym_default] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(537)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1761),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(538)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1763),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(539)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1765),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(540)] = {
    [ts_builtin_sym_end] = ACTIONS(1493),
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1767),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(541)] = {
    [ts_builtin_sym_end] = ACTIONS(1693),
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(542)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_case] = ACTIONS(1685),
    [anon_sym_default] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(543)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1769),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(544)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_case] = ACTIONS(1685),
    [anon_sym_default] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(545)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_case] = ACTIONS(1691),
    [anon_sym_default] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(546)] = {
    [ts_builtin_sym_end] = ACTIONS(1499),
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1771),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(547)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_case] = ACTIONS(1691),
    [anon_sym_default] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(548)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1773),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(549)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_case] = ACTIONS(1665),
    [anon_sym_default] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(550)] = {
    [ts_builtin_sym_end] = ACTIONS(1493),
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1775),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(551)] = {
    [ts_builtin_sym_end] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_else] = ACTIONS(141),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(552)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_case] = ACTIONS(1659),
    [anon_sym_default] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(553)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1777),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(554)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1779),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(555)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1781),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(556)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1783),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(557)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1785),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(558)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1787),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(559)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1789),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(560)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1791),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(561)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1793),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(562)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1795),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(563)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(564)] = {
    [ts_builtin_sym_end] = ACTIONS(1693),
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(565)] = {
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_RBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_else] = ACTIONS(1531),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_timeout] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(566)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_case] = ACTIONS(1673),
    [anon_sym_default] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(567)] = {
    [ts_builtin_sym_end] = ACTIONS(1697),
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(568)] = {
    [ts_builtin_sym_end] = ACTIONS(1697),
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(569)] = {
    [ts_builtin_sym_end] = ACTIONS(1683),
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(570)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(571)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(572)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(573)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(574)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(575)] = {
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_RBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_timeout] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(576)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(577)] = {
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_RBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_timeout] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(578)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(579)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(580)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(581)] = {
    [ts_builtin_sym_end] = ACTIONS(1529),
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_timeout] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(582)] = {
    [ts_builtin_sym_end] = ACTIONS(1693),
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(583)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(584)] = {
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(585)] = {
    [ts_builtin_sym_end] = ACTIONS(1499),
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_timeout] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(586)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(587)] = {
    [ts_builtin_sym_end] = ACTIONS(1693),
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(588)] = {
    [ts_builtin_sym_end] = ACTIONS(1493),
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_timeout] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(589)] = {
    [ts_builtin_sym_end] = ACTIONS(1625),
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_timeout] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(590)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(591)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(592)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1797),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(593)] = {
    [ts_builtin_sym_end] = ACTIONS(1509),
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_timeout] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(594)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(595)] = {
    [ts_builtin_sym_end] = ACTIONS(1683),
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(596)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(597)] = {
    [ts_builtin_sym_end] = ACTIONS(1697),
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(598)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(599)] = {
    [ts_builtin_sym_end] = ACTIONS(1697),
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(600)] = {
    [ts_builtin_sym_end] = ACTIONS(1701),
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(601)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(602)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(603)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(604)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(605)] = {
    [ts_builtin_sym_end] = ACTIONS(1701),
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(606)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(607)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1799),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(608)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(609)] = {
    [ts_builtin_sym_end] = ACTIONS(1705),
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(610)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_timeout] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(611)] = {
    [ts_builtin_sym_end] = ACTIONS(1705),
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(612)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(613)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_timeout] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(614)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(615)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(616)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_timeout] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(617)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(618)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_timeout] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(619)] = {
    [ts_builtin_sym_end] = ACTIONS(1529),
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_else] = ACTIONS(1531),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(620)] = {
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_RBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_else] = ACTIONS(1531),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(621)] = {
    [ts_builtin_sym_end] = ACTIONS(139),
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(622)] = {
    [ts_builtin_sym_end] = ACTIONS(143),
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(623)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(624)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(625)] = {
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(626)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(627)] = {
    [ts_builtin_sym_end] = ACTIONS(1499),
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_else] = ACTIONS(1501),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(628)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(629)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(630)] = {
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_RBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_else] = ACTIONS(1627),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(631)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(632)] = {
    [ts_builtin_sym_end] = ACTIONS(1493),
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_else] = ACTIONS(1495),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(633)] = {
    [ts_builtin_sym_end] = ACTIONS(1625),
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_else] = ACTIONS(1627),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(634)] = {
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_RBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_else] = ACTIONS(1511),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(635)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1801),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(636)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(637)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1803),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(638)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(639)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1805),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(640)] = {
    [ts_builtin_sym_end] = ACTIONS(1683),
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_timeout] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(641)] = {
    [ts_builtin_sym_end] = ACTIONS(1509),
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_else] = ACTIONS(1511),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(642)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(643)] = {
    [ts_builtin_sym_end] = ACTIONS(1689),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(644)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1807),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(645)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(646)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1809),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(647)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1811),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(648)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(649)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(650)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1813),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(651)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1815),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(652)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(653)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1817),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(654)] = {
    [ts_builtin_sym_end] = ACTIONS(151),
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_timeout] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(655)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(656)] = {
    [ts_builtin_sym_end] = ACTIONS(1677),
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(657)] = {
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_const] = ACTIONS(141),
    [anon_sym_enum] = ACTIONS(141),
    [anon_sym_record] = ACTIONS(141),
    [anon_sym_print] = ACTIONS(141),
    [anon_sym_event] = ACTIONS(141),
    [anon_sym_if] = ACTIONS(141),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_switch] = ACTIONS(141),
    [anon_sym_for] = ACTIONS(141),
    [anon_sym_LBRACK] = ACTIONS(141),
    [anon_sym_while] = ACTIONS(141),
    [anon_sym_next] = ACTIONS(141),
    [anon_sym_break] = ACTIONS(141),
    [anon_sym_fallthrough] = ACTIONS(141),
    [anon_sym_return] = ACTIONS(141),
    [anon_sym_add] = ACTIONS(141),
    [anon_sym_delete] = ACTIONS(141),
    [anon_sym_local] = ACTIONS(141),
    [anon_sym_when] = ACTIONS(141),
    [anon_sym_assert] = ACTIONS(141),
    [anon_sym_function] = ACTIONS(141),
    [anon_sym_hook] = ACTIONS(141),
    [anon_sym_addr] = ACTIONS(141),
    [anon_sym_any] = ACTIONS(141),
    [anon_sym_bool] = ACTIONS(141),
    [anon_sym_count] = ACTIONS(141),
    [anon_sym_double] = ACTIONS(141),
    [anon_sym_file] = ACTIONS(141),
    [anon_sym_int] = ACTIONS(141),
    [anon_sym_interval] = ACTIONS(141),
    [anon_sym_list] = ACTIONS(141),
    [anon_sym_pattern] = ACTIONS(141),
    [anon_sym_port] = ACTIONS(141),
    [anon_sym_string] = ACTIONS(141),
    [anon_sym_subnet] = ACTIONS(141),
    [anon_sym_time] = ACTIONS(141),
    [anon_sym_opaque] = ACTIONS(141),
    [anon_sym_set] = ACTIONS(141),
    [anon_sym_table] = ACTIONS(141),
    [anon_sym_union] = ACTIONS(141),
    [anon_sym_vector] = ACTIONS(141),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(139),
    [anon_sym_PLUS_PLUS] = ACTIONS(139),
    [anon_sym_DASH_DASH] = ACTIONS(139),
    [anon_sym_BANG] = ACTIONS(139),
    [anon_sym_TILDE] = ACTIONS(139),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_copy] = ACTIONS(141),
    [anon_sym_schedule] = ACTIONS(141),
    [anon_sym_T] = ACTIONS(141),
    [anon_sym_F] = ACTIONS(141),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [anon_sym_ATDIR] = ACTIONS(139),
    [anon_sym_ATFILENAME] = ACTIONS(139),
    [sym_id] = ACTIONS(141),
    [sym_pattern] = ACTIONS(139),
    [sym_ipv4] = ACTIONS(141),
    [sym_ipv6] = ACTIONS(139),
    [sym_port] = ACTIONS(139),
    [sym_integer] = ACTIONS(141),
    [sym_floatp] = ACTIONS(141),
    [sym_hex] = ACTIONS(141),
    [sym_hostname] = ACTIONS(141),
    [aux_sym_string_token1] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(658)] = {
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_RBRACE] = ACTIONS(143),
    [anon_sym_const] = ACTIONS(145),
    [anon_sym_enum] = ACTIONS(145),
    [anon_sym_record] = ACTIONS(145),
    [anon_sym_print] = ACTIONS(145),
    [anon_sym_event] = ACTIONS(145),
    [anon_sym_if] = ACTIONS(145),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_switch] = ACTIONS(145),
    [anon_sym_for] = ACTIONS(145),
    [anon_sym_LBRACK] = ACTIONS(145),
    [anon_sym_while] = ACTIONS(145),
    [anon_sym_next] = ACTIONS(145),
    [anon_sym_break] = ACTIONS(145),
    [anon_sym_fallthrough] = ACTIONS(145),
    [anon_sym_return] = ACTIONS(145),
    [anon_sym_add] = ACTIONS(145),
    [anon_sym_delete] = ACTIONS(145),
    [anon_sym_local] = ACTIONS(145),
    [anon_sym_when] = ACTIONS(145),
    [anon_sym_assert] = ACTIONS(145),
    [anon_sym_function] = ACTIONS(145),
    [anon_sym_hook] = ACTIONS(145),
    [anon_sym_addr] = ACTIONS(145),
    [anon_sym_any] = ACTIONS(145),
    [anon_sym_bool] = ACTIONS(145),
    [anon_sym_count] = ACTIONS(145),
    [anon_sym_double] = ACTIONS(145),
    [anon_sym_file] = ACTIONS(145),
    [anon_sym_int] = ACTIONS(145),
    [anon_sym_interval] = ACTIONS(145),
    [anon_sym_list] = ACTIONS(145),
    [anon_sym_pattern] = ACTIONS(145),
    [anon_sym_port] = ACTIONS(145),
    [anon_sym_string] = ACTIONS(145),
    [anon_sym_subnet] = ACTIONS(145),
    [anon_sym_time] = ACTIONS(145),
    [anon_sym_opaque] = ACTIONS(145),
    [anon_sym_set] = ACTIONS(145),
    [anon_sym_table] = ACTIONS(145),
    [anon_sym_union] = ACTIONS(145),
    [anon_sym_vector] = ACTIONS(145),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(143),
    [anon_sym_PLUS_PLUS] = ACTIONS(143),
    [anon_sym_DASH_DASH] = ACTIONS(143),
    [anon_sym_BANG] = ACTIONS(143),
    [anon_sym_TILDE] = ACTIONS(143),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_copy] = ACTIONS(145),
    [anon_sym_schedule] = ACTIONS(145),
    [anon_sym_T] = ACTIONS(145),
    [anon_sym_F] = ACTIONS(145),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [anon_sym_ATDIR] = ACTIONS(143),
    [anon_sym_ATFILENAME] = ACTIONS(143),
    [sym_id] = ACTIONS(145),
    [sym_pattern] = ACTIONS(143),
    [sym_ipv4] = ACTIONS(145),
    [sym_ipv6] = ACTIONS(143),
    [sym_port] = ACTIONS(143),
    [sym_integer] = ACTIONS(145),
    [sym_floatp] = ACTIONS(145),
    [sym_hex] = ACTIONS(145),
    [sym_hostname] = ACTIONS(145),
    [aux_sym_string_token1] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(659)] = {
    [ts_builtin_sym_end] = ACTIONS(1677),
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_else] = ACTIONS(1679),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(660)] = {
    [ts_builtin_sym_end] = ACTIONS(151),
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_else] = ACTIONS(153),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(661)] = {
    [ts_builtin_sym_end] = ACTIONS(1499),
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_RPAREN] = ACTIONS(1819),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(662)] = {
    [ts_builtin_sym_end] = ACTIONS(1683),
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(663)] = {
    [ts_builtin_sym_end] = ACTIONS(1493),
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_RPAREN] = ACTIONS(1821),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(664)] = {
    [ts_builtin_sym_end] = ACTIONS(1683),
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_else] = ACTIONS(1685),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(665)] = {
    [ts_builtin_sym_end] = ACTIONS(1689),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(666)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(667)] = {
    [ts_builtin_sym_end] = ACTIONS(1689),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(668)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(669)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(670)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(671)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1665),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(672)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(673)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_else] = ACTIONS(1659),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(674)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(675)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(676)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1823),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(677)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1825),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(678)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1827),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(679)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_timeout] = ACTIONS(1829),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(680)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_timeout] = ACTIONS(1831),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(681)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1833),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(682)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(683)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(684)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(685)] = {
    [ts_builtin_sym_end] = ACTIONS(1689),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_timeout] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(686)] = {
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_RBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_timeout] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(687)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(688)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_else] = ACTIONS(1835),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(689)] = {
    [ts_builtin_sym_end] = ACTIONS(1677),
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(690)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_timeout] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(691)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_else] = ACTIONS(1673),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(692)] = {
    [ts_builtin_sym_end] = ACTIONS(1693),
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(693)] = {
    [ts_builtin_sym_end] = ACTIONS(1693),
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_else] = ACTIONS(1695),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(694)] = {
    [ts_builtin_sym_end] = ACTIONS(1697),
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(695)] = {
    [ts_builtin_sym_end] = ACTIONS(1697),
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_else] = ACTIONS(1699),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(696)] = {
    [ts_builtin_sym_end] = ACTIONS(1701),
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(697)] = {
    [ts_builtin_sym_end] = ACTIONS(1701),
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_else] = ACTIONS(1703),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(698)] = {
    [ts_builtin_sym_end] = ACTIONS(1705),
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(699)] = {
    [ts_builtin_sym_end] = ACTIONS(1705),
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_else] = ACTIONS(1707),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(700)] = {
    [ts_builtin_sym_end] = ACTIONS(1677),
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_timeout] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(701)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_else] = ACTIONS(1691),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(702)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(703)] = {
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_RBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(704)] = {
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_RBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(705)] = {
    [ts_builtin_sym_end] = ACTIONS(1683),
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(706)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(707)] = {
    [ts_builtin_sym_end] = ACTIONS(1677),
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(708)] = {
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_RBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(709)] = {
    [ts_builtin_sym_end] = ACTIONS(1689),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(710)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(711)] = {
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_RBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(712)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(713)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(714)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(715)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(716)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(717)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(718)] = {
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_RBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(719)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(720)] = {
    [ts_builtin_sym_end] = ACTIONS(1693),
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(721)] = {
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_RBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(722)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(723)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(724)] = {
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_RBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(725)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(726)] = {
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_RBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(727)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(728)] = {
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_RBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(729)] = {
    [ts_builtin_sym_end] = ACTIONS(1529),
    [anon_sym_SEMI] = ACTIONS(1529),
    [anon_sym_LBRACE] = ACTIONS(1529),
    [anon_sym_const] = ACTIONS(1531),
    [anon_sym_enum] = ACTIONS(1531),
    [anon_sym_record] = ACTIONS(1531),
    [anon_sym_print] = ACTIONS(1531),
    [anon_sym_event] = ACTIONS(1531),
    [anon_sym_if] = ACTIONS(1531),
    [anon_sym_LPAREN] = ACTIONS(1529),
    [anon_sym_switch] = ACTIONS(1531),
    [anon_sym_for] = ACTIONS(1531),
    [anon_sym_LBRACK] = ACTIONS(1531),
    [anon_sym_while] = ACTIONS(1531),
    [anon_sym_next] = ACTIONS(1531),
    [anon_sym_break] = ACTIONS(1531),
    [anon_sym_fallthrough] = ACTIONS(1531),
    [anon_sym_return] = ACTIONS(1531),
    [anon_sym_add] = ACTIONS(1531),
    [anon_sym_delete] = ACTIONS(1531),
    [anon_sym_local] = ACTIONS(1531),
    [anon_sym_when] = ACTIONS(1531),
    [anon_sym_assert] = ACTIONS(1531),
    [anon_sym_function] = ACTIONS(1531),
    [anon_sym_hook] = ACTIONS(1531),
    [anon_sym_addr] = ACTIONS(1531),
    [anon_sym_any] = ACTIONS(1531),
    [anon_sym_bool] = ACTIONS(1531),
    [anon_sym_count] = ACTIONS(1531),
    [anon_sym_double] = ACTIONS(1531),
    [anon_sym_file] = ACTIONS(1531),
    [anon_sym_int] = ACTIONS(1531),
    [anon_sym_interval] = ACTIONS(1531),
    [anon_sym_list] = ACTIONS(1531),
    [anon_sym_pattern] = ACTIONS(1531),
    [anon_sym_port] = ACTIONS(1531),
    [anon_sym_string] = ACTIONS(1531),
    [anon_sym_subnet] = ACTIONS(1531),
    [anon_sym_time] = ACTIONS(1531),
    [anon_sym_opaque] = ACTIONS(1531),
    [anon_sym_set] = ACTIONS(1531),
    [anon_sym_table] = ACTIONS(1531),
    [anon_sym_union] = ACTIONS(1531),
    [anon_sym_vector] = ACTIONS(1531),
    [anon_sym_DOLLAR] = ACTIONS(1529),
    [anon_sym_PIPE] = ACTIONS(1529),
    [anon_sym_PLUS_PLUS] = ACTIONS(1529),
    [anon_sym_DASH_DASH] = ACTIONS(1529),
    [anon_sym_BANG] = ACTIONS(1529),
    [anon_sym_TILDE] = ACTIONS(1529),
    [anon_sym_DASH] = ACTIONS(1531),
    [anon_sym_PLUS] = ACTIONS(1531),
    [anon_sym_copy] = ACTIONS(1531),
    [anon_sym_schedule] = ACTIONS(1531),
    [anon_sym_T] = ACTIONS(1531),
    [anon_sym_F] = ACTIONS(1531),
    [anon_sym_ATdeprecated] = ACTIONS(1529),
    [anon_sym_ATload] = ACTIONS(1531),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1529),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1529),
    [anon_sym_ATunload] = ACTIONS(1529),
    [anon_sym_ATprefixes] = ACTIONS(1529),
    [anon_sym_ATif] = ACTIONS(1531),
    [anon_sym_ATifdef] = ACTIONS(1529),
    [anon_sym_ATifndef] = ACTIONS(1529),
    [anon_sym_ATendif] = ACTIONS(1529),
    [anon_sym_ATelse] = ACTIONS(1529),
    [anon_sym_ATpragma] = ACTIONS(1529),
    [anon_sym_ATDIR] = ACTIONS(1529),
    [anon_sym_ATFILENAME] = ACTIONS(1529),
    [sym_id] = ACTIONS(1531),
    [sym_pattern] = ACTIONS(1529),
    [sym_ipv4] = ACTIONS(1531),
    [sym_ipv6] = ACTIONS(1529),
    [sym_port] = ACTIONS(1529),
    [sym_integer] = ACTIONS(1531),
    [sym_floatp] = ACTIONS(1531),
    [sym_hex] = ACTIONS(1531),
    [sym_hostname] = ACTIONS(1531),
    [aux_sym_string_token1] = ACTIONS(1529),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(730)] = {
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_RBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(731)] = {
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_RBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(732)] = {
    [ts_builtin_sym_end] = ACTIONS(1705),
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(733)] = {
    [ts_builtin_sym_end] = ACTIONS(1693),
    [anon_sym_SEMI] = ACTIONS(1693),
    [anon_sym_LBRACE] = ACTIONS(1693),
    [anon_sym_const] = ACTIONS(1695),
    [anon_sym_enum] = ACTIONS(1695),
    [anon_sym_record] = ACTIONS(1695),
    [anon_sym_print] = ACTIONS(1695),
    [anon_sym_event] = ACTIONS(1695),
    [anon_sym_if] = ACTIONS(1695),
    [anon_sym_LPAREN] = ACTIONS(1693),
    [anon_sym_switch] = ACTIONS(1695),
    [anon_sym_for] = ACTIONS(1695),
    [anon_sym_LBRACK] = ACTIONS(1695),
    [anon_sym_while] = ACTIONS(1695),
    [anon_sym_next] = ACTIONS(1695),
    [anon_sym_break] = ACTIONS(1695),
    [anon_sym_fallthrough] = ACTIONS(1695),
    [anon_sym_return] = ACTIONS(1695),
    [anon_sym_add] = ACTIONS(1695),
    [anon_sym_delete] = ACTIONS(1695),
    [anon_sym_local] = ACTIONS(1695),
    [anon_sym_when] = ACTIONS(1695),
    [anon_sym_assert] = ACTIONS(1695),
    [anon_sym_function] = ACTIONS(1695),
    [anon_sym_hook] = ACTIONS(1695),
    [anon_sym_addr] = ACTIONS(1695),
    [anon_sym_any] = ACTIONS(1695),
    [anon_sym_bool] = ACTIONS(1695),
    [anon_sym_count] = ACTIONS(1695),
    [anon_sym_double] = ACTIONS(1695),
    [anon_sym_file] = ACTIONS(1695),
    [anon_sym_int] = ACTIONS(1695),
    [anon_sym_interval] = ACTIONS(1695),
    [anon_sym_list] = ACTIONS(1695),
    [anon_sym_pattern] = ACTIONS(1695),
    [anon_sym_port] = ACTIONS(1695),
    [anon_sym_string] = ACTIONS(1695),
    [anon_sym_subnet] = ACTIONS(1695),
    [anon_sym_time] = ACTIONS(1695),
    [anon_sym_opaque] = ACTIONS(1695),
    [anon_sym_set] = ACTIONS(1695),
    [anon_sym_table] = ACTIONS(1695),
    [anon_sym_union] = ACTIONS(1695),
    [anon_sym_vector] = ACTIONS(1695),
    [anon_sym_DOLLAR] = ACTIONS(1693),
    [anon_sym_PIPE] = ACTIONS(1693),
    [anon_sym_PLUS_PLUS] = ACTIONS(1693),
    [anon_sym_DASH_DASH] = ACTIONS(1693),
    [anon_sym_BANG] = ACTIONS(1693),
    [anon_sym_TILDE] = ACTIONS(1693),
    [anon_sym_DASH] = ACTIONS(1695),
    [anon_sym_PLUS] = ACTIONS(1695),
    [anon_sym_copy] = ACTIONS(1695),
    [anon_sym_schedule] = ACTIONS(1695),
    [anon_sym_T] = ACTIONS(1695),
    [anon_sym_F] = ACTIONS(1695),
    [anon_sym_ATdeprecated] = ACTIONS(1693),
    [anon_sym_ATload] = ACTIONS(1695),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1693),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1693),
    [anon_sym_ATunload] = ACTIONS(1693),
    [anon_sym_ATprefixes] = ACTIONS(1693),
    [anon_sym_ATif] = ACTIONS(1695),
    [anon_sym_ATifdef] = ACTIONS(1693),
    [anon_sym_ATifndef] = ACTIONS(1693),
    [anon_sym_ATendif] = ACTIONS(1693),
    [anon_sym_ATelse] = ACTIONS(1693),
    [anon_sym_ATpragma] = ACTIONS(1693),
    [anon_sym_ATDIR] = ACTIONS(1693),
    [anon_sym_ATFILENAME] = ACTIONS(1693),
    [sym_id] = ACTIONS(1695),
    [sym_pattern] = ACTIONS(1693),
    [sym_ipv4] = ACTIONS(1695),
    [sym_ipv6] = ACTIONS(1693),
    [sym_port] = ACTIONS(1693),
    [sym_integer] = ACTIONS(1695),
    [sym_floatp] = ACTIONS(1695),
    [sym_hex] = ACTIONS(1695),
    [sym_hostname] = ACTIONS(1695),
    [aux_sym_string_token1] = ACTIONS(1693),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(734)] = {
    [ts_builtin_sym_end] = ACTIONS(1499),
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(735)] = {
    [ts_builtin_sym_end] = ACTIONS(1683),
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(736)] = {
    [ts_builtin_sym_end] = ACTIONS(151),
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(737)] = {
    [ts_builtin_sym_end] = ACTIONS(1493),
    [anon_sym_SEMI] = ACTIONS(1493),
    [anon_sym_LBRACE] = ACTIONS(1493),
    [anon_sym_const] = ACTIONS(1495),
    [anon_sym_enum] = ACTIONS(1495),
    [anon_sym_record] = ACTIONS(1495),
    [anon_sym_print] = ACTIONS(1495),
    [anon_sym_event] = ACTIONS(1495),
    [anon_sym_if] = ACTIONS(1495),
    [anon_sym_LPAREN] = ACTIONS(1493),
    [anon_sym_switch] = ACTIONS(1495),
    [anon_sym_for] = ACTIONS(1495),
    [anon_sym_LBRACK] = ACTIONS(1495),
    [anon_sym_while] = ACTIONS(1495),
    [anon_sym_next] = ACTIONS(1495),
    [anon_sym_break] = ACTIONS(1495),
    [anon_sym_fallthrough] = ACTIONS(1495),
    [anon_sym_return] = ACTIONS(1495),
    [anon_sym_add] = ACTIONS(1495),
    [anon_sym_delete] = ACTIONS(1495),
    [anon_sym_local] = ACTIONS(1495),
    [anon_sym_when] = ACTIONS(1495),
    [anon_sym_assert] = ACTIONS(1495),
    [anon_sym_function] = ACTIONS(1495),
    [anon_sym_hook] = ACTIONS(1495),
    [anon_sym_addr] = ACTIONS(1495),
    [anon_sym_any] = ACTIONS(1495),
    [anon_sym_bool] = ACTIONS(1495),
    [anon_sym_count] = ACTIONS(1495),
    [anon_sym_double] = ACTIONS(1495),
    [anon_sym_file] = ACTIONS(1495),
    [anon_sym_int] = ACTIONS(1495),
    [anon_sym_interval] = ACTIONS(1495),
    [anon_sym_list] = ACTIONS(1495),
    [anon_sym_pattern] = ACTIONS(1495),
    [anon_sym_port] = ACTIONS(1495),
    [anon_sym_string] = ACTIONS(1495),
    [anon_sym_subnet] = ACTIONS(1495),
    [anon_sym_time] = ACTIONS(1495),
    [anon_sym_opaque] = ACTIONS(1495),
    [anon_sym_set] = ACTIONS(1495),
    [anon_sym_table] = ACTIONS(1495),
    [anon_sym_union] = ACTIONS(1495),
    [anon_sym_vector] = ACTIONS(1495),
    [anon_sym_DOLLAR] = ACTIONS(1493),
    [anon_sym_PIPE] = ACTIONS(1493),
    [anon_sym_PLUS_PLUS] = ACTIONS(1493),
    [anon_sym_DASH_DASH] = ACTIONS(1493),
    [anon_sym_BANG] = ACTIONS(1493),
    [anon_sym_TILDE] = ACTIONS(1493),
    [anon_sym_DASH] = ACTIONS(1495),
    [anon_sym_PLUS] = ACTIONS(1495),
    [anon_sym_copy] = ACTIONS(1495),
    [anon_sym_schedule] = ACTIONS(1495),
    [anon_sym_T] = ACTIONS(1495),
    [anon_sym_F] = ACTIONS(1495),
    [anon_sym_ATdeprecated] = ACTIONS(1493),
    [anon_sym_ATload] = ACTIONS(1495),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1493),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1493),
    [anon_sym_ATunload] = ACTIONS(1493),
    [anon_sym_ATprefixes] = ACTIONS(1493),
    [anon_sym_ATif] = ACTIONS(1495),
    [anon_sym_ATifdef] = ACTIONS(1493),
    [anon_sym_ATifndef] = ACTIONS(1493),
    [anon_sym_ATendif] = ACTIONS(1493),
    [anon_sym_ATelse] = ACTIONS(1493),
    [anon_sym_ATpragma] = ACTIONS(1493),
    [anon_sym_ATDIR] = ACTIONS(1493),
    [anon_sym_ATFILENAME] = ACTIONS(1493),
    [sym_id] = ACTIONS(1495),
    [sym_pattern] = ACTIONS(1493),
    [sym_ipv4] = ACTIONS(1495),
    [sym_ipv6] = ACTIONS(1493),
    [sym_port] = ACTIONS(1493),
    [sym_integer] = ACTIONS(1495),
    [sym_floatp] = ACTIONS(1495),
    [sym_hex] = ACTIONS(1495),
    [sym_hostname] = ACTIONS(1495),
    [aux_sym_string_token1] = ACTIONS(1493),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(738)] = {
    [ts_builtin_sym_end] = ACTIONS(1625),
    [anon_sym_SEMI] = ACTIONS(1625),
    [anon_sym_LBRACE] = ACTIONS(1625),
    [anon_sym_const] = ACTIONS(1627),
    [anon_sym_enum] = ACTIONS(1627),
    [anon_sym_record] = ACTIONS(1627),
    [anon_sym_print] = ACTIONS(1627),
    [anon_sym_event] = ACTIONS(1627),
    [anon_sym_if] = ACTIONS(1627),
    [anon_sym_LPAREN] = ACTIONS(1625),
    [anon_sym_switch] = ACTIONS(1627),
    [anon_sym_for] = ACTIONS(1627),
    [anon_sym_LBRACK] = ACTIONS(1627),
    [anon_sym_while] = ACTIONS(1627),
    [anon_sym_next] = ACTIONS(1627),
    [anon_sym_break] = ACTIONS(1627),
    [anon_sym_fallthrough] = ACTIONS(1627),
    [anon_sym_return] = ACTIONS(1627),
    [anon_sym_add] = ACTIONS(1627),
    [anon_sym_delete] = ACTIONS(1627),
    [anon_sym_local] = ACTIONS(1627),
    [anon_sym_when] = ACTIONS(1627),
    [anon_sym_assert] = ACTIONS(1627),
    [anon_sym_function] = ACTIONS(1627),
    [anon_sym_hook] = ACTIONS(1627),
    [anon_sym_addr] = ACTIONS(1627),
    [anon_sym_any] = ACTIONS(1627),
    [anon_sym_bool] = ACTIONS(1627),
    [anon_sym_count] = ACTIONS(1627),
    [anon_sym_double] = ACTIONS(1627),
    [anon_sym_file] = ACTIONS(1627),
    [anon_sym_int] = ACTIONS(1627),
    [anon_sym_interval] = ACTIONS(1627),
    [anon_sym_list] = ACTIONS(1627),
    [anon_sym_pattern] = ACTIONS(1627),
    [anon_sym_port] = ACTIONS(1627),
    [anon_sym_string] = ACTIONS(1627),
    [anon_sym_subnet] = ACTIONS(1627),
    [anon_sym_time] = ACTIONS(1627),
    [anon_sym_opaque] = ACTIONS(1627),
    [anon_sym_set] = ACTIONS(1627),
    [anon_sym_table] = ACTIONS(1627),
    [anon_sym_union] = ACTIONS(1627),
    [anon_sym_vector] = ACTIONS(1627),
    [anon_sym_DOLLAR] = ACTIONS(1625),
    [anon_sym_PIPE] = ACTIONS(1625),
    [anon_sym_PLUS_PLUS] = ACTIONS(1625),
    [anon_sym_DASH_DASH] = ACTIONS(1625),
    [anon_sym_BANG] = ACTIONS(1625),
    [anon_sym_TILDE] = ACTIONS(1625),
    [anon_sym_DASH] = ACTIONS(1627),
    [anon_sym_PLUS] = ACTIONS(1627),
    [anon_sym_copy] = ACTIONS(1627),
    [anon_sym_schedule] = ACTIONS(1627),
    [anon_sym_T] = ACTIONS(1627),
    [anon_sym_F] = ACTIONS(1627),
    [anon_sym_ATdeprecated] = ACTIONS(1625),
    [anon_sym_ATload] = ACTIONS(1627),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1625),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1625),
    [anon_sym_ATunload] = ACTIONS(1625),
    [anon_sym_ATprefixes] = ACTIONS(1625),
    [anon_sym_ATif] = ACTIONS(1627),
    [anon_sym_ATifdef] = ACTIONS(1625),
    [anon_sym_ATifndef] = ACTIONS(1625),
    [anon_sym_ATendif] = ACTIONS(1625),
    [anon_sym_ATelse] = ACTIONS(1625),
    [anon_sym_ATpragma] = ACTIONS(1625),
    [anon_sym_ATDIR] = ACTIONS(1625),
    [anon_sym_ATFILENAME] = ACTIONS(1625),
    [sym_id] = ACTIONS(1627),
    [sym_pattern] = ACTIONS(1625),
    [sym_ipv4] = ACTIONS(1627),
    [sym_ipv6] = ACTIONS(1625),
    [sym_port] = ACTIONS(1625),
    [sym_integer] = ACTIONS(1627),
    [sym_floatp] = ACTIONS(1627),
    [sym_hex] = ACTIONS(1627),
    [sym_hostname] = ACTIONS(1627),
    [aux_sym_string_token1] = ACTIONS(1625),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(739)] = {
    [ts_builtin_sym_end] = ACTIONS(1509),
    [anon_sym_SEMI] = ACTIONS(1509),
    [anon_sym_LBRACE] = ACTIONS(1509),
    [anon_sym_const] = ACTIONS(1511),
    [anon_sym_enum] = ACTIONS(1511),
    [anon_sym_record] = ACTIONS(1511),
    [anon_sym_print] = ACTIONS(1511),
    [anon_sym_event] = ACTIONS(1511),
    [anon_sym_if] = ACTIONS(1511),
    [anon_sym_LPAREN] = ACTIONS(1509),
    [anon_sym_switch] = ACTIONS(1511),
    [anon_sym_for] = ACTIONS(1511),
    [anon_sym_LBRACK] = ACTIONS(1511),
    [anon_sym_while] = ACTIONS(1511),
    [anon_sym_next] = ACTIONS(1511),
    [anon_sym_break] = ACTIONS(1511),
    [anon_sym_fallthrough] = ACTIONS(1511),
    [anon_sym_return] = ACTIONS(1511),
    [anon_sym_add] = ACTIONS(1511),
    [anon_sym_delete] = ACTIONS(1511),
    [anon_sym_local] = ACTIONS(1511),
    [anon_sym_when] = ACTIONS(1511),
    [anon_sym_assert] = ACTIONS(1511),
    [anon_sym_function] = ACTIONS(1511),
    [anon_sym_hook] = ACTIONS(1511),
    [anon_sym_addr] = ACTIONS(1511),
    [anon_sym_any] = ACTIONS(1511),
    [anon_sym_bool] = ACTIONS(1511),
    [anon_sym_count] = ACTIONS(1511),
    [anon_sym_double] = ACTIONS(1511),
    [anon_sym_file] = ACTIONS(1511),
    [anon_sym_int] = ACTIONS(1511),
    [anon_sym_interval] = ACTIONS(1511),
    [anon_sym_list] = ACTIONS(1511),
    [anon_sym_pattern] = ACTIONS(1511),
    [anon_sym_port] = ACTIONS(1511),
    [anon_sym_string] = ACTIONS(1511),
    [anon_sym_subnet] = ACTIONS(1511),
    [anon_sym_time] = ACTIONS(1511),
    [anon_sym_opaque] = ACTIONS(1511),
    [anon_sym_set] = ACTIONS(1511),
    [anon_sym_table] = ACTIONS(1511),
    [anon_sym_union] = ACTIONS(1511),
    [anon_sym_vector] = ACTIONS(1511),
    [anon_sym_DOLLAR] = ACTIONS(1509),
    [anon_sym_PIPE] = ACTIONS(1509),
    [anon_sym_PLUS_PLUS] = ACTIONS(1509),
    [anon_sym_DASH_DASH] = ACTIONS(1509),
    [anon_sym_BANG] = ACTIONS(1509),
    [anon_sym_TILDE] = ACTIONS(1509),
    [anon_sym_DASH] = ACTIONS(1511),
    [anon_sym_PLUS] = ACTIONS(1511),
    [anon_sym_copy] = ACTIONS(1511),
    [anon_sym_schedule] = ACTIONS(1511),
    [anon_sym_T] = ACTIONS(1511),
    [anon_sym_F] = ACTIONS(1511),
    [anon_sym_ATdeprecated] = ACTIONS(1509),
    [anon_sym_ATload] = ACTIONS(1511),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1509),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1509),
    [anon_sym_ATunload] = ACTIONS(1509),
    [anon_sym_ATprefixes] = ACTIONS(1509),
    [anon_sym_ATif] = ACTIONS(1511),
    [anon_sym_ATifdef] = ACTIONS(1509),
    [anon_sym_ATifndef] = ACTIONS(1509),
    [anon_sym_ATendif] = ACTIONS(1509),
    [anon_sym_ATelse] = ACTIONS(1509),
    [anon_sym_ATpragma] = ACTIONS(1509),
    [anon_sym_ATDIR] = ACTIONS(1509),
    [anon_sym_ATFILENAME] = ACTIONS(1509),
    [sym_id] = ACTIONS(1511),
    [sym_pattern] = ACTIONS(1509),
    [sym_ipv4] = ACTIONS(1511),
    [sym_ipv6] = ACTIONS(1509),
    [sym_port] = ACTIONS(1509),
    [sym_integer] = ACTIONS(1511),
    [sym_floatp] = ACTIONS(1511),
    [sym_hex] = ACTIONS(1511),
    [sym_hostname] = ACTIONS(1511),
    [aux_sym_string_token1] = ACTIONS(1509),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(740)] = {
    [ts_builtin_sym_end] = ACTIONS(1677),
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(741)] = {
    [ts_builtin_sym_end] = ACTIONS(1689),
    [anon_sym_SEMI] = ACTIONS(1689),
    [anon_sym_LBRACE] = ACTIONS(1689),
    [anon_sym_const] = ACTIONS(1691),
    [anon_sym_enum] = ACTIONS(1691),
    [anon_sym_record] = ACTIONS(1691),
    [anon_sym_print] = ACTIONS(1691),
    [anon_sym_event] = ACTIONS(1691),
    [anon_sym_if] = ACTIONS(1691),
    [anon_sym_LPAREN] = ACTIONS(1689),
    [anon_sym_switch] = ACTIONS(1691),
    [anon_sym_for] = ACTIONS(1691),
    [anon_sym_LBRACK] = ACTIONS(1691),
    [anon_sym_while] = ACTIONS(1691),
    [anon_sym_next] = ACTIONS(1691),
    [anon_sym_break] = ACTIONS(1691),
    [anon_sym_fallthrough] = ACTIONS(1691),
    [anon_sym_return] = ACTIONS(1691),
    [anon_sym_add] = ACTIONS(1691),
    [anon_sym_delete] = ACTIONS(1691),
    [anon_sym_local] = ACTIONS(1691),
    [anon_sym_when] = ACTIONS(1691),
    [anon_sym_assert] = ACTIONS(1691),
    [anon_sym_function] = ACTIONS(1691),
    [anon_sym_hook] = ACTIONS(1691),
    [anon_sym_addr] = ACTIONS(1691),
    [anon_sym_any] = ACTIONS(1691),
    [anon_sym_bool] = ACTIONS(1691),
    [anon_sym_count] = ACTIONS(1691),
    [anon_sym_double] = ACTIONS(1691),
    [anon_sym_file] = ACTIONS(1691),
    [anon_sym_int] = ACTIONS(1691),
    [anon_sym_interval] = ACTIONS(1691),
    [anon_sym_list] = ACTIONS(1691),
    [anon_sym_pattern] = ACTIONS(1691),
    [anon_sym_port] = ACTIONS(1691),
    [anon_sym_string] = ACTIONS(1691),
    [anon_sym_subnet] = ACTIONS(1691),
    [anon_sym_time] = ACTIONS(1691),
    [anon_sym_opaque] = ACTIONS(1691),
    [anon_sym_set] = ACTIONS(1691),
    [anon_sym_table] = ACTIONS(1691),
    [anon_sym_union] = ACTIONS(1691),
    [anon_sym_vector] = ACTIONS(1691),
    [anon_sym_DOLLAR] = ACTIONS(1689),
    [anon_sym_PIPE] = ACTIONS(1689),
    [anon_sym_PLUS_PLUS] = ACTIONS(1689),
    [anon_sym_DASH_DASH] = ACTIONS(1689),
    [anon_sym_BANG] = ACTIONS(1689),
    [anon_sym_TILDE] = ACTIONS(1689),
    [anon_sym_DASH] = ACTIONS(1691),
    [anon_sym_PLUS] = ACTIONS(1691),
    [anon_sym_copy] = ACTIONS(1691),
    [anon_sym_schedule] = ACTIONS(1691),
    [anon_sym_T] = ACTIONS(1691),
    [anon_sym_F] = ACTIONS(1691),
    [anon_sym_ATdeprecated] = ACTIONS(1689),
    [anon_sym_ATload] = ACTIONS(1691),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1689),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1689),
    [anon_sym_ATunload] = ACTIONS(1689),
    [anon_sym_ATprefixes] = ACTIONS(1689),
    [anon_sym_ATif] = ACTIONS(1691),
    [anon_sym_ATifdef] = ACTIONS(1689),
    [anon_sym_ATifndef] = ACTIONS(1689),
    [anon_sym_ATendif] = ACTIONS(1689),
    [anon_sym_ATelse] = ACTIONS(1689),
    [anon_sym_ATpragma] = ACTIONS(1689),
    [anon_sym_ATDIR] = ACTIONS(1689),
    [anon_sym_ATFILENAME] = ACTIONS(1689),
    [sym_id] = ACTIONS(1691),
    [sym_pattern] = ACTIONS(1689),
    [sym_ipv4] = ACTIONS(1691),
    [sym_ipv6] = ACTIONS(1689),
    [sym_port] = ACTIONS(1689),
    [sym_integer] = ACTIONS(1691),
    [sym_floatp] = ACTIONS(1691),
    [sym_hex] = ACTIONS(1691),
    [sym_hostname] = ACTIONS(1691),
    [aux_sym_string_token1] = ACTIONS(1689),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(742)] = {
    [ts_builtin_sym_end] = ACTIONS(1657),
    [anon_sym_SEMI] = ACTIONS(1657),
    [anon_sym_LBRACE] = ACTIONS(1657),
    [anon_sym_const] = ACTIONS(1659),
    [anon_sym_enum] = ACTIONS(1659),
    [anon_sym_record] = ACTIONS(1659),
    [anon_sym_print] = ACTIONS(1659),
    [anon_sym_event] = ACTIONS(1659),
    [anon_sym_if] = ACTIONS(1659),
    [anon_sym_LPAREN] = ACTIONS(1657),
    [anon_sym_switch] = ACTIONS(1659),
    [anon_sym_for] = ACTIONS(1659),
    [anon_sym_LBRACK] = ACTIONS(1659),
    [anon_sym_while] = ACTIONS(1659),
    [anon_sym_next] = ACTIONS(1659),
    [anon_sym_break] = ACTIONS(1659),
    [anon_sym_fallthrough] = ACTIONS(1659),
    [anon_sym_return] = ACTIONS(1659),
    [anon_sym_add] = ACTIONS(1659),
    [anon_sym_delete] = ACTIONS(1659),
    [anon_sym_local] = ACTIONS(1659),
    [anon_sym_when] = ACTIONS(1659),
    [anon_sym_assert] = ACTIONS(1659),
    [anon_sym_function] = ACTIONS(1659),
    [anon_sym_hook] = ACTIONS(1659),
    [anon_sym_addr] = ACTIONS(1659),
    [anon_sym_any] = ACTIONS(1659),
    [anon_sym_bool] = ACTIONS(1659),
    [anon_sym_count] = ACTIONS(1659),
    [anon_sym_double] = ACTIONS(1659),
    [anon_sym_file] = ACTIONS(1659),
    [anon_sym_int] = ACTIONS(1659),
    [anon_sym_interval] = ACTIONS(1659),
    [anon_sym_list] = ACTIONS(1659),
    [anon_sym_pattern] = ACTIONS(1659),
    [anon_sym_port] = ACTIONS(1659),
    [anon_sym_string] = ACTIONS(1659),
    [anon_sym_subnet] = ACTIONS(1659),
    [anon_sym_time] = ACTIONS(1659),
    [anon_sym_opaque] = ACTIONS(1659),
    [anon_sym_set] = ACTIONS(1659),
    [anon_sym_table] = ACTIONS(1659),
    [anon_sym_union] = ACTIONS(1659),
    [anon_sym_vector] = ACTIONS(1659),
    [anon_sym_DOLLAR] = ACTIONS(1657),
    [anon_sym_PIPE] = ACTIONS(1657),
    [anon_sym_PLUS_PLUS] = ACTIONS(1657),
    [anon_sym_DASH_DASH] = ACTIONS(1657),
    [anon_sym_BANG] = ACTIONS(1657),
    [anon_sym_TILDE] = ACTIONS(1657),
    [anon_sym_DASH] = ACTIONS(1659),
    [anon_sym_PLUS] = ACTIONS(1659),
    [anon_sym_copy] = ACTIONS(1659),
    [anon_sym_schedule] = ACTIONS(1659),
    [anon_sym_T] = ACTIONS(1659),
    [anon_sym_F] = ACTIONS(1659),
    [anon_sym_ATdeprecated] = ACTIONS(1657),
    [anon_sym_ATload] = ACTIONS(1659),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1657),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1657),
    [anon_sym_ATunload] = ACTIONS(1657),
    [anon_sym_ATprefixes] = ACTIONS(1657),
    [anon_sym_ATif] = ACTIONS(1659),
    [anon_sym_ATifdef] = ACTIONS(1657),
    [anon_sym_ATifndef] = ACTIONS(1657),
    [anon_sym_ATendif] = ACTIONS(1657),
    [anon_sym_ATelse] = ACTIONS(1657),
    [anon_sym_ATpragma] = ACTIONS(1657),
    [anon_sym_ATDIR] = ACTIONS(1657),
    [anon_sym_ATFILENAME] = ACTIONS(1657),
    [sym_id] = ACTIONS(1659),
    [sym_pattern] = ACTIONS(1657),
    [sym_ipv4] = ACTIONS(1659),
    [sym_ipv6] = ACTIONS(1657),
    [sym_port] = ACTIONS(1657),
    [sym_integer] = ACTIONS(1659),
    [sym_floatp] = ACTIONS(1659),
    [sym_hex] = ACTIONS(1659),
    [sym_hostname] = ACTIONS(1659),
    [aux_sym_string_token1] = ACTIONS(1657),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(743)] = {
    [ts_builtin_sym_end] = ACTIONS(1697),
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(744)] = {
    [anon_sym_SEMI] = ACTIONS(151),
    [anon_sym_LBRACE] = ACTIONS(151),
    [anon_sym_RBRACE] = ACTIONS(151),
    [anon_sym_const] = ACTIONS(153),
    [anon_sym_enum] = ACTIONS(153),
    [anon_sym_record] = ACTIONS(153),
    [anon_sym_print] = ACTIONS(153),
    [anon_sym_event] = ACTIONS(153),
    [anon_sym_if] = ACTIONS(153),
    [anon_sym_LPAREN] = ACTIONS(151),
    [anon_sym_switch] = ACTIONS(153),
    [anon_sym_for] = ACTIONS(153),
    [anon_sym_LBRACK] = ACTIONS(153),
    [anon_sym_while] = ACTIONS(153),
    [anon_sym_next] = ACTIONS(153),
    [anon_sym_break] = ACTIONS(153),
    [anon_sym_fallthrough] = ACTIONS(153),
    [anon_sym_return] = ACTIONS(153),
    [anon_sym_add] = ACTIONS(153),
    [anon_sym_delete] = ACTIONS(153),
    [anon_sym_local] = ACTIONS(153),
    [anon_sym_when] = ACTIONS(153),
    [anon_sym_assert] = ACTIONS(153),
    [anon_sym_function] = ACTIONS(153),
    [anon_sym_hook] = ACTIONS(153),
    [anon_sym_addr] = ACTIONS(153),
    [anon_sym_any] = ACTIONS(153),
    [anon_sym_bool] = ACTIONS(153),
    [anon_sym_count] = ACTIONS(153),
    [anon_sym_double] = ACTIONS(153),
    [anon_sym_file] = ACTIONS(153),
    [anon_sym_int] = ACTIONS(153),
    [anon_sym_interval] = ACTIONS(153),
    [anon_sym_list] = ACTIONS(153),
    [anon_sym_pattern] = ACTIONS(153),
    [anon_sym_port] = ACTIONS(153),
    [anon_sym_string] = ACTIONS(153),
    [anon_sym_subnet] = ACTIONS(153),
    [anon_sym_time] = ACTIONS(153),
    [anon_sym_opaque] = ACTIONS(153),
    [anon_sym_set] = ACTIONS(153),
    [anon_sym_table] = ACTIONS(153),
    [anon_sym_union] = ACTIONS(153),
    [anon_sym_vector] = ACTIONS(153),
    [anon_sym_DOLLAR] = ACTIONS(151),
    [anon_sym_PIPE] = ACTIONS(151),
    [anon_sym_PLUS_PLUS] = ACTIONS(151),
    [anon_sym_DASH_DASH] = ACTIONS(151),
    [anon_sym_BANG] = ACTIONS(151),
    [anon_sym_TILDE] = ACTIONS(151),
    [anon_sym_DASH] = ACTIONS(153),
    [anon_sym_PLUS] = ACTIONS(153),
    [anon_sym_copy] = ACTIONS(153),
    [anon_sym_schedule] = ACTIONS(153),
    [anon_sym_T] = ACTIONS(153),
    [anon_sym_F] = ACTIONS(153),
    [anon_sym_ATdeprecated] = ACTIONS(151),
    [anon_sym_ATload] = ACTIONS(153),
    [anon_sym_ATload_DASHsigs] = ACTIONS(151),
    [anon_sym_ATload_DASHplugin] = ACTIONS(151),
    [anon_sym_ATunload] = ACTIONS(151),
    [anon_sym_ATprefixes] = ACTIONS(151),
    [anon_sym_ATif] = ACTIONS(153),
    [anon_sym_ATifdef] = ACTIONS(151),
    [anon_sym_ATifndef] = ACTIONS(151),
    [anon_sym_ATendif] = ACTIONS(151),
    [anon_sym_ATelse] = ACTIONS(151),
    [anon_sym_ATpragma] = ACTIONS(151),
    [anon_sym_ATDIR] = ACTIONS(151),
    [anon_sym_ATFILENAME] = ACTIONS(151),
    [sym_id] = ACTIONS(153),
    [sym_pattern] = ACTIONS(151),
    [sym_ipv4] = ACTIONS(153),
    [sym_ipv6] = ACTIONS(151),
    [sym_port] = ACTIONS(151),
    [sym_integer] = ACTIONS(153),
    [sym_floatp] = ACTIONS(153),
    [sym_hex] = ACTIONS(153),
    [sym_hostname] = ACTIONS(153),
    [aux_sym_string_token1] = ACTIONS(151),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(745)] = {
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_RBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(746)] = {
    [anon_sym_SEMI] = ACTIONS(1499),
    [anon_sym_LBRACE] = ACTIONS(1499),
    [anon_sym_RBRACE] = ACTIONS(1499),
    [anon_sym_const] = ACTIONS(1501),
    [anon_sym_enum] = ACTIONS(1501),
    [anon_sym_record] = ACTIONS(1501),
    [anon_sym_print] = ACTIONS(1501),
    [anon_sym_event] = ACTIONS(1501),
    [anon_sym_if] = ACTIONS(1501),
    [anon_sym_LPAREN] = ACTIONS(1499),
    [anon_sym_switch] = ACTIONS(1501),
    [anon_sym_for] = ACTIONS(1501),
    [anon_sym_LBRACK] = ACTIONS(1501),
    [anon_sym_while] = ACTIONS(1501),
    [anon_sym_next] = ACTIONS(1501),
    [anon_sym_break] = ACTIONS(1501),
    [anon_sym_fallthrough] = ACTIONS(1501),
    [anon_sym_return] = ACTIONS(1501),
    [anon_sym_add] = ACTIONS(1501),
    [anon_sym_delete] = ACTIONS(1501),
    [anon_sym_local] = ACTIONS(1501),
    [anon_sym_when] = ACTIONS(1501),
    [anon_sym_assert] = ACTIONS(1501),
    [anon_sym_function] = ACTIONS(1501),
    [anon_sym_hook] = ACTIONS(1501),
    [anon_sym_addr] = ACTIONS(1501),
    [anon_sym_any] = ACTIONS(1501),
    [anon_sym_bool] = ACTIONS(1501),
    [anon_sym_count] = ACTIONS(1501),
    [anon_sym_double] = ACTIONS(1501),
    [anon_sym_file] = ACTIONS(1501),
    [anon_sym_int] = ACTIONS(1501),
    [anon_sym_interval] = ACTIONS(1501),
    [anon_sym_list] = ACTIONS(1501),
    [anon_sym_pattern] = ACTIONS(1501),
    [anon_sym_port] = ACTIONS(1501),
    [anon_sym_string] = ACTIONS(1501),
    [anon_sym_subnet] = ACTIONS(1501),
    [anon_sym_time] = ACTIONS(1501),
    [anon_sym_opaque] = ACTIONS(1501),
    [anon_sym_set] = ACTIONS(1501),
    [anon_sym_table] = ACTIONS(1501),
    [anon_sym_union] = ACTIONS(1501),
    [anon_sym_vector] = ACTIONS(1501),
    [anon_sym_DOLLAR] = ACTIONS(1499),
    [anon_sym_PIPE] = ACTIONS(1499),
    [anon_sym_PLUS_PLUS] = ACTIONS(1499),
    [anon_sym_DASH_DASH] = ACTIONS(1499),
    [anon_sym_BANG] = ACTIONS(1499),
    [anon_sym_TILDE] = ACTIONS(1499),
    [anon_sym_DASH] = ACTIONS(1501),
    [anon_sym_PLUS] = ACTIONS(1501),
    [anon_sym_copy] = ACTIONS(1501),
    [anon_sym_schedule] = ACTIONS(1501),
    [anon_sym_T] = ACTIONS(1501),
    [anon_sym_F] = ACTIONS(1501),
    [anon_sym_ATdeprecated] = ACTIONS(1499),
    [anon_sym_ATload] = ACTIONS(1501),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1499),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1499),
    [anon_sym_ATunload] = ACTIONS(1499),
    [anon_sym_ATprefixes] = ACTIONS(1499),
    [anon_sym_ATif] = ACTIONS(1501),
    [anon_sym_ATifdef] = ACTIONS(1499),
    [anon_sym_ATifndef] = ACTIONS(1499),
    [anon_sym_ATendif] = ACTIONS(1499),
    [anon_sym_ATelse] = ACTIONS(1499),
    [anon_sym_ATpragma] = ACTIONS(1499),
    [anon_sym_ATDIR] = ACTIONS(1499),
    [anon_sym_ATFILENAME] = ACTIONS(1499),
    [sym_id] = ACTIONS(1501),
    [sym_pattern] = ACTIONS(1499),
    [sym_ipv4] = ACTIONS(1501),
    [sym_ipv6] = ACTIONS(1499),
    [sym_port] = ACTIONS(1499),
    [sym_integer] = ACTIONS(1501),
    [sym_floatp] = ACTIONS(1501),
    [sym_hex] = ACTIONS(1501),
    [sym_hostname] = ACTIONS(1501),
    [aux_sym_string_token1] = ACTIONS(1499),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(747)] = {
    [ts_builtin_sym_end] = ACTIONS(1697),
    [anon_sym_SEMI] = ACTIONS(1697),
    [anon_sym_LBRACE] = ACTIONS(1697),
    [anon_sym_const] = ACTIONS(1699),
    [anon_sym_enum] = ACTIONS(1699),
    [anon_sym_record] = ACTIONS(1699),
    [anon_sym_print] = ACTIONS(1699),
    [anon_sym_event] = ACTIONS(1699),
    [anon_sym_if] = ACTIONS(1699),
    [anon_sym_LPAREN] = ACTIONS(1697),
    [anon_sym_switch] = ACTIONS(1699),
    [anon_sym_for] = ACTIONS(1699),
    [anon_sym_LBRACK] = ACTIONS(1699),
    [anon_sym_while] = ACTIONS(1699),
    [anon_sym_next] = ACTIONS(1699),
    [anon_sym_break] = ACTIONS(1699),
    [anon_sym_fallthrough] = ACTIONS(1699),
    [anon_sym_return] = ACTIONS(1699),
    [anon_sym_add] = ACTIONS(1699),
    [anon_sym_delete] = ACTIONS(1699),
    [anon_sym_local] = ACTIONS(1699),
    [anon_sym_when] = ACTIONS(1699),
    [anon_sym_assert] = ACTIONS(1699),
    [anon_sym_function] = ACTIONS(1699),
    [anon_sym_hook] = ACTIONS(1699),
    [anon_sym_addr] = ACTIONS(1699),
    [anon_sym_any] = ACTIONS(1699),
    [anon_sym_bool] = ACTIONS(1699),
    [anon_sym_count] = ACTIONS(1699),
    [anon_sym_double] = ACTIONS(1699),
    [anon_sym_file] = ACTIONS(1699),
    [anon_sym_int] = ACTIONS(1699),
    [anon_sym_interval] = ACTIONS(1699),
    [anon_sym_list] = ACTIONS(1699),
    [anon_sym_pattern] = ACTIONS(1699),
    [anon_sym_port] = ACTIONS(1699),
    [anon_sym_string] = ACTIONS(1699),
    [anon_sym_subnet] = ACTIONS(1699),
    [anon_sym_time] = ACTIONS(1699),
    [anon_sym_opaque] = ACTIONS(1699),
    [anon_sym_set] = ACTIONS(1699),
    [anon_sym_table] = ACTIONS(1699),
    [anon_sym_union] = ACTIONS(1699),
    [anon_sym_vector] = ACTIONS(1699),
    [anon_sym_DOLLAR] = ACTIONS(1697),
    [anon_sym_PIPE] = ACTIONS(1697),
    [anon_sym_PLUS_PLUS] = ACTIONS(1697),
    [anon_sym_DASH_DASH] = ACTIONS(1697),
    [anon_sym_BANG] = ACTIONS(1697),
    [anon_sym_TILDE] = ACTIONS(1697),
    [anon_sym_DASH] = ACTIONS(1699),
    [anon_sym_PLUS] = ACTIONS(1699),
    [anon_sym_copy] = ACTIONS(1699),
    [anon_sym_schedule] = ACTIONS(1699),
    [anon_sym_T] = ACTIONS(1699),
    [anon_sym_F] = ACTIONS(1699),
    [anon_sym_ATdeprecated] = ACTIONS(1697),
    [anon_sym_ATload] = ACTIONS(1699),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1697),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1697),
    [anon_sym_ATunload] = ACTIONS(1697),
    [anon_sym_ATprefixes] = ACTIONS(1697),
    [anon_sym_ATif] = ACTIONS(1699),
    [anon_sym_ATifdef] = ACTIONS(1697),
    [anon_sym_ATifndef] = ACTIONS(1697),
    [anon_sym_ATendif] = ACTIONS(1697),
    [anon_sym_ATelse] = ACTIONS(1697),
    [anon_sym_ATpragma] = ACTIONS(1697),
    [anon_sym_ATDIR] = ACTIONS(1697),
    [anon_sym_ATFILENAME] = ACTIONS(1697),
    [sym_id] = ACTIONS(1699),
    [sym_pattern] = ACTIONS(1697),
    [sym_ipv4] = ACTIONS(1699),
    [sym_ipv6] = ACTIONS(1697),
    [sym_port] = ACTIONS(1697),
    [sym_integer] = ACTIONS(1699),
    [sym_floatp] = ACTIONS(1699),
    [sym_hex] = ACTIONS(1699),
    [sym_hostname] = ACTIONS(1699),
    [aux_sym_string_token1] = ACTIONS(1697),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(748)] = {
    [anon_sym_SEMI] = ACTIONS(1683),
    [anon_sym_LBRACE] = ACTIONS(1683),
    [anon_sym_RBRACE] = ACTIONS(1683),
    [anon_sym_const] = ACTIONS(1685),
    [anon_sym_enum] = ACTIONS(1685),
    [anon_sym_record] = ACTIONS(1685),
    [anon_sym_print] = ACTIONS(1685),
    [anon_sym_event] = ACTIONS(1685),
    [anon_sym_if] = ACTIONS(1685),
    [anon_sym_LPAREN] = ACTIONS(1683),
    [anon_sym_switch] = ACTIONS(1685),
    [anon_sym_for] = ACTIONS(1685),
    [anon_sym_LBRACK] = ACTIONS(1685),
    [anon_sym_while] = ACTIONS(1685),
    [anon_sym_next] = ACTIONS(1685),
    [anon_sym_break] = ACTIONS(1685),
    [anon_sym_fallthrough] = ACTIONS(1685),
    [anon_sym_return] = ACTIONS(1685),
    [anon_sym_add] = ACTIONS(1685),
    [anon_sym_delete] = ACTIONS(1685),
    [anon_sym_local] = ACTIONS(1685),
    [anon_sym_when] = ACTIONS(1685),
    [anon_sym_assert] = ACTIONS(1685),
    [anon_sym_function] = ACTIONS(1685),
    [anon_sym_hook] = ACTIONS(1685),
    [anon_sym_addr] = ACTIONS(1685),
    [anon_sym_any] = ACTIONS(1685),
    [anon_sym_bool] = ACTIONS(1685),
    [anon_sym_count] = ACTIONS(1685),
    [anon_sym_double] = ACTIONS(1685),
    [anon_sym_file] = ACTIONS(1685),
    [anon_sym_int] = ACTIONS(1685),
    [anon_sym_interval] = ACTIONS(1685),
    [anon_sym_list] = ACTIONS(1685),
    [anon_sym_pattern] = ACTIONS(1685),
    [anon_sym_port] = ACTIONS(1685),
    [anon_sym_string] = ACTIONS(1685),
    [anon_sym_subnet] = ACTIONS(1685),
    [anon_sym_time] = ACTIONS(1685),
    [anon_sym_opaque] = ACTIONS(1685),
    [anon_sym_set] = ACTIONS(1685),
    [anon_sym_table] = ACTIONS(1685),
    [anon_sym_union] = ACTIONS(1685),
    [anon_sym_vector] = ACTIONS(1685),
    [anon_sym_DOLLAR] = ACTIONS(1683),
    [anon_sym_PIPE] = ACTIONS(1683),
    [anon_sym_PLUS_PLUS] = ACTIONS(1683),
    [anon_sym_DASH_DASH] = ACTIONS(1683),
    [anon_sym_BANG] = ACTIONS(1683),
    [anon_sym_TILDE] = ACTIONS(1683),
    [anon_sym_DASH] = ACTIONS(1685),
    [anon_sym_PLUS] = ACTIONS(1685),
    [anon_sym_copy] = ACTIONS(1685),
    [anon_sym_schedule] = ACTIONS(1685),
    [anon_sym_T] = ACTIONS(1685),
    [anon_sym_F] = ACTIONS(1685),
    [anon_sym_ATdeprecated] = ACTIONS(1683),
    [anon_sym_ATload] = ACTIONS(1685),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1683),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1683),
    [anon_sym_ATunload] = ACTIONS(1683),
    [anon_sym_ATprefixes] = ACTIONS(1683),
    [anon_sym_ATif] = ACTIONS(1685),
    [anon_sym_ATifdef] = ACTIONS(1683),
    [anon_sym_ATifndef] = ACTIONS(1683),
    [anon_sym_ATendif] = ACTIONS(1683),
    [anon_sym_ATelse] = ACTIONS(1683),
    [anon_sym_ATpragma] = ACTIONS(1683),
    [anon_sym_ATDIR] = ACTIONS(1683),
    [anon_sym_ATFILENAME] = ACTIONS(1683),
    [sym_id] = ACTIONS(1685),
    [sym_pattern] = ACTIONS(1683),
    [sym_ipv4] = ACTIONS(1685),
    [sym_ipv6] = ACTIONS(1683),
    [sym_port] = ACTIONS(1683),
    [sym_integer] = ACTIONS(1685),
    [sym_floatp] = ACTIONS(1685),
    [sym_hex] = ACTIONS(1685),
    [sym_hostname] = ACTIONS(1685),
    [aux_sym_string_token1] = ACTIONS(1683),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(749)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(750)] = {
    [ts_builtin_sym_end] = ACTIONS(1701),
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(751)] = {
    [ts_builtin_sym_end] = ACTIONS(1671),
    [anon_sym_SEMI] = ACTIONS(1671),
    [anon_sym_LBRACE] = ACTIONS(1671),
    [anon_sym_const] = ACTIONS(1673),
    [anon_sym_enum] = ACTIONS(1673),
    [anon_sym_record] = ACTIONS(1673),
    [anon_sym_print] = ACTIONS(1673),
    [anon_sym_event] = ACTIONS(1673),
    [anon_sym_if] = ACTIONS(1673),
    [anon_sym_LPAREN] = ACTIONS(1671),
    [anon_sym_switch] = ACTIONS(1673),
    [anon_sym_for] = ACTIONS(1673),
    [anon_sym_LBRACK] = ACTIONS(1673),
    [anon_sym_while] = ACTIONS(1673),
    [anon_sym_next] = ACTIONS(1673),
    [anon_sym_break] = ACTIONS(1673),
    [anon_sym_fallthrough] = ACTIONS(1673),
    [anon_sym_return] = ACTIONS(1673),
    [anon_sym_add] = ACTIONS(1673),
    [anon_sym_delete] = ACTIONS(1673),
    [anon_sym_local] = ACTIONS(1673),
    [anon_sym_when] = ACTIONS(1673),
    [anon_sym_assert] = ACTIONS(1673),
    [anon_sym_function] = ACTIONS(1673),
    [anon_sym_hook] = ACTIONS(1673),
    [anon_sym_addr] = ACTIONS(1673),
    [anon_sym_any] = ACTIONS(1673),
    [anon_sym_bool] = ACTIONS(1673),
    [anon_sym_count] = ACTIONS(1673),
    [anon_sym_double] = ACTIONS(1673),
    [anon_sym_file] = ACTIONS(1673),
    [anon_sym_int] = ACTIONS(1673),
    [anon_sym_interval] = ACTIONS(1673),
    [anon_sym_list] = ACTIONS(1673),
    [anon_sym_pattern] = ACTIONS(1673),
    [anon_sym_port] = ACTIONS(1673),
    [anon_sym_string] = ACTIONS(1673),
    [anon_sym_subnet] = ACTIONS(1673),
    [anon_sym_time] = ACTIONS(1673),
    [anon_sym_opaque] = ACTIONS(1673),
    [anon_sym_set] = ACTIONS(1673),
    [anon_sym_table] = ACTIONS(1673),
    [anon_sym_union] = ACTIONS(1673),
    [anon_sym_vector] = ACTIONS(1673),
    [anon_sym_DOLLAR] = ACTIONS(1671),
    [anon_sym_PIPE] = ACTIONS(1671),
    [anon_sym_PLUS_PLUS] = ACTIONS(1671),
    [anon_sym_DASH_DASH] = ACTIONS(1671),
    [anon_sym_BANG] = ACTIONS(1671),
    [anon_sym_TILDE] = ACTIONS(1671),
    [anon_sym_DASH] = ACTIONS(1673),
    [anon_sym_PLUS] = ACTIONS(1673),
    [anon_sym_copy] = ACTIONS(1673),
    [anon_sym_schedule] = ACTIONS(1673),
    [anon_sym_T] = ACTIONS(1673),
    [anon_sym_F] = ACTIONS(1673),
    [anon_sym_ATdeprecated] = ACTIONS(1671),
    [anon_sym_ATload] = ACTIONS(1673),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1671),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1671),
    [anon_sym_ATunload] = ACTIONS(1671),
    [anon_sym_ATprefixes] = ACTIONS(1671),
    [anon_sym_ATif] = ACTIONS(1673),
    [anon_sym_ATifdef] = ACTIONS(1671),
    [anon_sym_ATifndef] = ACTIONS(1671),
    [anon_sym_ATendif] = ACTIONS(1671),
    [anon_sym_ATelse] = ACTIONS(1671),
    [anon_sym_ATpragma] = ACTIONS(1671),
    [anon_sym_ATDIR] = ACTIONS(1671),
    [anon_sym_ATFILENAME] = ACTIONS(1671),
    [sym_id] = ACTIONS(1673),
    [sym_pattern] = ACTIONS(1671),
    [sym_ipv4] = ACTIONS(1673),
    [sym_ipv6] = ACTIONS(1671),
    [sym_port] = ACTIONS(1671),
    [sym_integer] = ACTIONS(1673),
    [sym_floatp] = ACTIONS(1673),
    [sym_hex] = ACTIONS(1673),
    [sym_hostname] = ACTIONS(1673),
    [aux_sym_string_token1] = ACTIONS(1671),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(752)] = {
    [anon_sym_SEMI] = ACTIONS(1677),
    [anon_sym_LBRACE] = ACTIONS(1677),
    [anon_sym_RBRACE] = ACTIONS(1677),
    [anon_sym_const] = ACTIONS(1679),
    [anon_sym_enum] = ACTIONS(1679),
    [anon_sym_record] = ACTIONS(1679),
    [anon_sym_print] = ACTIONS(1679),
    [anon_sym_event] = ACTIONS(1679),
    [anon_sym_if] = ACTIONS(1679),
    [anon_sym_LPAREN] = ACTIONS(1677),
    [anon_sym_switch] = ACTIONS(1679),
    [anon_sym_for] = ACTIONS(1679),
    [anon_sym_LBRACK] = ACTIONS(1679),
    [anon_sym_while] = ACTIONS(1679),
    [anon_sym_next] = ACTIONS(1679),
    [anon_sym_break] = ACTIONS(1679),
    [anon_sym_fallthrough] = ACTIONS(1679),
    [anon_sym_return] = ACTIONS(1679),
    [anon_sym_add] = ACTIONS(1679),
    [anon_sym_delete] = ACTIONS(1679),
    [anon_sym_local] = ACTIONS(1679),
    [anon_sym_when] = ACTIONS(1679),
    [anon_sym_assert] = ACTIONS(1679),
    [anon_sym_function] = ACTIONS(1679),
    [anon_sym_hook] = ACTIONS(1679),
    [anon_sym_addr] = ACTIONS(1679),
    [anon_sym_any] = ACTIONS(1679),
    [anon_sym_bool] = ACTIONS(1679),
    [anon_sym_count] = ACTIONS(1679),
    [anon_sym_double] = ACTIONS(1679),
    [anon_sym_file] = ACTIONS(1679),
    [anon_sym_int] = ACTIONS(1679),
    [anon_sym_interval] = ACTIONS(1679),
    [anon_sym_list] = ACTIONS(1679),
    [anon_sym_pattern] = ACTIONS(1679),
    [anon_sym_port] = ACTIONS(1679),
    [anon_sym_string] = ACTIONS(1679),
    [anon_sym_subnet] = ACTIONS(1679),
    [anon_sym_time] = ACTIONS(1679),
    [anon_sym_opaque] = ACTIONS(1679),
    [anon_sym_set] = ACTIONS(1679),
    [anon_sym_table] = ACTIONS(1679),
    [anon_sym_union] = ACTIONS(1679),
    [anon_sym_vector] = ACTIONS(1679),
    [anon_sym_DOLLAR] = ACTIONS(1677),
    [anon_sym_PIPE] = ACTIONS(1677),
    [anon_sym_PLUS_PLUS] = ACTIONS(1677),
    [anon_sym_DASH_DASH] = ACTIONS(1677),
    [anon_sym_BANG] = ACTIONS(1677),
    [anon_sym_TILDE] = ACTIONS(1677),
    [anon_sym_DASH] = ACTIONS(1679),
    [anon_sym_PLUS] = ACTIONS(1679),
    [anon_sym_copy] = ACTIONS(1679),
    [anon_sym_schedule] = ACTIONS(1679),
    [anon_sym_T] = ACTIONS(1679),
    [anon_sym_F] = ACTIONS(1679),
    [anon_sym_ATdeprecated] = ACTIONS(1677),
    [anon_sym_ATload] = ACTIONS(1679),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1677),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1677),
    [anon_sym_ATunload] = ACTIONS(1677),
    [anon_sym_ATprefixes] = ACTIONS(1677),
    [anon_sym_ATif] = ACTIONS(1679),
    [anon_sym_ATifdef] = ACTIONS(1677),
    [anon_sym_ATifndef] = ACTIONS(1677),
    [anon_sym_ATendif] = ACTIONS(1677),
    [anon_sym_ATelse] = ACTIONS(1677),
    [anon_sym_ATpragma] = ACTIONS(1677),
    [anon_sym_ATDIR] = ACTIONS(1677),
    [anon_sym_ATFILENAME] = ACTIONS(1677),
    [sym_id] = ACTIONS(1679),
    [sym_pattern] = ACTIONS(1677),
    [sym_ipv4] = ACTIONS(1679),
    [sym_ipv6] = ACTIONS(1677),
    [sym_port] = ACTIONS(1677),
    [sym_integer] = ACTIONS(1679),
    [sym_floatp] = ACTIONS(1679),
    [sym_hex] = ACTIONS(1679),
    [sym_hostname] = ACTIONS(1679),
    [aux_sym_string_token1] = ACTIONS(1677),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(753)] = {
    [ts_builtin_sym_end] = ACTIONS(1705),
    [anon_sym_SEMI] = ACTIONS(1705),
    [anon_sym_LBRACE] = ACTIONS(1705),
    [anon_sym_const] = ACTIONS(1707),
    [anon_sym_enum] = ACTIONS(1707),
    [anon_sym_record] = ACTIONS(1707),
    [anon_sym_print] = ACTIONS(1707),
    [anon_sym_event] = ACTIONS(1707),
    [anon_sym_if] = ACTIONS(1707),
    [anon_sym_LPAREN] = ACTIONS(1705),
    [anon_sym_switch] = ACTIONS(1707),
    [anon_sym_for] = ACTIONS(1707),
    [anon_sym_LBRACK] = ACTIONS(1707),
    [anon_sym_while] = ACTIONS(1707),
    [anon_sym_next] = ACTIONS(1707),
    [anon_sym_break] = ACTIONS(1707),
    [anon_sym_fallthrough] = ACTIONS(1707),
    [anon_sym_return] = ACTIONS(1707),
    [anon_sym_add] = ACTIONS(1707),
    [anon_sym_delete] = ACTIONS(1707),
    [anon_sym_local] = ACTIONS(1707),
    [anon_sym_when] = ACTIONS(1707),
    [anon_sym_assert] = ACTIONS(1707),
    [anon_sym_function] = ACTIONS(1707),
    [anon_sym_hook] = ACTIONS(1707),
    [anon_sym_addr] = ACTIONS(1707),
    [anon_sym_any] = ACTIONS(1707),
    [anon_sym_bool] = ACTIONS(1707),
    [anon_sym_count] = ACTIONS(1707),
    [anon_sym_double] = ACTIONS(1707),
    [anon_sym_file] = ACTIONS(1707),
    [anon_sym_int] = ACTIONS(1707),
    [anon_sym_interval] = ACTIONS(1707),
    [anon_sym_list] = ACTIONS(1707),
    [anon_sym_pattern] = ACTIONS(1707),
    [anon_sym_port] = ACTIONS(1707),
    [anon_sym_string] = ACTIONS(1707),
    [anon_sym_subnet] = ACTIONS(1707),
    [anon_sym_time] = ACTIONS(1707),
    [anon_sym_opaque] = ACTIONS(1707),
    [anon_sym_set] = ACTIONS(1707),
    [anon_sym_table] = ACTIONS(1707),
    [anon_sym_union] = ACTIONS(1707),
    [anon_sym_vector] = ACTIONS(1707),
    [anon_sym_DOLLAR] = ACTIONS(1705),
    [anon_sym_PIPE] = ACTIONS(1705),
    [anon_sym_PLUS_PLUS] = ACTIONS(1705),
    [anon_sym_DASH_DASH] = ACTIONS(1705),
    [anon_sym_BANG] = ACTIONS(1705),
    [anon_sym_TILDE] = ACTIONS(1705),
    [anon_sym_DASH] = ACTIONS(1707),
    [anon_sym_PLUS] = ACTIONS(1707),
    [anon_sym_copy] = ACTIONS(1707),
    [anon_sym_schedule] = ACTIONS(1707),
    [anon_sym_T] = ACTIONS(1707),
    [anon_sym_F] = ACTIONS(1707),
    [anon_sym_ATdeprecated] = ACTIONS(1705),
    [anon_sym_ATload] = ACTIONS(1707),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1705),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1705),
    [anon_sym_ATunload] = ACTIONS(1705),
    [anon_sym_ATprefixes] = ACTIONS(1705),
    [anon_sym_ATif] = ACTIONS(1707),
    [anon_sym_ATifdef] = ACTIONS(1705),
    [anon_sym_ATifndef] = ACTIONS(1705),
    [anon_sym_ATendif] = ACTIONS(1705),
    [anon_sym_ATelse] = ACTIONS(1705),
    [anon_sym_ATpragma] = ACTIONS(1705),
    [anon_sym_ATDIR] = ACTIONS(1705),
    [anon_sym_ATFILENAME] = ACTIONS(1705),
    [sym_id] = ACTIONS(1707),
    [sym_pattern] = ACTIONS(1705),
    [sym_ipv4] = ACTIONS(1707),
    [sym_ipv6] = ACTIONS(1705),
    [sym_port] = ACTIONS(1705),
    [sym_integer] = ACTIONS(1707),
    [sym_floatp] = ACTIONS(1707),
    [sym_hex] = ACTIONS(1707),
    [sym_hostname] = ACTIONS(1707),
    [aux_sym_string_token1] = ACTIONS(1705),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(754)] = {
    [ts_builtin_sym_end] = ACTIONS(1663),
    [anon_sym_SEMI] = ACTIONS(1663),
    [anon_sym_LBRACE] = ACTIONS(1663),
    [anon_sym_const] = ACTIONS(1665),
    [anon_sym_enum] = ACTIONS(1665),
    [anon_sym_record] = ACTIONS(1665),
    [anon_sym_print] = ACTIONS(1665),
    [anon_sym_event] = ACTIONS(1665),
    [anon_sym_if] = ACTIONS(1665),
    [anon_sym_LPAREN] = ACTIONS(1663),
    [anon_sym_switch] = ACTIONS(1665),
    [anon_sym_for] = ACTIONS(1665),
    [anon_sym_LBRACK] = ACTIONS(1665),
    [anon_sym_while] = ACTIONS(1665),
    [anon_sym_next] = ACTIONS(1665),
    [anon_sym_break] = ACTIONS(1665),
    [anon_sym_fallthrough] = ACTIONS(1665),
    [anon_sym_return] = ACTIONS(1665),
    [anon_sym_add] = ACTIONS(1665),
    [anon_sym_delete] = ACTIONS(1665),
    [anon_sym_local] = ACTIONS(1665),
    [anon_sym_when] = ACTIONS(1665),
    [anon_sym_assert] = ACTIONS(1665),
    [anon_sym_function] = ACTIONS(1665),
    [anon_sym_hook] = ACTIONS(1665),
    [anon_sym_addr] = ACTIONS(1665),
    [anon_sym_any] = ACTIONS(1665),
    [anon_sym_bool] = ACTIONS(1665),
    [anon_sym_count] = ACTIONS(1665),
    [anon_sym_double] = ACTIONS(1665),
    [anon_sym_file] = ACTIONS(1665),
    [anon_sym_int] = ACTIONS(1665),
    [anon_sym_interval] = ACTIONS(1665),
    [anon_sym_list] = ACTIONS(1665),
    [anon_sym_pattern] = ACTIONS(1665),
    [anon_sym_port] = ACTIONS(1665),
    [anon_sym_string] = ACTIONS(1665),
    [anon_sym_subnet] = ACTIONS(1665),
    [anon_sym_time] = ACTIONS(1665),
    [anon_sym_opaque] = ACTIONS(1665),
    [anon_sym_set] = ACTIONS(1665),
    [anon_sym_table] = ACTIONS(1665),
    [anon_sym_union] = ACTIONS(1665),
    [anon_sym_vector] = ACTIONS(1665),
    [anon_sym_DOLLAR] = ACTIONS(1663),
    [anon_sym_PIPE] = ACTIONS(1663),
    [anon_sym_PLUS_PLUS] = ACTIONS(1663),
    [anon_sym_DASH_DASH] = ACTIONS(1663),
    [anon_sym_BANG] = ACTIONS(1663),
    [anon_sym_TILDE] = ACTIONS(1663),
    [anon_sym_DASH] = ACTIONS(1665),
    [anon_sym_PLUS] = ACTIONS(1665),
    [anon_sym_copy] = ACTIONS(1665),
    [anon_sym_schedule] = ACTIONS(1665),
    [anon_sym_T] = ACTIONS(1665),
    [anon_sym_F] = ACTIONS(1665),
    [anon_sym_ATdeprecated] = ACTIONS(1663),
    [anon_sym_ATload] = ACTIONS(1665),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1663),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1663),
    [anon_sym_ATunload] = ACTIONS(1663),
    [anon_sym_ATprefixes] = ACTIONS(1663),
    [anon_sym_ATif] = ACTIONS(1665),
    [anon_sym_ATifdef] = ACTIONS(1663),
    [anon_sym_ATifndef] = ACTIONS(1663),
    [anon_sym_ATendif] = ACTIONS(1663),
    [anon_sym_ATelse] = ACTIONS(1663),
    [anon_sym_ATpragma] = ACTIONS(1663),
    [anon_sym_ATDIR] = ACTIONS(1663),
    [anon_sym_ATFILENAME] = ACTIONS(1663),
    [sym_id] = ACTIONS(1665),
    [sym_pattern] = ACTIONS(1663),
    [sym_ipv4] = ACTIONS(1665),
    [sym_ipv6] = ACTIONS(1663),
    [sym_port] = ACTIONS(1663),
    [sym_integer] = ACTIONS(1665),
    [sym_floatp] = ACTIONS(1665),
    [sym_hex] = ACTIONS(1665),
    [sym_hostname] = ACTIONS(1665),
    [aux_sym_string_token1] = ACTIONS(1663),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(755)] = {
    [ts_builtin_sym_end] = ACTIONS(1701),
    [anon_sym_SEMI] = ACTIONS(1701),
    [anon_sym_LBRACE] = ACTIONS(1701),
    [anon_sym_const] = ACTIONS(1703),
    [anon_sym_enum] = ACTIONS(1703),
    [anon_sym_record] = ACTIONS(1703),
    [anon_sym_print] = ACTIONS(1703),
    [anon_sym_event] = ACTIONS(1703),
    [anon_sym_if] = ACTIONS(1703),
    [anon_sym_LPAREN] = ACTIONS(1701),
    [anon_sym_switch] = ACTIONS(1703),
    [anon_sym_for] = ACTIONS(1703),
    [anon_sym_LBRACK] = ACTIONS(1703),
    [anon_sym_while] = ACTIONS(1703),
    [anon_sym_next] = ACTIONS(1703),
    [anon_sym_break] = ACTIONS(1703),
    [anon_sym_fallthrough] = ACTIONS(1703),
    [anon_sym_return] = ACTIONS(1703),
    [anon_sym_add] = ACTIONS(1703),
    [anon_sym_delete] = ACTIONS(1703),
    [anon_sym_local] = ACTIONS(1703),
    [anon_sym_when] = ACTIONS(1703),
    [anon_sym_assert] = ACTIONS(1703),
    [anon_sym_function] = ACTIONS(1703),
    [anon_sym_hook] = ACTIONS(1703),
    [anon_sym_addr] = ACTIONS(1703),
    [anon_sym_any] = ACTIONS(1703),
    [anon_sym_bool] = ACTIONS(1703),
    [anon_sym_count] = ACTIONS(1703),
    [anon_sym_double] = ACTIONS(1703),
    [anon_sym_file] = ACTIONS(1703),
    [anon_sym_int] = ACTIONS(1703),
    [anon_sym_interval] = ACTIONS(1703),
    [anon_sym_list] = ACTIONS(1703),
    [anon_sym_pattern] = ACTIONS(1703),
    [anon_sym_port] = ACTIONS(1703),
    [anon_sym_string] = ACTIONS(1703),
    [anon_sym_subnet] = ACTIONS(1703),
    [anon_sym_time] = ACTIONS(1703),
    [anon_sym_opaque] = ACTIONS(1703),
    [anon_sym_set] = ACTIONS(1703),
    [anon_sym_table] = ACTIONS(1703),
    [anon_sym_union] = ACTIONS(1703),
    [anon_sym_vector] = ACTIONS(1703),
    [anon_sym_DOLLAR] = ACTIONS(1701),
    [anon_sym_PIPE] = ACTIONS(1701),
    [anon_sym_PLUS_PLUS] = ACTIONS(1701),
    [anon_sym_DASH_DASH] = ACTIONS(1701),
    [anon_sym_BANG] = ACTIONS(1701),
    [anon_sym_TILDE] = ACTIONS(1701),
    [anon_sym_DASH] = ACTIONS(1703),
    [anon_sym_PLUS] = ACTIONS(1703),
    [anon_sym_copy] = ACTIONS(1703),
    [anon_sym_schedule] = ACTIONS(1703),
    [anon_sym_T] = ACTIONS(1703),
    [anon_sym_F] = ACTIONS(1703),
    [anon_sym_ATdeprecated] = ACTIONS(1701),
    [anon_sym_ATload] = ACTIONS(1703),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1701),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1701),
    [anon_sym_ATunload] = ACTIONS(1701),
    [anon_sym_ATprefixes] = ACTIONS(1701),
    [anon_sym_ATif] = ACTIONS(1703),
    [anon_sym_ATifdef] = ACTIONS(1701),
    [anon_sym_ATifndef] = ACTIONS(1701),
    [anon_sym_ATendif] = ACTIONS(1701),
    [anon_sym_ATelse] = ACTIONS(1701),
    [anon_sym_ATpragma] = ACTIONS(1701),
    [anon_sym_ATDIR] = ACTIONS(1701),
    [anon_sym_ATFILENAME] = ACTIONS(1701),
    [sym_id] = ACTIONS(1703),
    [sym_pattern] = ACTIONS(1701),
    [sym_ipv4] = ACTIONS(1703),
    [sym_ipv6] = ACTIONS(1701),
    [sym_port] = ACTIONS(1701),
    [sym_integer] = ACTIONS(1703),
    [sym_floatp] = ACTIONS(1703),
    [sym_hex] = ACTIONS(1703),
    [sym_hostname] = ACTIONS(1703),
    [aux_sym_string_token1] = ACTIONS(1701),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(756)] = {
    [anon_sym_SEMI] = ACTIONS(1837),
    [anon_sym_LBRACE] = ACTIONS(1837),
    [anon_sym_enum] = ACTIONS(1839),
    [anon_sym_PLUS_EQ] = ACTIONS(1837),
    [anon_sym_record] = ACTIONS(1839),
    [anon_sym_DASH_EQ] = ACTIONS(1837),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_LBRACK] = ACTIONS(1839),
    [anon_sym_local] = ACTIONS(1839),
    [anon_sym_EQ] = ACTIONS(1837),
    [anon_sym_function] = ACTIONS(1839),
    [anon_sym_hook] = ACTIONS(1839),
    [anon_sym_addr] = ACTIONS(1839),
    [anon_sym_any] = ACTIONS(1839),
    [anon_sym_bool] = ACTIONS(1839),
    [anon_sym_count] = ACTIONS(1839),
    [anon_sym_double] = ACTIONS(1839),
    [anon_sym_file] = ACTIONS(1839),
    [anon_sym_int] = ACTIONS(1839),
    [anon_sym_interval] = ACTIONS(1839),
    [anon_sym_list] = ACTIONS(1839),
    [anon_sym_pattern] = ACTIONS(1839),
    [anon_sym_port] = ACTIONS(1839),
    [anon_sym_string] = ACTIONS(1839),
    [anon_sym_subnet] = ACTIONS(1839),
    [anon_sym_time] = ACTIONS(1839),
    [anon_sym_of] = ACTIONS(1841),
    [anon_sym_opaque] = ACTIONS(1839),
    [anon_sym_set] = ACTIONS(1839),
    [anon_sym_table] = ACTIONS(1839),
    [anon_sym_union] = ACTIONS(1839),
    [anon_sym_vector] = ACTIONS(1839),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1837),
    [anon_sym_AMPdeprecated] = ACTIONS(1837),
    [anon_sym_AMPerror_handler] = ACTIONS(1837),
    [anon_sym_AMPis_assigned] = ACTIONS(1837),
    [anon_sym_AMPis_used] = ACTIONS(1837),
    [anon_sym_AMPlog] = ACTIONS(1837),
    [anon_sym_AMPoptional] = ACTIONS(1837),
    [anon_sym_AMPordered] = ACTIONS(1837),
    [anon_sym_AMPraw_output] = ACTIONS(1837),
    [anon_sym_AMPredef] = ACTIONS(1837),
    [anon_sym_AMPadd_func] = ACTIONS(1837),
    [anon_sym_AMPbackend] = ACTIONS(1837),
    [anon_sym_AMPbroker_store] = ACTIONS(1837),
    [anon_sym_AMPcreate_expire] = ACTIONS(1837),
    [anon_sym_AMPdefault] = ACTIONS(1837),
    [anon_sym_AMPdelete_func] = ACTIONS(1837),
    [anon_sym_AMPexpire_func] = ACTIONS(1837),
    [anon_sym_AMPgroup] = ACTIONS(1837),
    [anon_sym_AMPon_change] = ACTIONS(1837),
    [anon_sym_AMPpriority] = ACTIONS(1837),
    [anon_sym_AMPread_expire] = ACTIONS(1837),
    [anon_sym_AMPtype_column] = ACTIONS(1837),
    [anon_sym_AMPwrite_expire] = ACTIONS(1837),
    [anon_sym_DOLLAR] = ACTIONS(1837),
    [anon_sym_PIPE] = ACTIONS(1837),
    [anon_sym_PLUS_PLUS] = ACTIONS(1837),
    [anon_sym_DASH_DASH] = ACTIONS(1837),
    [anon_sym_BANG] = ACTIONS(1837),
    [anon_sym_TILDE] = ACTIONS(1837),
    [anon_sym_DASH] = ACTIONS(1839),
    [anon_sym_PLUS] = ACTIONS(1839),
    [anon_sym_copy] = ACTIONS(1839),
    [anon_sym_schedule] = ACTIONS(1839),
    [anon_sym_T] = ACTIONS(1839),
    [anon_sym_F] = ACTIONS(1839),
    [anon_sym_ATDIR] = ACTIONS(1837),
    [anon_sym_ATFILENAME] = ACTIONS(1837),
    [sym_id] = ACTIONS(1839),
    [sym_pattern] = ACTIONS(1837),
    [sym_ipv4] = ACTIONS(1839),
    [sym_ipv6] = ACTIONS(1837),
    [sym_port] = ACTIONS(1837),
    [sym_integer] = ACTIONS(1839),
    [sym_floatp] = ACTIONS(1839),
    [sym_hex] = ACTIONS(1839),
    [sym_hostname] = ACTIONS(1839),
    [aux_sym_string_token1] = ACTIONS(1837),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(757)] = {
    [anon_sym_SEMI] = ACTIONS(1843),
    [anon_sym_LBRACE] = ACTIONS(1843),
    [anon_sym_COLON] = ACTIONS(1845),
    [anon_sym_enum] = ACTIONS(1847),
    [anon_sym_PLUS_EQ] = ACTIONS(1843),
    [anon_sym_record] = ACTIONS(1847),
    [anon_sym_DASH_EQ] = ACTIONS(1843),
    [anon_sym_LPAREN] = ACTIONS(1843),
    [anon_sym_LBRACK] = ACTIONS(1847),
    [anon_sym_local] = ACTIONS(1847),
    [anon_sym_EQ] = ACTIONS(1843),
    [anon_sym_function] = ACTIONS(1847),
    [anon_sym_hook] = ACTIONS(1847),
    [anon_sym_addr] = ACTIONS(1847),
    [anon_sym_any] = ACTIONS(1847),
    [anon_sym_bool] = ACTIONS(1847),
    [anon_sym_count] = ACTIONS(1847),
    [anon_sym_double] = ACTIONS(1847),
    [anon_sym_file] = ACTIONS(1847),
    [anon_sym_int] = ACTIONS(1847),
    [anon_sym_interval] = ACTIONS(1847),
    [anon_sym_list] = ACTIONS(1847),
    [anon_sym_pattern] = ACTIONS(1847),
    [anon_sym_port] = ACTIONS(1847),
    [anon_sym_string] = ACTIONS(1847),
    [anon_sym_subnet] = ACTIONS(1847),
    [anon_sym_time] = ACTIONS(1847),
    [anon_sym_opaque] = ACTIONS(1847),
    [anon_sym_set] = ACTIONS(1847),
    [anon_sym_table] = ACTIONS(1847),
    [anon_sym_union] = ACTIONS(1847),
    [anon_sym_vector] = ACTIONS(1847),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1843),
    [anon_sym_AMPdeprecated] = ACTIONS(1843),
    [anon_sym_AMPerror_handler] = ACTIONS(1843),
    [anon_sym_AMPis_assigned] = ACTIONS(1843),
    [anon_sym_AMPis_used] = ACTIONS(1843),
    [anon_sym_AMPlog] = ACTIONS(1843),
    [anon_sym_AMPoptional] = ACTIONS(1843),
    [anon_sym_AMPordered] = ACTIONS(1843),
    [anon_sym_AMPraw_output] = ACTIONS(1843),
    [anon_sym_AMPredef] = ACTIONS(1843),
    [anon_sym_AMPadd_func] = ACTIONS(1843),
    [anon_sym_AMPbackend] = ACTIONS(1843),
    [anon_sym_AMPbroker_store] = ACTIONS(1843),
    [anon_sym_AMPcreate_expire] = ACTIONS(1843),
    [anon_sym_AMPdefault] = ACTIONS(1843),
    [anon_sym_AMPdelete_func] = ACTIONS(1843),
    [anon_sym_AMPexpire_func] = ACTIONS(1843),
    [anon_sym_AMPgroup] = ACTIONS(1843),
    [anon_sym_AMPon_change] = ACTIONS(1843),
    [anon_sym_AMPpriority] = ACTIONS(1843),
    [anon_sym_AMPread_expire] = ACTIONS(1843),
    [anon_sym_AMPtype_column] = ACTIONS(1843),
    [anon_sym_AMPwrite_expire] = ACTIONS(1843),
    [anon_sym_DOLLAR] = ACTIONS(1843),
    [anon_sym_PIPE] = ACTIONS(1843),
    [anon_sym_PLUS_PLUS] = ACTIONS(1843),
    [anon_sym_DASH_DASH] = ACTIONS(1843),
    [anon_sym_BANG] = ACTIONS(1843),
    [anon_sym_TILDE] = ACTIONS(1843),
    [anon_sym_DASH] = ACTIONS(1847),
    [anon_sym_PLUS] = ACTIONS(1847),
    [anon_sym_copy] = ACTIONS(1847),
    [anon_sym_schedule] = ACTIONS(1847),
    [anon_sym_T] = ACTIONS(1847),
    [anon_sym_F] = ACTIONS(1847),
    [anon_sym_ATDIR] = ACTIONS(1843),
    [anon_sym_ATFILENAME] = ACTIONS(1843),
    [sym_id] = ACTIONS(1847),
    [sym_pattern] = ACTIONS(1843),
    [sym_ipv4] = ACTIONS(1847),
    [sym_ipv6] = ACTIONS(1843),
    [sym_port] = ACTIONS(1843),
    [sym_integer] = ACTIONS(1847),
    [sym_floatp] = ACTIONS(1847),
    [sym_hex] = ACTIONS(1847),
    [sym_hostname] = ACTIONS(1847),
    [aux_sym_string_token1] = ACTIONS(1843),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(758)] = {
    [anon_sym_SEMI] = ACTIONS(1849),
    [anon_sym_LBRACE] = ACTIONS(1849),
    [anon_sym_COLON] = ACTIONS(1851),
    [anon_sym_enum] = ACTIONS(1853),
    [anon_sym_PLUS_EQ] = ACTIONS(1849),
    [anon_sym_record] = ACTIONS(1853),
    [anon_sym_DASH_EQ] = ACTIONS(1849),
    [anon_sym_LPAREN] = ACTIONS(1849),
    [anon_sym_LBRACK] = ACTIONS(1853),
    [anon_sym_local] = ACTIONS(1853),
    [anon_sym_EQ] = ACTIONS(1849),
    [anon_sym_function] = ACTIONS(1853),
    [anon_sym_hook] = ACTIONS(1853),
    [anon_sym_addr] = ACTIONS(1853),
    [anon_sym_any] = ACTIONS(1853),
    [anon_sym_bool] = ACTIONS(1853),
    [anon_sym_count] = ACTIONS(1853),
    [anon_sym_double] = ACTIONS(1853),
    [anon_sym_file] = ACTIONS(1853),
    [anon_sym_int] = ACTIONS(1853),
    [anon_sym_interval] = ACTIONS(1853),
    [anon_sym_list] = ACTIONS(1853),
    [anon_sym_pattern] = ACTIONS(1853),
    [anon_sym_port] = ACTIONS(1853),
    [anon_sym_string] = ACTIONS(1853),
    [anon_sym_subnet] = ACTIONS(1853),
    [anon_sym_time] = ACTIONS(1853),
    [anon_sym_opaque] = ACTIONS(1853),
    [anon_sym_set] = ACTIONS(1853),
    [anon_sym_table] = ACTIONS(1853),
    [anon_sym_union] = ACTIONS(1853),
    [anon_sym_vector] = ACTIONS(1853),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1849),
    [anon_sym_AMPdeprecated] = ACTIONS(1849),
    [anon_sym_AMPerror_handler] = ACTIONS(1849),
    [anon_sym_AMPis_assigned] = ACTIONS(1849),
    [anon_sym_AMPis_used] = ACTIONS(1849),
    [anon_sym_AMPlog] = ACTIONS(1849),
    [anon_sym_AMPoptional] = ACTIONS(1849),
    [anon_sym_AMPordered] = ACTIONS(1849),
    [anon_sym_AMPraw_output] = ACTIONS(1849),
    [anon_sym_AMPredef] = ACTIONS(1849),
    [anon_sym_AMPadd_func] = ACTIONS(1849),
    [anon_sym_AMPbackend] = ACTIONS(1849),
    [anon_sym_AMPbroker_store] = ACTIONS(1849),
    [anon_sym_AMPcreate_expire] = ACTIONS(1849),
    [anon_sym_AMPdefault] = ACTIONS(1849),
    [anon_sym_AMPdelete_func] = ACTIONS(1849),
    [anon_sym_AMPexpire_func] = ACTIONS(1849),
    [anon_sym_AMPgroup] = ACTIONS(1849),
    [anon_sym_AMPon_change] = ACTIONS(1849),
    [anon_sym_AMPpriority] = ACTIONS(1849),
    [anon_sym_AMPread_expire] = ACTIONS(1849),
    [anon_sym_AMPtype_column] = ACTIONS(1849),
    [anon_sym_AMPwrite_expire] = ACTIONS(1849),
    [anon_sym_DOLLAR] = ACTIONS(1849),
    [anon_sym_PIPE] = ACTIONS(1849),
    [anon_sym_PLUS_PLUS] = ACTIONS(1849),
    [anon_sym_DASH_DASH] = ACTIONS(1849),
    [anon_sym_BANG] = ACTIONS(1849),
    [anon_sym_TILDE] = ACTIONS(1849),
    [anon_sym_DASH] = ACTIONS(1853),
    [anon_sym_PLUS] = ACTIONS(1853),
    [anon_sym_copy] = ACTIONS(1853),
    [anon_sym_schedule] = ACTIONS(1853),
    [anon_sym_T] = ACTIONS(1853),
    [anon_sym_F] = ACTIONS(1853),
    [anon_sym_ATDIR] = ACTIONS(1849),
    [anon_sym_ATFILENAME] = ACTIONS(1849),
    [sym_id] = ACTIONS(1853),
    [sym_pattern] = ACTIONS(1849),
    [sym_ipv4] = ACTIONS(1853),
    [sym_ipv6] = ACTIONS(1849),
    [sym_port] = ACTIONS(1849),
    [sym_integer] = ACTIONS(1853),
    [sym_floatp] = ACTIONS(1853),
    [sym_hex] = ACTIONS(1853),
    [sym_hostname] = ACTIONS(1853),
    [aux_sym_string_token1] = ACTIONS(1849),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(759)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1307),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(129),
    [anon_sym_LBRACK] = ACTIONS(129),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(129),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(129),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(129),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(760)] = {
    [anon_sym_SEMI] = ACTIONS(1855),
    [anon_sym_LBRACE] = ACTIONS(1855),
    [anon_sym_enum] = ACTIONS(1857),
    [anon_sym_PLUS_EQ] = ACTIONS(1855),
    [anon_sym_record] = ACTIONS(1857),
    [anon_sym_DASH_EQ] = ACTIONS(1855),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_LBRACK] = ACTIONS(1857),
    [anon_sym_local] = ACTIONS(1857),
    [anon_sym_EQ] = ACTIONS(1855),
    [anon_sym_function] = ACTIONS(1857),
    [anon_sym_hook] = ACTIONS(1857),
    [anon_sym_addr] = ACTIONS(1857),
    [anon_sym_any] = ACTIONS(1857),
    [anon_sym_bool] = ACTIONS(1857),
    [anon_sym_count] = ACTIONS(1857),
    [anon_sym_double] = ACTIONS(1857),
    [anon_sym_file] = ACTIONS(1857),
    [anon_sym_int] = ACTIONS(1857),
    [anon_sym_interval] = ACTIONS(1857),
    [anon_sym_list] = ACTIONS(1857),
    [anon_sym_pattern] = ACTIONS(1857),
    [anon_sym_port] = ACTIONS(1857),
    [anon_sym_string] = ACTIONS(1857),
    [anon_sym_subnet] = ACTIONS(1857),
    [anon_sym_time] = ACTIONS(1857),
    [anon_sym_opaque] = ACTIONS(1857),
    [anon_sym_set] = ACTIONS(1857),
    [anon_sym_table] = ACTIONS(1857),
    [anon_sym_union] = ACTIONS(1857),
    [anon_sym_vector] = ACTIONS(1857),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1855),
    [anon_sym_AMPdeprecated] = ACTIONS(1855),
    [anon_sym_AMPerror_handler] = ACTIONS(1855),
    [anon_sym_AMPis_assigned] = ACTIONS(1855),
    [anon_sym_AMPis_used] = ACTIONS(1855),
    [anon_sym_AMPlog] = ACTIONS(1855),
    [anon_sym_AMPoptional] = ACTIONS(1855),
    [anon_sym_AMPordered] = ACTIONS(1855),
    [anon_sym_AMPraw_output] = ACTIONS(1855),
    [anon_sym_AMPredef] = ACTIONS(1855),
    [anon_sym_AMPadd_func] = ACTIONS(1855),
    [anon_sym_AMPbackend] = ACTIONS(1855),
    [anon_sym_AMPbroker_store] = ACTIONS(1855),
    [anon_sym_AMPcreate_expire] = ACTIONS(1855),
    [anon_sym_AMPdefault] = ACTIONS(1855),
    [anon_sym_AMPdelete_func] = ACTIONS(1855),
    [anon_sym_AMPexpire_func] = ACTIONS(1855),
    [anon_sym_AMPgroup] = ACTIONS(1855),
    [anon_sym_AMPon_change] = ACTIONS(1855),
    [anon_sym_AMPpriority] = ACTIONS(1855),
    [anon_sym_AMPread_expire] = ACTIONS(1855),
    [anon_sym_AMPtype_column] = ACTIONS(1855),
    [anon_sym_AMPwrite_expire] = ACTIONS(1855),
    [anon_sym_DOLLAR] = ACTIONS(1855),
    [anon_sym_PIPE] = ACTIONS(1855),
    [anon_sym_PLUS_PLUS] = ACTIONS(1855),
    [anon_sym_DASH_DASH] = ACTIONS(1855),
    [anon_sym_BANG] = ACTIONS(1855),
    [anon_sym_TILDE] = ACTIONS(1855),
    [anon_sym_DASH] = ACTIONS(1857),
    [anon_sym_PLUS] = ACTIONS(1857),
    [anon_sym_copy] = ACTIONS(1857),
    [anon_sym_schedule] = ACTIONS(1857),
    [anon_sym_T] = ACTIONS(1857),
    [anon_sym_F] = ACTIONS(1857),
    [anon_sym_ATDIR] = ACTIONS(1855),
    [anon_sym_ATFILENAME] = ACTIONS(1855),
    [sym_id] = ACTIONS(1857),
    [sym_pattern] = ACTIONS(1855),
    [sym_ipv4] = ACTIONS(1857),
    [sym_ipv6] = ACTIONS(1855),
    [sym_port] = ACTIONS(1855),
    [sym_integer] = ACTIONS(1857),
    [sym_floatp] = ACTIONS(1857),
    [sym_hex] = ACTIONS(1857),
    [sym_hostname] = ACTIONS(1857),
    [aux_sym_string_token1] = ACTIONS(1855),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(761)] = {
    [anon_sym_SEMI] = ACTIONS(1859),
    [anon_sym_LBRACE] = ACTIONS(1859),
    [anon_sym_enum] = ACTIONS(1861),
    [anon_sym_PLUS_EQ] = ACTIONS(1859),
    [anon_sym_record] = ACTIONS(1861),
    [anon_sym_DASH_EQ] = ACTIONS(1859),
    [anon_sym_LPAREN] = ACTIONS(1859),
    [anon_sym_LBRACK] = ACTIONS(1861),
    [anon_sym_local] = ACTIONS(1861),
    [anon_sym_EQ] = ACTIONS(1859),
    [anon_sym_function] = ACTIONS(1861),
    [anon_sym_hook] = ACTIONS(1861),
    [anon_sym_addr] = ACTIONS(1861),
    [anon_sym_any] = ACTIONS(1861),
    [anon_sym_bool] = ACTIONS(1861),
    [anon_sym_count] = ACTIONS(1861),
    [anon_sym_double] = ACTIONS(1861),
    [anon_sym_file] = ACTIONS(1861),
    [anon_sym_int] = ACTIONS(1861),
    [anon_sym_interval] = ACTIONS(1861),
    [anon_sym_list] = ACTIONS(1861),
    [anon_sym_pattern] = ACTIONS(1861),
    [anon_sym_port] = ACTIONS(1861),
    [anon_sym_string] = ACTIONS(1861),
    [anon_sym_subnet] = ACTIONS(1861),
    [anon_sym_time] = ACTIONS(1861),
    [anon_sym_opaque] = ACTIONS(1861),
    [anon_sym_set] = ACTIONS(1861),
    [anon_sym_table] = ACTIONS(1861),
    [anon_sym_union] = ACTIONS(1861),
    [anon_sym_vector] = ACTIONS(1861),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1859),
    [anon_sym_AMPdeprecated] = ACTIONS(1859),
    [anon_sym_AMPerror_handler] = ACTIONS(1859),
    [anon_sym_AMPis_assigned] = ACTIONS(1859),
    [anon_sym_AMPis_used] = ACTIONS(1859),
    [anon_sym_AMPlog] = ACTIONS(1859),
    [anon_sym_AMPoptional] = ACTIONS(1859),
    [anon_sym_AMPordered] = ACTIONS(1859),
    [anon_sym_AMPraw_output] = ACTIONS(1859),
    [anon_sym_AMPredef] = ACTIONS(1859),
    [anon_sym_AMPadd_func] = ACTIONS(1859),
    [anon_sym_AMPbackend] = ACTIONS(1859),
    [anon_sym_AMPbroker_store] = ACTIONS(1859),
    [anon_sym_AMPcreate_expire] = ACTIONS(1859),
    [anon_sym_AMPdefault] = ACTIONS(1859),
    [anon_sym_AMPdelete_func] = ACTIONS(1859),
    [anon_sym_AMPexpire_func] = ACTIONS(1859),
    [anon_sym_AMPgroup] = ACTIONS(1859),
    [anon_sym_AMPon_change] = ACTIONS(1859),
    [anon_sym_AMPpriority] = ACTIONS(1859),
    [anon_sym_AMPread_expire] = ACTIONS(1859),
    [anon_sym_AMPtype_column] = ACTIONS(1859),
    [anon_sym_AMPwrite_expire] = ACTIONS(1859),
    [anon_sym_DOLLAR] = ACTIONS(1859),
    [anon_sym_PIPE] = ACTIONS(1859),
    [anon_sym_PLUS_PLUS] = ACTIONS(1859),
    [anon_sym_DASH_DASH] = ACTIONS(1859),
    [anon_sym_BANG] = ACTIONS(1859),
    [anon_sym_TILDE] = ACTIONS(1859),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_copy] = ACTIONS(1861),
    [anon_sym_schedule] = ACTIONS(1861),
    [anon_sym_T] = ACTIONS(1861),
    [anon_sym_F] = ACTIONS(1861),
    [anon_sym_ATDIR] = ACTIONS(1859),
    [anon_sym_ATFILENAME] = ACTIONS(1859),
    [sym_id] = ACTIONS(1861),
    [sym_pattern] = ACTIONS(1859),
    [sym_ipv4] = ACTIONS(1861),
    [sym_ipv6] = ACTIONS(1859),
    [sym_port] = ACTIONS(1859),
    [sym_integer] = ACTIONS(1861),
    [sym_floatp] = ACTIONS(1861),
    [sym_hex] = ACTIONS(1861),
    [sym_hostname] = ACTIONS(1861),
    [aux_sym_string_token1] = ACTIONS(1859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(762)] = {
    [anon_sym_SEMI] = ACTIONS(1837),
    [anon_sym_LBRACE] = ACTIONS(1837),
    [anon_sym_enum] = ACTIONS(1839),
    [anon_sym_PLUS_EQ] = ACTIONS(1837),
    [anon_sym_record] = ACTIONS(1839),
    [anon_sym_DASH_EQ] = ACTIONS(1837),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_LBRACK] = ACTIONS(1839),
    [anon_sym_local] = ACTIONS(1839),
    [anon_sym_EQ] = ACTIONS(1837),
    [anon_sym_function] = ACTIONS(1839),
    [anon_sym_hook] = ACTIONS(1839),
    [anon_sym_addr] = ACTIONS(1839),
    [anon_sym_any] = ACTIONS(1839),
    [anon_sym_bool] = ACTIONS(1839),
    [anon_sym_count] = ACTIONS(1839),
    [anon_sym_double] = ACTIONS(1839),
    [anon_sym_file] = ACTIONS(1839),
    [anon_sym_int] = ACTIONS(1839),
    [anon_sym_interval] = ACTIONS(1839),
    [anon_sym_list] = ACTIONS(1839),
    [anon_sym_pattern] = ACTIONS(1839),
    [anon_sym_port] = ACTIONS(1839),
    [anon_sym_string] = ACTIONS(1839),
    [anon_sym_subnet] = ACTIONS(1839),
    [anon_sym_time] = ACTIONS(1839),
    [anon_sym_opaque] = ACTIONS(1839),
    [anon_sym_set] = ACTIONS(1839),
    [anon_sym_table] = ACTIONS(1839),
    [anon_sym_union] = ACTIONS(1839),
    [anon_sym_vector] = ACTIONS(1839),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1837),
    [anon_sym_AMPdeprecated] = ACTIONS(1837),
    [anon_sym_AMPerror_handler] = ACTIONS(1837),
    [anon_sym_AMPis_assigned] = ACTIONS(1837),
    [anon_sym_AMPis_used] = ACTIONS(1837),
    [anon_sym_AMPlog] = ACTIONS(1837),
    [anon_sym_AMPoptional] = ACTIONS(1837),
    [anon_sym_AMPordered] = ACTIONS(1837),
    [anon_sym_AMPraw_output] = ACTIONS(1837),
    [anon_sym_AMPredef] = ACTIONS(1837),
    [anon_sym_AMPadd_func] = ACTIONS(1837),
    [anon_sym_AMPbackend] = ACTIONS(1837),
    [anon_sym_AMPbroker_store] = ACTIONS(1837),
    [anon_sym_AMPcreate_expire] = ACTIONS(1837),
    [anon_sym_AMPdefault] = ACTIONS(1837),
    [anon_sym_AMPdelete_func] = ACTIONS(1837),
    [anon_sym_AMPexpire_func] = ACTIONS(1837),
    [anon_sym_AMPgroup] = ACTIONS(1837),
    [anon_sym_AMPon_change] = ACTIONS(1837),
    [anon_sym_AMPpriority] = ACTIONS(1837),
    [anon_sym_AMPread_expire] = ACTIONS(1837),
    [anon_sym_AMPtype_column] = ACTIONS(1837),
    [anon_sym_AMPwrite_expire] = ACTIONS(1837),
    [anon_sym_DOLLAR] = ACTIONS(1837),
    [anon_sym_PIPE] = ACTIONS(1837),
    [anon_sym_PLUS_PLUS] = ACTIONS(1837),
    [anon_sym_DASH_DASH] = ACTIONS(1837),
    [anon_sym_BANG] = ACTIONS(1837),
    [anon_sym_TILDE] = ACTIONS(1837),
    [anon_sym_DASH] = ACTIONS(1839),
    [anon_sym_PLUS] = ACTIONS(1839),
    [anon_sym_copy] = ACTIONS(1839),
    [anon_sym_schedule] = ACTIONS(1839),
    [anon_sym_T] = ACTIONS(1839),
    [anon_sym_F] = ACTIONS(1839),
    [anon_sym_ATDIR] = ACTIONS(1837),
    [anon_sym_ATFILENAME] = ACTIONS(1837),
    [sym_id] = ACTIONS(1839),
    [sym_pattern] = ACTIONS(1837),
    [sym_ipv4] = ACTIONS(1839),
    [sym_ipv6] = ACTIONS(1837),
    [sym_port] = ACTIONS(1837),
    [sym_integer] = ACTIONS(1839),
    [sym_floatp] = ACTIONS(1839),
    [sym_hex] = ACTIONS(1839),
    [sym_hostname] = ACTIONS(1839),
    [aux_sym_string_token1] = ACTIONS(1837),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(763)] = {
    [anon_sym_SEMI] = ACTIONS(1863),
    [anon_sym_LBRACE] = ACTIONS(1863),
    [anon_sym_enum] = ACTIONS(1865),
    [anon_sym_PLUS_EQ] = ACTIONS(1863),
    [anon_sym_record] = ACTIONS(1865),
    [anon_sym_DASH_EQ] = ACTIONS(1863),
    [anon_sym_LPAREN] = ACTIONS(1863),
    [anon_sym_LBRACK] = ACTIONS(1865),
    [anon_sym_local] = ACTIONS(1865),
    [anon_sym_EQ] = ACTIONS(1863),
    [anon_sym_function] = ACTIONS(1865),
    [anon_sym_hook] = ACTIONS(1865),
    [anon_sym_addr] = ACTIONS(1865),
    [anon_sym_any] = ACTIONS(1865),
    [anon_sym_bool] = ACTIONS(1865),
    [anon_sym_count] = ACTIONS(1865),
    [anon_sym_double] = ACTIONS(1865),
    [anon_sym_file] = ACTIONS(1865),
    [anon_sym_int] = ACTIONS(1865),
    [anon_sym_interval] = ACTIONS(1865),
    [anon_sym_list] = ACTIONS(1865),
    [anon_sym_pattern] = ACTIONS(1865),
    [anon_sym_port] = ACTIONS(1865),
    [anon_sym_string] = ACTIONS(1865),
    [anon_sym_subnet] = ACTIONS(1865),
    [anon_sym_time] = ACTIONS(1865),
    [anon_sym_opaque] = ACTIONS(1865),
    [anon_sym_set] = ACTIONS(1865),
    [anon_sym_table] = ACTIONS(1865),
    [anon_sym_union] = ACTIONS(1865),
    [anon_sym_vector] = ACTIONS(1865),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1863),
    [anon_sym_AMPdeprecated] = ACTIONS(1863),
    [anon_sym_AMPerror_handler] = ACTIONS(1863),
    [anon_sym_AMPis_assigned] = ACTIONS(1863),
    [anon_sym_AMPis_used] = ACTIONS(1863),
    [anon_sym_AMPlog] = ACTIONS(1863),
    [anon_sym_AMPoptional] = ACTIONS(1863),
    [anon_sym_AMPordered] = ACTIONS(1863),
    [anon_sym_AMPraw_output] = ACTIONS(1863),
    [anon_sym_AMPredef] = ACTIONS(1863),
    [anon_sym_AMPadd_func] = ACTIONS(1863),
    [anon_sym_AMPbackend] = ACTIONS(1863),
    [anon_sym_AMPbroker_store] = ACTIONS(1863),
    [anon_sym_AMPcreate_expire] = ACTIONS(1863),
    [anon_sym_AMPdefault] = ACTIONS(1863),
    [anon_sym_AMPdelete_func] = ACTIONS(1863),
    [anon_sym_AMPexpire_func] = ACTIONS(1863),
    [anon_sym_AMPgroup] = ACTIONS(1863),
    [anon_sym_AMPon_change] = ACTIONS(1863),
    [anon_sym_AMPpriority] = ACTIONS(1863),
    [anon_sym_AMPread_expire] = ACTIONS(1863),
    [anon_sym_AMPtype_column] = ACTIONS(1863),
    [anon_sym_AMPwrite_expire] = ACTIONS(1863),
    [anon_sym_DOLLAR] = ACTIONS(1863),
    [anon_sym_PIPE] = ACTIONS(1863),
    [anon_sym_PLUS_PLUS] = ACTIONS(1863),
    [anon_sym_DASH_DASH] = ACTIONS(1863),
    [anon_sym_BANG] = ACTIONS(1863),
    [anon_sym_TILDE] = ACTIONS(1863),
    [anon_sym_DASH] = ACTIONS(1865),
    [anon_sym_PLUS] = ACTIONS(1865),
    [anon_sym_copy] = ACTIONS(1865),
    [anon_sym_schedule] = ACTIONS(1865),
    [anon_sym_T] = ACTIONS(1865),
    [anon_sym_F] = ACTIONS(1865),
    [anon_sym_ATDIR] = ACTIONS(1863),
    [anon_sym_ATFILENAME] = ACTIONS(1863),
    [sym_id] = ACTIONS(1865),
    [sym_pattern] = ACTIONS(1863),
    [sym_ipv4] = ACTIONS(1865),
    [sym_ipv6] = ACTIONS(1863),
    [sym_port] = ACTIONS(1863),
    [sym_integer] = ACTIONS(1865),
    [sym_floatp] = ACTIONS(1865),
    [sym_hex] = ACTIONS(1865),
    [sym_hostname] = ACTIONS(1865),
    [aux_sym_string_token1] = ACTIONS(1863),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(764)] = {
    [anon_sym_SEMI] = ACTIONS(1867),
    [anon_sym_LBRACE] = ACTIONS(1867),
    [anon_sym_enum] = ACTIONS(1869),
    [anon_sym_PLUS_EQ] = ACTIONS(1867),
    [anon_sym_record] = ACTIONS(1869),
    [anon_sym_DASH_EQ] = ACTIONS(1867),
    [anon_sym_LPAREN] = ACTIONS(1867),
    [anon_sym_LBRACK] = ACTIONS(1869),
    [anon_sym_local] = ACTIONS(1869),
    [anon_sym_EQ] = ACTIONS(1867),
    [anon_sym_function] = ACTIONS(1869),
    [anon_sym_hook] = ACTIONS(1869),
    [anon_sym_addr] = ACTIONS(1869),
    [anon_sym_any] = ACTIONS(1869),
    [anon_sym_bool] = ACTIONS(1869),
    [anon_sym_count] = ACTIONS(1869),
    [anon_sym_double] = ACTIONS(1869),
    [anon_sym_file] = ACTIONS(1869),
    [anon_sym_int] = ACTIONS(1869),
    [anon_sym_interval] = ACTIONS(1869),
    [anon_sym_list] = ACTIONS(1869),
    [anon_sym_pattern] = ACTIONS(1869),
    [anon_sym_port] = ACTIONS(1869),
    [anon_sym_string] = ACTIONS(1869),
    [anon_sym_subnet] = ACTIONS(1869),
    [anon_sym_time] = ACTIONS(1869),
    [anon_sym_opaque] = ACTIONS(1869),
    [anon_sym_set] = ACTIONS(1869),
    [anon_sym_table] = ACTIONS(1869),
    [anon_sym_union] = ACTIONS(1869),
    [anon_sym_vector] = ACTIONS(1869),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1867),
    [anon_sym_AMPdeprecated] = ACTIONS(1867),
    [anon_sym_AMPerror_handler] = ACTIONS(1867),
    [anon_sym_AMPis_assigned] = ACTIONS(1867),
    [anon_sym_AMPis_used] = ACTIONS(1867),
    [anon_sym_AMPlog] = ACTIONS(1867),
    [anon_sym_AMPoptional] = ACTIONS(1867),
    [anon_sym_AMPordered] = ACTIONS(1867),
    [anon_sym_AMPraw_output] = ACTIONS(1867),
    [anon_sym_AMPredef] = ACTIONS(1867),
    [anon_sym_AMPadd_func] = ACTIONS(1867),
    [anon_sym_AMPbackend] = ACTIONS(1867),
    [anon_sym_AMPbroker_store] = ACTIONS(1867),
    [anon_sym_AMPcreate_expire] = ACTIONS(1867),
    [anon_sym_AMPdefault] = ACTIONS(1867),
    [anon_sym_AMPdelete_func] = ACTIONS(1867),
    [anon_sym_AMPexpire_func] = ACTIONS(1867),
    [anon_sym_AMPgroup] = ACTIONS(1867),
    [anon_sym_AMPon_change] = ACTIONS(1867),
    [anon_sym_AMPpriority] = ACTIONS(1867),
    [anon_sym_AMPread_expire] = ACTIONS(1867),
    [anon_sym_AMPtype_column] = ACTIONS(1867),
    [anon_sym_AMPwrite_expire] = ACTIONS(1867),
    [anon_sym_DOLLAR] = ACTIONS(1867),
    [anon_sym_PIPE] = ACTIONS(1867),
    [anon_sym_PLUS_PLUS] = ACTIONS(1867),
    [anon_sym_DASH_DASH] = ACTIONS(1867),
    [anon_sym_BANG] = ACTIONS(1867),
    [anon_sym_TILDE] = ACTIONS(1867),
    [anon_sym_DASH] = ACTIONS(1869),
    [anon_sym_PLUS] = ACTIONS(1869),
    [anon_sym_copy] = ACTIONS(1869),
    [anon_sym_schedule] = ACTIONS(1869),
    [anon_sym_T] = ACTIONS(1869),
    [anon_sym_F] = ACTIONS(1869),
    [anon_sym_ATDIR] = ACTIONS(1867),
    [anon_sym_ATFILENAME] = ACTIONS(1867),
    [sym_id] = ACTIONS(1869),
    [sym_pattern] = ACTIONS(1867),
    [sym_ipv4] = ACTIONS(1869),
    [sym_ipv6] = ACTIONS(1867),
    [sym_port] = ACTIONS(1867),
    [sym_integer] = ACTIONS(1869),
    [sym_floatp] = ACTIONS(1869),
    [sym_hex] = ACTIONS(1869),
    [sym_hostname] = ACTIONS(1869),
    [aux_sym_string_token1] = ACTIONS(1867),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(765)] = {
    [anon_sym_SEMI] = ACTIONS(1871),
    [anon_sym_LBRACE] = ACTIONS(1871),
    [anon_sym_enum] = ACTIONS(1873),
    [anon_sym_PLUS_EQ] = ACTIONS(1871),
    [anon_sym_record] = ACTIONS(1873),
    [anon_sym_DASH_EQ] = ACTIONS(1871),
    [anon_sym_LPAREN] = ACTIONS(1871),
    [anon_sym_LBRACK] = ACTIONS(1873),
    [anon_sym_local] = ACTIONS(1873),
    [anon_sym_EQ] = ACTIONS(1871),
    [anon_sym_function] = ACTIONS(1873),
    [anon_sym_hook] = ACTIONS(1873),
    [anon_sym_addr] = ACTIONS(1873),
    [anon_sym_any] = ACTIONS(1873),
    [anon_sym_bool] = ACTIONS(1873),
    [anon_sym_count] = ACTIONS(1873),
    [anon_sym_double] = ACTIONS(1873),
    [anon_sym_file] = ACTIONS(1873),
    [anon_sym_int] = ACTIONS(1873),
    [anon_sym_interval] = ACTIONS(1873),
    [anon_sym_list] = ACTIONS(1873),
    [anon_sym_pattern] = ACTIONS(1873),
    [anon_sym_port] = ACTIONS(1873),
    [anon_sym_string] = ACTIONS(1873),
    [anon_sym_subnet] = ACTIONS(1873),
    [anon_sym_time] = ACTIONS(1873),
    [anon_sym_opaque] = ACTIONS(1873),
    [anon_sym_set] = ACTIONS(1873),
    [anon_sym_table] = ACTIONS(1873),
    [anon_sym_union] = ACTIONS(1873),
    [anon_sym_vector] = ACTIONS(1873),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1871),
    [anon_sym_AMPdeprecated] = ACTIONS(1871),
    [anon_sym_AMPerror_handler] = ACTIONS(1871),
    [anon_sym_AMPis_assigned] = ACTIONS(1871),
    [anon_sym_AMPis_used] = ACTIONS(1871),
    [anon_sym_AMPlog] = ACTIONS(1871),
    [anon_sym_AMPoptional] = ACTIONS(1871),
    [anon_sym_AMPordered] = ACTIONS(1871),
    [anon_sym_AMPraw_output] = ACTIONS(1871),
    [anon_sym_AMPredef] = ACTIONS(1871),
    [anon_sym_AMPadd_func] = ACTIONS(1871),
    [anon_sym_AMPbackend] = ACTIONS(1871),
    [anon_sym_AMPbroker_store] = ACTIONS(1871),
    [anon_sym_AMPcreate_expire] = ACTIONS(1871),
    [anon_sym_AMPdefault] = ACTIONS(1871),
    [anon_sym_AMPdelete_func] = ACTIONS(1871),
    [anon_sym_AMPexpire_func] = ACTIONS(1871),
    [anon_sym_AMPgroup] = ACTIONS(1871),
    [anon_sym_AMPon_change] = ACTIONS(1871),
    [anon_sym_AMPpriority] = ACTIONS(1871),
    [anon_sym_AMPread_expire] = ACTIONS(1871),
    [anon_sym_AMPtype_column] = ACTIONS(1871),
    [anon_sym_AMPwrite_expire] = ACTIONS(1871),
    [anon_sym_DOLLAR] = ACTIONS(1871),
    [anon_sym_PIPE] = ACTIONS(1871),
    [anon_sym_PLUS_PLUS] = ACTIONS(1871),
    [anon_sym_DASH_DASH] = ACTIONS(1871),
    [anon_sym_BANG] = ACTIONS(1871),
    [anon_sym_TILDE] = ACTIONS(1871),
    [anon_sym_DASH] = ACTIONS(1873),
    [anon_sym_PLUS] = ACTIONS(1873),
    [anon_sym_copy] = ACTIONS(1873),
    [anon_sym_schedule] = ACTIONS(1873),
    [anon_sym_T] = ACTIONS(1873),
    [anon_sym_F] = ACTIONS(1873),
    [anon_sym_ATDIR] = ACTIONS(1871),
    [anon_sym_ATFILENAME] = ACTIONS(1871),
    [sym_id] = ACTIONS(1873),
    [sym_pattern] = ACTIONS(1871),
    [sym_ipv4] = ACTIONS(1873),
    [sym_ipv6] = ACTIONS(1871),
    [sym_port] = ACTIONS(1871),
    [sym_integer] = ACTIONS(1873),
    [sym_floatp] = ACTIONS(1873),
    [sym_hex] = ACTIONS(1873),
    [sym_hostname] = ACTIONS(1873),
    [aux_sym_string_token1] = ACTIONS(1871),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(766)] = {
    [anon_sym_SEMI] = ACTIONS(1875),
    [anon_sym_LBRACE] = ACTIONS(1875),
    [anon_sym_RBRACE] = ACTIONS(1875),
    [anon_sym_COLON] = ACTIONS(1875),
    [anon_sym_PLUS_EQ] = ACTIONS(1875),
    [anon_sym_DASH_EQ] = ACTIONS(1875),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_RPAREN] = ACTIONS(1875),
    [anon_sym_COMMA] = ACTIONS(1875),
    [anon_sym_in] = ACTIONS(1875),
    [anon_sym_LBRACK] = ACTIONS(1875),
    [anon_sym_RBRACK] = ACTIONS(1875),
    [anon_sym_EQ] = ACTIONS(1877),
    [anon_sym_as] = ACTIONS(1875),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1875),
    [anon_sym_AMPdeprecated] = ACTIONS(1875),
    [anon_sym_AMPerror_handler] = ACTIONS(1875),
    [anon_sym_AMPis_assigned] = ACTIONS(1875),
    [anon_sym_AMPis_used] = ACTIONS(1875),
    [anon_sym_AMPlog] = ACTIONS(1875),
    [anon_sym_AMPoptional] = ACTIONS(1875),
    [anon_sym_AMPordered] = ACTIONS(1875),
    [anon_sym_AMPraw_output] = ACTIONS(1875),
    [anon_sym_AMPredef] = ACTIONS(1875),
    [anon_sym_AMPadd_func] = ACTIONS(1875),
    [anon_sym_AMPbackend] = ACTIONS(1875),
    [anon_sym_AMPbroker_store] = ACTIONS(1875),
    [anon_sym_AMPcreate_expire] = ACTIONS(1875),
    [anon_sym_AMPdefault] = ACTIONS(1875),
    [anon_sym_AMPdelete_func] = ACTIONS(1875),
    [anon_sym_AMPexpire_func] = ACTIONS(1875),
    [anon_sym_AMPgroup] = ACTIONS(1875),
    [anon_sym_AMPon_change] = ACTIONS(1875),
    [anon_sym_AMPpriority] = ACTIONS(1875),
    [anon_sym_AMPread_expire] = ACTIONS(1875),
    [anon_sym_AMPtype_column] = ACTIONS(1875),
    [anon_sym_AMPwrite_expire] = ACTIONS(1875),
    [anon_sym_DOLLAR] = ACTIONS(1875),
    [anon_sym_PIPE] = ACTIONS(1877),
    [anon_sym_BANG] = ACTIONS(1877),
    [anon_sym_DASH] = ACTIONS(1877),
    [anon_sym_PLUS] = ACTIONS(1877),
    [anon_sym_is] = ACTIONS(1875),
    [anon_sym_STAR] = ACTIONS(1875),
    [anon_sym_SLASH] = ACTIONS(1875),
    [anon_sym_PERCENT] = ACTIONS(1875),
    [anon_sym_LT] = ACTIONS(1877),
    [anon_sym_LT_EQ] = ACTIONS(1875),
    [anon_sym_GT] = ACTIONS(1877),
    [anon_sym_GT_EQ] = ACTIONS(1875),
    [anon_sym_AMP] = ACTIONS(1877),
    [anon_sym_CARET] = ACTIONS(1875),
    [anon_sym_QMARK] = ACTIONS(1877),
    [anon_sym_EQ_EQ] = ACTIONS(1875),
    [anon_sym_BANG_EQ] = ACTIONS(1875),
    [anon_sym_AMP_AMP] = ACTIONS(1875),
    [anon_sym_PIPE_PIPE] = ACTIONS(1875),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1875),
    [anon_sym_ATdeprecated] = ACTIONS(1875),
    [anon_sym_ATload] = ACTIONS(1877),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1875),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1875),
    [anon_sym_ATunload] = ACTIONS(1875),
    [anon_sym_ATprefixes] = ACTIONS(1875),
    [anon_sym_ATif] = ACTIONS(1877),
    [anon_sym_ATifdef] = ACTIONS(1875),
    [anon_sym_ATifndef] = ACTIONS(1875),
    [anon_sym_ATendif] = ACTIONS(1875),
    [anon_sym_ATelse] = ACTIONS(1875),
    [anon_sym_ATpragma] = ACTIONS(1875),
    [sym_time_unit] = ACTIONS(1879),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(767)] = {
    [anon_sym_SEMI] = ACTIONS(1875),
    [anon_sym_LBRACE] = ACTIONS(1875),
    [anon_sym_RBRACE] = ACTIONS(1875),
    [anon_sym_COLON] = ACTIONS(1875),
    [anon_sym_PLUS_EQ] = ACTIONS(1875),
    [anon_sym_DASH_EQ] = ACTIONS(1875),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_RPAREN] = ACTIONS(1875),
    [anon_sym_COMMA] = ACTIONS(1875),
    [anon_sym_in] = ACTIONS(1875),
    [anon_sym_LBRACK] = ACTIONS(1875),
    [anon_sym_RBRACK] = ACTIONS(1875),
    [anon_sym_EQ] = ACTIONS(1877),
    [anon_sym_as] = ACTIONS(1875),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1875),
    [anon_sym_AMPdeprecated] = ACTIONS(1875),
    [anon_sym_AMPerror_handler] = ACTIONS(1875),
    [anon_sym_AMPis_assigned] = ACTIONS(1875),
    [anon_sym_AMPis_used] = ACTIONS(1875),
    [anon_sym_AMPlog] = ACTIONS(1875),
    [anon_sym_AMPoptional] = ACTIONS(1875),
    [anon_sym_AMPordered] = ACTIONS(1875),
    [anon_sym_AMPraw_output] = ACTIONS(1875),
    [anon_sym_AMPredef] = ACTIONS(1875),
    [anon_sym_AMPadd_func] = ACTIONS(1875),
    [anon_sym_AMPbackend] = ACTIONS(1875),
    [anon_sym_AMPbroker_store] = ACTIONS(1875),
    [anon_sym_AMPcreate_expire] = ACTIONS(1875),
    [anon_sym_AMPdefault] = ACTIONS(1875),
    [anon_sym_AMPdelete_func] = ACTIONS(1875),
    [anon_sym_AMPexpire_func] = ACTIONS(1875),
    [anon_sym_AMPgroup] = ACTIONS(1875),
    [anon_sym_AMPon_change] = ACTIONS(1875),
    [anon_sym_AMPpriority] = ACTIONS(1875),
    [anon_sym_AMPread_expire] = ACTIONS(1875),
    [anon_sym_AMPtype_column] = ACTIONS(1875),
    [anon_sym_AMPwrite_expire] = ACTIONS(1875),
    [anon_sym_DOLLAR] = ACTIONS(1875),
    [anon_sym_PIPE] = ACTIONS(1877),
    [anon_sym_BANG] = ACTIONS(1877),
    [anon_sym_DASH] = ACTIONS(1877),
    [anon_sym_PLUS] = ACTIONS(1877),
    [anon_sym_is] = ACTIONS(1875),
    [anon_sym_STAR] = ACTIONS(1875),
    [anon_sym_SLASH] = ACTIONS(1875),
    [anon_sym_PERCENT] = ACTIONS(1875),
    [anon_sym_LT] = ACTIONS(1877),
    [anon_sym_LT_EQ] = ACTIONS(1875),
    [anon_sym_GT] = ACTIONS(1877),
    [anon_sym_GT_EQ] = ACTIONS(1875),
    [anon_sym_AMP] = ACTIONS(1877),
    [anon_sym_CARET] = ACTIONS(1875),
    [anon_sym_QMARK] = ACTIONS(1877),
    [anon_sym_EQ_EQ] = ACTIONS(1875),
    [anon_sym_BANG_EQ] = ACTIONS(1875),
    [anon_sym_AMP_AMP] = ACTIONS(1875),
    [anon_sym_PIPE_PIPE] = ACTIONS(1875),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1875),
    [anon_sym_ATdeprecated] = ACTIONS(1875),
    [anon_sym_ATload] = ACTIONS(1877),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1875),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1875),
    [anon_sym_ATunload] = ACTIONS(1875),
    [anon_sym_ATprefixes] = ACTIONS(1875),
    [anon_sym_ATif] = ACTIONS(1877),
    [anon_sym_ATifdef] = ACTIONS(1875),
    [anon_sym_ATifndef] = ACTIONS(1875),
    [anon_sym_ATendif] = ACTIONS(1875),
    [anon_sym_ATelse] = ACTIONS(1875),
    [anon_sym_ATpragma] = ACTIONS(1875),
    [sym_time_unit] = ACTIONS(1879),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(768)] = {
    [anon_sym_SEMI] = ACTIONS(1881),
    [anon_sym_LBRACE] = ACTIONS(1881),
    [anon_sym_RBRACE] = ACTIONS(1881),
    [anon_sym_COLON] = ACTIONS(1881),
    [anon_sym_PLUS_EQ] = ACTIONS(1881),
    [anon_sym_DASH_EQ] = ACTIONS(1881),
    [anon_sym_LPAREN] = ACTIONS(1881),
    [anon_sym_RPAREN] = ACTIONS(1881),
    [anon_sym_COMMA] = ACTIONS(1881),
    [anon_sym_in] = ACTIONS(1881),
    [anon_sym_LBRACK] = ACTIONS(1881),
    [anon_sym_RBRACK] = ACTIONS(1881),
    [anon_sym_EQ] = ACTIONS(1883),
    [anon_sym_as] = ACTIONS(1881),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1881),
    [anon_sym_AMPdeprecated] = ACTIONS(1881),
    [anon_sym_AMPerror_handler] = ACTIONS(1881),
    [anon_sym_AMPis_assigned] = ACTIONS(1881),
    [anon_sym_AMPis_used] = ACTIONS(1881),
    [anon_sym_AMPlog] = ACTIONS(1881),
    [anon_sym_AMPoptional] = ACTIONS(1881),
    [anon_sym_AMPordered] = ACTIONS(1881),
    [anon_sym_AMPraw_output] = ACTIONS(1881),
    [anon_sym_AMPredef] = ACTIONS(1881),
    [anon_sym_AMPadd_func] = ACTIONS(1881),
    [anon_sym_AMPbackend] = ACTIONS(1881),
    [anon_sym_AMPbroker_store] = ACTIONS(1881),
    [anon_sym_AMPcreate_expire] = ACTIONS(1881),
    [anon_sym_AMPdefault] = ACTIONS(1881),
    [anon_sym_AMPdelete_func] = ACTIONS(1881),
    [anon_sym_AMPexpire_func] = ACTIONS(1881),
    [anon_sym_AMPgroup] = ACTIONS(1881),
    [anon_sym_AMPon_change] = ACTIONS(1881),
    [anon_sym_AMPpriority] = ACTIONS(1881),
    [anon_sym_AMPread_expire] = ACTIONS(1881),
    [anon_sym_AMPtype_column] = ACTIONS(1881),
    [anon_sym_AMPwrite_expire] = ACTIONS(1881),
    [anon_sym_DOLLAR] = ACTIONS(1881),
    [anon_sym_PIPE] = ACTIONS(1883),
    [anon_sym_BANG] = ACTIONS(1883),
    [anon_sym_DASH] = ACTIONS(1883),
    [anon_sym_PLUS] = ACTIONS(1883),
    [anon_sym_is] = ACTIONS(1881),
    [anon_sym_STAR] = ACTIONS(1881),
    [anon_sym_SLASH] = ACTIONS(1881),
    [anon_sym_PERCENT] = ACTIONS(1881),
    [anon_sym_LT] = ACTIONS(1883),
    [anon_sym_LT_EQ] = ACTIONS(1881),
    [anon_sym_GT] = ACTIONS(1883),
    [anon_sym_GT_EQ] = ACTIONS(1881),
    [anon_sym_AMP] = ACTIONS(1883),
    [anon_sym_CARET] = ACTIONS(1881),
    [anon_sym_QMARK] = ACTIONS(1883),
    [anon_sym_EQ_EQ] = ACTIONS(1881),
    [anon_sym_BANG_EQ] = ACTIONS(1881),
    [anon_sym_AMP_AMP] = ACTIONS(1881),
    [anon_sym_PIPE_PIPE] = ACTIONS(1881),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1881),
    [anon_sym_ATdeprecated] = ACTIONS(1881),
    [anon_sym_ATload] = ACTIONS(1883),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1881),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1881),
    [anon_sym_ATunload] = ACTIONS(1881),
    [anon_sym_ATprefixes] = ACTIONS(1881),
    [anon_sym_ATif] = ACTIONS(1883),
    [anon_sym_ATifdef] = ACTIONS(1881),
    [anon_sym_ATifndef] = ACTIONS(1881),
    [anon_sym_ATendif] = ACTIONS(1881),
    [anon_sym_ATelse] = ACTIONS(1881),
    [anon_sym_ATpragma] = ACTIONS(1881),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(769)] = {
    [anon_sym_SEMI] = ACTIONS(1875),
    [anon_sym_LBRACE] = ACTIONS(1875),
    [anon_sym_RBRACE] = ACTIONS(1875),
    [anon_sym_COLON] = ACTIONS(1875),
    [anon_sym_PLUS_EQ] = ACTIONS(1875),
    [anon_sym_DASH_EQ] = ACTIONS(1875),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_RPAREN] = ACTIONS(1875),
    [anon_sym_COMMA] = ACTIONS(1875),
    [anon_sym_in] = ACTIONS(1875),
    [anon_sym_LBRACK] = ACTIONS(1875),
    [anon_sym_RBRACK] = ACTIONS(1875),
    [anon_sym_EQ] = ACTIONS(1877),
    [anon_sym_as] = ACTIONS(1875),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1875),
    [anon_sym_AMPdeprecated] = ACTIONS(1875),
    [anon_sym_AMPerror_handler] = ACTIONS(1875),
    [anon_sym_AMPis_assigned] = ACTIONS(1875),
    [anon_sym_AMPis_used] = ACTIONS(1875),
    [anon_sym_AMPlog] = ACTIONS(1875),
    [anon_sym_AMPoptional] = ACTIONS(1875),
    [anon_sym_AMPordered] = ACTIONS(1875),
    [anon_sym_AMPraw_output] = ACTIONS(1875),
    [anon_sym_AMPredef] = ACTIONS(1875),
    [anon_sym_AMPadd_func] = ACTIONS(1875),
    [anon_sym_AMPbackend] = ACTIONS(1875),
    [anon_sym_AMPbroker_store] = ACTIONS(1875),
    [anon_sym_AMPcreate_expire] = ACTIONS(1875),
    [anon_sym_AMPdefault] = ACTIONS(1875),
    [anon_sym_AMPdelete_func] = ACTIONS(1875),
    [anon_sym_AMPexpire_func] = ACTIONS(1875),
    [anon_sym_AMPgroup] = ACTIONS(1875),
    [anon_sym_AMPon_change] = ACTIONS(1875),
    [anon_sym_AMPpriority] = ACTIONS(1875),
    [anon_sym_AMPread_expire] = ACTIONS(1875),
    [anon_sym_AMPtype_column] = ACTIONS(1875),
    [anon_sym_AMPwrite_expire] = ACTIONS(1875),
    [anon_sym_DOLLAR] = ACTIONS(1875),
    [anon_sym_PIPE] = ACTIONS(1877),
    [anon_sym_BANG] = ACTIONS(1877),
    [anon_sym_DASH] = ACTIONS(1877),
    [anon_sym_PLUS] = ACTIONS(1877),
    [anon_sym_is] = ACTIONS(1875),
    [anon_sym_STAR] = ACTIONS(1875),
    [anon_sym_SLASH] = ACTIONS(1875),
    [anon_sym_PERCENT] = ACTIONS(1875),
    [anon_sym_LT] = ACTIONS(1877),
    [anon_sym_LT_EQ] = ACTIONS(1875),
    [anon_sym_GT] = ACTIONS(1877),
    [anon_sym_GT_EQ] = ACTIONS(1875),
    [anon_sym_AMP] = ACTIONS(1877),
    [anon_sym_CARET] = ACTIONS(1875),
    [anon_sym_QMARK] = ACTIONS(1877),
    [anon_sym_EQ_EQ] = ACTIONS(1875),
    [anon_sym_BANG_EQ] = ACTIONS(1875),
    [anon_sym_AMP_AMP] = ACTIONS(1875),
    [anon_sym_PIPE_PIPE] = ACTIONS(1875),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1875),
    [anon_sym_ATdeprecated] = ACTIONS(1875),
    [anon_sym_ATload] = ACTIONS(1877),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1875),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1875),
    [anon_sym_ATunload] = ACTIONS(1875),
    [anon_sym_ATprefixes] = ACTIONS(1875),
    [anon_sym_ATif] = ACTIONS(1877),
    [anon_sym_ATifdef] = ACTIONS(1875),
    [anon_sym_ATifndef] = ACTIONS(1875),
    [anon_sym_ATendif] = ACTIONS(1875),
    [anon_sym_ATelse] = ACTIONS(1875),
    [anon_sym_ATpragma] = ACTIONS(1875),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(770)] = {
    [anon_sym_SEMI] = ACTIONS(1885),
    [anon_sym_LBRACE] = ACTIONS(1885),
    [anon_sym_RBRACE] = ACTIONS(1885),
    [anon_sym_COLON] = ACTIONS(1885),
    [anon_sym_PLUS_EQ] = ACTIONS(1885),
    [anon_sym_DASH_EQ] = ACTIONS(1885),
    [anon_sym_LPAREN] = ACTIONS(1887),
    [anon_sym_RPAREN] = ACTIONS(1885),
    [anon_sym_COMMA] = ACTIONS(1885),
    [anon_sym_in] = ACTIONS(1885),
    [anon_sym_LBRACK] = ACTIONS(1885),
    [anon_sym_RBRACK] = ACTIONS(1885),
    [anon_sym_EQ] = ACTIONS(1889),
    [anon_sym_as] = ACTIONS(1885),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1885),
    [anon_sym_AMPdeprecated] = ACTIONS(1885),
    [anon_sym_AMPerror_handler] = ACTIONS(1885),
    [anon_sym_AMPis_assigned] = ACTIONS(1885),
    [anon_sym_AMPis_used] = ACTIONS(1885),
    [anon_sym_AMPlog] = ACTIONS(1885),
    [anon_sym_AMPoptional] = ACTIONS(1885),
    [anon_sym_AMPordered] = ACTIONS(1885),
    [anon_sym_AMPraw_output] = ACTIONS(1885),
    [anon_sym_AMPredef] = ACTIONS(1885),
    [anon_sym_AMPadd_func] = ACTIONS(1885),
    [anon_sym_AMPbackend] = ACTIONS(1885),
    [anon_sym_AMPbroker_store] = ACTIONS(1885),
    [anon_sym_AMPcreate_expire] = ACTIONS(1885),
    [anon_sym_AMPdefault] = ACTIONS(1885),
    [anon_sym_AMPdelete_func] = ACTIONS(1885),
    [anon_sym_AMPexpire_func] = ACTIONS(1885),
    [anon_sym_AMPgroup] = ACTIONS(1885),
    [anon_sym_AMPon_change] = ACTIONS(1885),
    [anon_sym_AMPpriority] = ACTIONS(1885),
    [anon_sym_AMPread_expire] = ACTIONS(1885),
    [anon_sym_AMPtype_column] = ACTIONS(1885),
    [anon_sym_AMPwrite_expire] = ACTIONS(1885),
    [anon_sym_DOLLAR] = ACTIONS(1885),
    [anon_sym_PIPE] = ACTIONS(1889),
    [anon_sym_BANG] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1889),
    [anon_sym_PLUS] = ACTIONS(1889),
    [anon_sym_is] = ACTIONS(1885),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_SLASH] = ACTIONS(1885),
    [anon_sym_PERCENT] = ACTIONS(1885),
    [anon_sym_LT] = ACTIONS(1889),
    [anon_sym_LT_EQ] = ACTIONS(1885),
    [anon_sym_GT] = ACTIONS(1889),
    [anon_sym_GT_EQ] = ACTIONS(1885),
    [anon_sym_AMP] = ACTIONS(1889),
    [anon_sym_CARET] = ACTIONS(1885),
    [anon_sym_QMARK] = ACTIONS(1889),
    [anon_sym_EQ_EQ] = ACTIONS(1885),
    [anon_sym_BANG_EQ] = ACTIONS(1885),
    [anon_sym_AMP_AMP] = ACTIONS(1885),
    [anon_sym_PIPE_PIPE] = ACTIONS(1885),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1885),
    [anon_sym_ATdeprecated] = ACTIONS(1885),
    [anon_sym_ATload] = ACTIONS(1889),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1885),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1885),
    [anon_sym_ATunload] = ACTIONS(1885),
    [anon_sym_ATprefixes] = ACTIONS(1885),
    [anon_sym_ATif] = ACTIONS(1889),
    [anon_sym_ATifdef] = ACTIONS(1885),
    [anon_sym_ATifndef] = ACTIONS(1885),
    [anon_sym_ATendif] = ACTIONS(1885),
    [anon_sym_ATelse] = ACTIONS(1885),
    [anon_sym_ATpragma] = ACTIONS(1885),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(771)] = {
    [anon_sym_SEMI] = ACTIONS(1891),
    [anon_sym_LBRACE] = ACTIONS(1891),
    [anon_sym_RBRACE] = ACTIONS(1891),
    [anon_sym_COLON] = ACTIONS(1891),
    [anon_sym_PLUS_EQ] = ACTIONS(1891),
    [anon_sym_DASH_EQ] = ACTIONS(1891),
    [anon_sym_LPAREN] = ACTIONS(1891),
    [anon_sym_RPAREN] = ACTIONS(1891),
    [anon_sym_COMMA] = ACTIONS(1891),
    [anon_sym_in] = ACTIONS(1891),
    [anon_sym_LBRACK] = ACTIONS(1891),
    [anon_sym_RBRACK] = ACTIONS(1891),
    [anon_sym_EQ] = ACTIONS(1893),
    [anon_sym_as] = ACTIONS(1891),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1891),
    [anon_sym_AMPdeprecated] = ACTIONS(1891),
    [anon_sym_AMPerror_handler] = ACTIONS(1891),
    [anon_sym_AMPis_assigned] = ACTIONS(1891),
    [anon_sym_AMPis_used] = ACTIONS(1891),
    [anon_sym_AMPlog] = ACTIONS(1891),
    [anon_sym_AMPoptional] = ACTIONS(1891),
    [anon_sym_AMPordered] = ACTIONS(1891),
    [anon_sym_AMPraw_output] = ACTIONS(1891),
    [anon_sym_AMPredef] = ACTIONS(1891),
    [anon_sym_AMPadd_func] = ACTIONS(1891),
    [anon_sym_AMPbackend] = ACTIONS(1891),
    [anon_sym_AMPbroker_store] = ACTIONS(1891),
    [anon_sym_AMPcreate_expire] = ACTIONS(1891),
    [anon_sym_AMPdefault] = ACTIONS(1891),
    [anon_sym_AMPdelete_func] = ACTIONS(1891),
    [anon_sym_AMPexpire_func] = ACTIONS(1891),
    [anon_sym_AMPgroup] = ACTIONS(1891),
    [anon_sym_AMPon_change] = ACTIONS(1891),
    [anon_sym_AMPpriority] = ACTIONS(1891),
    [anon_sym_AMPread_expire] = ACTIONS(1891),
    [anon_sym_AMPtype_column] = ACTIONS(1891),
    [anon_sym_AMPwrite_expire] = ACTIONS(1891),
    [anon_sym_DOLLAR] = ACTIONS(1891),
    [anon_sym_PIPE] = ACTIONS(1893),
    [anon_sym_BANG] = ACTIONS(1893),
    [anon_sym_DASH] = ACTIONS(1893),
    [anon_sym_PLUS] = ACTIONS(1893),
    [anon_sym_is] = ACTIONS(1891),
    [anon_sym_STAR] = ACTIONS(1891),
    [anon_sym_SLASH] = ACTIONS(1891),
    [anon_sym_PERCENT] = ACTIONS(1891),
    [anon_sym_LT] = ACTIONS(1893),
    [anon_sym_LT_EQ] = ACTIONS(1891),
    [anon_sym_GT] = ACTIONS(1893),
    [anon_sym_GT_EQ] = ACTIONS(1891),
    [anon_sym_AMP] = ACTIONS(1893),
    [anon_sym_CARET] = ACTIONS(1891),
    [anon_sym_QMARK] = ACTIONS(1893),
    [anon_sym_EQ_EQ] = ACTIONS(1891),
    [anon_sym_BANG_EQ] = ACTIONS(1891),
    [anon_sym_AMP_AMP] = ACTIONS(1891),
    [anon_sym_PIPE_PIPE] = ACTIONS(1891),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1891),
    [anon_sym_ATdeprecated] = ACTIONS(1891),
    [anon_sym_ATload] = ACTIONS(1893),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1891),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1891),
    [anon_sym_ATunload] = ACTIONS(1891),
    [anon_sym_ATprefixes] = ACTIONS(1891),
    [anon_sym_ATif] = ACTIONS(1893),
    [anon_sym_ATifdef] = ACTIONS(1891),
    [anon_sym_ATifndef] = ACTIONS(1891),
    [anon_sym_ATendif] = ACTIONS(1891),
    [anon_sym_ATelse] = ACTIONS(1891),
    [anon_sym_ATpragma] = ACTIONS(1891),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(772)] = {
    [anon_sym_SEMI] = ACTIONS(627),
    [anon_sym_LBRACE] = ACTIONS(627),
    [anon_sym_RBRACE] = ACTIONS(627),
    [anon_sym_COLON] = ACTIONS(627),
    [anon_sym_PLUS_EQ] = ACTIONS(627),
    [anon_sym_DASH_EQ] = ACTIONS(627),
    [anon_sym_LPAREN] = ACTIONS(627),
    [anon_sym_RPAREN] = ACTIONS(627),
    [anon_sym_COMMA] = ACTIONS(627),
    [anon_sym_in] = ACTIONS(627),
    [anon_sym_LBRACK] = ACTIONS(627),
    [anon_sym_RBRACK] = ACTIONS(627),
    [anon_sym_EQ] = ACTIONS(629),
    [anon_sym_as] = ACTIONS(627),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(627),
    [anon_sym_AMPdeprecated] = ACTIONS(627),
    [anon_sym_AMPerror_handler] = ACTIONS(627),
    [anon_sym_AMPis_assigned] = ACTIONS(627),
    [anon_sym_AMPis_used] = ACTIONS(627),
    [anon_sym_AMPlog] = ACTIONS(627),
    [anon_sym_AMPoptional] = ACTIONS(627),
    [anon_sym_AMPordered] = ACTIONS(627),
    [anon_sym_AMPraw_output] = ACTIONS(627),
    [anon_sym_AMPredef] = ACTIONS(627),
    [anon_sym_AMPadd_func] = ACTIONS(627),
    [anon_sym_AMPbackend] = ACTIONS(627),
    [anon_sym_AMPbroker_store] = ACTIONS(627),
    [anon_sym_AMPcreate_expire] = ACTIONS(627),
    [anon_sym_AMPdefault] = ACTIONS(627),
    [anon_sym_AMPdelete_func] = ACTIONS(627),
    [anon_sym_AMPexpire_func] = ACTIONS(627),
    [anon_sym_AMPgroup] = ACTIONS(627),
    [anon_sym_AMPon_change] = ACTIONS(627),
    [anon_sym_AMPpriority] = ACTIONS(627),
    [anon_sym_AMPread_expire] = ACTIONS(627),
    [anon_sym_AMPtype_column] = ACTIONS(627),
    [anon_sym_AMPwrite_expire] = ACTIONS(627),
    [anon_sym_DOLLAR] = ACTIONS(627),
    [anon_sym_PIPE] = ACTIONS(629),
    [anon_sym_BANG] = ACTIONS(629),
    [anon_sym_DASH] = ACTIONS(629),
    [anon_sym_PLUS] = ACTIONS(629),
    [anon_sym_is] = ACTIONS(627),
    [anon_sym_STAR] = ACTIONS(627),
    [anon_sym_SLASH] = ACTIONS(627),
    [anon_sym_PERCENT] = ACTIONS(627),
    [anon_sym_LT] = ACTIONS(629),
    [anon_sym_LT_EQ] = ACTIONS(627),
    [anon_sym_GT] = ACTIONS(629),
    [anon_sym_GT_EQ] = ACTIONS(627),
    [anon_sym_AMP] = ACTIONS(629),
    [anon_sym_CARET] = ACTIONS(627),
    [anon_sym_QMARK] = ACTIONS(629),
    [anon_sym_EQ_EQ] = ACTIONS(627),
    [anon_sym_BANG_EQ] = ACTIONS(627),
    [anon_sym_AMP_AMP] = ACTIONS(627),
    [anon_sym_PIPE_PIPE] = ACTIONS(627),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(627),
    [anon_sym_ATdeprecated] = ACTIONS(627),
    [anon_sym_ATload] = ACTIONS(629),
    [anon_sym_ATload_DASHsigs] = ACTIONS(627),
    [anon_sym_ATload_DASHplugin] = ACTIONS(627),
    [anon_sym_ATunload] = ACTIONS(627),
    [anon_sym_ATprefixes] = ACTIONS(627),
    [anon_sym_ATif] = ACTIONS(629),
    [anon_sym_ATifdef] = ACTIONS(627),
    [anon_sym_ATifndef] = ACTIONS(627),
    [anon_sym_ATendif] = ACTIONS(627),
    [anon_sym_ATelse] = ACTIONS(627),
    [anon_sym_ATpragma] = ACTIONS(627),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(773)] = {
    [anon_sym_SEMI] = ACTIONS(1885),
    [anon_sym_LBRACE] = ACTIONS(1885),
    [anon_sym_RBRACE] = ACTIONS(1885),
    [anon_sym_COLON] = ACTIONS(1885),
    [anon_sym_PLUS_EQ] = ACTIONS(1885),
    [anon_sym_DASH_EQ] = ACTIONS(1885),
    [anon_sym_LPAREN] = ACTIONS(1885),
    [anon_sym_RPAREN] = ACTIONS(1885),
    [anon_sym_COMMA] = ACTIONS(1885),
    [anon_sym_in] = ACTIONS(1885),
    [anon_sym_LBRACK] = ACTIONS(1885),
    [anon_sym_RBRACK] = ACTIONS(1885),
    [anon_sym_EQ] = ACTIONS(1889),
    [anon_sym_as] = ACTIONS(1885),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1885),
    [anon_sym_AMPdeprecated] = ACTIONS(1885),
    [anon_sym_AMPerror_handler] = ACTIONS(1885),
    [anon_sym_AMPis_assigned] = ACTIONS(1885),
    [anon_sym_AMPis_used] = ACTIONS(1885),
    [anon_sym_AMPlog] = ACTIONS(1885),
    [anon_sym_AMPoptional] = ACTIONS(1885),
    [anon_sym_AMPordered] = ACTIONS(1885),
    [anon_sym_AMPraw_output] = ACTIONS(1885),
    [anon_sym_AMPredef] = ACTIONS(1885),
    [anon_sym_AMPadd_func] = ACTIONS(1885),
    [anon_sym_AMPbackend] = ACTIONS(1885),
    [anon_sym_AMPbroker_store] = ACTIONS(1885),
    [anon_sym_AMPcreate_expire] = ACTIONS(1885),
    [anon_sym_AMPdefault] = ACTIONS(1885),
    [anon_sym_AMPdelete_func] = ACTIONS(1885),
    [anon_sym_AMPexpire_func] = ACTIONS(1885),
    [anon_sym_AMPgroup] = ACTIONS(1885),
    [anon_sym_AMPon_change] = ACTIONS(1885),
    [anon_sym_AMPpriority] = ACTIONS(1885),
    [anon_sym_AMPread_expire] = ACTIONS(1885),
    [anon_sym_AMPtype_column] = ACTIONS(1885),
    [anon_sym_AMPwrite_expire] = ACTIONS(1885),
    [anon_sym_DOLLAR] = ACTIONS(1885),
    [anon_sym_PIPE] = ACTIONS(1889),
    [anon_sym_BANG] = ACTIONS(1889),
    [anon_sym_DASH] = ACTIONS(1889),
    [anon_sym_PLUS] = ACTIONS(1889),
    [anon_sym_is] = ACTIONS(1885),
    [anon_sym_STAR] = ACTIONS(1885),
    [anon_sym_SLASH] = ACTIONS(1885),
    [anon_sym_PERCENT] = ACTIONS(1885),
    [anon_sym_LT] = ACTIONS(1889),
    [anon_sym_LT_EQ] = ACTIONS(1885),
    [anon_sym_GT] = ACTIONS(1889),
    [anon_sym_GT_EQ] = ACTIONS(1885),
    [anon_sym_AMP] = ACTIONS(1889),
    [anon_sym_CARET] = ACTIONS(1885),
    [anon_sym_QMARK] = ACTIONS(1889),
    [anon_sym_EQ_EQ] = ACTIONS(1885),
    [anon_sym_BANG_EQ] = ACTIONS(1885),
    [anon_sym_AMP_AMP] = ACTIONS(1885),
    [anon_sym_PIPE_PIPE] = ACTIONS(1885),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1885),
    [anon_sym_ATdeprecated] = ACTIONS(1885),
    [anon_sym_ATload] = ACTIONS(1889),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1885),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1885),
    [anon_sym_ATunload] = ACTIONS(1885),
    [anon_sym_ATprefixes] = ACTIONS(1885),
    [anon_sym_ATif] = ACTIONS(1889),
    [anon_sym_ATifdef] = ACTIONS(1885),
    [anon_sym_ATifndef] = ACTIONS(1885),
    [anon_sym_ATendif] = ACTIONS(1885),
    [anon_sym_ATelse] = ACTIONS(1885),
    [anon_sym_ATpragma] = ACTIONS(1885),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(774)] = {
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_COLON] = ACTIONS(127),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(127),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(127),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(127),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(775)] = {
    [anon_sym_SEMI] = ACTIONS(1505),
    [anon_sym_LBRACE] = ACTIONS(1505),
    [anon_sym_RBRACE] = ACTIONS(1505),
    [anon_sym_COLON] = ACTIONS(1505),
    [anon_sym_PLUS_EQ] = ACTIONS(1505),
    [anon_sym_DASH_EQ] = ACTIONS(1505),
    [anon_sym_LPAREN] = ACTIONS(1505),
    [anon_sym_RPAREN] = ACTIONS(1505),
    [anon_sym_COMMA] = ACTIONS(1505),
    [anon_sym_in] = ACTIONS(1505),
    [anon_sym_LBRACK] = ACTIONS(1505),
    [anon_sym_RBRACK] = ACTIONS(1505),
    [anon_sym_EQ] = ACTIONS(1507),
    [anon_sym_as] = ACTIONS(1505),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1505),
    [anon_sym_AMPdeprecated] = ACTIONS(1505),
    [anon_sym_AMPerror_handler] = ACTIONS(1505),
    [anon_sym_AMPis_assigned] = ACTIONS(1505),
    [anon_sym_AMPis_used] = ACTIONS(1505),
    [anon_sym_AMPlog] = ACTIONS(1505),
    [anon_sym_AMPoptional] = ACTIONS(1505),
    [anon_sym_AMPordered] = ACTIONS(1505),
    [anon_sym_AMPraw_output] = ACTIONS(1505),
    [anon_sym_AMPredef] = ACTIONS(1505),
    [anon_sym_AMPadd_func] = ACTIONS(1505),
    [anon_sym_AMPbackend] = ACTIONS(1505),
    [anon_sym_AMPbroker_store] = ACTIONS(1505),
    [anon_sym_AMPcreate_expire] = ACTIONS(1505),
    [anon_sym_AMPdefault] = ACTIONS(1505),
    [anon_sym_AMPdelete_func] = ACTIONS(1505),
    [anon_sym_AMPexpire_func] = ACTIONS(1505),
    [anon_sym_AMPgroup] = ACTIONS(1505),
    [anon_sym_AMPon_change] = ACTIONS(1505),
    [anon_sym_AMPpriority] = ACTIONS(1505),
    [anon_sym_AMPread_expire] = ACTIONS(1505),
    [anon_sym_AMPtype_column] = ACTIONS(1505),
    [anon_sym_AMPwrite_expire] = ACTIONS(1505),
    [anon_sym_DOLLAR] = ACTIONS(1505),
    [anon_sym_PIPE] = ACTIONS(1507),
    [anon_sym_BANG] = ACTIONS(1507),
    [anon_sym_DASH] = ACTIONS(1507),
    [anon_sym_PLUS] = ACTIONS(1507),
    [anon_sym_is] = ACTIONS(1505),
    [anon_sym_STAR] = ACTIONS(1505),
    [anon_sym_SLASH] = ACTIONS(1505),
    [anon_sym_PERCENT] = ACTIONS(1505),
    [anon_sym_LT] = ACTIONS(1507),
    [anon_sym_LT_EQ] = ACTIONS(1505),
    [anon_sym_GT] = ACTIONS(1507),
    [anon_sym_GT_EQ] = ACTIONS(1505),
    [anon_sym_AMP] = ACTIONS(1507),
    [anon_sym_CARET] = ACTIONS(1505),
    [anon_sym_QMARK] = ACTIONS(1507),
    [anon_sym_EQ_EQ] = ACTIONS(1505),
    [anon_sym_BANG_EQ] = ACTIONS(1505),
    [anon_sym_AMP_AMP] = ACTIONS(1505),
    [anon_sym_PIPE_PIPE] = ACTIONS(1505),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1505),
    [anon_sym_ATdeprecated] = ACTIONS(1505),
    [anon_sym_ATload] = ACTIONS(1507),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1505),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1505),
    [anon_sym_ATunload] = ACTIONS(1505),
    [anon_sym_ATprefixes] = ACTIONS(1505),
    [anon_sym_ATif] = ACTIONS(1507),
    [anon_sym_ATifdef] = ACTIONS(1505),
    [anon_sym_ATifndef] = ACTIONS(1505),
    [anon_sym_ATendif] = ACTIONS(1505),
    [anon_sym_ATelse] = ACTIONS(1505),
    [anon_sym_ATpragma] = ACTIONS(1505),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(776)] = {
    [anon_sym_SEMI] = ACTIONS(1895),
    [anon_sym_LBRACE] = ACTIONS(1895),
    [anon_sym_RBRACE] = ACTIONS(1895),
    [anon_sym_COLON] = ACTIONS(1895),
    [anon_sym_PLUS_EQ] = ACTIONS(1895),
    [anon_sym_DASH_EQ] = ACTIONS(1895),
    [anon_sym_LPAREN] = ACTIONS(1895),
    [anon_sym_RPAREN] = ACTIONS(1895),
    [anon_sym_COMMA] = ACTIONS(1895),
    [anon_sym_in] = ACTIONS(1895),
    [anon_sym_LBRACK] = ACTIONS(1895),
    [anon_sym_RBRACK] = ACTIONS(1895),
    [anon_sym_EQ] = ACTIONS(1897),
    [anon_sym_as] = ACTIONS(1895),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1895),
    [anon_sym_AMPdeprecated] = ACTIONS(1895),
    [anon_sym_AMPerror_handler] = ACTIONS(1895),
    [anon_sym_AMPis_assigned] = ACTIONS(1895),
    [anon_sym_AMPis_used] = ACTIONS(1895),
    [anon_sym_AMPlog] = ACTIONS(1895),
    [anon_sym_AMPoptional] = ACTIONS(1895),
    [anon_sym_AMPordered] = ACTIONS(1895),
    [anon_sym_AMPraw_output] = ACTIONS(1895),
    [anon_sym_AMPredef] = ACTIONS(1895),
    [anon_sym_AMPadd_func] = ACTIONS(1895),
    [anon_sym_AMPbackend] = ACTIONS(1895),
    [anon_sym_AMPbroker_store] = ACTIONS(1895),
    [anon_sym_AMPcreate_expire] = ACTIONS(1895),
    [anon_sym_AMPdefault] = ACTIONS(1895),
    [anon_sym_AMPdelete_func] = ACTIONS(1895),
    [anon_sym_AMPexpire_func] = ACTIONS(1895),
    [anon_sym_AMPgroup] = ACTIONS(1895),
    [anon_sym_AMPon_change] = ACTIONS(1895),
    [anon_sym_AMPpriority] = ACTIONS(1895),
    [anon_sym_AMPread_expire] = ACTIONS(1895),
    [anon_sym_AMPtype_column] = ACTIONS(1895),
    [anon_sym_AMPwrite_expire] = ACTIONS(1895),
    [anon_sym_DOLLAR] = ACTIONS(1895),
    [anon_sym_PIPE] = ACTIONS(1897),
    [anon_sym_BANG] = ACTIONS(1897),
    [anon_sym_DASH] = ACTIONS(1897),
    [anon_sym_PLUS] = ACTIONS(1897),
    [anon_sym_is] = ACTIONS(1895),
    [anon_sym_STAR] = ACTIONS(1895),
    [anon_sym_SLASH] = ACTIONS(1895),
    [anon_sym_PERCENT] = ACTIONS(1895),
    [anon_sym_LT] = ACTIONS(1897),
    [anon_sym_LT_EQ] = ACTIONS(1895),
    [anon_sym_GT] = ACTIONS(1897),
    [anon_sym_GT_EQ] = ACTIONS(1895),
    [anon_sym_AMP] = ACTIONS(1897),
    [anon_sym_CARET] = ACTIONS(1895),
    [anon_sym_QMARK] = ACTIONS(1897),
    [anon_sym_EQ_EQ] = ACTIONS(1895),
    [anon_sym_BANG_EQ] = ACTIONS(1895),
    [anon_sym_AMP_AMP] = ACTIONS(1895),
    [anon_sym_PIPE_PIPE] = ACTIONS(1895),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1895),
    [anon_sym_ATdeprecated] = ACTIONS(1895),
    [anon_sym_ATload] = ACTIONS(1897),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1895),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1895),
    [anon_sym_ATunload] = ACTIONS(1895),
    [anon_sym_ATprefixes] = ACTIONS(1895),
    [anon_sym_ATif] = ACTIONS(1897),
    [anon_sym_ATifdef] = ACTIONS(1895),
    [anon_sym_ATifndef] = ACTIONS(1895),
    [anon_sym_ATendif] = ACTIONS(1895),
    [anon_sym_ATelse] = ACTIONS(1895),
    [anon_sym_ATpragma] = ACTIONS(1895),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(777)] = {
    [anon_sym_SEMI] = ACTIONS(1899),
    [anon_sym_LBRACE] = ACTIONS(1899),
    [anon_sym_RBRACE] = ACTIONS(1899),
    [anon_sym_COLON] = ACTIONS(1899),
    [anon_sym_PLUS_EQ] = ACTIONS(1899),
    [anon_sym_DASH_EQ] = ACTIONS(1899),
    [anon_sym_LPAREN] = ACTIONS(1899),
    [anon_sym_RPAREN] = ACTIONS(1899),
    [anon_sym_COMMA] = ACTIONS(1899),
    [anon_sym_in] = ACTIONS(1899),
    [anon_sym_LBRACK] = ACTIONS(1899),
    [anon_sym_RBRACK] = ACTIONS(1899),
    [anon_sym_EQ] = ACTIONS(1901),
    [anon_sym_as] = ACTIONS(1899),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1899),
    [anon_sym_AMPdeprecated] = ACTIONS(1899),
    [anon_sym_AMPerror_handler] = ACTIONS(1899),
    [anon_sym_AMPis_assigned] = ACTIONS(1899),
    [anon_sym_AMPis_used] = ACTIONS(1899),
    [anon_sym_AMPlog] = ACTIONS(1899),
    [anon_sym_AMPoptional] = ACTIONS(1899),
    [anon_sym_AMPordered] = ACTIONS(1899),
    [anon_sym_AMPraw_output] = ACTIONS(1899),
    [anon_sym_AMPredef] = ACTIONS(1899),
    [anon_sym_AMPadd_func] = ACTIONS(1899),
    [anon_sym_AMPbackend] = ACTIONS(1899),
    [anon_sym_AMPbroker_store] = ACTIONS(1899),
    [anon_sym_AMPcreate_expire] = ACTIONS(1899),
    [anon_sym_AMPdefault] = ACTIONS(1899),
    [anon_sym_AMPdelete_func] = ACTIONS(1899),
    [anon_sym_AMPexpire_func] = ACTIONS(1899),
    [anon_sym_AMPgroup] = ACTIONS(1899),
    [anon_sym_AMPon_change] = ACTIONS(1899),
    [anon_sym_AMPpriority] = ACTIONS(1899),
    [anon_sym_AMPread_expire] = ACTIONS(1899),
    [anon_sym_AMPtype_column] = ACTIONS(1899),
    [anon_sym_AMPwrite_expire] = ACTIONS(1899),
    [anon_sym_DOLLAR] = ACTIONS(1899),
    [anon_sym_PIPE] = ACTIONS(1901),
    [anon_sym_BANG] = ACTIONS(1901),
    [anon_sym_DASH] = ACTIONS(1901),
    [anon_sym_PLUS] = ACTIONS(1901),
    [anon_sym_is] = ACTIONS(1899),
    [anon_sym_STAR] = ACTIONS(1899),
    [anon_sym_SLASH] = ACTIONS(1899),
    [anon_sym_PERCENT] = ACTIONS(1899),
    [anon_sym_LT] = ACTIONS(1901),
    [anon_sym_LT_EQ] = ACTIONS(1899),
    [anon_sym_GT] = ACTIONS(1901),
    [anon_sym_GT_EQ] = ACTIONS(1899),
    [anon_sym_AMP] = ACTIONS(1901),
    [anon_sym_CARET] = ACTIONS(1899),
    [anon_sym_QMARK] = ACTIONS(1901),
    [anon_sym_EQ_EQ] = ACTIONS(1899),
    [anon_sym_BANG_EQ] = ACTIONS(1899),
    [anon_sym_AMP_AMP] = ACTIONS(1899),
    [anon_sym_PIPE_PIPE] = ACTIONS(1899),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1899),
    [anon_sym_ATdeprecated] = ACTIONS(1899),
    [anon_sym_ATload] = ACTIONS(1901),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1899),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1899),
    [anon_sym_ATunload] = ACTIONS(1899),
    [anon_sym_ATprefixes] = ACTIONS(1899),
    [anon_sym_ATif] = ACTIONS(1901),
    [anon_sym_ATifdef] = ACTIONS(1899),
    [anon_sym_ATifndef] = ACTIONS(1899),
    [anon_sym_ATendif] = ACTIONS(1899),
    [anon_sym_ATelse] = ACTIONS(1899),
    [anon_sym_ATpragma] = ACTIONS(1899),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(778)] = {
    [anon_sym_SEMI] = ACTIONS(1903),
    [anon_sym_LBRACE] = ACTIONS(1903),
    [anon_sym_RBRACE] = ACTIONS(1903),
    [anon_sym_COLON] = ACTIONS(1903),
    [anon_sym_PLUS_EQ] = ACTIONS(1903),
    [anon_sym_DASH_EQ] = ACTIONS(1903),
    [anon_sym_LPAREN] = ACTIONS(1903),
    [anon_sym_RPAREN] = ACTIONS(1903),
    [anon_sym_COMMA] = ACTIONS(1903),
    [anon_sym_in] = ACTIONS(1903),
    [anon_sym_LBRACK] = ACTIONS(1903),
    [anon_sym_RBRACK] = ACTIONS(1903),
    [anon_sym_EQ] = ACTIONS(1905),
    [anon_sym_as] = ACTIONS(1903),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1903),
    [anon_sym_AMPdeprecated] = ACTIONS(1903),
    [anon_sym_AMPerror_handler] = ACTIONS(1903),
    [anon_sym_AMPis_assigned] = ACTIONS(1903),
    [anon_sym_AMPis_used] = ACTIONS(1903),
    [anon_sym_AMPlog] = ACTIONS(1903),
    [anon_sym_AMPoptional] = ACTIONS(1903),
    [anon_sym_AMPordered] = ACTIONS(1903),
    [anon_sym_AMPraw_output] = ACTIONS(1903),
    [anon_sym_AMPredef] = ACTIONS(1903),
    [anon_sym_AMPadd_func] = ACTIONS(1903),
    [anon_sym_AMPbackend] = ACTIONS(1903),
    [anon_sym_AMPbroker_store] = ACTIONS(1903),
    [anon_sym_AMPcreate_expire] = ACTIONS(1903),
    [anon_sym_AMPdefault] = ACTIONS(1903),
    [anon_sym_AMPdelete_func] = ACTIONS(1903),
    [anon_sym_AMPexpire_func] = ACTIONS(1903),
    [anon_sym_AMPgroup] = ACTIONS(1903),
    [anon_sym_AMPon_change] = ACTIONS(1903),
    [anon_sym_AMPpriority] = ACTIONS(1903),
    [anon_sym_AMPread_expire] = ACTIONS(1903),
    [anon_sym_AMPtype_column] = ACTIONS(1903),
    [anon_sym_AMPwrite_expire] = ACTIONS(1903),
    [anon_sym_DOLLAR] = ACTIONS(1903),
    [anon_sym_PIPE] = ACTIONS(1905),
    [anon_sym_BANG] = ACTIONS(1905),
    [anon_sym_DASH] = ACTIONS(1905),
    [anon_sym_PLUS] = ACTIONS(1905),
    [anon_sym_is] = ACTIONS(1903),
    [anon_sym_STAR] = ACTIONS(1903),
    [anon_sym_SLASH] = ACTIONS(1903),
    [anon_sym_PERCENT] = ACTIONS(1903),
    [anon_sym_LT] = ACTIONS(1905),
    [anon_sym_LT_EQ] = ACTIONS(1903),
    [anon_sym_GT] = ACTIONS(1905),
    [anon_sym_GT_EQ] = ACTIONS(1903),
    [anon_sym_AMP] = ACTIONS(1905),
    [anon_sym_CARET] = ACTIONS(1903),
    [anon_sym_QMARK] = ACTIONS(1905),
    [anon_sym_EQ_EQ] = ACTIONS(1903),
    [anon_sym_BANG_EQ] = ACTIONS(1903),
    [anon_sym_AMP_AMP] = ACTIONS(1903),
    [anon_sym_PIPE_PIPE] = ACTIONS(1903),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1903),
    [anon_sym_ATdeprecated] = ACTIONS(1903),
    [anon_sym_ATload] = ACTIONS(1905),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1903),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1903),
    [anon_sym_ATunload] = ACTIONS(1903),
    [anon_sym_ATprefixes] = ACTIONS(1903),
    [anon_sym_ATif] = ACTIONS(1905),
    [anon_sym_ATifdef] = ACTIONS(1903),
    [anon_sym_ATifndef] = ACTIONS(1903),
    [anon_sym_ATendif] = ACTIONS(1903),
    [anon_sym_ATelse] = ACTIONS(1903),
    [anon_sym_ATpragma] = ACTIONS(1903),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(779)] = {
    [anon_sym_SEMI] = ACTIONS(779),
    [anon_sym_LBRACE] = ACTIONS(779),
    [anon_sym_RBRACE] = ACTIONS(779),
    [anon_sym_COLON] = ACTIONS(779),
    [anon_sym_PLUS_EQ] = ACTIONS(779),
    [anon_sym_DASH_EQ] = ACTIONS(779),
    [anon_sym_LPAREN] = ACTIONS(779),
    [anon_sym_RPAREN] = ACTIONS(779),
    [anon_sym_COMMA] = ACTIONS(779),
    [anon_sym_in] = ACTIONS(779),
    [anon_sym_LBRACK] = ACTIONS(779),
    [anon_sym_RBRACK] = ACTIONS(779),
    [anon_sym_EQ] = ACTIONS(781),
    [anon_sym_as] = ACTIONS(779),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(779),
    [anon_sym_AMPdeprecated] = ACTIONS(779),
    [anon_sym_AMPerror_handler] = ACTIONS(779),
    [anon_sym_AMPis_assigned] = ACTIONS(779),
    [anon_sym_AMPis_used] = ACTIONS(779),
    [anon_sym_AMPlog] = ACTIONS(779),
    [anon_sym_AMPoptional] = ACTIONS(779),
    [anon_sym_AMPordered] = ACTIONS(779),
    [anon_sym_AMPraw_output] = ACTIONS(779),
    [anon_sym_AMPredef] = ACTIONS(779),
    [anon_sym_AMPadd_func] = ACTIONS(779),
    [anon_sym_AMPbackend] = ACTIONS(779),
    [anon_sym_AMPbroker_store] = ACTIONS(779),
    [anon_sym_AMPcreate_expire] = ACTIONS(779),
    [anon_sym_AMPdefault] = ACTIONS(779),
    [anon_sym_AMPdelete_func] = ACTIONS(779),
    [anon_sym_AMPexpire_func] = ACTIONS(779),
    [anon_sym_AMPgroup] = ACTIONS(779),
    [anon_sym_AMPon_change] = ACTIONS(779),
    [anon_sym_AMPpriority] = ACTIONS(779),
    [anon_sym_AMPread_expire] = ACTIONS(779),
    [anon_sym_AMPtype_column] = ACTIONS(779),
    [anon_sym_AMPwrite_expire] = ACTIONS(779),
    [anon_sym_DOLLAR] = ACTIONS(779),
    [anon_sym_PIPE] = ACTIONS(781),
    [anon_sym_BANG] = ACTIONS(781),
    [anon_sym_DASH] = ACTIONS(781),
    [anon_sym_PLUS] = ACTIONS(781),
    [anon_sym_is] = ACTIONS(779),
    [anon_sym_STAR] = ACTIONS(779),
    [anon_sym_SLASH] = ACTIONS(779),
    [anon_sym_PERCENT] = ACTIONS(779),
    [anon_sym_LT] = ACTIONS(781),
    [anon_sym_LT_EQ] = ACTIONS(779),
    [anon_sym_GT] = ACTIONS(781),
    [anon_sym_GT_EQ] = ACTIONS(779),
    [anon_sym_AMP] = ACTIONS(781),
    [anon_sym_CARET] = ACTIONS(779),
    [anon_sym_QMARK] = ACTIONS(781),
    [anon_sym_EQ_EQ] = ACTIONS(779),
    [anon_sym_BANG_EQ] = ACTIONS(779),
    [anon_sym_AMP_AMP] = ACTIONS(779),
    [anon_sym_PIPE_PIPE] = ACTIONS(779),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(779),
    [anon_sym_ATdeprecated] = ACTIONS(779),
    [anon_sym_ATload] = ACTIONS(781),
    [anon_sym_ATload_DASHsigs] = ACTIONS(779),
    [anon_sym_ATload_DASHplugin] = ACTIONS(779),
    [anon_sym_ATunload] = ACTIONS(779),
    [anon_sym_ATprefixes] = ACTIONS(779),
    [anon_sym_ATif] = ACTIONS(781),
    [anon_sym_ATifdef] = ACTIONS(779),
    [anon_sym_ATifndef] = ACTIONS(779),
    [anon_sym_ATendif] = ACTIONS(779),
    [anon_sym_ATelse] = ACTIONS(779),
    [anon_sym_ATpragma] = ACTIONS(779),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(780)] = {
    [anon_sym_SEMI] = ACTIONS(1513),
    [anon_sym_LBRACE] = ACTIONS(1513),
    [anon_sym_RBRACE] = ACTIONS(1513),
    [anon_sym_COLON] = ACTIONS(1513),
    [anon_sym_PLUS_EQ] = ACTIONS(1513),
    [anon_sym_DASH_EQ] = ACTIONS(1513),
    [anon_sym_LPAREN] = ACTIONS(1513),
    [anon_sym_RPAREN] = ACTIONS(1513),
    [anon_sym_COMMA] = ACTIONS(1513),
    [anon_sym_in] = ACTIONS(1513),
    [anon_sym_LBRACK] = ACTIONS(1513),
    [anon_sym_RBRACK] = ACTIONS(1513),
    [anon_sym_EQ] = ACTIONS(1515),
    [anon_sym_as] = ACTIONS(1513),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1513),
    [anon_sym_AMPdeprecated] = ACTIONS(1513),
    [anon_sym_AMPerror_handler] = ACTIONS(1513),
    [anon_sym_AMPis_assigned] = ACTIONS(1513),
    [anon_sym_AMPis_used] = ACTIONS(1513),
    [anon_sym_AMPlog] = ACTIONS(1513),
    [anon_sym_AMPoptional] = ACTIONS(1513),
    [anon_sym_AMPordered] = ACTIONS(1513),
    [anon_sym_AMPraw_output] = ACTIONS(1513),
    [anon_sym_AMPredef] = ACTIONS(1513),
    [anon_sym_AMPadd_func] = ACTIONS(1513),
    [anon_sym_AMPbackend] = ACTIONS(1513),
    [anon_sym_AMPbroker_store] = ACTIONS(1513),
    [anon_sym_AMPcreate_expire] = ACTIONS(1513),
    [anon_sym_AMPdefault] = ACTIONS(1513),
    [anon_sym_AMPdelete_func] = ACTIONS(1513),
    [anon_sym_AMPexpire_func] = ACTIONS(1513),
    [anon_sym_AMPgroup] = ACTIONS(1513),
    [anon_sym_AMPon_change] = ACTIONS(1513),
    [anon_sym_AMPpriority] = ACTIONS(1513),
    [anon_sym_AMPread_expire] = ACTIONS(1513),
    [anon_sym_AMPtype_column] = ACTIONS(1513),
    [anon_sym_AMPwrite_expire] = ACTIONS(1513),
    [anon_sym_DOLLAR] = ACTIONS(1513),
    [anon_sym_PIPE] = ACTIONS(1515),
    [anon_sym_BANG] = ACTIONS(1515),
    [anon_sym_DASH] = ACTIONS(1515),
    [anon_sym_PLUS] = ACTIONS(1515),
    [anon_sym_is] = ACTIONS(1513),
    [anon_sym_STAR] = ACTIONS(1513),
    [anon_sym_SLASH] = ACTIONS(1513),
    [anon_sym_PERCENT] = ACTIONS(1513),
    [anon_sym_LT] = ACTIONS(1515),
    [anon_sym_LT_EQ] = ACTIONS(1513),
    [anon_sym_GT] = ACTIONS(1515),
    [anon_sym_GT_EQ] = ACTIONS(1513),
    [anon_sym_AMP] = ACTIONS(1515),
    [anon_sym_CARET] = ACTIONS(1513),
    [anon_sym_QMARK] = ACTIONS(1515),
    [anon_sym_EQ_EQ] = ACTIONS(1513),
    [anon_sym_BANG_EQ] = ACTIONS(1513),
    [anon_sym_AMP_AMP] = ACTIONS(1513),
    [anon_sym_PIPE_PIPE] = ACTIONS(1513),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1513),
    [anon_sym_ATdeprecated] = ACTIONS(1513),
    [anon_sym_ATload] = ACTIONS(1515),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1513),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1513),
    [anon_sym_ATunload] = ACTIONS(1513),
    [anon_sym_ATprefixes] = ACTIONS(1513),
    [anon_sym_ATif] = ACTIONS(1515),
    [anon_sym_ATifdef] = ACTIONS(1513),
    [anon_sym_ATifndef] = ACTIONS(1513),
    [anon_sym_ATendif] = ACTIONS(1513),
    [anon_sym_ATelse] = ACTIONS(1513),
    [anon_sym_ATpragma] = ACTIONS(1513),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(781)] = {
    [anon_sym_SEMI] = ACTIONS(1875),
    [anon_sym_LBRACE] = ACTIONS(1875),
    [anon_sym_RBRACE] = ACTIONS(1875),
    [anon_sym_COLON] = ACTIONS(1875),
    [anon_sym_PLUS_EQ] = ACTIONS(1875),
    [anon_sym_DASH_EQ] = ACTIONS(1875),
    [anon_sym_LPAREN] = ACTIONS(1875),
    [anon_sym_RPAREN] = ACTIONS(1875),
    [anon_sym_COMMA] = ACTIONS(1875),
    [anon_sym_in] = ACTIONS(1875),
    [anon_sym_LBRACK] = ACTIONS(1875),
    [anon_sym_RBRACK] = ACTIONS(1875),
    [anon_sym_EQ] = ACTIONS(1877),
    [anon_sym_as] = ACTIONS(1875),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1875),
    [anon_sym_AMPdeprecated] = ACTIONS(1875),
    [anon_sym_AMPerror_handler] = ACTIONS(1875),
    [anon_sym_AMPis_assigned] = ACTIONS(1875),
    [anon_sym_AMPis_used] = ACTIONS(1875),
    [anon_sym_AMPlog] = ACTIONS(1875),
    [anon_sym_AMPoptional] = ACTIONS(1875),
    [anon_sym_AMPordered] = ACTIONS(1875),
    [anon_sym_AMPraw_output] = ACTIONS(1875),
    [anon_sym_AMPredef] = ACTIONS(1875),
    [anon_sym_AMPadd_func] = ACTIONS(1875),
    [anon_sym_AMPbackend] = ACTIONS(1875),
    [anon_sym_AMPbroker_store] = ACTIONS(1875),
    [anon_sym_AMPcreate_expire] = ACTIONS(1875),
    [anon_sym_AMPdefault] = ACTIONS(1875),
    [anon_sym_AMPdelete_func] = ACTIONS(1875),
    [anon_sym_AMPexpire_func] = ACTIONS(1875),
    [anon_sym_AMPgroup] = ACTIONS(1875),
    [anon_sym_AMPon_change] = ACTIONS(1875),
    [anon_sym_AMPpriority] = ACTIONS(1875),
    [anon_sym_AMPread_expire] = ACTIONS(1875),
    [anon_sym_AMPtype_column] = ACTIONS(1875),
    [anon_sym_AMPwrite_expire] = ACTIONS(1875),
    [anon_sym_DOLLAR] = ACTIONS(1875),
    [anon_sym_PIPE] = ACTIONS(1877),
    [anon_sym_BANG] = ACTIONS(1877),
    [anon_sym_DASH] = ACTIONS(1877),
    [anon_sym_PLUS] = ACTIONS(1877),
    [anon_sym_is] = ACTIONS(1875),
    [anon_sym_STAR] = ACTIONS(1875),
    [anon_sym_SLASH] = ACTIONS(1907),
    [anon_sym_PERCENT] = ACTIONS(1875),
    [anon_sym_LT] = ACTIONS(1877),
    [anon_sym_LT_EQ] = ACTIONS(1875),
    [anon_sym_GT] = ACTIONS(1877),
    [anon_sym_GT_EQ] = ACTIONS(1875),
    [anon_sym_AMP] = ACTIONS(1877),
    [anon_sym_CARET] = ACTIONS(1875),
    [anon_sym_QMARK] = ACTIONS(1877),
    [anon_sym_EQ_EQ] = ACTIONS(1875),
    [anon_sym_BANG_EQ] = ACTIONS(1875),
    [anon_sym_AMP_AMP] = ACTIONS(1875),
    [anon_sym_PIPE_PIPE] = ACTIONS(1875),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1875),
    [anon_sym_ATdeprecated] = ACTIONS(1875),
    [anon_sym_ATload] = ACTIONS(1877),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1875),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1875),
    [anon_sym_ATunload] = ACTIONS(1875),
    [anon_sym_ATprefixes] = ACTIONS(1875),
    [anon_sym_ATif] = ACTIONS(1877),
    [anon_sym_ATifdef] = ACTIONS(1875),
    [anon_sym_ATifndef] = ACTIONS(1875),
    [anon_sym_ATendif] = ACTIONS(1875),
    [anon_sym_ATelse] = ACTIONS(1875),
    [anon_sym_ATpragma] = ACTIONS(1875),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(782)] = {
    [anon_sym_SEMI] = ACTIONS(1867),
    [anon_sym_LBRACE] = ACTIONS(1867),
    [anon_sym_RBRACE] = ACTIONS(1867),
    [anon_sym_COLON] = ACTIONS(1867),
    [anon_sym_PLUS_EQ] = ACTIONS(1867),
    [anon_sym_DASH_EQ] = ACTIONS(1867),
    [anon_sym_LPAREN] = ACTIONS(1867),
    [anon_sym_RPAREN] = ACTIONS(1867),
    [anon_sym_COMMA] = ACTIONS(1867),
    [anon_sym_in] = ACTIONS(1867),
    [anon_sym_LBRACK] = ACTIONS(1867),
    [anon_sym_RBRACK] = ACTIONS(1867),
    [anon_sym_EQ] = ACTIONS(1869),
    [anon_sym_as] = ACTIONS(1867),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1867),
    [anon_sym_AMPdeprecated] = ACTIONS(1867),
    [anon_sym_AMPerror_handler] = ACTIONS(1867),
    [anon_sym_AMPis_assigned] = ACTIONS(1867),
    [anon_sym_AMPis_used] = ACTIONS(1867),
    [anon_sym_AMPlog] = ACTIONS(1867),
    [anon_sym_AMPoptional] = ACTIONS(1867),
    [anon_sym_AMPordered] = ACTIONS(1867),
    [anon_sym_AMPraw_output] = ACTIONS(1867),
    [anon_sym_AMPredef] = ACTIONS(1867),
    [anon_sym_AMPadd_func] = ACTIONS(1867),
    [anon_sym_AMPbackend] = ACTIONS(1867),
    [anon_sym_AMPbroker_store] = ACTIONS(1867),
    [anon_sym_AMPcreate_expire] = ACTIONS(1867),
    [anon_sym_AMPdefault] = ACTIONS(1867),
    [anon_sym_AMPdelete_func] = ACTIONS(1867),
    [anon_sym_AMPexpire_func] = ACTIONS(1867),
    [anon_sym_AMPgroup] = ACTIONS(1867),
    [anon_sym_AMPon_change] = ACTIONS(1867),
    [anon_sym_AMPpriority] = ACTIONS(1867),
    [anon_sym_AMPread_expire] = ACTIONS(1867),
    [anon_sym_AMPtype_column] = ACTIONS(1867),
    [anon_sym_AMPwrite_expire] = ACTIONS(1867),
    [anon_sym_DOLLAR] = ACTIONS(1867),
    [anon_sym_PIPE] = ACTIONS(1869),
    [anon_sym_BANG] = ACTIONS(1869),
    [anon_sym_DASH] = ACTIONS(1869),
    [anon_sym_PLUS] = ACTIONS(1869),
    [anon_sym_is] = ACTIONS(1867),
    [anon_sym_STAR] = ACTIONS(1867),
    [anon_sym_SLASH] = ACTIONS(1867),
    [anon_sym_PERCENT] = ACTIONS(1867),
    [anon_sym_LT] = ACTIONS(1869),
    [anon_sym_LT_EQ] = ACTIONS(1867),
    [anon_sym_GT] = ACTIONS(1869),
    [anon_sym_GT_EQ] = ACTIONS(1867),
    [anon_sym_AMP] = ACTIONS(1869),
    [anon_sym_CARET] = ACTIONS(1867),
    [anon_sym_QMARK] = ACTIONS(1869),
    [anon_sym_EQ_EQ] = ACTIONS(1867),
    [anon_sym_BANG_EQ] = ACTIONS(1867),
    [anon_sym_AMP_AMP] = ACTIONS(1867),
    [anon_sym_PIPE_PIPE] = ACTIONS(1867),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1867),
    [anon_sym_ATdeprecated] = ACTIONS(1867),
    [anon_sym_ATload] = ACTIONS(1869),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1867),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1867),
    [anon_sym_ATunload] = ACTIONS(1867),
    [anon_sym_ATprefixes] = ACTIONS(1867),
    [anon_sym_ATif] = ACTIONS(1869),
    [anon_sym_ATifdef] = ACTIONS(1867),
    [anon_sym_ATifndef] = ACTIONS(1867),
    [anon_sym_ATendif] = ACTIONS(1867),
    [anon_sym_ATelse] = ACTIONS(1867),
    [anon_sym_ATpragma] = ACTIONS(1867),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(783)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(127),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(784)] = {
    [anon_sym_SEMI] = ACTIONS(352),
    [anon_sym_LBRACE] = ACTIONS(352),
    [anon_sym_RBRACE] = ACTIONS(352),
    [anon_sym_COLON] = ACTIONS(352),
    [anon_sym_PLUS_EQ] = ACTIONS(352),
    [anon_sym_DASH_EQ] = ACTIONS(352),
    [anon_sym_LPAREN] = ACTIONS(352),
    [anon_sym_RPAREN] = ACTIONS(352),
    [anon_sym_COMMA] = ACTIONS(352),
    [anon_sym_in] = ACTIONS(352),
    [anon_sym_LBRACK] = ACTIONS(352),
    [anon_sym_RBRACK] = ACTIONS(352),
    [anon_sym_EQ] = ACTIONS(354),
    [anon_sym_as] = ACTIONS(352),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(352),
    [anon_sym_AMPdeprecated] = ACTIONS(352),
    [anon_sym_AMPerror_handler] = ACTIONS(352),
    [anon_sym_AMPis_assigned] = ACTIONS(352),
    [anon_sym_AMPis_used] = ACTIONS(352),
    [anon_sym_AMPlog] = ACTIONS(352),
    [anon_sym_AMPoptional] = ACTIONS(352),
    [anon_sym_AMPordered] = ACTIONS(352),
    [anon_sym_AMPraw_output] = ACTIONS(352),
    [anon_sym_AMPredef] = ACTIONS(352),
    [anon_sym_AMPadd_func] = ACTIONS(352),
    [anon_sym_AMPbackend] = ACTIONS(352),
    [anon_sym_AMPbroker_store] = ACTIONS(352),
    [anon_sym_AMPcreate_expire] = ACTIONS(352),
    [anon_sym_AMPdefault] = ACTIONS(352),
    [anon_sym_AMPdelete_func] = ACTIONS(352),
    [anon_sym_AMPexpire_func] = ACTIONS(352),
    [anon_sym_AMPgroup] = ACTIONS(352),
    [anon_sym_AMPon_change] = ACTIONS(352),
    [anon_sym_AMPpriority] = ACTIONS(352),
    [anon_sym_AMPread_expire] = ACTIONS(352),
    [anon_sym_AMPtype_column] = ACTIONS(352),
    [anon_sym_AMPwrite_expire] = ACTIONS(352),
    [anon_sym_DOLLAR] = ACTIONS(352),
    [anon_sym_PIPE] = ACTIONS(354),
    [anon_sym_BANG] = ACTIONS(354),
    [anon_sym_DASH] = ACTIONS(354),
    [anon_sym_PLUS] = ACTIONS(354),
    [anon_sym_is] = ACTIONS(352),
    [anon_sym_STAR] = ACTIONS(352),
    [anon_sym_SLASH] = ACTIONS(352),
    [anon_sym_PERCENT] = ACTIONS(352),
    [anon_sym_LT] = ACTIONS(354),
    [anon_sym_LT_EQ] = ACTIONS(352),
    [anon_sym_GT] = ACTIONS(354),
    [anon_sym_GT_EQ] = ACTIONS(352),
    [anon_sym_AMP] = ACTIONS(354),
    [anon_sym_CARET] = ACTIONS(352),
    [anon_sym_QMARK] = ACTIONS(354),
    [anon_sym_EQ_EQ] = ACTIONS(352),
    [anon_sym_BANG_EQ] = ACTIONS(352),
    [anon_sym_AMP_AMP] = ACTIONS(352),
    [anon_sym_PIPE_PIPE] = ACTIONS(352),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(352),
    [anon_sym_ATdeprecated] = ACTIONS(352),
    [anon_sym_ATload] = ACTIONS(354),
    [anon_sym_ATload_DASHsigs] = ACTIONS(352),
    [anon_sym_ATload_DASHplugin] = ACTIONS(352),
    [anon_sym_ATunload] = ACTIONS(352),
    [anon_sym_ATprefixes] = ACTIONS(352),
    [anon_sym_ATif] = ACTIONS(354),
    [anon_sym_ATifdef] = ACTIONS(352),
    [anon_sym_ATifndef] = ACTIONS(352),
    [anon_sym_ATendif] = ACTIONS(352),
    [anon_sym_ATelse] = ACTIONS(352),
    [anon_sym_ATpragma] = ACTIONS(352),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(785)] = {
    [anon_sym_SEMI] = ACTIONS(703),
    [anon_sym_LBRACE] = ACTIONS(703),
    [anon_sym_RBRACE] = ACTIONS(703),
    [anon_sym_COLON] = ACTIONS(703),
    [anon_sym_PLUS_EQ] = ACTIONS(703),
    [anon_sym_DASH_EQ] = ACTIONS(703),
    [anon_sym_LPAREN] = ACTIONS(703),
    [anon_sym_RPAREN] = ACTIONS(703),
    [anon_sym_COMMA] = ACTIONS(703),
    [anon_sym_in] = ACTIONS(703),
    [anon_sym_LBRACK] = ACTIONS(703),
    [anon_sym_RBRACK] = ACTIONS(703),
    [anon_sym_EQ] = ACTIONS(705),
    [anon_sym_as] = ACTIONS(703),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(703),
    [anon_sym_AMPdeprecated] = ACTIONS(703),
    [anon_sym_AMPerror_handler] = ACTIONS(703),
    [anon_sym_AMPis_assigned] = ACTIONS(703),
    [anon_sym_AMPis_used] = ACTIONS(703),
    [anon_sym_AMPlog] = ACTIONS(703),
    [anon_sym_AMPoptional] = ACTIONS(703),
    [anon_sym_AMPordered] = ACTIONS(703),
    [anon_sym_AMPraw_output] = ACTIONS(703),
    [anon_sym_AMPredef] = ACTIONS(703),
    [anon_sym_AMPadd_func] = ACTIONS(703),
    [anon_sym_AMPbackend] = ACTIONS(703),
    [anon_sym_AMPbroker_store] = ACTIONS(703),
    [anon_sym_AMPcreate_expire] = ACTIONS(703),
    [anon_sym_AMPdefault] = ACTIONS(703),
    [anon_sym_AMPdelete_func] = ACTIONS(703),
    [anon_sym_AMPexpire_func] = ACTIONS(703),
    [anon_sym_AMPgroup] = ACTIONS(703),
    [anon_sym_AMPon_change] = ACTIONS(703),
    [anon_sym_AMPpriority] = ACTIONS(703),
    [anon_sym_AMPread_expire] = ACTIONS(703),
    [anon_sym_AMPtype_column] = ACTIONS(703),
    [anon_sym_AMPwrite_expire] = ACTIONS(703),
    [anon_sym_DOLLAR] = ACTIONS(703),
    [anon_sym_PIPE] = ACTIONS(705),
    [anon_sym_BANG] = ACTIONS(705),
    [anon_sym_DASH] = ACTIONS(705),
    [anon_sym_PLUS] = ACTIONS(705),
    [anon_sym_is] = ACTIONS(703),
    [anon_sym_STAR] = ACTIONS(703),
    [anon_sym_SLASH] = ACTIONS(703),
    [anon_sym_PERCENT] = ACTIONS(703),
    [anon_sym_LT] = ACTIONS(705),
    [anon_sym_LT_EQ] = ACTIONS(703),
    [anon_sym_GT] = ACTIONS(705),
    [anon_sym_GT_EQ] = ACTIONS(703),
    [anon_sym_AMP] = ACTIONS(705),
    [anon_sym_CARET] = ACTIONS(703),
    [anon_sym_QMARK] = ACTIONS(705),
    [anon_sym_EQ_EQ] = ACTIONS(703),
    [anon_sym_BANG_EQ] = ACTIONS(703),
    [anon_sym_AMP_AMP] = ACTIONS(703),
    [anon_sym_PIPE_PIPE] = ACTIONS(703),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(703),
    [anon_sym_ATdeprecated] = ACTIONS(703),
    [anon_sym_ATload] = ACTIONS(705),
    [anon_sym_ATload_DASHsigs] = ACTIONS(703),
    [anon_sym_ATload_DASHplugin] = ACTIONS(703),
    [anon_sym_ATunload] = ACTIONS(703),
    [anon_sym_ATprefixes] = ACTIONS(703),
    [anon_sym_ATif] = ACTIONS(705),
    [anon_sym_ATifdef] = ACTIONS(703),
    [anon_sym_ATifndef] = ACTIONS(703),
    [anon_sym_ATendif] = ACTIONS(703),
    [anon_sym_ATelse] = ACTIONS(703),
    [anon_sym_ATpragma] = ACTIONS(703),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(786)] = {
    [anon_sym_SEMI] = ACTIONS(1915),
    [anon_sym_LBRACE] = ACTIONS(1915),
    [anon_sym_RBRACE] = ACTIONS(1915),
    [anon_sym_COLON] = ACTIONS(1915),
    [anon_sym_PLUS_EQ] = ACTIONS(1915),
    [anon_sym_DASH_EQ] = ACTIONS(1915),
    [anon_sym_LPAREN] = ACTIONS(1915),
    [anon_sym_RPAREN] = ACTIONS(1915),
    [anon_sym_COMMA] = ACTIONS(1915),
    [anon_sym_in] = ACTIONS(1915),
    [anon_sym_LBRACK] = ACTIONS(1915),
    [anon_sym_RBRACK] = ACTIONS(1915),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_as] = ACTIONS(1915),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1915),
    [anon_sym_AMPdeprecated] = ACTIONS(1915),
    [anon_sym_AMPerror_handler] = ACTIONS(1915),
    [anon_sym_AMPis_assigned] = ACTIONS(1915),
    [anon_sym_AMPis_used] = ACTIONS(1915),
    [anon_sym_AMPlog] = ACTIONS(1915),
    [anon_sym_AMPoptional] = ACTIONS(1915),
    [anon_sym_AMPordered] = ACTIONS(1915),
    [anon_sym_AMPraw_output] = ACTIONS(1915),
    [anon_sym_AMPredef] = ACTIONS(1915),
    [anon_sym_AMPadd_func] = ACTIONS(1915),
    [anon_sym_AMPbackend] = ACTIONS(1915),
    [anon_sym_AMPbroker_store] = ACTIONS(1915),
    [anon_sym_AMPcreate_expire] = ACTIONS(1915),
    [anon_sym_AMPdefault] = ACTIONS(1915),
    [anon_sym_AMPdelete_func] = ACTIONS(1915),
    [anon_sym_AMPexpire_func] = ACTIONS(1915),
    [anon_sym_AMPgroup] = ACTIONS(1915),
    [anon_sym_AMPon_change] = ACTIONS(1915),
    [anon_sym_AMPpriority] = ACTIONS(1915),
    [anon_sym_AMPread_expire] = ACTIONS(1915),
    [anon_sym_AMPtype_column] = ACTIONS(1915),
    [anon_sym_AMPwrite_expire] = ACTIONS(1915),
    [anon_sym_DOLLAR] = ACTIONS(1915),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_BANG] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_is] = ACTIONS(1915),
    [anon_sym_STAR] = ACTIONS(1915),
    [anon_sym_SLASH] = ACTIONS(1915),
    [anon_sym_PERCENT] = ACTIONS(1915),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_EQ] = ACTIONS(1915),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1915),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1915),
    [anon_sym_QMARK] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1915),
    [anon_sym_BANG_EQ] = ACTIONS(1915),
    [anon_sym_AMP_AMP] = ACTIONS(1915),
    [anon_sym_PIPE_PIPE] = ACTIONS(1915),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1915),
    [anon_sym_ATdeprecated] = ACTIONS(1915),
    [anon_sym_ATload] = ACTIONS(1917),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1915),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1915),
    [anon_sym_ATunload] = ACTIONS(1915),
    [anon_sym_ATprefixes] = ACTIONS(1915),
    [anon_sym_ATif] = ACTIONS(1917),
    [anon_sym_ATifdef] = ACTIONS(1915),
    [anon_sym_ATifndef] = ACTIONS(1915),
    [anon_sym_ATendif] = ACTIONS(1915),
    [anon_sym_ATelse] = ACTIONS(1915),
    [anon_sym_ATpragma] = ACTIONS(1915),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(787)] = {
    [anon_sym_SEMI] = ACTIONS(1859),
    [anon_sym_LBRACE] = ACTIONS(1859),
    [anon_sym_RBRACE] = ACTIONS(1859),
    [anon_sym_COLON] = ACTIONS(1859),
    [anon_sym_PLUS_EQ] = ACTIONS(1859),
    [anon_sym_DASH_EQ] = ACTIONS(1859),
    [anon_sym_LPAREN] = ACTIONS(1859),
    [anon_sym_RPAREN] = ACTIONS(1859),
    [anon_sym_COMMA] = ACTIONS(1859),
    [anon_sym_in] = ACTIONS(1859),
    [anon_sym_LBRACK] = ACTIONS(1859),
    [anon_sym_RBRACK] = ACTIONS(1859),
    [anon_sym_EQ] = ACTIONS(1861),
    [anon_sym_as] = ACTIONS(1859),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1859),
    [anon_sym_AMPdeprecated] = ACTIONS(1859),
    [anon_sym_AMPerror_handler] = ACTIONS(1859),
    [anon_sym_AMPis_assigned] = ACTIONS(1859),
    [anon_sym_AMPis_used] = ACTIONS(1859),
    [anon_sym_AMPlog] = ACTIONS(1859),
    [anon_sym_AMPoptional] = ACTIONS(1859),
    [anon_sym_AMPordered] = ACTIONS(1859),
    [anon_sym_AMPraw_output] = ACTIONS(1859),
    [anon_sym_AMPredef] = ACTIONS(1859),
    [anon_sym_AMPadd_func] = ACTIONS(1859),
    [anon_sym_AMPbackend] = ACTIONS(1859),
    [anon_sym_AMPbroker_store] = ACTIONS(1859),
    [anon_sym_AMPcreate_expire] = ACTIONS(1859),
    [anon_sym_AMPdefault] = ACTIONS(1859),
    [anon_sym_AMPdelete_func] = ACTIONS(1859),
    [anon_sym_AMPexpire_func] = ACTIONS(1859),
    [anon_sym_AMPgroup] = ACTIONS(1859),
    [anon_sym_AMPon_change] = ACTIONS(1859),
    [anon_sym_AMPpriority] = ACTIONS(1859),
    [anon_sym_AMPread_expire] = ACTIONS(1859),
    [anon_sym_AMPtype_column] = ACTIONS(1859),
    [anon_sym_AMPwrite_expire] = ACTIONS(1859),
    [anon_sym_DOLLAR] = ACTIONS(1859),
    [anon_sym_PIPE] = ACTIONS(1861),
    [anon_sym_BANG] = ACTIONS(1861),
    [anon_sym_DASH] = ACTIONS(1861),
    [anon_sym_PLUS] = ACTIONS(1861),
    [anon_sym_is] = ACTIONS(1859),
    [anon_sym_STAR] = ACTIONS(1859),
    [anon_sym_SLASH] = ACTIONS(1859),
    [anon_sym_PERCENT] = ACTIONS(1859),
    [anon_sym_LT] = ACTIONS(1861),
    [anon_sym_LT_EQ] = ACTIONS(1859),
    [anon_sym_GT] = ACTIONS(1861),
    [anon_sym_GT_EQ] = ACTIONS(1859),
    [anon_sym_AMP] = ACTIONS(1861),
    [anon_sym_CARET] = ACTIONS(1859),
    [anon_sym_QMARK] = ACTIONS(1861),
    [anon_sym_EQ_EQ] = ACTIONS(1859),
    [anon_sym_BANG_EQ] = ACTIONS(1859),
    [anon_sym_AMP_AMP] = ACTIONS(1859),
    [anon_sym_PIPE_PIPE] = ACTIONS(1859),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1859),
    [anon_sym_ATdeprecated] = ACTIONS(1859),
    [anon_sym_ATload] = ACTIONS(1861),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1859),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1859),
    [anon_sym_ATunload] = ACTIONS(1859),
    [anon_sym_ATprefixes] = ACTIONS(1859),
    [anon_sym_ATif] = ACTIONS(1861),
    [anon_sym_ATifdef] = ACTIONS(1859),
    [anon_sym_ATifndef] = ACTIONS(1859),
    [anon_sym_ATendif] = ACTIONS(1859),
    [anon_sym_ATelse] = ACTIONS(1859),
    [anon_sym_ATpragma] = ACTIONS(1859),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(788)] = {
    [anon_sym_SEMI] = ACTIONS(1837),
    [anon_sym_LBRACE] = ACTIONS(1837),
    [anon_sym_RBRACE] = ACTIONS(1837),
    [anon_sym_PLUS_EQ] = ACTIONS(1837),
    [anon_sym_DASH_EQ] = ACTIONS(1837),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_RPAREN] = ACTIONS(1837),
    [anon_sym_COMMA] = ACTIONS(1837),
    [anon_sym_in] = ACTIONS(1837),
    [anon_sym_LBRACK] = ACTIONS(1837),
    [anon_sym_RBRACK] = ACTIONS(1837),
    [anon_sym_EQ] = ACTIONS(1839),
    [anon_sym_as] = ACTIONS(1837),
    [anon_sym_of] = ACTIONS(1919),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1837),
    [anon_sym_AMPdeprecated] = ACTIONS(1837),
    [anon_sym_AMPerror_handler] = ACTIONS(1837),
    [anon_sym_AMPis_assigned] = ACTIONS(1837),
    [anon_sym_AMPis_used] = ACTIONS(1837),
    [anon_sym_AMPlog] = ACTIONS(1837),
    [anon_sym_AMPoptional] = ACTIONS(1837),
    [anon_sym_AMPordered] = ACTIONS(1837),
    [anon_sym_AMPraw_output] = ACTIONS(1837),
    [anon_sym_AMPredef] = ACTIONS(1837),
    [anon_sym_AMPadd_func] = ACTIONS(1837),
    [anon_sym_AMPbackend] = ACTIONS(1837),
    [anon_sym_AMPbroker_store] = ACTIONS(1837),
    [anon_sym_AMPcreate_expire] = ACTIONS(1837),
    [anon_sym_AMPdefault] = ACTIONS(1837),
    [anon_sym_AMPdelete_func] = ACTIONS(1837),
    [anon_sym_AMPexpire_func] = ACTIONS(1837),
    [anon_sym_AMPgroup] = ACTIONS(1837),
    [anon_sym_AMPon_change] = ACTIONS(1837),
    [anon_sym_AMPpriority] = ACTIONS(1837),
    [anon_sym_AMPread_expire] = ACTIONS(1837),
    [anon_sym_AMPtype_column] = ACTIONS(1837),
    [anon_sym_AMPwrite_expire] = ACTIONS(1837),
    [anon_sym_DOLLAR] = ACTIONS(1837),
    [anon_sym_PIPE] = ACTIONS(1839),
    [anon_sym_BANG] = ACTIONS(1839),
    [anon_sym_DASH] = ACTIONS(1839),
    [anon_sym_PLUS] = ACTIONS(1839),
    [anon_sym_is] = ACTIONS(1837),
    [anon_sym_STAR] = ACTIONS(1837),
    [anon_sym_SLASH] = ACTIONS(1837),
    [anon_sym_PERCENT] = ACTIONS(1837),
    [anon_sym_LT] = ACTIONS(1839),
    [anon_sym_LT_EQ] = ACTIONS(1837),
    [anon_sym_GT] = ACTIONS(1839),
    [anon_sym_GT_EQ] = ACTIONS(1837),
    [anon_sym_AMP] = ACTIONS(1839),
    [anon_sym_CARET] = ACTIONS(1837),
    [anon_sym_QMARK] = ACTIONS(1839),
    [anon_sym_EQ_EQ] = ACTIONS(1837),
    [anon_sym_BANG_EQ] = ACTIONS(1837),
    [anon_sym_AMP_AMP] = ACTIONS(1837),
    [anon_sym_PIPE_PIPE] = ACTIONS(1837),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1837),
    [anon_sym_ATdeprecated] = ACTIONS(1837),
    [anon_sym_ATload] = ACTIONS(1839),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1837),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1837),
    [anon_sym_ATunload] = ACTIONS(1837),
    [anon_sym_ATprefixes] = ACTIONS(1837),
    [anon_sym_ATif] = ACTIONS(1839),
    [anon_sym_ATifdef] = ACTIONS(1837),
    [anon_sym_ATifndef] = ACTIONS(1837),
    [anon_sym_ATendif] = ACTIONS(1837),
    [anon_sym_ATelse] = ACTIONS(1837),
    [anon_sym_ATpragma] = ACTIONS(1837),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(789)] = {
    [anon_sym_SEMI] = ACTIONS(783),
    [anon_sym_LBRACE] = ACTIONS(783),
    [anon_sym_RBRACE] = ACTIONS(783),
    [anon_sym_COLON] = ACTIONS(783),
    [anon_sym_PLUS_EQ] = ACTIONS(783),
    [anon_sym_DASH_EQ] = ACTIONS(783),
    [anon_sym_LPAREN] = ACTIONS(783),
    [anon_sym_RPAREN] = ACTIONS(783),
    [anon_sym_COMMA] = ACTIONS(783),
    [anon_sym_in] = ACTIONS(783),
    [anon_sym_LBRACK] = ACTIONS(783),
    [anon_sym_RBRACK] = ACTIONS(783),
    [anon_sym_EQ] = ACTIONS(785),
    [anon_sym_as] = ACTIONS(783),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(783),
    [anon_sym_AMPdeprecated] = ACTIONS(783),
    [anon_sym_AMPerror_handler] = ACTIONS(783),
    [anon_sym_AMPis_assigned] = ACTIONS(783),
    [anon_sym_AMPis_used] = ACTIONS(783),
    [anon_sym_AMPlog] = ACTIONS(783),
    [anon_sym_AMPoptional] = ACTIONS(783),
    [anon_sym_AMPordered] = ACTIONS(783),
    [anon_sym_AMPraw_output] = ACTIONS(783),
    [anon_sym_AMPredef] = ACTIONS(783),
    [anon_sym_AMPadd_func] = ACTIONS(783),
    [anon_sym_AMPbackend] = ACTIONS(783),
    [anon_sym_AMPbroker_store] = ACTIONS(783),
    [anon_sym_AMPcreate_expire] = ACTIONS(783),
    [anon_sym_AMPdefault] = ACTIONS(783),
    [anon_sym_AMPdelete_func] = ACTIONS(783),
    [anon_sym_AMPexpire_func] = ACTIONS(783),
    [anon_sym_AMPgroup] = ACTIONS(783),
    [anon_sym_AMPon_change] = ACTIONS(783),
    [anon_sym_AMPpriority] = ACTIONS(783),
    [anon_sym_AMPread_expire] = ACTIONS(783),
    [anon_sym_AMPtype_column] = ACTIONS(783),
    [anon_sym_AMPwrite_expire] = ACTIONS(783),
    [anon_sym_DOLLAR] = ACTIONS(783),
    [anon_sym_PIPE] = ACTIONS(785),
    [anon_sym_BANG] = ACTIONS(785),
    [anon_sym_DASH] = ACTIONS(785),
    [anon_sym_PLUS] = ACTIONS(785),
    [anon_sym_is] = ACTIONS(783),
    [anon_sym_STAR] = ACTIONS(783),
    [anon_sym_SLASH] = ACTIONS(783),
    [anon_sym_PERCENT] = ACTIONS(783),
    [anon_sym_LT] = ACTIONS(785),
    [anon_sym_LT_EQ] = ACTIONS(783),
    [anon_sym_GT] = ACTIONS(785),
    [anon_sym_GT_EQ] = ACTIONS(783),
    [anon_sym_AMP] = ACTIONS(785),
    [anon_sym_CARET] = ACTIONS(783),
    [anon_sym_QMARK] = ACTIONS(785),
    [anon_sym_EQ_EQ] = ACTIONS(783),
    [anon_sym_BANG_EQ] = ACTIONS(783),
    [anon_sym_AMP_AMP] = ACTIONS(783),
    [anon_sym_PIPE_PIPE] = ACTIONS(783),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(783),
    [anon_sym_ATdeprecated] = ACTIONS(783),
    [anon_sym_ATload] = ACTIONS(785),
    [anon_sym_ATload_DASHsigs] = ACTIONS(783),
    [anon_sym_ATload_DASHplugin] = ACTIONS(783),
    [anon_sym_ATunload] = ACTIONS(783),
    [anon_sym_ATprefixes] = ACTIONS(783),
    [anon_sym_ATif] = ACTIONS(785),
    [anon_sym_ATifdef] = ACTIONS(783),
    [anon_sym_ATifndef] = ACTIONS(783),
    [anon_sym_ATendif] = ACTIONS(783),
    [anon_sym_ATelse] = ACTIONS(783),
    [anon_sym_ATpragma] = ACTIONS(783),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(790)] = {
    [anon_sym_SEMI] = ACTIONS(1843),
    [anon_sym_LBRACE] = ACTIONS(1843),
    [anon_sym_RBRACE] = ACTIONS(1843),
    [anon_sym_COLON] = ACTIONS(1921),
    [anon_sym_PLUS_EQ] = ACTIONS(1843),
    [anon_sym_DASH_EQ] = ACTIONS(1843),
    [anon_sym_LPAREN] = ACTIONS(1843),
    [anon_sym_RPAREN] = ACTIONS(1843),
    [anon_sym_COMMA] = ACTIONS(1843),
    [anon_sym_in] = ACTIONS(1843),
    [anon_sym_LBRACK] = ACTIONS(1843),
    [anon_sym_RBRACK] = ACTIONS(1843),
    [anon_sym_EQ] = ACTIONS(1847),
    [anon_sym_as] = ACTIONS(1843),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1843),
    [anon_sym_AMPdeprecated] = ACTIONS(1843),
    [anon_sym_AMPerror_handler] = ACTIONS(1843),
    [anon_sym_AMPis_assigned] = ACTIONS(1843),
    [anon_sym_AMPis_used] = ACTIONS(1843),
    [anon_sym_AMPlog] = ACTIONS(1843),
    [anon_sym_AMPoptional] = ACTIONS(1843),
    [anon_sym_AMPordered] = ACTIONS(1843),
    [anon_sym_AMPraw_output] = ACTIONS(1843),
    [anon_sym_AMPredef] = ACTIONS(1843),
    [anon_sym_AMPadd_func] = ACTIONS(1843),
    [anon_sym_AMPbackend] = ACTIONS(1843),
    [anon_sym_AMPbroker_store] = ACTIONS(1843),
    [anon_sym_AMPcreate_expire] = ACTIONS(1843),
    [anon_sym_AMPdefault] = ACTIONS(1843),
    [anon_sym_AMPdelete_func] = ACTIONS(1843),
    [anon_sym_AMPexpire_func] = ACTIONS(1843),
    [anon_sym_AMPgroup] = ACTIONS(1843),
    [anon_sym_AMPon_change] = ACTIONS(1843),
    [anon_sym_AMPpriority] = ACTIONS(1843),
    [anon_sym_AMPread_expire] = ACTIONS(1843),
    [anon_sym_AMPtype_column] = ACTIONS(1843),
    [anon_sym_AMPwrite_expire] = ACTIONS(1843),
    [anon_sym_DOLLAR] = ACTIONS(1843),
    [anon_sym_PIPE] = ACTIONS(1847),
    [anon_sym_BANG] = ACTIONS(1847),
    [anon_sym_DASH] = ACTIONS(1847),
    [anon_sym_PLUS] = ACTIONS(1847),
    [anon_sym_is] = ACTIONS(1843),
    [anon_sym_STAR] = ACTIONS(1843),
    [anon_sym_SLASH] = ACTIONS(1843),
    [anon_sym_PERCENT] = ACTIONS(1843),
    [anon_sym_LT] = ACTIONS(1847),
    [anon_sym_LT_EQ] = ACTIONS(1843),
    [anon_sym_GT] = ACTIONS(1847),
    [anon_sym_GT_EQ] = ACTIONS(1843),
    [anon_sym_AMP] = ACTIONS(1847),
    [anon_sym_CARET] = ACTIONS(1843),
    [anon_sym_QMARK] = ACTIONS(1847),
    [anon_sym_EQ_EQ] = ACTIONS(1843),
    [anon_sym_BANG_EQ] = ACTIONS(1843),
    [anon_sym_AMP_AMP] = ACTIONS(1843),
    [anon_sym_PIPE_PIPE] = ACTIONS(1843),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1843),
    [anon_sym_ATdeprecated] = ACTIONS(1843),
    [anon_sym_ATload] = ACTIONS(1847),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1843),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1843),
    [anon_sym_ATunload] = ACTIONS(1843),
    [anon_sym_ATprefixes] = ACTIONS(1843),
    [anon_sym_ATif] = ACTIONS(1847),
    [anon_sym_ATifdef] = ACTIONS(1843),
    [anon_sym_ATifndef] = ACTIONS(1843),
    [anon_sym_ATendif] = ACTIONS(1843),
    [anon_sym_ATelse] = ACTIONS(1843),
    [anon_sym_ATpragma] = ACTIONS(1843),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(791)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(149),
    [anon_sym_RBRACE] = ACTIONS(149),
    [anon_sym_COLON] = ACTIONS(149),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_RPAREN] = ACTIONS(149),
    [anon_sym_COMMA] = ACTIONS(149),
    [anon_sym_in] = ACTIONS(149),
    [anon_sym_LBRACK] = ACTIONS(149),
    [anon_sym_RBRACK] = ACTIONS(149),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_as] = ACTIONS(149),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(149),
    [anon_sym_AMPdeprecated] = ACTIONS(149),
    [anon_sym_AMPerror_handler] = ACTIONS(149),
    [anon_sym_AMPis_assigned] = ACTIONS(149),
    [anon_sym_AMPis_used] = ACTIONS(149),
    [anon_sym_AMPlog] = ACTIONS(149),
    [anon_sym_AMPoptional] = ACTIONS(149),
    [anon_sym_AMPordered] = ACTIONS(149),
    [anon_sym_AMPraw_output] = ACTIONS(149),
    [anon_sym_AMPredef] = ACTIONS(149),
    [anon_sym_AMPadd_func] = ACTIONS(149),
    [anon_sym_AMPbackend] = ACTIONS(149),
    [anon_sym_AMPbroker_store] = ACTIONS(149),
    [anon_sym_AMPcreate_expire] = ACTIONS(149),
    [anon_sym_AMPdefault] = ACTIONS(149),
    [anon_sym_AMPdelete_func] = ACTIONS(149),
    [anon_sym_AMPexpire_func] = ACTIONS(149),
    [anon_sym_AMPgroup] = ACTIONS(149),
    [anon_sym_AMPon_change] = ACTIONS(149),
    [anon_sym_AMPpriority] = ACTIONS(149),
    [anon_sym_AMPread_expire] = ACTIONS(149),
    [anon_sym_AMPtype_column] = ACTIONS(149),
    [anon_sym_AMPwrite_expire] = ACTIONS(149),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(149),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(149),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_ATdeprecated] = ACTIONS(149),
    [anon_sym_ATload] = ACTIONS(155),
    [anon_sym_ATload_DASHsigs] = ACTIONS(149),
    [anon_sym_ATload_DASHplugin] = ACTIONS(149),
    [anon_sym_ATunload] = ACTIONS(149),
    [anon_sym_ATprefixes] = ACTIONS(149),
    [anon_sym_ATif] = ACTIONS(155),
    [anon_sym_ATifdef] = ACTIONS(149),
    [anon_sym_ATifndef] = ACTIONS(149),
    [anon_sym_ATendif] = ACTIONS(149),
    [anon_sym_ATelse] = ACTIONS(149),
    [anon_sym_ATpragma] = ACTIONS(149),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(792)] = {
    [anon_sym_SEMI] = ACTIONS(1923),
    [anon_sym_LBRACE] = ACTIONS(1923),
    [anon_sym_RBRACE] = ACTIONS(1923),
    [anon_sym_COLON] = ACTIONS(1923),
    [anon_sym_PLUS_EQ] = ACTIONS(1923),
    [anon_sym_DASH_EQ] = ACTIONS(1923),
    [anon_sym_LPAREN] = ACTIONS(1923),
    [anon_sym_RPAREN] = ACTIONS(1923),
    [anon_sym_COMMA] = ACTIONS(1923),
    [anon_sym_in] = ACTIONS(1923),
    [anon_sym_LBRACK] = ACTIONS(1923),
    [anon_sym_RBRACK] = ACTIONS(1923),
    [anon_sym_EQ] = ACTIONS(1925),
    [anon_sym_as] = ACTIONS(1923),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1923),
    [anon_sym_AMPdeprecated] = ACTIONS(1923),
    [anon_sym_AMPerror_handler] = ACTIONS(1923),
    [anon_sym_AMPis_assigned] = ACTIONS(1923),
    [anon_sym_AMPis_used] = ACTIONS(1923),
    [anon_sym_AMPlog] = ACTIONS(1923),
    [anon_sym_AMPoptional] = ACTIONS(1923),
    [anon_sym_AMPordered] = ACTIONS(1923),
    [anon_sym_AMPraw_output] = ACTIONS(1923),
    [anon_sym_AMPredef] = ACTIONS(1923),
    [anon_sym_AMPadd_func] = ACTIONS(1923),
    [anon_sym_AMPbackend] = ACTIONS(1923),
    [anon_sym_AMPbroker_store] = ACTIONS(1923),
    [anon_sym_AMPcreate_expire] = ACTIONS(1923),
    [anon_sym_AMPdefault] = ACTIONS(1923),
    [anon_sym_AMPdelete_func] = ACTIONS(1923),
    [anon_sym_AMPexpire_func] = ACTIONS(1923),
    [anon_sym_AMPgroup] = ACTIONS(1923),
    [anon_sym_AMPon_change] = ACTIONS(1923),
    [anon_sym_AMPpriority] = ACTIONS(1923),
    [anon_sym_AMPread_expire] = ACTIONS(1923),
    [anon_sym_AMPtype_column] = ACTIONS(1923),
    [anon_sym_AMPwrite_expire] = ACTIONS(1923),
    [anon_sym_DOLLAR] = ACTIONS(1923),
    [anon_sym_PIPE] = ACTIONS(1925),
    [anon_sym_BANG] = ACTIONS(1925),
    [anon_sym_DASH] = ACTIONS(1925),
    [anon_sym_PLUS] = ACTIONS(1925),
    [anon_sym_is] = ACTIONS(1923),
    [anon_sym_STAR] = ACTIONS(1923),
    [anon_sym_SLASH] = ACTIONS(1923),
    [anon_sym_PERCENT] = ACTIONS(1923),
    [anon_sym_LT] = ACTIONS(1925),
    [anon_sym_LT_EQ] = ACTIONS(1923),
    [anon_sym_GT] = ACTIONS(1925),
    [anon_sym_GT_EQ] = ACTIONS(1923),
    [anon_sym_AMP] = ACTIONS(1925),
    [anon_sym_CARET] = ACTIONS(1923),
    [anon_sym_QMARK] = ACTIONS(1925),
    [anon_sym_EQ_EQ] = ACTIONS(1923),
    [anon_sym_BANG_EQ] = ACTIONS(1923),
    [anon_sym_AMP_AMP] = ACTIONS(1923),
    [anon_sym_PIPE_PIPE] = ACTIONS(1923),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1923),
    [anon_sym_ATdeprecated] = ACTIONS(1923),
    [anon_sym_ATload] = ACTIONS(1925),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1923),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1923),
    [anon_sym_ATunload] = ACTIONS(1923),
    [anon_sym_ATprefixes] = ACTIONS(1923),
    [anon_sym_ATif] = ACTIONS(1925),
    [anon_sym_ATifdef] = ACTIONS(1923),
    [anon_sym_ATifndef] = ACTIONS(1923),
    [anon_sym_ATendif] = ACTIONS(1923),
    [anon_sym_ATelse] = ACTIONS(1923),
    [anon_sym_ATpragma] = ACTIONS(1923),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(793)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(149),
    [anon_sym_RBRACE] = ACTIONS(149),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_RPAREN] = ACTIONS(149),
    [anon_sym_COMMA] = ACTIONS(149),
    [anon_sym_in] = ACTIONS(149),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_RBRACK] = ACTIONS(149),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(149),
    [anon_sym_AMPdeprecated] = ACTIONS(149),
    [anon_sym_AMPerror_handler] = ACTIONS(149),
    [anon_sym_AMPis_assigned] = ACTIONS(149),
    [anon_sym_AMPis_used] = ACTIONS(149),
    [anon_sym_AMPlog] = ACTIONS(149),
    [anon_sym_AMPoptional] = ACTIONS(149),
    [anon_sym_AMPordered] = ACTIONS(149),
    [anon_sym_AMPraw_output] = ACTIONS(149),
    [anon_sym_AMPredef] = ACTIONS(149),
    [anon_sym_AMPadd_func] = ACTIONS(149),
    [anon_sym_AMPbackend] = ACTIONS(149),
    [anon_sym_AMPbroker_store] = ACTIONS(149),
    [anon_sym_AMPcreate_expire] = ACTIONS(149),
    [anon_sym_AMPdefault] = ACTIONS(149),
    [anon_sym_AMPdelete_func] = ACTIONS(149),
    [anon_sym_AMPexpire_func] = ACTIONS(149),
    [anon_sym_AMPgroup] = ACTIONS(149),
    [anon_sym_AMPon_change] = ACTIONS(149),
    [anon_sym_AMPpriority] = ACTIONS(149),
    [anon_sym_AMPread_expire] = ACTIONS(149),
    [anon_sym_AMPtype_column] = ACTIONS(149),
    [anon_sym_AMPwrite_expire] = ACTIONS(149),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(149),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_ATdeprecated] = ACTIONS(149),
    [anon_sym_ATload] = ACTIONS(155),
    [anon_sym_ATload_DASHsigs] = ACTIONS(149),
    [anon_sym_ATload_DASHplugin] = ACTIONS(149),
    [anon_sym_ATunload] = ACTIONS(149),
    [anon_sym_ATprefixes] = ACTIONS(149),
    [anon_sym_ATif] = ACTIONS(155),
    [anon_sym_ATifdef] = ACTIONS(149),
    [anon_sym_ATifndef] = ACTIONS(149),
    [anon_sym_ATendif] = ACTIONS(149),
    [anon_sym_ATelse] = ACTIONS(149),
    [anon_sym_ATpragma] = ACTIONS(149),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(794)] = {
    [anon_sym_SEMI] = ACTIONS(1927),
    [anon_sym_LBRACE] = ACTIONS(1927),
    [anon_sym_RBRACE] = ACTIONS(1927),
    [anon_sym_COLON] = ACTIONS(1927),
    [anon_sym_PLUS_EQ] = ACTIONS(1927),
    [anon_sym_DASH_EQ] = ACTIONS(1927),
    [anon_sym_LPAREN] = ACTIONS(1927),
    [anon_sym_RPAREN] = ACTIONS(1927),
    [anon_sym_COMMA] = ACTIONS(1927),
    [anon_sym_in] = ACTIONS(1927),
    [anon_sym_LBRACK] = ACTIONS(1927),
    [anon_sym_RBRACK] = ACTIONS(1927),
    [anon_sym_EQ] = ACTIONS(1929),
    [anon_sym_as] = ACTIONS(1927),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1927),
    [anon_sym_AMPdeprecated] = ACTIONS(1927),
    [anon_sym_AMPerror_handler] = ACTIONS(1927),
    [anon_sym_AMPis_assigned] = ACTIONS(1927),
    [anon_sym_AMPis_used] = ACTIONS(1927),
    [anon_sym_AMPlog] = ACTIONS(1927),
    [anon_sym_AMPoptional] = ACTIONS(1927),
    [anon_sym_AMPordered] = ACTIONS(1927),
    [anon_sym_AMPraw_output] = ACTIONS(1927),
    [anon_sym_AMPredef] = ACTIONS(1927),
    [anon_sym_AMPadd_func] = ACTIONS(1927),
    [anon_sym_AMPbackend] = ACTIONS(1927),
    [anon_sym_AMPbroker_store] = ACTIONS(1927),
    [anon_sym_AMPcreate_expire] = ACTIONS(1927),
    [anon_sym_AMPdefault] = ACTIONS(1927),
    [anon_sym_AMPdelete_func] = ACTIONS(1927),
    [anon_sym_AMPexpire_func] = ACTIONS(1927),
    [anon_sym_AMPgroup] = ACTIONS(1927),
    [anon_sym_AMPon_change] = ACTIONS(1927),
    [anon_sym_AMPpriority] = ACTIONS(1927),
    [anon_sym_AMPread_expire] = ACTIONS(1927),
    [anon_sym_AMPtype_column] = ACTIONS(1927),
    [anon_sym_AMPwrite_expire] = ACTIONS(1927),
    [anon_sym_DOLLAR] = ACTIONS(1927),
    [anon_sym_PIPE] = ACTIONS(1929),
    [anon_sym_BANG] = ACTIONS(1929),
    [anon_sym_DASH] = ACTIONS(1929),
    [anon_sym_PLUS] = ACTIONS(1929),
    [anon_sym_is] = ACTIONS(1927),
    [anon_sym_STAR] = ACTIONS(1927),
    [anon_sym_SLASH] = ACTIONS(1927),
    [anon_sym_PERCENT] = ACTIONS(1927),
    [anon_sym_LT] = ACTIONS(1929),
    [anon_sym_LT_EQ] = ACTIONS(1927),
    [anon_sym_GT] = ACTIONS(1929),
    [anon_sym_GT_EQ] = ACTIONS(1927),
    [anon_sym_AMP] = ACTIONS(1929),
    [anon_sym_CARET] = ACTIONS(1927),
    [anon_sym_QMARK] = ACTIONS(1929),
    [anon_sym_EQ_EQ] = ACTIONS(1927),
    [anon_sym_BANG_EQ] = ACTIONS(1927),
    [anon_sym_AMP_AMP] = ACTIONS(1927),
    [anon_sym_PIPE_PIPE] = ACTIONS(1927),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1927),
    [anon_sym_ATdeprecated] = ACTIONS(1927),
    [anon_sym_ATload] = ACTIONS(1929),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1927),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1927),
    [anon_sym_ATunload] = ACTIONS(1927),
    [anon_sym_ATprefixes] = ACTIONS(1927),
    [anon_sym_ATif] = ACTIONS(1929),
    [anon_sym_ATifdef] = ACTIONS(1927),
    [anon_sym_ATifndef] = ACTIONS(1927),
    [anon_sym_ATendif] = ACTIONS(1927),
    [anon_sym_ATelse] = ACTIONS(1927),
    [anon_sym_ATpragma] = ACTIONS(1927),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(795)] = {
    [anon_sym_SEMI] = ACTIONS(149),
    [anon_sym_LBRACE] = ACTIONS(149),
    [anon_sym_RBRACE] = ACTIONS(149),
    [anon_sym_COLON] = ACTIONS(149),
    [anon_sym_PLUS_EQ] = ACTIONS(149),
    [anon_sym_DASH_EQ] = ACTIONS(149),
    [anon_sym_LPAREN] = ACTIONS(149),
    [anon_sym_RPAREN] = ACTIONS(149),
    [anon_sym_COMMA] = ACTIONS(149),
    [anon_sym_in] = ACTIONS(149),
    [anon_sym_LBRACK] = ACTIONS(149),
    [anon_sym_RBRACK] = ACTIONS(149),
    [anon_sym_EQ] = ACTIONS(155),
    [anon_sym_as] = ACTIONS(149),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(149),
    [anon_sym_AMPdeprecated] = ACTIONS(149),
    [anon_sym_AMPerror_handler] = ACTIONS(149),
    [anon_sym_AMPis_assigned] = ACTIONS(149),
    [anon_sym_AMPis_used] = ACTIONS(149),
    [anon_sym_AMPlog] = ACTIONS(149),
    [anon_sym_AMPoptional] = ACTIONS(149),
    [anon_sym_AMPordered] = ACTIONS(149),
    [anon_sym_AMPraw_output] = ACTIONS(149),
    [anon_sym_AMPredef] = ACTIONS(149),
    [anon_sym_AMPadd_func] = ACTIONS(149),
    [anon_sym_AMPbackend] = ACTIONS(149),
    [anon_sym_AMPbroker_store] = ACTIONS(149),
    [anon_sym_AMPcreate_expire] = ACTIONS(149),
    [anon_sym_AMPdefault] = ACTIONS(149),
    [anon_sym_AMPdelete_func] = ACTIONS(149),
    [anon_sym_AMPexpire_func] = ACTIONS(149),
    [anon_sym_AMPgroup] = ACTIONS(149),
    [anon_sym_AMPon_change] = ACTIONS(149),
    [anon_sym_AMPpriority] = ACTIONS(149),
    [anon_sym_AMPread_expire] = ACTIONS(149),
    [anon_sym_AMPtype_column] = ACTIONS(149),
    [anon_sym_AMPwrite_expire] = ACTIONS(149),
    [anon_sym_DOLLAR] = ACTIONS(149),
    [anon_sym_PIPE] = ACTIONS(155),
    [anon_sym_BANG] = ACTIONS(155),
    [anon_sym_DASH] = ACTIONS(155),
    [anon_sym_PLUS] = ACTIONS(155),
    [anon_sym_is] = ACTIONS(149),
    [anon_sym_STAR] = ACTIONS(149),
    [anon_sym_SLASH] = ACTIONS(149),
    [anon_sym_PERCENT] = ACTIONS(149),
    [anon_sym_LT] = ACTIONS(155),
    [anon_sym_LT_EQ] = ACTIONS(149),
    [anon_sym_GT] = ACTIONS(155),
    [anon_sym_GT_EQ] = ACTIONS(149),
    [anon_sym_AMP] = ACTIONS(155),
    [anon_sym_CARET] = ACTIONS(149),
    [anon_sym_QMARK] = ACTIONS(155),
    [anon_sym_EQ_EQ] = ACTIONS(149),
    [anon_sym_BANG_EQ] = ACTIONS(149),
    [anon_sym_AMP_AMP] = ACTIONS(149),
    [anon_sym_PIPE_PIPE] = ACTIONS(149),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(149),
    [anon_sym_ATdeprecated] = ACTIONS(149),
    [anon_sym_ATload] = ACTIONS(155),
    [anon_sym_ATload_DASHsigs] = ACTIONS(149),
    [anon_sym_ATload_DASHplugin] = ACTIONS(149),
    [anon_sym_ATunload] = ACTIONS(149),
    [anon_sym_ATprefixes] = ACTIONS(149),
    [anon_sym_ATif] = ACTIONS(155),
    [anon_sym_ATifdef] = ACTIONS(149),
    [anon_sym_ATifndef] = ACTIONS(149),
    [anon_sym_ATendif] = ACTIONS(149),
    [anon_sym_ATelse] = ACTIONS(149),
    [anon_sym_ATpragma] = ACTIONS(149),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(796)] = {
    [anon_sym_SEMI] = ACTIONS(1871),
    [anon_sym_LBRACE] = ACTIONS(1871),
    [anon_sym_RBRACE] = ACTIONS(1871),
    [anon_sym_COLON] = ACTIONS(1871),
    [anon_sym_PLUS_EQ] = ACTIONS(1871),
    [anon_sym_DASH_EQ] = ACTIONS(1871),
    [anon_sym_LPAREN] = ACTIONS(1871),
    [anon_sym_RPAREN] = ACTIONS(1871),
    [anon_sym_COMMA] = ACTIONS(1871),
    [anon_sym_in] = ACTIONS(1871),
    [anon_sym_LBRACK] = ACTIONS(1871),
    [anon_sym_RBRACK] = ACTIONS(1871),
    [anon_sym_EQ] = ACTIONS(1873),
    [anon_sym_as] = ACTIONS(1871),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1871),
    [anon_sym_AMPdeprecated] = ACTIONS(1871),
    [anon_sym_AMPerror_handler] = ACTIONS(1871),
    [anon_sym_AMPis_assigned] = ACTIONS(1871),
    [anon_sym_AMPis_used] = ACTIONS(1871),
    [anon_sym_AMPlog] = ACTIONS(1871),
    [anon_sym_AMPoptional] = ACTIONS(1871),
    [anon_sym_AMPordered] = ACTIONS(1871),
    [anon_sym_AMPraw_output] = ACTIONS(1871),
    [anon_sym_AMPredef] = ACTIONS(1871),
    [anon_sym_AMPadd_func] = ACTIONS(1871),
    [anon_sym_AMPbackend] = ACTIONS(1871),
    [anon_sym_AMPbroker_store] = ACTIONS(1871),
    [anon_sym_AMPcreate_expire] = ACTIONS(1871),
    [anon_sym_AMPdefault] = ACTIONS(1871),
    [anon_sym_AMPdelete_func] = ACTIONS(1871),
    [anon_sym_AMPexpire_func] = ACTIONS(1871),
    [anon_sym_AMPgroup] = ACTIONS(1871),
    [anon_sym_AMPon_change] = ACTIONS(1871),
    [anon_sym_AMPpriority] = ACTIONS(1871),
    [anon_sym_AMPread_expire] = ACTIONS(1871),
    [anon_sym_AMPtype_column] = ACTIONS(1871),
    [anon_sym_AMPwrite_expire] = ACTIONS(1871),
    [anon_sym_DOLLAR] = ACTIONS(1871),
    [anon_sym_PIPE] = ACTIONS(1873),
    [anon_sym_BANG] = ACTIONS(1873),
    [anon_sym_DASH] = ACTIONS(1873),
    [anon_sym_PLUS] = ACTIONS(1873),
    [anon_sym_is] = ACTIONS(1871),
    [anon_sym_STAR] = ACTIONS(1871),
    [anon_sym_SLASH] = ACTIONS(1871),
    [anon_sym_PERCENT] = ACTIONS(1871),
    [anon_sym_LT] = ACTIONS(1873),
    [anon_sym_LT_EQ] = ACTIONS(1871),
    [anon_sym_GT] = ACTIONS(1873),
    [anon_sym_GT_EQ] = ACTIONS(1871),
    [anon_sym_AMP] = ACTIONS(1873),
    [anon_sym_CARET] = ACTIONS(1871),
    [anon_sym_QMARK] = ACTIONS(1873),
    [anon_sym_EQ_EQ] = ACTIONS(1871),
    [anon_sym_BANG_EQ] = ACTIONS(1871),
    [anon_sym_AMP_AMP] = ACTIONS(1871),
    [anon_sym_PIPE_PIPE] = ACTIONS(1871),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1871),
    [anon_sym_ATdeprecated] = ACTIONS(1871),
    [anon_sym_ATload] = ACTIONS(1873),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1871),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1871),
    [anon_sym_ATunload] = ACTIONS(1871),
    [anon_sym_ATprefixes] = ACTIONS(1871),
    [anon_sym_ATif] = ACTIONS(1873),
    [anon_sym_ATifdef] = ACTIONS(1871),
    [anon_sym_ATifndef] = ACTIONS(1871),
    [anon_sym_ATendif] = ACTIONS(1871),
    [anon_sym_ATelse] = ACTIONS(1871),
    [anon_sym_ATpragma] = ACTIONS(1871),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(797)] = {
    [anon_sym_SEMI] = ACTIONS(1915),
    [anon_sym_LBRACE] = ACTIONS(1915),
    [anon_sym_RBRACE] = ACTIONS(1915),
    [anon_sym_COLON] = ACTIONS(1915),
    [anon_sym_PLUS_EQ] = ACTIONS(1915),
    [anon_sym_DASH_EQ] = ACTIONS(1915),
    [anon_sym_LPAREN] = ACTIONS(1915),
    [anon_sym_RPAREN] = ACTIONS(1915),
    [anon_sym_COMMA] = ACTIONS(1915),
    [anon_sym_in] = ACTIONS(1915),
    [anon_sym_LBRACK] = ACTIONS(1915),
    [anon_sym_RBRACK] = ACTIONS(1915),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_as] = ACTIONS(1915),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1915),
    [anon_sym_AMPdeprecated] = ACTIONS(1915),
    [anon_sym_AMPerror_handler] = ACTIONS(1915),
    [anon_sym_AMPis_assigned] = ACTIONS(1915),
    [anon_sym_AMPis_used] = ACTIONS(1915),
    [anon_sym_AMPlog] = ACTIONS(1915),
    [anon_sym_AMPoptional] = ACTIONS(1915),
    [anon_sym_AMPordered] = ACTIONS(1915),
    [anon_sym_AMPraw_output] = ACTIONS(1915),
    [anon_sym_AMPredef] = ACTIONS(1915),
    [anon_sym_AMPadd_func] = ACTIONS(1915),
    [anon_sym_AMPbackend] = ACTIONS(1915),
    [anon_sym_AMPbroker_store] = ACTIONS(1915),
    [anon_sym_AMPcreate_expire] = ACTIONS(1915),
    [anon_sym_AMPdefault] = ACTIONS(1915),
    [anon_sym_AMPdelete_func] = ACTIONS(1915),
    [anon_sym_AMPexpire_func] = ACTIONS(1915),
    [anon_sym_AMPgroup] = ACTIONS(1915),
    [anon_sym_AMPon_change] = ACTIONS(1915),
    [anon_sym_AMPpriority] = ACTIONS(1915),
    [anon_sym_AMPread_expire] = ACTIONS(1915),
    [anon_sym_AMPtype_column] = ACTIONS(1915),
    [anon_sym_AMPwrite_expire] = ACTIONS(1915),
    [anon_sym_DOLLAR] = ACTIONS(1915),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_BANG] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_is] = ACTIONS(1915),
    [anon_sym_STAR] = ACTIONS(1915),
    [anon_sym_SLASH] = ACTIONS(1915),
    [anon_sym_PERCENT] = ACTIONS(1915),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_EQ] = ACTIONS(1915),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1915),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1915),
    [anon_sym_QMARK] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1915),
    [anon_sym_BANG_EQ] = ACTIONS(1915),
    [anon_sym_AMP_AMP] = ACTIONS(1915),
    [anon_sym_PIPE_PIPE] = ACTIONS(1915),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1915),
    [anon_sym_ATdeprecated] = ACTIONS(1915),
    [anon_sym_ATload] = ACTIONS(1917),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1915),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1915),
    [anon_sym_ATunload] = ACTIONS(1915),
    [anon_sym_ATprefixes] = ACTIONS(1915),
    [anon_sym_ATif] = ACTIONS(1917),
    [anon_sym_ATifdef] = ACTIONS(1915),
    [anon_sym_ATifndef] = ACTIONS(1915),
    [anon_sym_ATendif] = ACTIONS(1915),
    [anon_sym_ATelse] = ACTIONS(1915),
    [anon_sym_ATpragma] = ACTIONS(1915),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(798)] = {
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_COLON] = ACTIONS(127),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(127),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(127),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(127),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(799)] = {
    [anon_sym_SEMI] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1931),
    [anon_sym_RBRACE] = ACTIONS(1931),
    [anon_sym_COLON] = ACTIONS(1931),
    [anon_sym_PLUS_EQ] = ACTIONS(1931),
    [anon_sym_DASH_EQ] = ACTIONS(1931),
    [anon_sym_LPAREN] = ACTIONS(1931),
    [anon_sym_RPAREN] = ACTIONS(1931),
    [anon_sym_COMMA] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_RBRACK] = ACTIONS(1931),
    [anon_sym_EQ] = ACTIONS(1933),
    [anon_sym_as] = ACTIONS(1931),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1931),
    [anon_sym_AMPdeprecated] = ACTIONS(1931),
    [anon_sym_AMPerror_handler] = ACTIONS(1931),
    [anon_sym_AMPis_assigned] = ACTIONS(1931),
    [anon_sym_AMPis_used] = ACTIONS(1931),
    [anon_sym_AMPlog] = ACTIONS(1931),
    [anon_sym_AMPoptional] = ACTIONS(1931),
    [anon_sym_AMPordered] = ACTIONS(1931),
    [anon_sym_AMPraw_output] = ACTIONS(1931),
    [anon_sym_AMPredef] = ACTIONS(1931),
    [anon_sym_AMPadd_func] = ACTIONS(1931),
    [anon_sym_AMPbackend] = ACTIONS(1931),
    [anon_sym_AMPbroker_store] = ACTIONS(1931),
    [anon_sym_AMPcreate_expire] = ACTIONS(1931),
    [anon_sym_AMPdefault] = ACTIONS(1931),
    [anon_sym_AMPdelete_func] = ACTIONS(1931),
    [anon_sym_AMPexpire_func] = ACTIONS(1931),
    [anon_sym_AMPgroup] = ACTIONS(1931),
    [anon_sym_AMPon_change] = ACTIONS(1931),
    [anon_sym_AMPpriority] = ACTIONS(1931),
    [anon_sym_AMPread_expire] = ACTIONS(1931),
    [anon_sym_AMPtype_column] = ACTIONS(1931),
    [anon_sym_AMPwrite_expire] = ACTIONS(1931),
    [anon_sym_DOLLAR] = ACTIONS(1931),
    [anon_sym_PIPE] = ACTIONS(1933),
    [anon_sym_BANG] = ACTIONS(1933),
    [anon_sym_DASH] = ACTIONS(1933),
    [anon_sym_PLUS] = ACTIONS(1933),
    [anon_sym_is] = ACTIONS(1931),
    [anon_sym_STAR] = ACTIONS(1931),
    [anon_sym_SLASH] = ACTIONS(1931),
    [anon_sym_PERCENT] = ACTIONS(1931),
    [anon_sym_LT] = ACTIONS(1933),
    [anon_sym_LT_EQ] = ACTIONS(1931),
    [anon_sym_GT] = ACTIONS(1933),
    [anon_sym_GT_EQ] = ACTIONS(1931),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_CARET] = ACTIONS(1931),
    [anon_sym_QMARK] = ACTIONS(1933),
    [anon_sym_EQ_EQ] = ACTIONS(1931),
    [anon_sym_BANG_EQ] = ACTIONS(1931),
    [anon_sym_AMP_AMP] = ACTIONS(1931),
    [anon_sym_PIPE_PIPE] = ACTIONS(1931),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1931),
    [anon_sym_ATdeprecated] = ACTIONS(1931),
    [anon_sym_ATload] = ACTIONS(1933),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1931),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1931),
    [anon_sym_ATunload] = ACTIONS(1931),
    [anon_sym_ATprefixes] = ACTIONS(1931),
    [anon_sym_ATif] = ACTIONS(1933),
    [anon_sym_ATifdef] = ACTIONS(1931),
    [anon_sym_ATifndef] = ACTIONS(1931),
    [anon_sym_ATendif] = ACTIONS(1931),
    [anon_sym_ATelse] = ACTIONS(1931),
    [anon_sym_ATpragma] = ACTIONS(1931),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(800)] = {
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_RBRACE] = ACTIONS(1935),
    [anon_sym_COLON] = ACTIONS(1935),
    [anon_sym_PLUS_EQ] = ACTIONS(1935),
    [anon_sym_DASH_EQ] = ACTIONS(1935),
    [anon_sym_LPAREN] = ACTIONS(1935),
    [anon_sym_RPAREN] = ACTIONS(1935),
    [anon_sym_COMMA] = ACTIONS(1935),
    [anon_sym_in] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(1935),
    [anon_sym_RBRACK] = ACTIONS(1935),
    [anon_sym_EQ] = ACTIONS(1937),
    [anon_sym_as] = ACTIONS(1935),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1935),
    [anon_sym_AMPdeprecated] = ACTIONS(1935),
    [anon_sym_AMPerror_handler] = ACTIONS(1935),
    [anon_sym_AMPis_assigned] = ACTIONS(1935),
    [anon_sym_AMPis_used] = ACTIONS(1935),
    [anon_sym_AMPlog] = ACTIONS(1935),
    [anon_sym_AMPoptional] = ACTIONS(1935),
    [anon_sym_AMPordered] = ACTIONS(1935),
    [anon_sym_AMPraw_output] = ACTIONS(1935),
    [anon_sym_AMPredef] = ACTIONS(1935),
    [anon_sym_AMPadd_func] = ACTIONS(1935),
    [anon_sym_AMPbackend] = ACTIONS(1935),
    [anon_sym_AMPbroker_store] = ACTIONS(1935),
    [anon_sym_AMPcreate_expire] = ACTIONS(1935),
    [anon_sym_AMPdefault] = ACTIONS(1935),
    [anon_sym_AMPdelete_func] = ACTIONS(1935),
    [anon_sym_AMPexpire_func] = ACTIONS(1935),
    [anon_sym_AMPgroup] = ACTIONS(1935),
    [anon_sym_AMPon_change] = ACTIONS(1935),
    [anon_sym_AMPpriority] = ACTIONS(1935),
    [anon_sym_AMPread_expire] = ACTIONS(1935),
    [anon_sym_AMPtype_column] = ACTIONS(1935),
    [anon_sym_AMPwrite_expire] = ACTIONS(1935),
    [anon_sym_DOLLAR] = ACTIONS(1935),
    [anon_sym_PIPE] = ACTIONS(1937),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_DASH] = ACTIONS(1937),
    [anon_sym_PLUS] = ACTIONS(1937),
    [anon_sym_is] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_SLASH] = ACTIONS(1935),
    [anon_sym_PERCENT] = ACTIONS(1935),
    [anon_sym_LT] = ACTIONS(1937),
    [anon_sym_LT_EQ] = ACTIONS(1935),
    [anon_sym_GT] = ACTIONS(1937),
    [anon_sym_GT_EQ] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_CARET] = ACTIONS(1935),
    [anon_sym_QMARK] = ACTIONS(1937),
    [anon_sym_EQ_EQ] = ACTIONS(1935),
    [anon_sym_BANG_EQ] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_PIPE_PIPE] = ACTIONS(1935),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1935),
    [anon_sym_ATdeprecated] = ACTIONS(1935),
    [anon_sym_ATload] = ACTIONS(1937),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1935),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1935),
    [anon_sym_ATunload] = ACTIONS(1935),
    [anon_sym_ATprefixes] = ACTIONS(1935),
    [anon_sym_ATif] = ACTIONS(1937),
    [anon_sym_ATifdef] = ACTIONS(1935),
    [anon_sym_ATifndef] = ACTIONS(1935),
    [anon_sym_ATendif] = ACTIONS(1935),
    [anon_sym_ATelse] = ACTIONS(1935),
    [anon_sym_ATpragma] = ACTIONS(1935),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(801)] = {
    [anon_sym_SEMI] = ACTIONS(1855),
    [anon_sym_LBRACE] = ACTIONS(1855),
    [anon_sym_RBRACE] = ACTIONS(1855),
    [anon_sym_COLON] = ACTIONS(1855),
    [anon_sym_PLUS_EQ] = ACTIONS(1855),
    [anon_sym_DASH_EQ] = ACTIONS(1855),
    [anon_sym_LPAREN] = ACTIONS(1855),
    [anon_sym_RPAREN] = ACTIONS(1855),
    [anon_sym_COMMA] = ACTIONS(1855),
    [anon_sym_in] = ACTIONS(1855),
    [anon_sym_LBRACK] = ACTIONS(1855),
    [anon_sym_RBRACK] = ACTIONS(1855),
    [anon_sym_EQ] = ACTIONS(1857),
    [anon_sym_as] = ACTIONS(1855),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1855),
    [anon_sym_AMPdeprecated] = ACTIONS(1855),
    [anon_sym_AMPerror_handler] = ACTIONS(1855),
    [anon_sym_AMPis_assigned] = ACTIONS(1855),
    [anon_sym_AMPis_used] = ACTIONS(1855),
    [anon_sym_AMPlog] = ACTIONS(1855),
    [anon_sym_AMPoptional] = ACTIONS(1855),
    [anon_sym_AMPordered] = ACTIONS(1855),
    [anon_sym_AMPraw_output] = ACTIONS(1855),
    [anon_sym_AMPredef] = ACTIONS(1855),
    [anon_sym_AMPadd_func] = ACTIONS(1855),
    [anon_sym_AMPbackend] = ACTIONS(1855),
    [anon_sym_AMPbroker_store] = ACTIONS(1855),
    [anon_sym_AMPcreate_expire] = ACTIONS(1855),
    [anon_sym_AMPdefault] = ACTIONS(1855),
    [anon_sym_AMPdelete_func] = ACTIONS(1855),
    [anon_sym_AMPexpire_func] = ACTIONS(1855),
    [anon_sym_AMPgroup] = ACTIONS(1855),
    [anon_sym_AMPon_change] = ACTIONS(1855),
    [anon_sym_AMPpriority] = ACTIONS(1855),
    [anon_sym_AMPread_expire] = ACTIONS(1855),
    [anon_sym_AMPtype_column] = ACTIONS(1855),
    [anon_sym_AMPwrite_expire] = ACTIONS(1855),
    [anon_sym_DOLLAR] = ACTIONS(1855),
    [anon_sym_PIPE] = ACTIONS(1857),
    [anon_sym_BANG] = ACTIONS(1857),
    [anon_sym_DASH] = ACTIONS(1857),
    [anon_sym_PLUS] = ACTIONS(1857),
    [anon_sym_is] = ACTIONS(1855),
    [anon_sym_STAR] = ACTIONS(1855),
    [anon_sym_SLASH] = ACTIONS(1855),
    [anon_sym_PERCENT] = ACTIONS(1855),
    [anon_sym_LT] = ACTIONS(1857),
    [anon_sym_LT_EQ] = ACTIONS(1855),
    [anon_sym_GT] = ACTIONS(1857),
    [anon_sym_GT_EQ] = ACTIONS(1855),
    [anon_sym_AMP] = ACTIONS(1857),
    [anon_sym_CARET] = ACTIONS(1855),
    [anon_sym_QMARK] = ACTIONS(1857),
    [anon_sym_EQ_EQ] = ACTIONS(1855),
    [anon_sym_BANG_EQ] = ACTIONS(1855),
    [anon_sym_AMP_AMP] = ACTIONS(1855),
    [anon_sym_PIPE_PIPE] = ACTIONS(1855),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1855),
    [anon_sym_ATdeprecated] = ACTIONS(1855),
    [anon_sym_ATload] = ACTIONS(1857),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1855),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1855),
    [anon_sym_ATunload] = ACTIONS(1855),
    [anon_sym_ATprefixes] = ACTIONS(1855),
    [anon_sym_ATif] = ACTIONS(1857),
    [anon_sym_ATifdef] = ACTIONS(1855),
    [anon_sym_ATifndef] = ACTIONS(1855),
    [anon_sym_ATendif] = ACTIONS(1855),
    [anon_sym_ATelse] = ACTIONS(1855),
    [anon_sym_ATpragma] = ACTIONS(1855),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(802)] = {
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_COLON] = ACTIONS(127),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(127),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(127),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(127),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(803)] = {
    [anon_sym_SEMI] = ACTIONS(1915),
    [anon_sym_LBRACE] = ACTIONS(1915),
    [anon_sym_RBRACE] = ACTIONS(1915),
    [anon_sym_COLON] = ACTIONS(1915),
    [anon_sym_PLUS_EQ] = ACTIONS(1915),
    [anon_sym_DASH_EQ] = ACTIONS(1915),
    [anon_sym_LPAREN] = ACTIONS(1915),
    [anon_sym_RPAREN] = ACTIONS(1915),
    [anon_sym_COMMA] = ACTIONS(1915),
    [anon_sym_in] = ACTIONS(1915),
    [anon_sym_LBRACK] = ACTIONS(1915),
    [anon_sym_RBRACK] = ACTIONS(1915),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_as] = ACTIONS(1915),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1915),
    [anon_sym_AMPdeprecated] = ACTIONS(1915),
    [anon_sym_AMPerror_handler] = ACTIONS(1915),
    [anon_sym_AMPis_assigned] = ACTIONS(1915),
    [anon_sym_AMPis_used] = ACTIONS(1915),
    [anon_sym_AMPlog] = ACTIONS(1915),
    [anon_sym_AMPoptional] = ACTIONS(1915),
    [anon_sym_AMPordered] = ACTIONS(1915),
    [anon_sym_AMPraw_output] = ACTIONS(1915),
    [anon_sym_AMPredef] = ACTIONS(1915),
    [anon_sym_AMPadd_func] = ACTIONS(1915),
    [anon_sym_AMPbackend] = ACTIONS(1915),
    [anon_sym_AMPbroker_store] = ACTIONS(1915),
    [anon_sym_AMPcreate_expire] = ACTIONS(1915),
    [anon_sym_AMPdefault] = ACTIONS(1915),
    [anon_sym_AMPdelete_func] = ACTIONS(1915),
    [anon_sym_AMPexpire_func] = ACTIONS(1915),
    [anon_sym_AMPgroup] = ACTIONS(1915),
    [anon_sym_AMPon_change] = ACTIONS(1915),
    [anon_sym_AMPpriority] = ACTIONS(1915),
    [anon_sym_AMPread_expire] = ACTIONS(1915),
    [anon_sym_AMPtype_column] = ACTIONS(1915),
    [anon_sym_AMPwrite_expire] = ACTIONS(1915),
    [anon_sym_DOLLAR] = ACTIONS(1915),
    [anon_sym_PIPE] = ACTIONS(1917),
    [anon_sym_BANG] = ACTIONS(1917),
    [anon_sym_DASH] = ACTIONS(1917),
    [anon_sym_PLUS] = ACTIONS(1917),
    [anon_sym_is] = ACTIONS(1915),
    [anon_sym_STAR] = ACTIONS(1915),
    [anon_sym_SLASH] = ACTIONS(1915),
    [anon_sym_PERCENT] = ACTIONS(1915),
    [anon_sym_LT] = ACTIONS(1917),
    [anon_sym_LT_EQ] = ACTIONS(1915),
    [anon_sym_GT] = ACTIONS(1917),
    [anon_sym_GT_EQ] = ACTIONS(1915),
    [anon_sym_AMP] = ACTIONS(1917),
    [anon_sym_CARET] = ACTIONS(1915),
    [anon_sym_QMARK] = ACTIONS(1917),
    [anon_sym_EQ_EQ] = ACTIONS(1915),
    [anon_sym_BANG_EQ] = ACTIONS(1915),
    [anon_sym_AMP_AMP] = ACTIONS(1915),
    [anon_sym_PIPE_PIPE] = ACTIONS(1915),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1915),
    [anon_sym_ATdeprecated] = ACTIONS(1915),
    [anon_sym_ATload] = ACTIONS(1917),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1915),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1915),
    [anon_sym_ATunload] = ACTIONS(1915),
    [anon_sym_ATprefixes] = ACTIONS(1915),
    [anon_sym_ATif] = ACTIONS(1917),
    [anon_sym_ATifdef] = ACTIONS(1915),
    [anon_sym_ATifndef] = ACTIONS(1915),
    [anon_sym_ATendif] = ACTIONS(1915),
    [anon_sym_ATelse] = ACTIONS(1915),
    [anon_sym_ATpragma] = ACTIONS(1915),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(804)] = {
    [anon_sym_SEMI] = ACTIONS(1863),
    [anon_sym_LBRACE] = ACTIONS(1863),
    [anon_sym_RBRACE] = ACTIONS(1863),
    [anon_sym_COLON] = ACTIONS(1863),
    [anon_sym_PLUS_EQ] = ACTIONS(1863),
    [anon_sym_DASH_EQ] = ACTIONS(1863),
    [anon_sym_LPAREN] = ACTIONS(1863),
    [anon_sym_RPAREN] = ACTIONS(1863),
    [anon_sym_COMMA] = ACTIONS(1863),
    [anon_sym_in] = ACTIONS(1863),
    [anon_sym_LBRACK] = ACTIONS(1863),
    [anon_sym_RBRACK] = ACTIONS(1863),
    [anon_sym_EQ] = ACTIONS(1865),
    [anon_sym_as] = ACTIONS(1863),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1863),
    [anon_sym_AMPdeprecated] = ACTIONS(1863),
    [anon_sym_AMPerror_handler] = ACTIONS(1863),
    [anon_sym_AMPis_assigned] = ACTIONS(1863),
    [anon_sym_AMPis_used] = ACTIONS(1863),
    [anon_sym_AMPlog] = ACTIONS(1863),
    [anon_sym_AMPoptional] = ACTIONS(1863),
    [anon_sym_AMPordered] = ACTIONS(1863),
    [anon_sym_AMPraw_output] = ACTIONS(1863),
    [anon_sym_AMPredef] = ACTIONS(1863),
    [anon_sym_AMPadd_func] = ACTIONS(1863),
    [anon_sym_AMPbackend] = ACTIONS(1863),
    [anon_sym_AMPbroker_store] = ACTIONS(1863),
    [anon_sym_AMPcreate_expire] = ACTIONS(1863),
    [anon_sym_AMPdefault] = ACTIONS(1863),
    [anon_sym_AMPdelete_func] = ACTIONS(1863),
    [anon_sym_AMPexpire_func] = ACTIONS(1863),
    [anon_sym_AMPgroup] = ACTIONS(1863),
    [anon_sym_AMPon_change] = ACTIONS(1863),
    [anon_sym_AMPpriority] = ACTIONS(1863),
    [anon_sym_AMPread_expire] = ACTIONS(1863),
    [anon_sym_AMPtype_column] = ACTIONS(1863),
    [anon_sym_AMPwrite_expire] = ACTIONS(1863),
    [anon_sym_DOLLAR] = ACTIONS(1863),
    [anon_sym_PIPE] = ACTIONS(1865),
    [anon_sym_BANG] = ACTIONS(1865),
    [anon_sym_DASH] = ACTIONS(1865),
    [anon_sym_PLUS] = ACTIONS(1865),
    [anon_sym_is] = ACTIONS(1863),
    [anon_sym_STAR] = ACTIONS(1863),
    [anon_sym_SLASH] = ACTIONS(1863),
    [anon_sym_PERCENT] = ACTIONS(1863),
    [anon_sym_LT] = ACTIONS(1865),
    [anon_sym_LT_EQ] = ACTIONS(1863),
    [anon_sym_GT] = ACTIONS(1865),
    [anon_sym_GT_EQ] = ACTIONS(1863),
    [anon_sym_AMP] = ACTIONS(1865),
    [anon_sym_CARET] = ACTIONS(1863),
    [anon_sym_QMARK] = ACTIONS(1865),
    [anon_sym_EQ_EQ] = ACTIONS(1863),
    [anon_sym_BANG_EQ] = ACTIONS(1863),
    [anon_sym_AMP_AMP] = ACTIONS(1863),
    [anon_sym_PIPE_PIPE] = ACTIONS(1863),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1863),
    [anon_sym_ATdeprecated] = ACTIONS(1863),
    [anon_sym_ATload] = ACTIONS(1865),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1863),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1863),
    [anon_sym_ATunload] = ACTIONS(1863),
    [anon_sym_ATprefixes] = ACTIONS(1863),
    [anon_sym_ATif] = ACTIONS(1865),
    [anon_sym_ATifdef] = ACTIONS(1863),
    [anon_sym_ATifndef] = ACTIONS(1863),
    [anon_sym_ATendif] = ACTIONS(1863),
    [anon_sym_ATelse] = ACTIONS(1863),
    [anon_sym_ATpragma] = ACTIONS(1863),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(805)] = {
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_RBRACE] = ACTIONS(1935),
    [anon_sym_COLON] = ACTIONS(1935),
    [anon_sym_PLUS_EQ] = ACTIONS(1935),
    [anon_sym_DASH_EQ] = ACTIONS(1935),
    [anon_sym_LPAREN] = ACTIONS(1935),
    [anon_sym_RPAREN] = ACTIONS(1935),
    [anon_sym_COMMA] = ACTIONS(1935),
    [anon_sym_in] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(1935),
    [anon_sym_RBRACK] = ACTIONS(1935),
    [anon_sym_EQ] = ACTIONS(1937),
    [anon_sym_as] = ACTIONS(1935),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1935),
    [anon_sym_AMPdeprecated] = ACTIONS(1935),
    [anon_sym_AMPerror_handler] = ACTIONS(1935),
    [anon_sym_AMPis_assigned] = ACTIONS(1935),
    [anon_sym_AMPis_used] = ACTIONS(1935),
    [anon_sym_AMPlog] = ACTIONS(1935),
    [anon_sym_AMPoptional] = ACTIONS(1935),
    [anon_sym_AMPordered] = ACTIONS(1935),
    [anon_sym_AMPraw_output] = ACTIONS(1935),
    [anon_sym_AMPredef] = ACTIONS(1935),
    [anon_sym_AMPadd_func] = ACTIONS(1935),
    [anon_sym_AMPbackend] = ACTIONS(1935),
    [anon_sym_AMPbroker_store] = ACTIONS(1935),
    [anon_sym_AMPcreate_expire] = ACTIONS(1935),
    [anon_sym_AMPdefault] = ACTIONS(1935),
    [anon_sym_AMPdelete_func] = ACTIONS(1935),
    [anon_sym_AMPexpire_func] = ACTIONS(1935),
    [anon_sym_AMPgroup] = ACTIONS(1935),
    [anon_sym_AMPon_change] = ACTIONS(1935),
    [anon_sym_AMPpriority] = ACTIONS(1935),
    [anon_sym_AMPread_expire] = ACTIONS(1935),
    [anon_sym_AMPtype_column] = ACTIONS(1935),
    [anon_sym_AMPwrite_expire] = ACTIONS(1935),
    [anon_sym_DOLLAR] = ACTIONS(1935),
    [anon_sym_PIPE] = ACTIONS(1937),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_DASH] = ACTIONS(1937),
    [anon_sym_PLUS] = ACTIONS(1937),
    [anon_sym_is] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_SLASH] = ACTIONS(1935),
    [anon_sym_PERCENT] = ACTIONS(1935),
    [anon_sym_LT] = ACTIONS(1937),
    [anon_sym_LT_EQ] = ACTIONS(1935),
    [anon_sym_GT] = ACTIONS(1937),
    [anon_sym_GT_EQ] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_CARET] = ACTIONS(1935),
    [anon_sym_QMARK] = ACTIONS(1937),
    [anon_sym_EQ_EQ] = ACTIONS(1935),
    [anon_sym_BANG_EQ] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_PIPE_PIPE] = ACTIONS(1935),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1935),
    [anon_sym_ATdeprecated] = ACTIONS(1935),
    [anon_sym_ATload] = ACTIONS(1937),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1935),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1935),
    [anon_sym_ATunload] = ACTIONS(1935),
    [anon_sym_ATprefixes] = ACTIONS(1935),
    [anon_sym_ATif] = ACTIONS(1937),
    [anon_sym_ATifdef] = ACTIONS(1935),
    [anon_sym_ATifndef] = ACTIONS(1935),
    [anon_sym_ATendif] = ACTIONS(1935),
    [anon_sym_ATelse] = ACTIONS(1935),
    [anon_sym_ATpragma] = ACTIONS(1935),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(806)] = {
    [anon_sym_SEMI] = ACTIONS(1837),
    [anon_sym_LBRACE] = ACTIONS(1837),
    [anon_sym_RBRACE] = ACTIONS(1837),
    [anon_sym_COLON] = ACTIONS(1837),
    [anon_sym_PLUS_EQ] = ACTIONS(1837),
    [anon_sym_DASH_EQ] = ACTIONS(1837),
    [anon_sym_LPAREN] = ACTIONS(1837),
    [anon_sym_RPAREN] = ACTIONS(1837),
    [anon_sym_COMMA] = ACTIONS(1837),
    [anon_sym_in] = ACTIONS(1837),
    [anon_sym_LBRACK] = ACTIONS(1837),
    [anon_sym_RBRACK] = ACTIONS(1837),
    [anon_sym_EQ] = ACTIONS(1839),
    [anon_sym_as] = ACTIONS(1837),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1837),
    [anon_sym_AMPdeprecated] = ACTIONS(1837),
    [anon_sym_AMPerror_handler] = ACTIONS(1837),
    [anon_sym_AMPis_assigned] = ACTIONS(1837),
    [anon_sym_AMPis_used] = ACTIONS(1837),
    [anon_sym_AMPlog] = ACTIONS(1837),
    [anon_sym_AMPoptional] = ACTIONS(1837),
    [anon_sym_AMPordered] = ACTIONS(1837),
    [anon_sym_AMPraw_output] = ACTIONS(1837),
    [anon_sym_AMPredef] = ACTIONS(1837),
    [anon_sym_AMPadd_func] = ACTIONS(1837),
    [anon_sym_AMPbackend] = ACTIONS(1837),
    [anon_sym_AMPbroker_store] = ACTIONS(1837),
    [anon_sym_AMPcreate_expire] = ACTIONS(1837),
    [anon_sym_AMPdefault] = ACTIONS(1837),
    [anon_sym_AMPdelete_func] = ACTIONS(1837),
    [anon_sym_AMPexpire_func] = ACTIONS(1837),
    [anon_sym_AMPgroup] = ACTIONS(1837),
    [anon_sym_AMPon_change] = ACTIONS(1837),
    [anon_sym_AMPpriority] = ACTIONS(1837),
    [anon_sym_AMPread_expire] = ACTIONS(1837),
    [anon_sym_AMPtype_column] = ACTIONS(1837),
    [anon_sym_AMPwrite_expire] = ACTIONS(1837),
    [anon_sym_DOLLAR] = ACTIONS(1837),
    [anon_sym_PIPE] = ACTIONS(1839),
    [anon_sym_BANG] = ACTIONS(1839),
    [anon_sym_DASH] = ACTIONS(1839),
    [anon_sym_PLUS] = ACTIONS(1839),
    [anon_sym_is] = ACTIONS(1837),
    [anon_sym_STAR] = ACTIONS(1837),
    [anon_sym_SLASH] = ACTIONS(1837),
    [anon_sym_PERCENT] = ACTIONS(1837),
    [anon_sym_LT] = ACTIONS(1839),
    [anon_sym_LT_EQ] = ACTIONS(1837),
    [anon_sym_GT] = ACTIONS(1839),
    [anon_sym_GT_EQ] = ACTIONS(1837),
    [anon_sym_AMP] = ACTIONS(1839),
    [anon_sym_CARET] = ACTIONS(1837),
    [anon_sym_QMARK] = ACTIONS(1839),
    [anon_sym_EQ_EQ] = ACTIONS(1837),
    [anon_sym_BANG_EQ] = ACTIONS(1837),
    [anon_sym_AMP_AMP] = ACTIONS(1837),
    [anon_sym_PIPE_PIPE] = ACTIONS(1837),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1837),
    [anon_sym_ATdeprecated] = ACTIONS(1837),
    [anon_sym_ATload] = ACTIONS(1839),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1837),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1837),
    [anon_sym_ATunload] = ACTIONS(1837),
    [anon_sym_ATprefixes] = ACTIONS(1837),
    [anon_sym_ATif] = ACTIONS(1839),
    [anon_sym_ATifdef] = ACTIONS(1837),
    [anon_sym_ATifndef] = ACTIONS(1837),
    [anon_sym_ATendif] = ACTIONS(1837),
    [anon_sym_ATelse] = ACTIONS(1837),
    [anon_sym_ATpragma] = ACTIONS(1837),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(807)] = {
    [anon_sym_SEMI] = ACTIONS(1931),
    [anon_sym_LBRACE] = ACTIONS(1931),
    [anon_sym_RBRACE] = ACTIONS(1931),
    [anon_sym_COLON] = ACTIONS(1931),
    [anon_sym_PLUS_EQ] = ACTIONS(1931),
    [anon_sym_DASH_EQ] = ACTIONS(1931),
    [anon_sym_LPAREN] = ACTIONS(1931),
    [anon_sym_RPAREN] = ACTIONS(1931),
    [anon_sym_COMMA] = ACTIONS(1931),
    [anon_sym_in] = ACTIONS(1931),
    [anon_sym_LBRACK] = ACTIONS(1931),
    [anon_sym_RBRACK] = ACTIONS(1931),
    [anon_sym_EQ] = ACTIONS(1933),
    [anon_sym_as] = ACTIONS(1931),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1931),
    [anon_sym_AMPdeprecated] = ACTIONS(1931),
    [anon_sym_AMPerror_handler] = ACTIONS(1931),
    [anon_sym_AMPis_assigned] = ACTIONS(1931),
    [anon_sym_AMPis_used] = ACTIONS(1931),
    [anon_sym_AMPlog] = ACTIONS(1931),
    [anon_sym_AMPoptional] = ACTIONS(1931),
    [anon_sym_AMPordered] = ACTIONS(1931),
    [anon_sym_AMPraw_output] = ACTIONS(1931),
    [anon_sym_AMPredef] = ACTIONS(1931),
    [anon_sym_AMPadd_func] = ACTIONS(1931),
    [anon_sym_AMPbackend] = ACTIONS(1931),
    [anon_sym_AMPbroker_store] = ACTIONS(1931),
    [anon_sym_AMPcreate_expire] = ACTIONS(1931),
    [anon_sym_AMPdefault] = ACTIONS(1931),
    [anon_sym_AMPdelete_func] = ACTIONS(1931),
    [anon_sym_AMPexpire_func] = ACTIONS(1931),
    [anon_sym_AMPgroup] = ACTIONS(1931),
    [anon_sym_AMPon_change] = ACTIONS(1931),
    [anon_sym_AMPpriority] = ACTIONS(1931),
    [anon_sym_AMPread_expire] = ACTIONS(1931),
    [anon_sym_AMPtype_column] = ACTIONS(1931),
    [anon_sym_AMPwrite_expire] = ACTIONS(1931),
    [anon_sym_DOLLAR] = ACTIONS(1931),
    [anon_sym_PIPE] = ACTIONS(1933),
    [anon_sym_BANG] = ACTIONS(1933),
    [anon_sym_DASH] = ACTIONS(1933),
    [anon_sym_PLUS] = ACTIONS(1933),
    [anon_sym_is] = ACTIONS(1931),
    [anon_sym_STAR] = ACTIONS(1931),
    [anon_sym_SLASH] = ACTIONS(1931),
    [anon_sym_PERCENT] = ACTIONS(1931),
    [anon_sym_LT] = ACTIONS(1933),
    [anon_sym_LT_EQ] = ACTIONS(1931),
    [anon_sym_GT] = ACTIONS(1933),
    [anon_sym_GT_EQ] = ACTIONS(1931),
    [anon_sym_AMP] = ACTIONS(1933),
    [anon_sym_CARET] = ACTIONS(1931),
    [anon_sym_QMARK] = ACTIONS(1933),
    [anon_sym_EQ_EQ] = ACTIONS(1931),
    [anon_sym_BANG_EQ] = ACTIONS(1931),
    [anon_sym_AMP_AMP] = ACTIONS(1931),
    [anon_sym_PIPE_PIPE] = ACTIONS(1931),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1931),
    [anon_sym_ATdeprecated] = ACTIONS(1931),
    [anon_sym_ATload] = ACTIONS(1933),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1931),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1931),
    [anon_sym_ATunload] = ACTIONS(1931),
    [anon_sym_ATprefixes] = ACTIONS(1931),
    [anon_sym_ATif] = ACTIONS(1933),
    [anon_sym_ATifdef] = ACTIONS(1931),
    [anon_sym_ATifndef] = ACTIONS(1931),
    [anon_sym_ATendif] = ACTIONS(1931),
    [anon_sym_ATelse] = ACTIONS(1931),
    [anon_sym_ATpragma] = ACTIONS(1931),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(808)] = {
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_RBRACE] = ACTIONS(127),
    [anon_sym_COLON] = ACTIONS(127),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_RPAREN] = ACTIONS(127),
    [anon_sym_COMMA] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(127),
    [anon_sym_RBRACK] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(127),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(127),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(809)] = {
    [anon_sym_SEMI] = ACTIONS(1935),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_RBRACE] = ACTIONS(1935),
    [anon_sym_COLON] = ACTIONS(1935),
    [anon_sym_PLUS_EQ] = ACTIONS(1935),
    [anon_sym_DASH_EQ] = ACTIONS(1935),
    [anon_sym_LPAREN] = ACTIONS(1935),
    [anon_sym_RPAREN] = ACTIONS(1935),
    [anon_sym_COMMA] = ACTIONS(1935),
    [anon_sym_in] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(1935),
    [anon_sym_RBRACK] = ACTIONS(1935),
    [anon_sym_EQ] = ACTIONS(1937),
    [anon_sym_as] = ACTIONS(1935),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1935),
    [anon_sym_AMPdeprecated] = ACTIONS(1935),
    [anon_sym_AMPerror_handler] = ACTIONS(1935),
    [anon_sym_AMPis_assigned] = ACTIONS(1935),
    [anon_sym_AMPis_used] = ACTIONS(1935),
    [anon_sym_AMPlog] = ACTIONS(1935),
    [anon_sym_AMPoptional] = ACTIONS(1935),
    [anon_sym_AMPordered] = ACTIONS(1935),
    [anon_sym_AMPraw_output] = ACTIONS(1935),
    [anon_sym_AMPredef] = ACTIONS(1935),
    [anon_sym_AMPadd_func] = ACTIONS(1935),
    [anon_sym_AMPbackend] = ACTIONS(1935),
    [anon_sym_AMPbroker_store] = ACTIONS(1935),
    [anon_sym_AMPcreate_expire] = ACTIONS(1935),
    [anon_sym_AMPdefault] = ACTIONS(1935),
    [anon_sym_AMPdelete_func] = ACTIONS(1935),
    [anon_sym_AMPexpire_func] = ACTIONS(1935),
    [anon_sym_AMPgroup] = ACTIONS(1935),
    [anon_sym_AMPon_change] = ACTIONS(1935),
    [anon_sym_AMPpriority] = ACTIONS(1935),
    [anon_sym_AMPread_expire] = ACTIONS(1935),
    [anon_sym_AMPtype_column] = ACTIONS(1935),
    [anon_sym_AMPwrite_expire] = ACTIONS(1935),
    [anon_sym_DOLLAR] = ACTIONS(1935),
    [anon_sym_PIPE] = ACTIONS(1937),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_DASH] = ACTIONS(1937),
    [anon_sym_PLUS] = ACTIONS(1937),
    [anon_sym_is] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_SLASH] = ACTIONS(1935),
    [anon_sym_PERCENT] = ACTIONS(1935),
    [anon_sym_LT] = ACTIONS(1937),
    [anon_sym_LT_EQ] = ACTIONS(1935),
    [anon_sym_GT] = ACTIONS(1937),
    [anon_sym_GT_EQ] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_CARET] = ACTIONS(1935),
    [anon_sym_QMARK] = ACTIONS(1937),
    [anon_sym_EQ_EQ] = ACTIONS(1935),
    [anon_sym_BANG_EQ] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_PIPE_PIPE] = ACTIONS(1935),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1935),
    [anon_sym_ATdeprecated] = ACTIONS(1935),
    [anon_sym_ATload] = ACTIONS(1937),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1935),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1935),
    [anon_sym_ATunload] = ACTIONS(1935),
    [anon_sym_ATprefixes] = ACTIONS(1935),
    [anon_sym_ATif] = ACTIONS(1937),
    [anon_sym_ATifdef] = ACTIONS(1935),
    [anon_sym_ATifndef] = ACTIONS(1935),
    [anon_sym_ATendif] = ACTIONS(1935),
    [anon_sym_ATelse] = ACTIONS(1935),
    [anon_sym_ATpragma] = ACTIONS(1935),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(810)] = {
    [anon_sym_SEMI] = ACTIONS(1849),
    [anon_sym_LBRACE] = ACTIONS(1849),
    [anon_sym_RBRACE] = ACTIONS(1849),
    [anon_sym_COLON] = ACTIONS(1939),
    [anon_sym_PLUS_EQ] = ACTIONS(1849),
    [anon_sym_DASH_EQ] = ACTIONS(1849),
    [anon_sym_LPAREN] = ACTIONS(1849),
    [anon_sym_RPAREN] = ACTIONS(1849),
    [anon_sym_COMMA] = ACTIONS(1849),
    [anon_sym_in] = ACTIONS(1849),
    [anon_sym_LBRACK] = ACTIONS(1849),
    [anon_sym_RBRACK] = ACTIONS(1849),
    [anon_sym_EQ] = ACTIONS(1853),
    [anon_sym_as] = ACTIONS(1849),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1849),
    [anon_sym_AMPdeprecated] = ACTIONS(1849),
    [anon_sym_AMPerror_handler] = ACTIONS(1849),
    [anon_sym_AMPis_assigned] = ACTIONS(1849),
    [anon_sym_AMPis_used] = ACTIONS(1849),
    [anon_sym_AMPlog] = ACTIONS(1849),
    [anon_sym_AMPoptional] = ACTIONS(1849),
    [anon_sym_AMPordered] = ACTIONS(1849),
    [anon_sym_AMPraw_output] = ACTIONS(1849),
    [anon_sym_AMPredef] = ACTIONS(1849),
    [anon_sym_AMPadd_func] = ACTIONS(1849),
    [anon_sym_AMPbackend] = ACTIONS(1849),
    [anon_sym_AMPbroker_store] = ACTIONS(1849),
    [anon_sym_AMPcreate_expire] = ACTIONS(1849),
    [anon_sym_AMPdefault] = ACTIONS(1849),
    [anon_sym_AMPdelete_func] = ACTIONS(1849),
    [anon_sym_AMPexpire_func] = ACTIONS(1849),
    [anon_sym_AMPgroup] = ACTIONS(1849),
    [anon_sym_AMPon_change] = ACTIONS(1849),
    [anon_sym_AMPpriority] = ACTIONS(1849),
    [anon_sym_AMPread_expire] = ACTIONS(1849),
    [anon_sym_AMPtype_column] = ACTIONS(1849),
    [anon_sym_AMPwrite_expire] = ACTIONS(1849),
    [anon_sym_DOLLAR] = ACTIONS(1849),
    [anon_sym_PIPE] = ACTIONS(1853),
    [anon_sym_BANG] = ACTIONS(1853),
    [anon_sym_DASH] = ACTIONS(1853),
    [anon_sym_PLUS] = ACTIONS(1853),
    [anon_sym_is] = ACTIONS(1849),
    [anon_sym_STAR] = ACTIONS(1849),
    [anon_sym_SLASH] = ACTIONS(1849),
    [anon_sym_PERCENT] = ACTIONS(1849),
    [anon_sym_LT] = ACTIONS(1853),
    [anon_sym_LT_EQ] = ACTIONS(1849),
    [anon_sym_GT] = ACTIONS(1853),
    [anon_sym_GT_EQ] = ACTIONS(1849),
    [anon_sym_AMP] = ACTIONS(1853),
    [anon_sym_CARET] = ACTIONS(1849),
    [anon_sym_QMARK] = ACTIONS(1853),
    [anon_sym_EQ_EQ] = ACTIONS(1849),
    [anon_sym_BANG_EQ] = ACTIONS(1849),
    [anon_sym_AMP_AMP] = ACTIONS(1849),
    [anon_sym_PIPE_PIPE] = ACTIONS(1849),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1849),
    [anon_sym_ATdeprecated] = ACTIONS(1849),
    [anon_sym_ATload] = ACTIONS(1853),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1849),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1849),
    [anon_sym_ATunload] = ACTIONS(1849),
    [anon_sym_ATprefixes] = ACTIONS(1849),
    [anon_sym_ATif] = ACTIONS(1853),
    [anon_sym_ATifdef] = ACTIONS(1849),
    [anon_sym_ATifndef] = ACTIONS(1849),
    [anon_sym_ATendif] = ACTIONS(1849),
    [anon_sym_ATelse] = ACTIONS(1849),
    [anon_sym_ATpragma] = ACTIONS(1849),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(811)] = {
    [anon_sym_SEMI] = ACTIONS(139),
    [anon_sym_LBRACE] = ACTIONS(139),
    [anon_sym_RBRACE] = ACTIONS(139),
    [anon_sym_COLON] = ACTIONS(139),
    [anon_sym_PLUS_EQ] = ACTIONS(139),
    [anon_sym_DASH_EQ] = ACTIONS(139),
    [anon_sym_LPAREN] = ACTIONS(139),
    [anon_sym_RPAREN] = ACTIONS(139),
    [anon_sym_COMMA] = ACTIONS(139),
    [anon_sym_in] = ACTIONS(139),
    [anon_sym_LBRACK] = ACTIONS(139),
    [anon_sym_RBRACK] = ACTIONS(139),
    [anon_sym_EQ] = ACTIONS(141),
    [anon_sym_as] = ACTIONS(139),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(139),
    [anon_sym_AMPdeprecated] = ACTIONS(139),
    [anon_sym_AMPerror_handler] = ACTIONS(139),
    [anon_sym_AMPis_assigned] = ACTIONS(139),
    [anon_sym_AMPis_used] = ACTIONS(139),
    [anon_sym_AMPlog] = ACTIONS(139),
    [anon_sym_AMPoptional] = ACTIONS(139),
    [anon_sym_AMPordered] = ACTIONS(139),
    [anon_sym_AMPraw_output] = ACTIONS(139),
    [anon_sym_AMPredef] = ACTIONS(139),
    [anon_sym_AMPadd_func] = ACTIONS(139),
    [anon_sym_AMPbackend] = ACTIONS(139),
    [anon_sym_AMPbroker_store] = ACTIONS(139),
    [anon_sym_AMPcreate_expire] = ACTIONS(139),
    [anon_sym_AMPdefault] = ACTIONS(139),
    [anon_sym_AMPdelete_func] = ACTIONS(139),
    [anon_sym_AMPexpire_func] = ACTIONS(139),
    [anon_sym_AMPgroup] = ACTIONS(139),
    [anon_sym_AMPon_change] = ACTIONS(139),
    [anon_sym_AMPpriority] = ACTIONS(139),
    [anon_sym_AMPread_expire] = ACTIONS(139),
    [anon_sym_AMPtype_column] = ACTIONS(139),
    [anon_sym_AMPwrite_expire] = ACTIONS(139),
    [anon_sym_DOLLAR] = ACTIONS(139),
    [anon_sym_PIPE] = ACTIONS(141),
    [anon_sym_BANG] = ACTIONS(141),
    [anon_sym_DASH] = ACTIONS(141),
    [anon_sym_PLUS] = ACTIONS(141),
    [anon_sym_is] = ACTIONS(139),
    [anon_sym_STAR] = ACTIONS(139),
    [anon_sym_SLASH] = ACTIONS(139),
    [anon_sym_PERCENT] = ACTIONS(139),
    [anon_sym_LT] = ACTIONS(141),
    [anon_sym_LT_EQ] = ACTIONS(139),
    [anon_sym_GT] = ACTIONS(141),
    [anon_sym_GT_EQ] = ACTIONS(139),
    [anon_sym_AMP] = ACTIONS(141),
    [anon_sym_CARET] = ACTIONS(139),
    [anon_sym_QMARK] = ACTIONS(141),
    [anon_sym_EQ_EQ] = ACTIONS(139),
    [anon_sym_BANG_EQ] = ACTIONS(139),
    [anon_sym_AMP_AMP] = ACTIONS(139),
    [anon_sym_PIPE_PIPE] = ACTIONS(139),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(139),
    [anon_sym_ATdeprecated] = ACTIONS(139),
    [anon_sym_ATload] = ACTIONS(141),
    [anon_sym_ATload_DASHsigs] = ACTIONS(139),
    [anon_sym_ATload_DASHplugin] = ACTIONS(139),
    [anon_sym_ATunload] = ACTIONS(139),
    [anon_sym_ATprefixes] = ACTIONS(139),
    [anon_sym_ATif] = ACTIONS(141),
    [anon_sym_ATifdef] = ACTIONS(139),
    [anon_sym_ATifndef] = ACTIONS(139),
    [anon_sym_ATendif] = ACTIONS(139),
    [anon_sym_ATelse] = ACTIONS(139),
    [anon_sym_ATpragma] = ACTIONS(139),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(812)] = {
    [anon_sym_SEMI] = ACTIONS(143),
    [anon_sym_LBRACE] = ACTIONS(143),
    [anon_sym_RBRACE] = ACTIONS(143),
    [anon_sym_COLON] = ACTIONS(143),
    [anon_sym_PLUS_EQ] = ACTIONS(143),
    [anon_sym_DASH_EQ] = ACTIONS(143),
    [anon_sym_LPAREN] = ACTIONS(143),
    [anon_sym_RPAREN] = ACTIONS(143),
    [anon_sym_COMMA] = ACTIONS(143),
    [anon_sym_in] = ACTIONS(143),
    [anon_sym_LBRACK] = ACTIONS(143),
    [anon_sym_RBRACK] = ACTIONS(143),
    [anon_sym_EQ] = ACTIONS(145),
    [anon_sym_as] = ACTIONS(143),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(143),
    [anon_sym_AMPdeprecated] = ACTIONS(143),
    [anon_sym_AMPerror_handler] = ACTIONS(143),
    [anon_sym_AMPis_assigned] = ACTIONS(143),
    [anon_sym_AMPis_used] = ACTIONS(143),
    [anon_sym_AMPlog] = ACTIONS(143),
    [anon_sym_AMPoptional] = ACTIONS(143),
    [anon_sym_AMPordered] = ACTIONS(143),
    [anon_sym_AMPraw_output] = ACTIONS(143),
    [anon_sym_AMPredef] = ACTIONS(143),
    [anon_sym_AMPadd_func] = ACTIONS(143),
    [anon_sym_AMPbackend] = ACTIONS(143),
    [anon_sym_AMPbroker_store] = ACTIONS(143),
    [anon_sym_AMPcreate_expire] = ACTIONS(143),
    [anon_sym_AMPdefault] = ACTIONS(143),
    [anon_sym_AMPdelete_func] = ACTIONS(143),
    [anon_sym_AMPexpire_func] = ACTIONS(143),
    [anon_sym_AMPgroup] = ACTIONS(143),
    [anon_sym_AMPon_change] = ACTIONS(143),
    [anon_sym_AMPpriority] = ACTIONS(143),
    [anon_sym_AMPread_expire] = ACTIONS(143),
    [anon_sym_AMPtype_column] = ACTIONS(143),
    [anon_sym_AMPwrite_expire] = ACTIONS(143),
    [anon_sym_DOLLAR] = ACTIONS(143),
    [anon_sym_PIPE] = ACTIONS(145),
    [anon_sym_BANG] = ACTIONS(145),
    [anon_sym_DASH] = ACTIONS(145),
    [anon_sym_PLUS] = ACTIONS(145),
    [anon_sym_is] = ACTIONS(143),
    [anon_sym_STAR] = ACTIONS(143),
    [anon_sym_SLASH] = ACTIONS(143),
    [anon_sym_PERCENT] = ACTIONS(143),
    [anon_sym_LT] = ACTIONS(145),
    [anon_sym_LT_EQ] = ACTIONS(143),
    [anon_sym_GT] = ACTIONS(145),
    [anon_sym_GT_EQ] = ACTIONS(143),
    [anon_sym_AMP] = ACTIONS(145),
    [anon_sym_CARET] = ACTIONS(143),
    [anon_sym_QMARK] = ACTIONS(145),
    [anon_sym_EQ_EQ] = ACTIONS(143),
    [anon_sym_BANG_EQ] = ACTIONS(143),
    [anon_sym_AMP_AMP] = ACTIONS(143),
    [anon_sym_PIPE_PIPE] = ACTIONS(143),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(143),
    [anon_sym_ATdeprecated] = ACTIONS(143),
    [anon_sym_ATload] = ACTIONS(145),
    [anon_sym_ATload_DASHsigs] = ACTIONS(143),
    [anon_sym_ATload_DASHplugin] = ACTIONS(143),
    [anon_sym_ATunload] = ACTIONS(143),
    [anon_sym_ATprefixes] = ACTIONS(143),
    [anon_sym_ATif] = ACTIONS(145),
    [anon_sym_ATifdef] = ACTIONS(143),
    [anon_sym_ATifndef] = ACTIONS(143),
    [anon_sym_ATendif] = ACTIONS(143),
    [anon_sym_ATelse] = ACTIONS(143),
    [anon_sym_ATpragma] = ACTIONS(143),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(813)] = {
    [anon_sym_SEMI] = ACTIONS(348),
    [anon_sym_LBRACE] = ACTIONS(348),
    [anon_sym_RBRACE] = ACTIONS(348),
    [anon_sym_COLON] = ACTIONS(348),
    [anon_sym_PLUS_EQ] = ACTIONS(348),
    [anon_sym_DASH_EQ] = ACTIONS(348),
    [anon_sym_LPAREN] = ACTIONS(348),
    [anon_sym_RPAREN] = ACTIONS(348),
    [anon_sym_COMMA] = ACTIONS(348),
    [anon_sym_in] = ACTIONS(348),
    [anon_sym_LBRACK] = ACTIONS(348),
    [anon_sym_RBRACK] = ACTIONS(348),
    [anon_sym_EQ] = ACTIONS(350),
    [anon_sym_as] = ACTIONS(348),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(348),
    [anon_sym_AMPdeprecated] = ACTIONS(348),
    [anon_sym_AMPerror_handler] = ACTIONS(348),
    [anon_sym_AMPis_assigned] = ACTIONS(348),
    [anon_sym_AMPis_used] = ACTIONS(348),
    [anon_sym_AMPlog] = ACTIONS(348),
    [anon_sym_AMPoptional] = ACTIONS(348),
    [anon_sym_AMPordered] = ACTIONS(348),
    [anon_sym_AMPraw_output] = ACTIONS(348),
    [anon_sym_AMPredef] = ACTIONS(348),
    [anon_sym_AMPadd_func] = ACTIONS(348),
    [anon_sym_AMPbackend] = ACTIONS(348),
    [anon_sym_AMPbroker_store] = ACTIONS(348),
    [anon_sym_AMPcreate_expire] = ACTIONS(348),
    [anon_sym_AMPdefault] = ACTIONS(348),
    [anon_sym_AMPdelete_func] = ACTIONS(348),
    [anon_sym_AMPexpire_func] = ACTIONS(348),
    [anon_sym_AMPgroup] = ACTIONS(348),
    [anon_sym_AMPon_change] = ACTIONS(348),
    [anon_sym_AMPpriority] = ACTIONS(348),
    [anon_sym_AMPread_expire] = ACTIONS(348),
    [anon_sym_AMPtype_column] = ACTIONS(348),
    [anon_sym_AMPwrite_expire] = ACTIONS(348),
    [anon_sym_DOLLAR] = ACTIONS(348),
    [anon_sym_PIPE] = ACTIONS(350),
    [anon_sym_BANG] = ACTIONS(350),
    [anon_sym_DASH] = ACTIONS(350),
    [anon_sym_PLUS] = ACTIONS(350),
    [anon_sym_is] = ACTIONS(348),
    [anon_sym_STAR] = ACTIONS(348),
    [anon_sym_SLASH] = ACTIONS(348),
    [anon_sym_PERCENT] = ACTIONS(348),
    [anon_sym_LT] = ACTIONS(350),
    [anon_sym_LT_EQ] = ACTIONS(348),
    [anon_sym_GT] = ACTIONS(350),
    [anon_sym_GT_EQ] = ACTIONS(348),
    [anon_sym_AMP] = ACTIONS(350),
    [anon_sym_CARET] = ACTIONS(348),
    [anon_sym_QMARK] = ACTIONS(350),
    [anon_sym_EQ_EQ] = ACTIONS(348),
    [anon_sym_BANG_EQ] = ACTIONS(348),
    [anon_sym_AMP_AMP] = ACTIONS(348),
    [anon_sym_PIPE_PIPE] = ACTIONS(348),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(348),
    [anon_sym_ATdeprecated] = ACTIONS(348),
    [anon_sym_ATload] = ACTIONS(350),
    [anon_sym_ATload_DASHsigs] = ACTIONS(348),
    [anon_sym_ATload_DASHplugin] = ACTIONS(348),
    [anon_sym_ATunload] = ACTIONS(348),
    [anon_sym_ATprefixes] = ACTIONS(348),
    [anon_sym_ATif] = ACTIONS(350),
    [anon_sym_ATifdef] = ACTIONS(348),
    [anon_sym_ATifndef] = ACTIONS(348),
    [anon_sym_ATendif] = ACTIONS(348),
    [anon_sym_ATelse] = ACTIONS(348),
    [anon_sym_ATpragma] = ACTIONS(348),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(814)] = {
    [sym_attr_list] = STATE(786),
    [sym_attr] = STATE(818),
    [aux_sym_attr_list_repeat1] = STATE(818),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_PLUS_EQ] = ACTIONS(1935),
    [anon_sym_DASH_EQ] = ACTIONS(1935),
    [anon_sym_LPAREN] = ACTIONS(1935),
    [anon_sym_in] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(1935),
    [anon_sym_EQ] = ACTIONS(1937),
    [anon_sym_as] = ACTIONS(1935),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1935),
    [anon_sym_AMPdeprecated] = ACTIONS(1935),
    [anon_sym_AMPerror_handler] = ACTIONS(1935),
    [anon_sym_AMPis_assigned] = ACTIONS(1935),
    [anon_sym_AMPis_used] = ACTIONS(1935),
    [anon_sym_AMPlog] = ACTIONS(1935),
    [anon_sym_AMPoptional] = ACTIONS(1935),
    [anon_sym_AMPordered] = ACTIONS(1935),
    [anon_sym_AMPraw_output] = ACTIONS(1935),
    [anon_sym_AMPredef] = ACTIONS(1935),
    [anon_sym_AMPadd_func] = ACTIONS(1935),
    [anon_sym_AMPbackend] = ACTIONS(1935),
    [anon_sym_AMPbroker_store] = ACTIONS(1935),
    [anon_sym_AMPcreate_expire] = ACTIONS(1935),
    [anon_sym_AMPdefault] = ACTIONS(1935),
    [anon_sym_AMPdelete_func] = ACTIONS(1935),
    [anon_sym_AMPexpire_func] = ACTIONS(1935),
    [anon_sym_AMPgroup] = ACTIONS(1935),
    [anon_sym_AMPon_change] = ACTIONS(1935),
    [anon_sym_AMPpriority] = ACTIONS(1935),
    [anon_sym_AMPread_expire] = ACTIONS(1935),
    [anon_sym_AMPtype_column] = ACTIONS(1935),
    [anon_sym_AMPwrite_expire] = ACTIONS(1935),
    [anon_sym_DOLLAR] = ACTIONS(1935),
    [anon_sym_PIPE] = ACTIONS(1937),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_DASH] = ACTIONS(1937),
    [anon_sym_PLUS] = ACTIONS(1937),
    [anon_sym_is] = ACTIONS(1935),
    [anon_sym_STAR] = ACTIONS(1935),
    [anon_sym_SLASH] = ACTIONS(1935),
    [anon_sym_PERCENT] = ACTIONS(1935),
    [anon_sym_LT] = ACTIONS(1937),
    [anon_sym_LT_EQ] = ACTIONS(1935),
    [anon_sym_GT] = ACTIONS(1937),
    [anon_sym_GT_EQ] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_CARET] = ACTIONS(1935),
    [anon_sym_QMARK] = ACTIONS(1937),
    [anon_sym_EQ_EQ] = ACTIONS(1935),
    [anon_sym_BANG_EQ] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_PIPE_PIPE] = ACTIONS(1935),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1935),
    [anon_sym_ATdeprecated] = ACTIONS(1935),
    [anon_sym_ATload] = ACTIONS(1937),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1935),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1935),
    [anon_sym_ATunload] = ACTIONS(1935),
    [anon_sym_ATprefixes] = ACTIONS(1935),
    [anon_sym_ATif] = ACTIONS(1937),
    [anon_sym_ATifdef] = ACTIONS(1935),
    [anon_sym_ATifndef] = ACTIONS(1935),
    [anon_sym_ATendif] = ACTIONS(1935),
    [anon_sym_ATelse] = ACTIONS(1935),
    [anon_sym_ATpragma] = ACTIONS(1935),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(815)] = {
    [sym_attr_list] = STATE(805),
    [sym_attr] = STATE(818),
    [aux_sym_attr_list_repeat1] = STATE(818),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(127),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(127),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(816)] = {
    [anon_sym_SEMI] = ACTIONS(127),
    [anon_sym_LBRACE] = ACTIONS(1849),
    [anon_sym_COLON] = ACTIONS(1941),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(127),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(127),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1849),
    [anon_sym_AMPdeprecated] = ACTIONS(1849),
    [anon_sym_AMPerror_handler] = ACTIONS(1849),
    [anon_sym_AMPis_assigned] = ACTIONS(1849),
    [anon_sym_AMPis_used] = ACTIONS(1849),
    [anon_sym_AMPlog] = ACTIONS(1849),
    [anon_sym_AMPoptional] = ACTIONS(1849),
    [anon_sym_AMPordered] = ACTIONS(1849),
    [anon_sym_AMPraw_output] = ACTIONS(1849),
    [anon_sym_AMPredef] = ACTIONS(1849),
    [anon_sym_AMPadd_func] = ACTIONS(1849),
    [anon_sym_AMPbackend] = ACTIONS(1849),
    [anon_sym_AMPbroker_store] = ACTIONS(1849),
    [anon_sym_AMPcreate_expire] = ACTIONS(1849),
    [anon_sym_AMPdefault] = ACTIONS(1849),
    [anon_sym_AMPdelete_func] = ACTIONS(1849),
    [anon_sym_AMPexpire_func] = ACTIONS(1849),
    [anon_sym_AMPgroup] = ACTIONS(1849),
    [anon_sym_AMPon_change] = ACTIONS(1849),
    [anon_sym_AMPpriority] = ACTIONS(1849),
    [anon_sym_AMPread_expire] = ACTIONS(1849),
    [anon_sym_AMPtype_column] = ACTIONS(1849),
    [anon_sym_AMPwrite_expire] = ACTIONS(1849),
    [anon_sym_DOLLAR] = ACTIONS(127),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(127),
    [anon_sym_STAR] = ACTIONS(127),
    [anon_sym_SLASH] = ACTIONS(127),
    [anon_sym_PERCENT] = ACTIONS(127),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(1849),
    [anon_sym_ATload] = ACTIONS(1853),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1849),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1849),
    [anon_sym_ATunload] = ACTIONS(1849),
    [anon_sym_ATprefixes] = ACTIONS(1849),
    [anon_sym_ATif] = ACTIONS(1853),
    [anon_sym_ATifdef] = ACTIONS(1849),
    [anon_sym_ATifndef] = ACTIONS(1849),
    [anon_sym_ATendif] = ACTIONS(1849),
    [anon_sym_ATelse] = ACTIONS(1849),
    [anon_sym_ATpragma] = ACTIONS(1849),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(817)] = {
    [sym_attr] = STATE(817),
    [aux_sym_attr_list_repeat1] = STATE(817),
    [anon_sym_LBRACE] = ACTIONS(1943),
    [anon_sym_PLUS_EQ] = ACTIONS(1943),
    [anon_sym_DASH_EQ] = ACTIONS(1943),
    [anon_sym_LPAREN] = ACTIONS(1943),
    [anon_sym_in] = ACTIONS(1943),
    [anon_sym_LBRACK] = ACTIONS(1943),
    [anon_sym_EQ] = ACTIONS(1945),
    [anon_sym_as] = ACTIONS(1943),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1947),
    [anon_sym_AMPdeprecated] = ACTIONS(1950),
    [anon_sym_AMPerror_handler] = ACTIONS(1947),
    [anon_sym_AMPis_assigned] = ACTIONS(1947),
    [anon_sym_AMPis_used] = ACTIONS(1947),
    [anon_sym_AMPlog] = ACTIONS(1947),
    [anon_sym_AMPoptional] = ACTIONS(1947),
    [anon_sym_AMPordered] = ACTIONS(1947),
    [anon_sym_AMPraw_output] = ACTIONS(1947),
    [anon_sym_AMPredef] = ACTIONS(1947),
    [anon_sym_AMPadd_func] = ACTIONS(1953),
    [anon_sym_AMPbackend] = ACTIONS(1953),
    [anon_sym_AMPbroker_store] = ACTIONS(1953),
    [anon_sym_AMPcreate_expire] = ACTIONS(1953),
    [anon_sym_AMPdefault] = ACTIONS(1953),
    [anon_sym_AMPdelete_func] = ACTIONS(1953),
    [anon_sym_AMPexpire_func] = ACTIONS(1953),
    [anon_sym_AMPgroup] = ACTIONS(1953),
    [anon_sym_AMPon_change] = ACTIONS(1953),
    [anon_sym_AMPpriority] = ACTIONS(1953),
    [anon_sym_AMPread_expire] = ACTIONS(1953),
    [anon_sym_AMPtype_column] = ACTIONS(1953),
    [anon_sym_AMPwrite_expire] = ACTIONS(1953),
    [anon_sym_DOLLAR] = ACTIONS(1943),
    [anon_sym_PIPE] = ACTIONS(1945),
    [anon_sym_BANG] = ACTIONS(1945),
    [anon_sym_DASH] = ACTIONS(1945),
    [anon_sym_PLUS] = ACTIONS(1945),
    [anon_sym_is] = ACTIONS(1943),
    [anon_sym_STAR] = ACTIONS(1943),
    [anon_sym_SLASH] = ACTIONS(1943),
    [anon_sym_PERCENT] = ACTIONS(1943),
    [anon_sym_LT] = ACTIONS(1945),
    [anon_sym_LT_EQ] = ACTIONS(1943),
    [anon_sym_GT] = ACTIONS(1945),
    [anon_sym_GT_EQ] = ACTIONS(1943),
    [anon_sym_AMP] = ACTIONS(1945),
    [anon_sym_CARET] = ACTIONS(1943),
    [anon_sym_QMARK] = ACTIONS(1945),
    [anon_sym_EQ_EQ] = ACTIONS(1943),
    [anon_sym_BANG_EQ] = ACTIONS(1943),
    [anon_sym_AMP_AMP] = ACTIONS(1943),
    [anon_sym_PIPE_PIPE] = ACTIONS(1943),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1943),
    [anon_sym_ATdeprecated] = ACTIONS(1943),
    [anon_sym_ATload] = ACTIONS(1945),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1943),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1943),
    [anon_sym_ATunload] = ACTIONS(1943),
    [anon_sym_ATprefixes] = ACTIONS(1943),
    [anon_sym_ATif] = ACTIONS(1945),
    [anon_sym_ATifdef] = ACTIONS(1943),
    [anon_sym_ATifndef] = ACTIONS(1943),
    [anon_sym_ATendif] = ACTIONS(1943),
    [anon_sym_ATelse] = ACTIONS(1943),
    [anon_sym_ATpragma] = ACTIONS(1943),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(818)] = {
    [sym_attr] = STATE(817),
    [aux_sym_attr_list_repeat1] = STATE(817),
    [anon_sym_LBRACE] = ACTIONS(1956),
    [anon_sym_PLUS_EQ] = ACTIONS(1956),
    [anon_sym_DASH_EQ] = ACTIONS(1956),
    [anon_sym_LPAREN] = ACTIONS(1956),
    [anon_sym_in] = ACTIONS(1956),
    [anon_sym_LBRACK] = ACTIONS(1956),
    [anon_sym_EQ] = ACTIONS(1958),
    [anon_sym_as] = ACTIONS(1956),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1956),
    [anon_sym_AMPdeprecated] = ACTIONS(1956),
    [anon_sym_AMPerror_handler] = ACTIONS(1956),
    [anon_sym_AMPis_assigned] = ACTIONS(1956),
    [anon_sym_AMPis_used] = ACTIONS(1956),
    [anon_sym_AMPlog] = ACTIONS(1956),
    [anon_sym_AMPoptional] = ACTIONS(1956),
    [anon_sym_AMPordered] = ACTIONS(1956),
    [anon_sym_AMPraw_output] = ACTIONS(1956),
    [anon_sym_AMPredef] = ACTIONS(1956),
    [anon_sym_AMPadd_func] = ACTIONS(1956),
    [anon_sym_AMPbackend] = ACTIONS(1956),
    [anon_sym_AMPbroker_store] = ACTIONS(1956),
    [anon_sym_AMPcreate_expire] = ACTIONS(1956),
    [anon_sym_AMPdefault] = ACTIONS(1956),
    [anon_sym_AMPdelete_func] = ACTIONS(1956),
    [anon_sym_AMPexpire_func] = ACTIONS(1956),
    [anon_sym_AMPgroup] = ACTIONS(1956),
    [anon_sym_AMPon_change] = ACTIONS(1956),
    [anon_sym_AMPpriority] = ACTIONS(1956),
    [anon_sym_AMPread_expire] = ACTIONS(1956),
    [anon_sym_AMPtype_column] = ACTIONS(1956),
    [anon_sym_AMPwrite_expire] = ACTIONS(1956),
    [anon_sym_DOLLAR] = ACTIONS(1956),
    [anon_sym_PIPE] = ACTIONS(1958),
    [anon_sym_BANG] = ACTIONS(1958),
    [anon_sym_DASH] = ACTIONS(1958),
    [anon_sym_PLUS] = ACTIONS(1958),
    [anon_sym_is] = ACTIONS(1956),
    [anon_sym_STAR] = ACTIONS(1956),
    [anon_sym_SLASH] = ACTIONS(1956),
    [anon_sym_PERCENT] = ACTIONS(1956),
    [anon_sym_LT] = ACTIONS(1958),
    [anon_sym_LT_EQ] = ACTIONS(1956),
    [anon_sym_GT] = ACTIONS(1958),
    [anon_sym_GT_EQ] = ACTIONS(1956),
    [anon_sym_AMP] = ACTIONS(1958),
    [anon_sym_CARET] = ACTIONS(1956),
    [anon_sym_QMARK] = ACTIONS(1958),
    [anon_sym_EQ_EQ] = ACTIONS(1956),
    [anon_sym_BANG_EQ] = ACTIONS(1956),
    [anon_sym_AMP_AMP] = ACTIONS(1956),
    [anon_sym_PIPE_PIPE] = ACTIONS(1956),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1956),
    [anon_sym_ATdeprecated] = ACTIONS(1956),
    [anon_sym_ATload] = ACTIONS(1958),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1956),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1956),
    [anon_sym_ATunload] = ACTIONS(1956),
    [anon_sym_ATprefixes] = ACTIONS(1956),
    [anon_sym_ATif] = ACTIONS(1958),
    [anon_sym_ATifdef] = ACTIONS(1956),
    [anon_sym_ATifndef] = ACTIONS(1956),
    [anon_sym_ATendif] = ACTIONS(1956),
    [anon_sym_ATelse] = ACTIONS(1956),
    [anon_sym_ATpragma] = ACTIONS(1956),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(819)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(1960),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(1962),
    [anon_sym_BANG] = ACTIONS(1964),
    [anon_sym_DASH] = ACTIONS(1962),
    [anon_sym_PLUS] = ACTIONS(1962),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(1962),
    [anon_sym_LT_EQ] = ACTIONS(1960),
    [anon_sym_GT] = ACTIONS(1962),
    [anon_sym_GT_EQ] = ACTIONS(1960),
    [anon_sym_AMP] = ACTIONS(1962),
    [anon_sym_CARET] = ACTIONS(1960),
    [anon_sym_QMARK] = ACTIONS(1968),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(820)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(1960),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(1962),
    [anon_sym_BANG] = ACTIONS(1964),
    [anon_sym_DASH] = ACTIONS(1962),
    [anon_sym_PLUS] = ACTIONS(1962),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(1962),
    [anon_sym_LT_EQ] = ACTIONS(1960),
    [anon_sym_GT] = ACTIONS(1962),
    [anon_sym_GT_EQ] = ACTIONS(1960),
    [anon_sym_AMP] = ACTIONS(1962),
    [anon_sym_CARET] = ACTIONS(1960),
    [anon_sym_QMARK] = ACTIONS(1968),
    [anon_sym_EQ_EQ] = ACTIONS(1970),
    [anon_sym_BANG_EQ] = ACTIONS(1970),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(821)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_PLUS_EQ] = ACTIONS(1935),
    [anon_sym_DASH_EQ] = ACTIONS(1935),
    [anon_sym_LPAREN] = ACTIONS(1935),
    [anon_sym_in] = ACTIONS(1935),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(1937),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1935),
    [anon_sym_AMPdeprecated] = ACTIONS(1935),
    [anon_sym_AMPerror_handler] = ACTIONS(1935),
    [anon_sym_AMPis_assigned] = ACTIONS(1935),
    [anon_sym_AMPis_used] = ACTIONS(1935),
    [anon_sym_AMPlog] = ACTIONS(1935),
    [anon_sym_AMPoptional] = ACTIONS(1935),
    [anon_sym_AMPordered] = ACTIONS(1935),
    [anon_sym_AMPraw_output] = ACTIONS(1935),
    [anon_sym_AMPredef] = ACTIONS(1935),
    [anon_sym_AMPadd_func] = ACTIONS(1935),
    [anon_sym_AMPbackend] = ACTIONS(1935),
    [anon_sym_AMPbroker_store] = ACTIONS(1935),
    [anon_sym_AMPcreate_expire] = ACTIONS(1935),
    [anon_sym_AMPdefault] = ACTIONS(1935),
    [anon_sym_AMPdelete_func] = ACTIONS(1935),
    [anon_sym_AMPexpire_func] = ACTIONS(1935),
    [anon_sym_AMPgroup] = ACTIONS(1935),
    [anon_sym_AMPon_change] = ACTIONS(1935),
    [anon_sym_AMPpriority] = ACTIONS(1935),
    [anon_sym_AMPread_expire] = ACTIONS(1935),
    [anon_sym_AMPtype_column] = ACTIONS(1935),
    [anon_sym_AMPwrite_expire] = ACTIONS(1935),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(1937),
    [anon_sym_BANG] = ACTIONS(1937),
    [anon_sym_DASH] = ACTIONS(1937),
    [anon_sym_PLUS] = ACTIONS(1937),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(1937),
    [anon_sym_LT_EQ] = ACTIONS(1935),
    [anon_sym_GT] = ACTIONS(1937),
    [anon_sym_GT_EQ] = ACTIONS(1935),
    [anon_sym_AMP] = ACTIONS(1937),
    [anon_sym_CARET] = ACTIONS(1935),
    [anon_sym_QMARK] = ACTIONS(1937),
    [anon_sym_EQ_EQ] = ACTIONS(1935),
    [anon_sym_BANG_EQ] = ACTIONS(1935),
    [anon_sym_AMP_AMP] = ACTIONS(1935),
    [anon_sym_PIPE_PIPE] = ACTIONS(1935),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1935),
    [anon_sym_ATdeprecated] = ACTIONS(1935),
    [anon_sym_ATload] = ACTIONS(1937),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1935),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1935),
    [anon_sym_ATunload] = ACTIONS(1935),
    [anon_sym_ATprefixes] = ACTIONS(1935),
    [anon_sym_ATif] = ACTIONS(1937),
    [anon_sym_ATifdef] = ACTIONS(1935),
    [anon_sym_ATifndef] = ACTIONS(1935),
    [anon_sym_ATendif] = ACTIONS(1935),
    [anon_sym_ATelse] = ACTIONS(1935),
    [anon_sym_ATpragma] = ACTIONS(1935),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(822)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_PLUS_EQ] = ACTIONS(1972),
    [anon_sym_DASH_EQ] = ACTIONS(1972),
    [anon_sym_LPAREN] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1960),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(1974),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1935),
    [anon_sym_AMPdeprecated] = ACTIONS(1935),
    [anon_sym_AMPerror_handler] = ACTIONS(1935),
    [anon_sym_AMPis_assigned] = ACTIONS(1935),
    [anon_sym_AMPis_used] = ACTIONS(1935),
    [anon_sym_AMPlog] = ACTIONS(1935),
    [anon_sym_AMPoptional] = ACTIONS(1935),
    [anon_sym_AMPordered] = ACTIONS(1935),
    [anon_sym_AMPraw_output] = ACTIONS(1935),
    [anon_sym_AMPredef] = ACTIONS(1935),
    [anon_sym_AMPadd_func] = ACTIONS(1935),
    [anon_sym_AMPbackend] = ACTIONS(1935),
    [anon_sym_AMPbroker_store] = ACTIONS(1935),
    [anon_sym_AMPcreate_expire] = ACTIONS(1935),
    [anon_sym_AMPdefault] = ACTIONS(1935),
    [anon_sym_AMPdelete_func] = ACTIONS(1935),
    [anon_sym_AMPexpire_func] = ACTIONS(1935),
    [anon_sym_AMPgroup] = ACTIONS(1935),
    [anon_sym_AMPon_change] = ACTIONS(1935),
    [anon_sym_AMPpriority] = ACTIONS(1935),
    [anon_sym_AMPread_expire] = ACTIONS(1935),
    [anon_sym_AMPtype_column] = ACTIONS(1935),
    [anon_sym_AMPwrite_expire] = ACTIONS(1935),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(1962),
    [anon_sym_BANG] = ACTIONS(1964),
    [anon_sym_DASH] = ACTIONS(1962),
    [anon_sym_PLUS] = ACTIONS(1962),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(1962),
    [anon_sym_LT_EQ] = ACTIONS(1960),
    [anon_sym_GT] = ACTIONS(1962),
    [anon_sym_GT_EQ] = ACTIONS(1960),
    [anon_sym_AMP] = ACTIONS(1962),
    [anon_sym_CARET] = ACTIONS(1960),
    [anon_sym_QMARK] = ACTIONS(1968),
    [anon_sym_EQ_EQ] = ACTIONS(1970),
    [anon_sym_BANG_EQ] = ACTIONS(1970),
    [anon_sym_AMP_AMP] = ACTIONS(1976),
    [anon_sym_PIPE_PIPE] = ACTIONS(1976),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1978),
    [anon_sym_ATdeprecated] = ACTIONS(1935),
    [anon_sym_ATload] = ACTIONS(1937),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1935),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1935),
    [anon_sym_ATunload] = ACTIONS(1935),
    [anon_sym_ATprefixes] = ACTIONS(1935),
    [anon_sym_ATif] = ACTIONS(1937),
    [anon_sym_ATifdef] = ACTIONS(1935),
    [anon_sym_ATifndef] = ACTIONS(1935),
    [anon_sym_ATendif] = ACTIONS(1935),
    [anon_sym_ATelse] = ACTIONS(1935),
    [anon_sym_ATpragma] = ACTIONS(1935),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(823)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(1935),
    [anon_sym_PLUS_EQ] = ACTIONS(1972),
    [anon_sym_DASH_EQ] = ACTIONS(1972),
    [anon_sym_LPAREN] = ACTIONS(1935),
    [anon_sym_in] = ACTIONS(1960),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(1974),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1935),
    [anon_sym_AMPdeprecated] = ACTIONS(1935),
    [anon_sym_AMPerror_handler] = ACTIONS(1935),
    [anon_sym_AMPis_assigned] = ACTIONS(1935),
    [anon_sym_AMPis_used] = ACTIONS(1935),
    [anon_sym_AMPlog] = ACTIONS(1935),
    [anon_sym_AMPoptional] = ACTIONS(1935),
    [anon_sym_AMPordered] = ACTIONS(1935),
    [anon_sym_AMPraw_output] = ACTIONS(1935),
    [anon_sym_AMPredef] = ACTIONS(1935),
    [anon_sym_AMPadd_func] = ACTIONS(1935),
    [anon_sym_AMPbackend] = ACTIONS(1935),
    [anon_sym_AMPbroker_store] = ACTIONS(1935),
    [anon_sym_AMPcreate_expire] = ACTIONS(1935),
    [anon_sym_AMPdefault] = ACTIONS(1935),
    [anon_sym_AMPdelete_func] = ACTIONS(1935),
    [anon_sym_AMPexpire_func] = ACTIONS(1935),
    [anon_sym_AMPgroup] = ACTIONS(1935),
    [anon_sym_AMPon_change] = ACTIONS(1935),
    [anon_sym_AMPpriority] = ACTIONS(1935),
    [anon_sym_AMPread_expire] = ACTIONS(1935),
    [anon_sym_AMPtype_column] = ACTIONS(1935),
    [anon_sym_AMPwrite_expire] = ACTIONS(1935),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(1962),
    [anon_sym_BANG] = ACTIONS(1964),
    [anon_sym_DASH] = ACTIONS(1962),
    [anon_sym_PLUS] = ACTIONS(1962),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(1962),
    [anon_sym_LT_EQ] = ACTIONS(1960),
    [anon_sym_GT] = ACTIONS(1962),
    [anon_sym_GT_EQ] = ACTIONS(1960),
    [anon_sym_AMP] = ACTIONS(1962),
    [anon_sym_CARET] = ACTIONS(1960),
    [anon_sym_QMARK] = ACTIONS(1968),
    [anon_sym_EQ_EQ] = ACTIONS(1970),
    [anon_sym_BANG_EQ] = ACTIONS(1970),
    [anon_sym_AMP_AMP] = ACTIONS(1976),
    [anon_sym_PIPE_PIPE] = ACTIONS(1976),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1935),
    [anon_sym_ATdeprecated] = ACTIONS(1935),
    [anon_sym_ATload] = ACTIONS(1937),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1935),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1935),
    [anon_sym_ATunload] = ACTIONS(1935),
    [anon_sym_ATprefixes] = ACTIONS(1935),
    [anon_sym_ATif] = ACTIONS(1937),
    [anon_sym_ATifdef] = ACTIONS(1935),
    [anon_sym_ATifndef] = ACTIONS(1935),
    [anon_sym_ATendif] = ACTIONS(1935),
    [anon_sym_ATelse] = ACTIONS(1935),
    [anon_sym_ATpragma] = ACTIONS(1935),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(824)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(1915),
    [anon_sym_PLUS_EQ] = ACTIONS(1915),
    [anon_sym_DASH_EQ] = ACTIONS(1915),
    [anon_sym_LPAREN] = ACTIONS(1915),
    [anon_sym_in] = ACTIONS(1960),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(1917),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1915),
    [anon_sym_AMPdeprecated] = ACTIONS(1915),
    [anon_sym_AMPerror_handler] = ACTIONS(1915),
    [anon_sym_AMPis_assigned] = ACTIONS(1915),
    [anon_sym_AMPis_used] = ACTIONS(1915),
    [anon_sym_AMPlog] = ACTIONS(1915),
    [anon_sym_AMPoptional] = ACTIONS(1915),
    [anon_sym_AMPordered] = ACTIONS(1915),
    [anon_sym_AMPraw_output] = ACTIONS(1915),
    [anon_sym_AMPredef] = ACTIONS(1915),
    [anon_sym_AMPadd_func] = ACTIONS(1915),
    [anon_sym_AMPbackend] = ACTIONS(1915),
    [anon_sym_AMPbroker_store] = ACTIONS(1915),
    [anon_sym_AMPcreate_expire] = ACTIONS(1915),
    [anon_sym_AMPdefault] = ACTIONS(1915),
    [anon_sym_AMPdelete_func] = ACTIONS(1915),
    [anon_sym_AMPexpire_func] = ACTIONS(1915),
    [anon_sym_AMPgroup] = ACTIONS(1915),
    [anon_sym_AMPon_change] = ACTIONS(1915),
    [anon_sym_AMPpriority] = ACTIONS(1915),
    [anon_sym_AMPread_expire] = ACTIONS(1915),
    [anon_sym_AMPtype_column] = ACTIONS(1915),
    [anon_sym_AMPwrite_expire] = ACTIONS(1915),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(1962),
    [anon_sym_BANG] = ACTIONS(1964),
    [anon_sym_DASH] = ACTIONS(1962),
    [anon_sym_PLUS] = ACTIONS(1962),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(1962),
    [anon_sym_LT_EQ] = ACTIONS(1960),
    [anon_sym_GT] = ACTIONS(1962),
    [anon_sym_GT_EQ] = ACTIONS(1960),
    [anon_sym_AMP] = ACTIONS(1962),
    [anon_sym_CARET] = ACTIONS(1960),
    [anon_sym_QMARK] = ACTIONS(1968),
    [anon_sym_EQ_EQ] = ACTIONS(1915),
    [anon_sym_BANG_EQ] = ACTIONS(1915),
    [anon_sym_AMP_AMP] = ACTIONS(1915),
    [anon_sym_PIPE_PIPE] = ACTIONS(1915),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1915),
    [anon_sym_ATdeprecated] = ACTIONS(1915),
    [anon_sym_ATload] = ACTIONS(1917),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1915),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1915),
    [anon_sym_ATunload] = ACTIONS(1915),
    [anon_sym_ATprefixes] = ACTIONS(1915),
    [anon_sym_ATif] = ACTIONS(1917),
    [anon_sym_ATifdef] = ACTIONS(1915),
    [anon_sym_ATifndef] = ACTIONS(1915),
    [anon_sym_ATendif] = ACTIONS(1915),
    [anon_sym_ATelse] = ACTIONS(1915),
    [anon_sym_ATpragma] = ACTIONS(1915),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(825)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(1923),
    [anon_sym_PLUS_EQ] = ACTIONS(1972),
    [anon_sym_DASH_EQ] = ACTIONS(1972),
    [anon_sym_LPAREN] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1960),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(1974),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1923),
    [anon_sym_AMPdeprecated] = ACTIONS(1923),
    [anon_sym_AMPerror_handler] = ACTIONS(1923),
    [anon_sym_AMPis_assigned] = ACTIONS(1923),
    [anon_sym_AMPis_used] = ACTIONS(1923),
    [anon_sym_AMPlog] = ACTIONS(1923),
    [anon_sym_AMPoptional] = ACTIONS(1923),
    [anon_sym_AMPordered] = ACTIONS(1923),
    [anon_sym_AMPraw_output] = ACTIONS(1923),
    [anon_sym_AMPredef] = ACTIONS(1923),
    [anon_sym_AMPadd_func] = ACTIONS(1923),
    [anon_sym_AMPbackend] = ACTIONS(1923),
    [anon_sym_AMPbroker_store] = ACTIONS(1923),
    [anon_sym_AMPcreate_expire] = ACTIONS(1923),
    [anon_sym_AMPdefault] = ACTIONS(1923),
    [anon_sym_AMPdelete_func] = ACTIONS(1923),
    [anon_sym_AMPexpire_func] = ACTIONS(1923),
    [anon_sym_AMPgroup] = ACTIONS(1923),
    [anon_sym_AMPon_change] = ACTIONS(1923),
    [anon_sym_AMPpriority] = ACTIONS(1923),
    [anon_sym_AMPread_expire] = ACTIONS(1923),
    [anon_sym_AMPtype_column] = ACTIONS(1923),
    [anon_sym_AMPwrite_expire] = ACTIONS(1923),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(1962),
    [anon_sym_BANG] = ACTIONS(1964),
    [anon_sym_DASH] = ACTIONS(1962),
    [anon_sym_PLUS] = ACTIONS(1962),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(1962),
    [anon_sym_LT_EQ] = ACTIONS(1960),
    [anon_sym_GT] = ACTIONS(1962),
    [anon_sym_GT_EQ] = ACTIONS(1960),
    [anon_sym_AMP] = ACTIONS(1962),
    [anon_sym_CARET] = ACTIONS(1960),
    [anon_sym_QMARK] = ACTIONS(1968),
    [anon_sym_EQ_EQ] = ACTIONS(1970),
    [anon_sym_BANG_EQ] = ACTIONS(1970),
    [anon_sym_AMP_AMP] = ACTIONS(1976),
    [anon_sym_PIPE_PIPE] = ACTIONS(1976),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1923),
    [anon_sym_ATdeprecated] = ACTIONS(1923),
    [anon_sym_ATload] = ACTIONS(1925),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1923),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1923),
    [anon_sym_ATunload] = ACTIONS(1923),
    [anon_sym_ATprefixes] = ACTIONS(1923),
    [anon_sym_ATif] = ACTIONS(1925),
    [anon_sym_ATifdef] = ACTIONS(1923),
    [anon_sym_ATifndef] = ACTIONS(1923),
    [anon_sym_ATendif] = ACTIONS(1923),
    [anon_sym_ATelse] = ACTIONS(1923),
    [anon_sym_ATpragma] = ACTIONS(1923),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(826)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(1923),
    [anon_sym_PLUS_EQ] = ACTIONS(1972),
    [anon_sym_DASH_EQ] = ACTIONS(1972),
    [anon_sym_LPAREN] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1960),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(1974),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(1923),
    [anon_sym_AMPdeprecated] = ACTIONS(1923),
    [anon_sym_AMPerror_handler] = ACTIONS(1923),
    [anon_sym_AMPis_assigned] = ACTIONS(1923),
    [anon_sym_AMPis_used] = ACTIONS(1923),
    [anon_sym_AMPlog] = ACTIONS(1923),
    [anon_sym_AMPoptional] = ACTIONS(1923),
    [anon_sym_AMPordered] = ACTIONS(1923),
    [anon_sym_AMPraw_output] = ACTIONS(1923),
    [anon_sym_AMPredef] = ACTIONS(1923),
    [anon_sym_AMPadd_func] = ACTIONS(1923),
    [anon_sym_AMPbackend] = ACTIONS(1923),
    [anon_sym_AMPbroker_store] = ACTIONS(1923),
    [anon_sym_AMPcreate_expire] = ACTIONS(1923),
    [anon_sym_AMPdefault] = ACTIONS(1923),
    [anon_sym_AMPdelete_func] = ACTIONS(1923),
    [anon_sym_AMPexpire_func] = ACTIONS(1923),
    [anon_sym_AMPgroup] = ACTIONS(1923),
    [anon_sym_AMPon_change] = ACTIONS(1923),
    [anon_sym_AMPpriority] = ACTIONS(1923),
    [anon_sym_AMPread_expire] = ACTIONS(1923),
    [anon_sym_AMPtype_column] = ACTIONS(1923),
    [anon_sym_AMPwrite_expire] = ACTIONS(1923),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(1962),
    [anon_sym_BANG] = ACTIONS(1964),
    [anon_sym_DASH] = ACTIONS(1962),
    [anon_sym_PLUS] = ACTIONS(1962),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(1962),
    [anon_sym_LT_EQ] = ACTIONS(1960),
    [anon_sym_GT] = ACTIONS(1962),
    [anon_sym_GT_EQ] = ACTIONS(1960),
    [anon_sym_AMP] = ACTIONS(1962),
    [anon_sym_CARET] = ACTIONS(1960),
    [anon_sym_QMARK] = ACTIONS(1968),
    [anon_sym_EQ_EQ] = ACTIONS(1970),
    [anon_sym_BANG_EQ] = ACTIONS(1970),
    [anon_sym_AMP_AMP] = ACTIONS(1976),
    [anon_sym_PIPE_PIPE] = ACTIONS(1976),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1978),
    [anon_sym_ATdeprecated] = ACTIONS(1923),
    [anon_sym_ATload] = ACTIONS(1925),
    [anon_sym_ATload_DASHsigs] = ACTIONS(1923),
    [anon_sym_ATload_DASHplugin] = ACTIONS(1923),
    [anon_sym_ATunload] = ACTIONS(1923),
    [anon_sym_ATprefixes] = ACTIONS(1923),
    [anon_sym_ATif] = ACTIONS(1925),
    [anon_sym_ATifdef] = ACTIONS(1923),
    [anon_sym_ATifndef] = ACTIONS(1923),
    [anon_sym_ATendif] = ACTIONS(1923),
    [anon_sym_ATelse] = ACTIONS(1923),
    [anon_sym_ATpragma] = ACTIONS(1923),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(827)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(149),
    [anon_sym_PLUS_EQ] = ACTIONS(1972),
    [anon_sym_DASH_EQ] = ACTIONS(1972),
    [anon_sym_LPAREN] = ACTIONS(1887),
    [anon_sym_in] = ACTIONS(1960),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(1974),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(149),
    [anon_sym_AMPdeprecated] = ACTIONS(149),
    [anon_sym_AMPerror_handler] = ACTIONS(149),
    [anon_sym_AMPis_assigned] = ACTIONS(149),
    [anon_sym_AMPis_used] = ACTIONS(149),
    [anon_sym_AMPlog] = ACTIONS(149),
    [anon_sym_AMPoptional] = ACTIONS(149),
    [anon_sym_AMPordered] = ACTIONS(149),
    [anon_sym_AMPraw_output] = ACTIONS(149),
    [anon_sym_AMPredef] = ACTIONS(149),
    [anon_sym_AMPadd_func] = ACTIONS(149),
    [anon_sym_AMPbackend] = ACTIONS(149),
    [anon_sym_AMPbroker_store] = ACTIONS(149),
    [anon_sym_AMPcreate_expire] = ACTIONS(149),
    [anon_sym_AMPdefault] = ACTIONS(149),
    [anon_sym_AMPdelete_func] = ACTIONS(149),
    [anon_sym_AMPexpire_func] = ACTIONS(149),
    [anon_sym_AMPgroup] = ACTIONS(149),
    [anon_sym_AMPon_change] = ACTIONS(149),
    [anon_sym_AMPpriority] = ACTIONS(149),
    [anon_sym_AMPread_expire] = ACTIONS(149),
    [anon_sym_AMPtype_column] = ACTIONS(149),
    [anon_sym_AMPwrite_expire] = ACTIONS(149),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(1962),
    [anon_sym_BANG] = ACTIONS(1964),
    [anon_sym_DASH] = ACTIONS(1962),
    [anon_sym_PLUS] = ACTIONS(1962),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(1962),
    [anon_sym_LT_EQ] = ACTIONS(1960),
    [anon_sym_GT] = ACTIONS(1962),
    [anon_sym_GT_EQ] = ACTIONS(1960),
    [anon_sym_AMP] = ACTIONS(1962),
    [anon_sym_CARET] = ACTIONS(1960),
    [anon_sym_QMARK] = ACTIONS(1968),
    [anon_sym_EQ_EQ] = ACTIONS(1970),
    [anon_sym_BANG_EQ] = ACTIONS(1970),
    [anon_sym_AMP_AMP] = ACTIONS(1976),
    [anon_sym_PIPE_PIPE] = ACTIONS(1976),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(1978),
    [anon_sym_ATdeprecated] = ACTIONS(149),
    [anon_sym_ATload] = ACTIONS(155),
    [anon_sym_ATload_DASHsigs] = ACTIONS(149),
    [anon_sym_ATload_DASHplugin] = ACTIONS(149),
    [anon_sym_ATunload] = ACTIONS(149),
    [anon_sym_ATprefixes] = ACTIONS(149),
    [anon_sym_ATif] = ACTIONS(155),
    [anon_sym_ATifdef] = ACTIONS(149),
    [anon_sym_ATifndef] = ACTIONS(149),
    [anon_sym_ATendif] = ACTIONS(149),
    [anon_sym_ATelse] = ACTIONS(149),
    [anon_sym_ATpragma] = ACTIONS(149),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(828)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_PLUS_EQ] = ACTIONS(1972),
    [anon_sym_DASH_EQ] = ACTIONS(1972),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(1960),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(1974),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(1962),
    [anon_sym_BANG] = ACTIONS(1964),
    [anon_sym_DASH] = ACTIONS(1962),
    [anon_sym_PLUS] = ACTIONS(1962),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(1962),
    [anon_sym_LT_EQ] = ACTIONS(1960),
    [anon_sym_GT] = ACTIONS(1962),
    [anon_sym_GT_EQ] = ACTIONS(1960),
    [anon_sym_AMP] = ACTIONS(1962),
    [anon_sym_CARET] = ACTIONS(1960),
    [anon_sym_QMARK] = ACTIONS(1968),
    [anon_sym_EQ_EQ] = ACTIONS(1970),
    [anon_sym_BANG_EQ] = ACTIONS(1970),
    [anon_sym_AMP_AMP] = ACTIONS(1976),
    [anon_sym_PIPE_PIPE] = ACTIONS(1976),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(829)] = {
    [sym_index_slice] = STATE(795),
    [anon_sym_LBRACE] = ACTIONS(127),
    [anon_sym_PLUS_EQ] = ACTIONS(127),
    [anon_sym_DASH_EQ] = ACTIONS(127),
    [anon_sym_LPAREN] = ACTIONS(127),
    [anon_sym_in] = ACTIONS(127),
    [anon_sym_LBRACK] = ACTIONS(1909),
    [anon_sym_EQ] = ACTIONS(129),
    [anon_sym_as] = ACTIONS(1911),
    [anon_sym_AMPbroker_allow_complex_type] = ACTIONS(127),
    [anon_sym_AMPdeprecated] = ACTIONS(127),
    [anon_sym_AMPerror_handler] = ACTIONS(127),
    [anon_sym_AMPis_assigned] = ACTIONS(127),
    [anon_sym_AMPis_used] = ACTIONS(127),
    [anon_sym_AMPlog] = ACTIONS(127),
    [anon_sym_AMPoptional] = ACTIONS(127),
    [anon_sym_AMPordered] = ACTIONS(127),
    [anon_sym_AMPraw_output] = ACTIONS(127),
    [anon_sym_AMPredef] = ACTIONS(127),
    [anon_sym_AMPadd_func] = ACTIONS(127),
    [anon_sym_AMPbackend] = ACTIONS(127),
    [anon_sym_AMPbroker_store] = ACTIONS(127),
    [anon_sym_AMPcreate_expire] = ACTIONS(127),
    [anon_sym_AMPdefault] = ACTIONS(127),
    [anon_sym_AMPdelete_func] = ACTIONS(127),
    [anon_sym_AMPexpire_func] = ACTIONS(127),
    [anon_sym_AMPgroup] = ACTIONS(127),
    [anon_sym_AMPon_change] = ACTIONS(127),
    [anon_sym_AMPpriority] = ACTIONS(127),
    [anon_sym_AMPread_expire] = ACTIONS(127),
    [anon_sym_AMPtype_column] = ACTIONS(127),
    [anon_sym_AMPwrite_expire] = ACTIONS(127),
    [anon_sym_DOLLAR] = ACTIONS(1913),
    [anon_sym_PIPE] = ACTIONS(129),
    [anon_sym_BANG] = ACTIONS(129),
    [anon_sym_DASH] = ACTIONS(129),
    [anon_sym_PLUS] = ACTIONS(129),
    [anon_sym_is] = ACTIONS(1911),
    [anon_sym_STAR] = ACTIONS(1966),
    [anon_sym_SLASH] = ACTIONS(1966),
    [anon_sym_PERCENT] = ACTIONS(1966),
    [anon_sym_LT] = ACTIONS(129),
    [anon_sym_LT_EQ] = ACTIONS(127),
    [anon_sym_GT] = ACTIONS(129),
    [anon_sym_GT_EQ] = ACTIONS(127),
    [anon_sym_AMP] = ACTIONS(129),
    [anon_sym_CARET] = ACTIONS(127),
    [anon_sym_QMARK] = ACTIONS(129),
    [anon_sym_EQ_EQ] = ACTIONS(127),
    [anon_sym_BANG_EQ] = ACTIONS(127),
    [anon_sym_AMP_AMP] = ACTIONS(127),
    [anon_sym_PIPE_PIPE] = ACTIONS(127),
    [anon_sym_QMARK_DOLLAR] = ACTIONS(127),
    [anon_sym_ATdeprecated] = ACTIONS(127),
    [anon_sym_ATload] = ACTIONS(129),
    [anon_sym_ATload_DASHsigs] = ACTIONS(127),
    [anon_sym_ATload_DASHplugin] = ACTIONS(127),
    [anon_sym_ATunload] = ACTIONS(127),
    [anon_sym_ATprefixes] = ACTIONS(127),
    [anon_sym_ATif] = ACTIONS(129),
    [anon_sym_ATifdef] = ACTIONS(127),
    [anon_sym_ATifndef] = ACTIONS(127),
    [anon_sym_ATendif] = ACTIONS(127),
    [anon_sym_ATelse] = ACTIONS(127),
    [anon_sym_ATpragma] = ACTIONS(127),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(830)] = {
    [sym__simple_type] = STATE(1305),
    [sym_formal_args] = STATE(2279),
    [sym_formal_arg] = STATE(1953),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2234),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_formal_args_repeat1] = STATE(1955),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(1980),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(1982),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(831)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1543),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(831),
    [anon_sym_SEMI] = ACTIONS(1984),
    [anon_sym_LBRACE] = ACTIONS(1986),
    [anon_sym_RBRACE] = ACTIONS(1984),
    [anon_sym_COLON] = ACTIONS(1989),
    [anon_sym_enum] = ACTIONS(1991),
    [anon_sym_record] = ACTIONS(1994),
    [anon_sym_LPAREN] = ACTIONS(1997),
    [anon_sym_RPAREN] = ACTIONS(1984),
    [anon_sym_LBRACK] = ACTIONS(2000),
    [anon_sym_RBRACK] = ACTIONS(1984),
    [anon_sym_local] = ACTIONS(2003),
    [anon_sym_function] = ACTIONS(2006),
    [anon_sym_hook] = ACTIONS(2009),
    [anon_sym_addr] = ACTIONS(2012),
    [anon_sym_any] = ACTIONS(2012),
    [anon_sym_bool] = ACTIONS(2012),
    [anon_sym_count] = ACTIONS(2012),
    [anon_sym_double] = ACTIONS(2012),
    [anon_sym_file] = ACTIONS(2015),
    [anon_sym_int] = ACTIONS(2012),
    [anon_sym_interval] = ACTIONS(2012),
    [anon_sym_list] = ACTIONS(2015),
    [anon_sym_pattern] = ACTIONS(2012),
    [anon_sym_port] = ACTIONS(2012),
    [anon_sym_string] = ACTIONS(2012),
    [anon_sym_subnet] = ACTIONS(2012),
    [anon_sym_time] = ACTIONS(2012),
    [anon_sym_opaque] = ACTIONS(2018),
    [anon_sym_set] = ACTIONS(2021),
    [anon_sym_table] = ACTIONS(2024),
    [anon_sym_union] = ACTIONS(2027),
    [anon_sym_vector] = ACTIONS(2030),
    [anon_sym_DOLLAR] = ACTIONS(2033),
    [anon_sym_PIPE] = ACTIONS(2036),
    [anon_sym_PLUS_PLUS] = ACTIONS(2039),
    [anon_sym_DASH_DASH] = ACTIONS(2039),
    [anon_sym_BANG] = ACTIONS(2039),
    [anon_sym_TILDE] = ACTIONS(2039),
    [anon_sym_DASH] = ACTIONS(2042),
    [anon_sym_PLUS] = ACTIONS(2042),
    [anon_sym_copy] = ACTIONS(2045),
    [anon_sym_schedule] = ACTIONS(2048),
    [anon_sym_T] = ACTIONS(2051),
    [anon_sym_F] = ACTIONS(2051),
    [anon_sym_ATDIR] = ACTIONS(2054),
    [anon_sym_ATFILENAME] = ACTIONS(2054),
    [sym_id] = ACTIONS(2057),
    [sym_pattern] = ACTIONS(2060),
    [sym_ipv4] = ACTIONS(2063),
    [sym_ipv6] = ACTIONS(2066),
    [sym_port] = ACTIONS(2069),
    [sym_integer] = ACTIONS(2072),
    [sym_floatp] = ACTIONS(2075),
    [sym_hex] = ACTIONS(2051),
    [sym_hostname] = ACTIONS(2051),
    [aux_sym_string_token1] = ACTIONS(2078),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(832)] = {
    [sym__simple_type] = STATE(1305),
    [sym_formal_args] = STATE(2279),
    [sym_formal_arg] = STATE(1953),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2270),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_formal_args_repeat1] = STATE(1955),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2081),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(1982),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(833)] = {
    [sym_case_type_list] = STATE(2387),
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1345),
    [sym_expr_list] = STATE(2387),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_case_type_list_repeat1] = STATE(2112),
    [aux_sym_expr_list_repeat1] = STATE(852),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_type] = ACTIONS(2083),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(2085),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(2087),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(2089),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(2089),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(2091),
    [anon_sym_table] = ACTIONS(2093),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(2095),
    [anon_sym_DOLLAR] = ACTIONS(2097),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(2099),
    [anon_sym_DASH_DASH] = ACTIONS(2099),
    [anon_sym_BANG] = ACTIONS(2099),
    [anon_sym_TILDE] = ACTIONS(2099),
    [anon_sym_DASH] = ACTIONS(2101),
    [anon_sym_PLUS] = ACTIONS(2101),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(834)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1309),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(831),
    [anon_sym_SEMI] = ACTIONS(2103),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_RBRACE] = ACTIONS(2103),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2103),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_RBRACK] = ACTIONS(2103),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(835)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1334),
    [sym_expr_list] = STATE(2888),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_COLON] = ACTIONS(2105),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_RBRACK] = ACTIONS(1489),
    [anon_sym_local] = ACTIONS(2085),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(2087),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(2089),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(2089),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(2091),
    [anon_sym_table] = ACTIONS(2093),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(2095),
    [anon_sym_DOLLAR] = ACTIONS(2097),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(2099),
    [anon_sym_DASH_DASH] = ACTIONS(2099),
    [anon_sym_BANG] = ACTIONS(2099),
    [anon_sym_TILDE] = ACTIONS(2099),
    [anon_sym_DASH] = ACTIONS(2101),
    [anon_sym_PLUS] = ACTIONS(2101),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(836)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2888),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_RBRACK] = ACTIONS(1489),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(837)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2859),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2107),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(838)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2271),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_RBRACK] = ACTIONS(2109),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(839)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2633),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2111),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(840)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2234),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2113),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(841)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1333),
    [sym_expr_list] = STATE(2405),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_COLON] = ACTIONS(2115),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(2085),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(2087),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(2089),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(2089),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(2091),
    [anon_sym_table] = ACTIONS(2093),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(2095),
    [anon_sym_DOLLAR] = ACTIONS(2097),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(2099),
    [anon_sym_DASH_DASH] = ACTIONS(2099),
    [anon_sym_BANG] = ACTIONS(2099),
    [anon_sym_TILDE] = ACTIONS(2099),
    [anon_sym_DASH] = ACTIONS(2101),
    [anon_sym_PLUS] = ACTIONS(2101),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(842)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2384),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2117),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(843)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2676),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2119),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(844)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2256),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_RBRACE] = ACTIONS(1489),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(845)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2703),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2121),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(846)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2270),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2123),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(847)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2364),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2125),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(848)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2849),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_RPAREN] = ACTIONS(2127),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(849)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1341),
    [sym_expr_list] = STATE(2832),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_COLON] = ACTIONS(2129),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(2085),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(2087),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(2089),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(2089),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(2091),
    [anon_sym_table] = ACTIONS(2093),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(2095),
    [anon_sym_DOLLAR] = ACTIONS(2097),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(2099),
    [anon_sym_DASH_DASH] = ACTIONS(2099),
    [anon_sym_BANG] = ACTIONS(2099),
    [anon_sym_TILDE] = ACTIONS(2099),
    [anon_sym_DASH] = ACTIONS(2101),
    [anon_sym_PLUS] = ACTIONS(2101),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(850)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2249),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_RBRACE] = ACTIONS(2109),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(851)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1594),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2131),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2133),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(852)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1349),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(831),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_COLON] = ACTIONS(2135),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(2085),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(2087),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(2089),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(2089),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(2091),
    [anon_sym_table] = ACTIONS(2093),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(2095),
    [anon_sym_DOLLAR] = ACTIONS(2097),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(2099),
    [anon_sym_DASH_DASH] = ACTIONS(2099),
    [anon_sym_BANG] = ACTIONS(2099),
    [anon_sym_TILDE] = ACTIONS(2099),
    [anon_sym_DASH] = ACTIONS(2101),
    [anon_sym_PLUS] = ACTIONS(2101),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(853)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1534),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2137),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2139),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(854)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2266),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(855)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2364),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(856)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1554),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2141),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2143),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(857)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1566),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2145),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2147),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(858)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2707),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(859)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2864),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(860)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2532),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(861)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2815),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(862)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2241),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(863)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1549),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2149),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2151),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(864)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2315),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(865)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2904),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(866)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2468),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(867)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1420),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2153),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2155),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(868)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2596),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(869)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2669),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(870)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2270),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(871)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1490),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2157),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2159),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(872)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1485),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2161),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2163),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(873)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1522),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2165),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2167),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(874)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1423),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2169),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2171),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(875)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1538),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2173),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2175),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(876)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1358),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [anon_sym_SEMI] = ACTIONS(2177),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_when] = ACTIONS(2179),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
  [STATE(877)] = {
    [sym__simple_type] = STATE(1305),
    [sym_expr] = STATE(1314),
    [sym_expr_list] = STATE(2380),
    [sym_constant] = STATE(1273),
    [sym_string_directive] = STATE(1209),
    [sym_subnet] = STATE(1270),
    [sym_interval] = STATE(1270),
    [sym_string] = STATE(1270),
    [aux_sym_expr_list_repeat1] = STATE(834),
    [anon_sym_LBRACE] = ACTIONS(147),
    [anon_sym_enum] = ACTIONS(25),
    [anon_sym_record] = ACTIONS(27),
    [anon_sym_LPAREN] = ACTIONS(37),
    [anon_sym_LBRACK] = ACTIONS(1491),
    [anon_sym_local] = ACTIONS(131),
    [anon_sym_function] = ACTIONS(133),
    [anon_sym_hook] = ACTIONS(135),
    [anon_sym_addr] = ACTIONS(63),
    [anon_sym_any] = ACTIONS(63),
    [anon_sym_bool] = ACTIONS(63),
    [anon_sym_count] = ACTIONS(63),
    [anon_sym_double] = ACTIONS(63),
    [anon_sym_file] = ACTIONS(65),
    [anon_sym_int] = ACTIONS(63),
    [anon_sym_interval] = ACTIONS(63),
    [anon_sym_list] = ACTIONS(65),
    [anon_sym_pattern] = ACTIONS(63),
    [anon_sym_port] = ACTIONS(63),
    [anon_sym_string] = ACTIONS(63),
    [anon_sym_subnet] = ACTIONS(63),
    [anon_sym_time] = ACTIONS(63),
    [anon_sym_opaque] = ACTIONS(67),
    [anon_sym_set] = ACTIONS(69),
    [anon_sym_table] = ACTIONS(71),
    [anon_sym_union] = ACTIONS(73),
    [anon_sym_vector] = ACTIONS(75),
    [anon_sym_DOLLAR] = ACTIONS(77),
    [anon_sym_PIPE] = ACTIONS(79),
    [anon_sym_PLUS_PLUS] = ACTIONS(81),
    [anon_sym_DASH_DASH] = ACTIONS(81),
    [anon_sym_BANG] = ACTIONS(81),
    [anon_sym_TILDE] = ACTIONS(81),
    [anon_sym_DASH] = ACTIONS(83),
    [anon_sym_PLUS] = ACTIONS(83),
    [anon_sym_copy] = ACTIONS(85),
    [anon_sym_schedule] = ACTIONS(87),
    [anon_sym_T] = ACTIONS(89),
    [anon_sym_F] = ACTIONS(89),
    [anon_sym_ATDIR] = ACTIONS(109),
    [anon_sym_ATFILENAME] = ACTIONS(109),
    [sym_id] = ACTIONS(111),
    [sym_pattern] = ACTIONS(113),
    [sym_ipv4] = ACTIONS(115),
    [sym_ipv6] = ACTIONS(117),
    [sym_port] = ACTIONS(119),
    [sym_integer] = ACTIONS(121),
    [sym_floatp] = ACTIONS(123),
    [sym_hex] = ACTIONS(89),
    [sym_hostname] = ACTIONS(89),
    [aux_sym_string_token1] = ACTIONS(125),
    [sym_zeekygen_head_comment] = ACTIONS(3),
    [sym_zeekygen_prev_comment] = ACTIONS(3),
    [sym_zeekygen_next_comment] = ACTIONS(5),
    [sym_minor_comment] = ACTIONS(5),
    [sym_nl] = ACTIONS(3),
  },
};

static const uint16_t ts_small_parse_table[] = {
  [0] = 39,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2181), 1,
      anon_sym_RBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1389), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [143] = 9,
    ACTIONS(2183), 1,
      anon_sym_AMPdeprecated,
    STATE(1274), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(914), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(2185), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(127), 24,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [226] = 6,
    STATE(805), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(967), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 47,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [303] = 39,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2187), 1,
      anon_sym_RBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1452), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [446] = 6,
    STATE(786), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(967), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1935), 47,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [523] = 39,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2189), 1,
      anon_sym_RBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1435), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [666] = 39,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2191), 1,
      anon_sym_RBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1499), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [809] = 39,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2193), 1,
      anon_sym_RBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1494), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [952] = 39,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2195), 1,
      anon_sym_RBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1505), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [1095] = 9,
    ACTIONS(2183), 1,
      anon_sym_AMPdeprecated,
    STATE(1294), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(914), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(2185), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(1935), 24,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [1178] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1323), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [1318] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1597), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [1458] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1491), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [1598] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1246), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [1738] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1518), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [1878] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1606), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [2018] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1361), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [2158] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1363), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [2298] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1299), 1,
      sym_expr,
    STATE(1305), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [2438] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1365), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [2578] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1364), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [2718] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2213), 1,
      sym_id,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1601), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [2858] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(793), 1,
      sym_expr,
    STATE(812), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [2998] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1508), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [3138] = 9,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1306), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(2215), 14,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
      sym_pattern,
      sym_ipv6,
      sym_port,
      aux_sym_string_token1,
    ACTIONS(2217), 37,
      anon_sym_enum,
      anon_sym_record,
      anon_sym_LBRACK,
      anon_sym_local,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_file,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_list,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
      anon_sym_opaque,
      anon_sym_set,
      anon_sym_table,
      anon_sym_union,
      anon_sym_vector,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_copy,
      anon_sym_schedule,
      anon_sym_T,
      anon_sym_F,
      sym_id,
      sym_ipv4,
      sym_integer,
      sym_floatp,
      sym_hex,
      sym_hostname,
  [3220] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1539), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [3360] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1207), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [3500] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1504), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [3640] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1308), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [3780] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1211), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [3920] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1212), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [4060] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(783), 1,
      sym_expr,
    STATE(812), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [4200] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1213), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [4340] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1220), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [4480] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1214), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [4620] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1377), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [4760] = 8,
    ACTIONS(2183), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(919), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(1958), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(2185), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(1956), 24,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [4840] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1315), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [4980] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1217), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [5120] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1218), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [5260] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1347), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [5400] = 8,
    ACTIONS(1950), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(919), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1945), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1947), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(2219), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(1943), 24,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [5480] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1216), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [5620] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1390), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [5760] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1224), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [5900] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(803), 1,
      anon_sym_local,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(807), 1,
      anon_sym_hook,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(815), 1,
      anon_sym_set,
    ACTIONS(817), 1,
      anon_sym_table,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(829), 1,
      anon_sym_DOLLAR,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1205), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(835), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(833), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [6040] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1397), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [6180] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2222), 1,
      anon_sym_LBRACE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1316), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [6320] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1306), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [6460] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1561), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [6600] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1563), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [6740] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1426), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [6880] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1417), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [7020] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1420), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [7160] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1338), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [7300] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1600), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [7440] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1299), 1,
      sym_expr,
    STATE(1305), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [7580] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1486), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [7720] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1313), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [7860] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1437), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [8000] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1441), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [8140] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1443), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [8280] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1368), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [8420] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1369), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [8560] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1278), 1,
      sym_expr,
    STATE(1305), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [8700] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1444), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [8840] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1370), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [8980] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1371), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [9120] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1351), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [9260] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1375), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [9400] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1376), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [9540] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1374), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [9680] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1459), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [9820] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1379), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [9960] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1466), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [10100] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1467), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [10240] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1470), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [10380] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1473), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [10520] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1240), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [10660] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1485), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [10800] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1340), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [10940] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1607), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [11080] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1501), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [11220] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1502), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [11360] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1503), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [11500] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1513), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [11640] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1514), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [11780] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1515), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [11920] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1519), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [12060] = 5,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(919), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1958), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1956), 47,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [12134] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1522), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [12274] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1344), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [12414] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1602), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [12554] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1525), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [12694] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1526), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [12834] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1527), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [12974] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1529), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [13114] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1530), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [13254] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1531), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [13394] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1533), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [13534] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1535), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [13674] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1538), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [13814] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1339), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [13954] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1540), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [14094] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1541), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [14234] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1542), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [14374] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1544), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [14514] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1546), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [14654] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1547), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [14794] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1548), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [14934] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1550), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [15074] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1554), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [15214] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1327), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [15354] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1558), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [15494] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1562), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [15634] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1568), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [15774] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1584), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [15914] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1585), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [16054] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1586), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [16194] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1587), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [16334] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1589), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [16474] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1594), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [16614] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1343), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [16754] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1385), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [16894] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1564), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [17034] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1493), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [17174] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1404), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [17314] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1598), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [17454] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1523), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [17594] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1536), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [17734] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1567), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [17874] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1512), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [18014] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1358), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [18154] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1328), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [18294] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1372), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [18434] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1383), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [18574] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1384), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [18714] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1386), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [18854] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1387), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [18994] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1388), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [19134] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1392), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [19274] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1400), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [19414] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1423), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [19554] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1332), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [19694] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1439), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [19834] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1446), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [19974] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1448), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [20114] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1469), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [20254] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1477), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [20394] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1478), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [20534] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1479), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [20674] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1484), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [20814] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1490), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [20954] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1336), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [21094] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1495), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [21234] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1496), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [21374] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1497), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [21514] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1500), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [21654] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1506), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [21794] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1507), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [21934] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1510), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [22074] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1520), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [22214] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1460), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [22354] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1534), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [22494] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1325), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [22634] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1545), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [22774] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1551), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [22914] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1552), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [23054] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1555), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [23194] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1556), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [23334] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1557), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [23474] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1559), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [23614] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1560), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [23754] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1566), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [23894] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1337), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [24034] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1588), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [24174] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1590), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [24314] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1593), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [24454] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1352), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [24594] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1353), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [24734] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1354), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [24874] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1355), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [25014] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1356), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [25154] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1359), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [25294] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1360), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [25434] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1362), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [25574] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1366), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [25714] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1367), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [25854] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1373), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [25994] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(826), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [26134] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1378), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [26274] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1380), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [26414] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1381), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [26554] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1382), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [26694] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(793), 1,
      sym_expr,
    STATE(812), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [26834] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(827), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [26974] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(828), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [27114] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(829), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [27254] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(783), 1,
      sym_expr,
    STATE(812), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [27394] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(819), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [27534] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(820), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [27674] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(823), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [27814] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1316), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [27954] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(821), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [28094] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1307), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [28234] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(822), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [28374] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(824), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [28514] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(821), 1,
      anon_sym_vector,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2242), 1,
      anon_sym_local,
    ACTIONS(2244), 1,
      anon_sym_hook,
    ACTIONS(2246), 1,
      anon_sym_set,
    ACTIONS(2248), 1,
      anon_sym_table,
    ACTIONS(2250), 1,
      anon_sym_DOLLAR,
    ACTIONS(2252), 1,
      anon_sym_PIPE,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(825), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2256), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2254), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [28654] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1511), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [28794] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1391), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [28934] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1393), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [29074] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1394), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [29214] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1395), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [29354] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1396), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [29494] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1398), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [29634] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1399), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [29774] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1401), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [29914] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1234), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [30054] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1233), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [30194] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1239), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [30334] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1241), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [30474] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1230), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [30614] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1231), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [30754] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1236), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [30894] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1237), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [31034] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1229), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [31174] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1235), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [31314] = 38,
    ACTIONS(789), 1,
      anon_sym_LBRACE,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(797), 1,
      anon_sym_record,
    ACTIONS(799), 1,
      anon_sym_LPAREN,
    ACTIONS(801), 1,
      anon_sym_LBRACK,
    ACTIONS(805), 1,
      anon_sym_function,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(831), 1,
      anon_sym_PIPE,
    ACTIONS(837), 1,
      anon_sym_copy,
    ACTIONS(839), 1,
      anon_sym_schedule,
    ACTIONS(845), 1,
      sym_id,
    ACTIONS(847), 1,
      sym_pattern,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(859), 1,
      aux_sym_string_token1,
    ACTIONS(2224), 1,
      anon_sym_local,
    ACTIONS(2226), 1,
      anon_sym_hook,
    ACTIONS(2230), 1,
      anon_sym_set,
    ACTIONS(2232), 1,
      anon_sym_table,
    ACTIONS(2234), 1,
      anon_sym_vector,
    ACTIONS(2236), 1,
      anon_sym_DOLLAR,
    STATE(773), 1,
      sym_constant,
    STATE(777), 1,
      sym__simple_type,
    STATE(812), 1,
      sym_string_directive,
    STATE(1238), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(843), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2240), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2238), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [31454] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1524), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [31594] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1402), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [31734] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1405), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [31874] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1406), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [32014] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1407), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [32154] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1408), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [32294] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1410), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [32434] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1411), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [32574] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1412), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [32714] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1413), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [32854] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1415), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [32994] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1416), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [33134] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1418), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [33274] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1419), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [33414] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1421), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [33554] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1422), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [33694] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1424), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [33834] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1425), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [33974] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1427), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [34114] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1428), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [34254] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1429), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [34394] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1430), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [34534] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1431), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [34674] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1432), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [34814] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1433), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [34954] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1434), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [35094] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1436), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [35234] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1438), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [35374] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1440), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [35514] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1442), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [35654] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1445), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [35794] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1447), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [35934] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1449), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [36074] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1450), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [36214] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1451), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [36354] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1453), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [36494] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1454), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [36634] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1455), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [36774] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1456), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [36914] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1457), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [37054] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1458), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [37194] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1461), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [37334] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1462), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [37474] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1463), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [37614] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1464), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [37754] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1465), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [37894] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1468), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [38034] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1472), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [38174] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1474), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [38314] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1475), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [38454] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1476), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [38594] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1480), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [38734] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1481), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [38874] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1482), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [39014] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1321), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [39154] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1487), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [39294] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1320), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [39434] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1488), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [39574] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1319), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [39714] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1322), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [39854] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1492), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [39994] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1324), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [40134] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1317), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [40274] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1329), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [40414] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1330), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [40554] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2258), 1,
      anon_sym_LBRACE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1316), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [40694] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1326), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [40834] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1331), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [40974] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1278), 1,
      sym_expr,
    STATE(1305), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [41114] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1498), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [41254] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1310), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [41394] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1311), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [41534] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1516), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [41674] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1549), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [41814] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1342), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [41954] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2260), 1,
      sym_id,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1312), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [42094] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1471), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [42234] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1569), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [42374] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1570), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [42514] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1571), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [42654] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1572), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [42794] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1573), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [42934] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1574), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [43074] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1575), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [43214] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1576), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [43354] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1577), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [43494] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1578), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [43634] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1579), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [43774] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1580), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [43914] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1581), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [44054] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1582), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [44194] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1583), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [44334] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2262), 1,
      sym_id,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1604), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [44474] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1312), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [44614] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2197), 1,
      anon_sym_local,
    ACTIONS(2199), 1,
      anon_sym_hook,
    ACTIONS(2201), 1,
      anon_sym_set,
    ACTIONS(2203), 1,
      anon_sym_table,
    ACTIONS(2205), 1,
      anon_sym_DOLLAR,
    ACTIONS(2207), 1,
      anon_sym_PIPE,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1528), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2211), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2209), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [44754] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    ACTIONS(2085), 1,
      anon_sym_local,
    ACTIONS(2087), 1,
      anon_sym_hook,
    ACTIONS(2091), 1,
      anon_sym_set,
    ACTIONS(2093), 1,
      anon_sym_table,
    ACTIONS(2095), 1,
      anon_sym_vector,
    ACTIONS(2097), 1,
      anon_sym_DOLLAR,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1591), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2101), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(2099), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [44894] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1595), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [45034] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1596), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [45174] = 38,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(27), 1,
      anon_sym_record,
    ACTIONS(37), 1,
      anon_sym_LPAREN,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(69), 1,
      anon_sym_set,
    ACTIONS(71), 1,
      anon_sym_table,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(75), 1,
      anon_sym_vector,
    ACTIONS(77), 1,
      anon_sym_DOLLAR,
    ACTIONS(79), 1,
      anon_sym_PIPE,
    ACTIONS(85), 1,
      anon_sym_copy,
    ACTIONS(87), 1,
      anon_sym_schedule,
    ACTIONS(111), 1,
      sym_id,
    ACTIONS(113), 1,
      sym_pattern,
    ACTIONS(115), 1,
      sym_ipv4,
    ACTIONS(117), 1,
      sym_ipv6,
    ACTIONS(119), 1,
      sym_port,
    ACTIONS(121), 1,
      sym_integer,
    ACTIONS(123), 1,
      sym_floatp,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(131), 1,
      anon_sym_local,
    ACTIONS(133), 1,
      anon_sym_function,
    ACTIONS(135), 1,
      anon_sym_hook,
    ACTIONS(147), 1,
      anon_sym_LBRACE,
    ACTIONS(1491), 1,
      anon_sym_LBRACK,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1273), 1,
      sym_constant,
    STATE(1305), 1,
      sym__simple_type,
    STATE(1517), 1,
      sym_expr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(83), 2,
      anon_sym_DASH,
      anon_sym_PLUS,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1270), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(81), 4,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
    ACTIONS(89), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [45314] = 13,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(1917), 1,
      anon_sym_EQ,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1915), 36,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [45403] = 6,
    STATE(786), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1227), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1935), 45,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [45478] = 18,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(1978), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    ACTIONS(2276), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2274), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2278), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2280), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(149), 28,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [45577] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(141), 11,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(139), 46,
      anon_sym_module,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_COLON,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_type,
      anon_sym_event,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [45648] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(145), 11,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(143), 46,
      anon_sym_module,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_COLON,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_type,
      anon_sym_event,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [45719] = 9,
    ACTIONS(2183), 1,
      anon_sym_AMPdeprecated,
    STATE(1294), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1225), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(2282), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(1935), 22,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [45800] = 16,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    ACTIONS(2276), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2274), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2278), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2280), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 30,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_QMARK_DOLLAR,
  [45895] = 9,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 40,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [45976] = 13,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 36,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [46065] = 14,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2278), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 34,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [46156] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1507), 11,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(1505), 46,
      anon_sym_module,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_COLON,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_type,
      anon_sym_event,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [46227] = 18,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(1978), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    ACTIONS(2276), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2274), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2278), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2280), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1935), 28,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [46326] = 16,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    ACTIONS(2276), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2274), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2278), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2280), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1935), 30,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_QMARK_DOLLAR,
  [46421] = 9,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1935), 40,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [46502] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1515), 11,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(1513), 46,
      anon_sym_module,
      anon_sym_SEMI,
      anon_sym_export,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_COLON,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_type,
      anon_sym_event,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [46573] = 17,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    ACTIONS(2276), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2274), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2278), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2280), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1923), 29,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_QMARK_DOLLAR,
  [46670] = 6,
    STATE(805), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1227), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 45,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [46745] = 9,
    ACTIONS(2183), 1,
      anon_sym_AMPdeprecated,
    STATE(1274), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1225), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(2282), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(127), 22,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [46826] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1984), 18,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
      anon_sym_DOLLAR,
      anon_sym_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
      sym_pattern,
      sym_ipv6,
      sym_port,
      aux_sym_string_token1,
    ACTIONS(1989), 38,
      anon_sym_COLON,
      anon_sym_enum,
      anon_sym_record,
      anon_sym_LBRACK,
      anon_sym_local,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_file,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_list,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
      anon_sym_opaque,
      anon_sym_set,
      anon_sym_table,
      anon_sym_union,
      anon_sym_vector,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_copy,
      anon_sym_schedule,
      anon_sym_T,
      anon_sym_F,
      sym_id,
      sym_ipv4,
      sym_integer,
      sym_floatp,
      sym_hex,
      sym_hostname,
  [46896] = 18,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(1978), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    ACTIONS(2276), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2274), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2278), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2280), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1923), 27,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [46994] = 8,
    ACTIONS(2183), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1226), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(1958), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(2282), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(1956), 22,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [47072] = 8,
    ACTIONS(1950), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1226), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1945), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1947), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(2284), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(1943), 22,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [47150] = 5,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1226), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1958), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1956), 45,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [47222] = 9,
    ACTIONS(2183), 1,
      anon_sym_AMPdeprecated,
    STATE(1294), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1243), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(2287), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(1935), 20,
      anon_sym_LBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [47301] = 9,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2291), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1935), 38,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [47380] = 8,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 41,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [47457] = 13,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(2297), 1,
      anon_sym_BANG,
    ACTIONS(2299), 1,
      anon_sym_QMARK,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2291), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2293), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2295), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 34,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [47544] = 5,
    ACTIONS(2301), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1839), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1837), 45,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [47615] = 18,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(1978), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2297), 1,
      anon_sym_BANG,
    ACTIONS(2299), 1,
      anon_sym_QMARK,
    ACTIONS(2305), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2303), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2307), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2309), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2291), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2293), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2295), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(149), 26,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [47712] = 8,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(155), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(149), 41,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [47789] = 18,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(1978), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2297), 1,
      anon_sym_BANG,
    ACTIONS(2299), 1,
      anon_sym_QMARK,
    ACTIONS(2305), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2303), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2307), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2309), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2291), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2293), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2295), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1935), 26,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [47886] = 14,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(2297), 1,
      anon_sym_BANG,
    ACTIONS(2299), 1,
      anon_sym_QMARK,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2307), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2291), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2293), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2295), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 32,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [47975] = 16,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(2297), 1,
      anon_sym_BANG,
    ACTIONS(2299), 1,
      anon_sym_QMARK,
    ACTIONS(2305), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2303), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2307), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2309), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2291), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2293), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2295), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1935), 28,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_QMARK_DOLLAR,
  [48068] = 13,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(1917), 1,
      anon_sym_EQ,
    ACTIONS(2297), 1,
      anon_sym_BANG,
    ACTIONS(2299), 1,
      anon_sym_QMARK,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2291), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2293), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2295), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1915), 34,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [48155] = 16,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(2297), 1,
      anon_sym_BANG,
    ACTIONS(2299), 1,
      anon_sym_QMARK,
    ACTIONS(2305), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2303), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2307), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2309), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2291), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2293), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2295), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 28,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_QMARK_DOLLAR,
  [48248] = 17,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(2297), 1,
      anon_sym_BANG,
    ACTIONS(2299), 1,
      anon_sym_QMARK,
    ACTIONS(2305), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2303), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2307), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2309), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2291), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2293), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2295), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1923), 27,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_QMARK_DOLLAR,
  [48343] = 9,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2289), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2291), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 38,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [48422] = 9,
    ACTIONS(2183), 1,
      anon_sym_AMPdeprecated,
    STATE(1274), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1243), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(2287), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(127), 20,
      anon_sym_LBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [48501] = 8,
    ACTIONS(2183), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(817), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(1958), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(2287), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
    ACTIONS(1956), 20,
      anon_sym_LBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [48577] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1847), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1843), 45,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [48645] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1853), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1849), 45,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [48713] = 18,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(1978), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    ACTIONS(2276), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2274), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2278), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2280), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(2311), 24,
      anon_sym_SEMI,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [48808] = 18,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(1909), 1,
      anon_sym_LBRACK,
    ACTIONS(1913), 1,
      anon_sym_DOLLAR,
    ACTIONS(1978), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2268), 1,
      anon_sym_BANG,
    ACTIONS(2272), 1,
      anon_sym_QMARK,
    ACTIONS(2276), 1,
      anon_sym_EQ,
    STATE(795), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1911), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2274), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2278), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2280), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2270), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2264), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2266), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(2313), 24,
      anon_sym_SEMI,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [48903] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2215), 14,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_DOLLAR,
      anon_sym_PIPE,
      anon_sym_PLUS_PLUS,
      anon_sym_DASH_DASH,
      anon_sym_BANG,
      anon_sym_TILDE,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
      sym_pattern,
      sym_ipv6,
      sym_port,
      aux_sym_string_token1,
    ACTIONS(2217), 37,
      anon_sym_enum,
      anon_sym_record,
      anon_sym_LBRACK,
      anon_sym_local,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_file,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_list,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
      anon_sym_opaque,
      anon_sym_set,
      anon_sym_table,
      anon_sym_union,
      anon_sym_vector,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_copy,
      anon_sym_schedule,
      anon_sym_T,
      anon_sym_F,
      sym_id,
      sym_ipv4,
      sym_integer,
      sym_floatp,
      sym_hex,
      sym_hostname,
  [48968] = 5,
    ACTIONS(2315), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1933), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1931), 38,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [49025] = 27,
    ACTIONS(157), 1,
      anon_sym_RBRACE,
    ACTIONS(2317), 1,
      anon_sym_module,
    ACTIONS(2320), 1,
      anon_sym_export,
    ACTIONS(2323), 1,
      anon_sym_global,
    ACTIONS(2326), 1,
      anon_sym_option,
    ACTIONS(2329), 1,
      anon_sym_const,
    ACTIONS(2332), 1,
      anon_sym_redef,
    ACTIONS(2335), 1,
      anon_sym_type,
    ACTIONS(2338), 1,
      anon_sym_event,
    ACTIONS(2341), 1,
      anon_sym_function,
    ACTIONS(2344), 1,
      anon_sym_hook,
    ACTIONS(2347), 1,
      anon_sym_ATdeprecated,
    ACTIONS(2350), 1,
      anon_sym_ATload,
    ACTIONS(2356), 1,
      anon_sym_ATload_DASHplugin,
    ACTIONS(2359), 1,
      anon_sym_ATprefixes,
    ACTIONS(2362), 1,
      anon_sym_ATif,
    ACTIONS(2371), 1,
      anon_sym_ATpragma,
    STATE(1822), 1,
      sym_pragma,
    STATE(1843), 1,
      sym_func_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2353), 2,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATunload,
    ACTIONS(2365), 2,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
    ACTIONS(2368), 2,
      anon_sym_ATendif,
      anon_sym_ATelse,
    STATE(1250), 2,
      sym_decl,
      aux_sym_source_file_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1850), 3,
      sym_func,
      sym_hook,
      sym_event,
    STATE(1823), 11,
      sym_module_decl,
      sym_export_decl,
      sym_global_decl,
      sym_option_decl,
      sym_const_decl,
      sym_redef_decl,
      sym_redef_enum_decl,
      sym_redef_record_decl,
      sym_type_decl,
      sym_func_decl,
      sym_preproc_directive,
  [49126] = 27,
    ACTIONS(2374), 1,
      anon_sym_module,
    ACTIONS(2376), 1,
      anon_sym_export,
    ACTIONS(2378), 1,
      anon_sym_RBRACE,
    ACTIONS(2380), 1,
      anon_sym_global,
    ACTIONS(2382), 1,
      anon_sym_option,
    ACTIONS(2384), 1,
      anon_sym_const,
    ACTIONS(2386), 1,
      anon_sym_redef,
    ACTIONS(2388), 1,
      anon_sym_type,
    ACTIONS(2390), 1,
      anon_sym_event,
    ACTIONS(2392), 1,
      anon_sym_function,
    ACTIONS(2394), 1,
      anon_sym_hook,
    ACTIONS(2396), 1,
      anon_sym_ATdeprecated,
    ACTIONS(2398), 1,
      anon_sym_ATload,
    ACTIONS(2402), 1,
      anon_sym_ATload_DASHplugin,
    ACTIONS(2404), 1,
      anon_sym_ATprefixes,
    ACTIONS(2406), 1,
      anon_sym_ATif,
    ACTIONS(2412), 1,
      anon_sym_ATpragma,
    STATE(1822), 1,
      sym_pragma,
    STATE(1843), 1,
      sym_func_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2400), 2,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATunload,
    ACTIONS(2408), 2,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
    ACTIONS(2410), 2,
      anon_sym_ATendif,
      anon_sym_ATelse,
    STATE(1253), 2,
      sym_decl,
      aux_sym_source_file_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1850), 3,
      sym_func,
      sym_hook,
      sym_event,
    STATE(1823), 11,
      sym_module_decl,
      sym_export_decl,
      sym_global_decl,
      sym_option_decl,
      sym_const_decl,
      sym_redef_decl,
      sym_redef_enum_decl,
      sym_redef_record_decl,
      sym_type_decl,
      sym_func_decl,
      sym_preproc_directive,
  [49227] = 27,
    ACTIONS(2374), 1,
      anon_sym_module,
    ACTIONS(2376), 1,
      anon_sym_export,
    ACTIONS(2380), 1,
      anon_sym_global,
    ACTIONS(2382), 1,
      anon_sym_option,
    ACTIONS(2384), 1,
      anon_sym_const,
    ACTIONS(2386), 1,
      anon_sym_redef,
    ACTIONS(2388), 1,
      anon_sym_type,
    ACTIONS(2390), 1,
      anon_sym_event,
    ACTIONS(2392), 1,
      anon_sym_function,
    ACTIONS(2394), 1,
      anon_sym_hook,
    ACTIONS(2396), 1,
      anon_sym_ATdeprecated,
    ACTIONS(2398), 1,
      anon_sym_ATload,
    ACTIONS(2402), 1,
      anon_sym_ATload_DASHplugin,
    ACTIONS(2404), 1,
      anon_sym_ATprefixes,
    ACTIONS(2406), 1,
      anon_sym_ATif,
    ACTIONS(2412), 1,
      anon_sym_ATpragma,
    ACTIONS(2414), 1,
      anon_sym_RBRACE,
    STATE(1822), 1,
      sym_pragma,
    STATE(1843), 1,
      sym_func_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2400), 2,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATunload,
    ACTIONS(2408), 2,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
    ACTIONS(2410), 2,
      anon_sym_ATendif,
      anon_sym_ATelse,
    STATE(1254), 2,
      sym_decl,
      aux_sym_source_file_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1850), 3,
      sym_func,
      sym_hook,
      sym_event,
    STATE(1823), 11,
      sym_module_decl,
      sym_export_decl,
      sym_global_decl,
      sym_option_decl,
      sym_const_decl,
      sym_redef_decl,
      sym_redef_enum_decl,
      sym_redef_record_decl,
      sym_type_decl,
      sym_func_decl,
      sym_preproc_directive,
  [49328] = 27,
    ACTIONS(2374), 1,
      anon_sym_module,
    ACTIONS(2376), 1,
      anon_sym_export,
    ACTIONS(2380), 1,
      anon_sym_global,
    ACTIONS(2382), 1,
      anon_sym_option,
    ACTIONS(2384), 1,
      anon_sym_const,
    ACTIONS(2386), 1,
      anon_sym_redef,
    ACTIONS(2388), 1,
      anon_sym_type,
    ACTIONS(2390), 1,
      anon_sym_event,
    ACTIONS(2392), 1,
      anon_sym_function,
    ACTIONS(2394), 1,
      anon_sym_hook,
    ACTIONS(2396), 1,
      anon_sym_ATdeprecated,
    ACTIONS(2398), 1,
      anon_sym_ATload,
    ACTIONS(2402), 1,
      anon_sym_ATload_DASHplugin,
    ACTIONS(2404), 1,
      anon_sym_ATprefixes,
    ACTIONS(2406), 1,
      anon_sym_ATif,
    ACTIONS(2412), 1,
      anon_sym_ATpragma,
    ACTIONS(2416), 1,
      anon_sym_RBRACE,
    STATE(1822), 1,
      sym_pragma,
    STATE(1843), 1,
      sym_func_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2400), 2,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATunload,
    ACTIONS(2408), 2,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
    ACTIONS(2410), 2,
      anon_sym_ATendif,
      anon_sym_ATelse,
    STATE(1250), 2,
      sym_decl,
      aux_sym_source_file_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1850), 3,
      sym_func,
      sym_hook,
      sym_event,
    STATE(1823), 11,
      sym_module_decl,
      sym_export_decl,
      sym_global_decl,
      sym_option_decl,
      sym_const_decl,
      sym_redef_decl,
      sym_redef_enum_decl,
      sym_redef_record_decl,
      sym_type_decl,
      sym_func_decl,
      sym_preproc_directive,
  [49429] = 27,
    ACTIONS(2374), 1,
      anon_sym_module,
    ACTIONS(2376), 1,
      anon_sym_export,
    ACTIONS(2380), 1,
      anon_sym_global,
    ACTIONS(2382), 1,
      anon_sym_option,
    ACTIONS(2384), 1,
      anon_sym_const,
    ACTIONS(2386), 1,
      anon_sym_redef,
    ACTIONS(2388), 1,
      anon_sym_type,
    ACTIONS(2390), 1,
      anon_sym_event,
    ACTIONS(2392), 1,
      anon_sym_function,
    ACTIONS(2394), 1,
      anon_sym_hook,
    ACTIONS(2396), 1,
      anon_sym_ATdeprecated,
    ACTIONS(2398), 1,
      anon_sym_ATload,
    ACTIONS(2402), 1,
      anon_sym_ATload_DASHplugin,
    ACTIONS(2404), 1,
      anon_sym_ATprefixes,
    ACTIONS(2406), 1,
      anon_sym_ATif,
    ACTIONS(2412), 1,
      anon_sym_ATpragma,
    ACTIONS(2418), 1,
      anon_sym_RBRACE,
    STATE(1822), 1,
      sym_pragma,
    STATE(1843), 1,
      sym_func_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2400), 2,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATunload,
    ACTIONS(2408), 2,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
    ACTIONS(2410), 2,
      anon_sym_ATendif,
      anon_sym_ATelse,
    STATE(1250), 2,
      sym_decl,
      aux_sym_source_file_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(1850), 3,
      sym_func,
      sym_hook,
      sym_event,
    STATE(1823), 11,
      sym_module_decl,
      sym_export_decl,
      sym_global_decl,
      sym_option_decl,
      sym_const_decl,
      sym_redef_decl,
      sym_redef_enum_decl,
      sym_redef_record_decl,
      sym_type_decl,
      sym_func_decl,
      sym_preproc_directive,
  [49530] = 5,
    ACTIONS(2420), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1847), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1843), 37,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [49586] = 5,
    ACTIONS(1941), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1853), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1849), 37,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [49642] = 5,
    ACTIONS(2422), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1839), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1837), 37,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [49698] = 9,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    STATE(1849), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2428), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    STATE(1263), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(2424), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
    ACTIONS(2426), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [49761] = 9,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    STATE(1848), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2432), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    STATE(1263), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(2430), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
    ACTIONS(2426), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [49824] = 9,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    STATE(1851), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2436), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    STATE(1263), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(2434), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
    ACTIONS(2426), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [49887] = 9,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    STATE(1847), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2440), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    STATE(1263), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(2438), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
    ACTIONS(2426), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [49950] = 6,
    ACTIONS(1941), 1,
      anon_sym_COLON,
    ACTIONS(2442), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1853), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1849), 34,
      anon_sym_LBRACE,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPdeprecated,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [50006] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1958), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    STATE(1264), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(1956), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
    ACTIONS(2426), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [50066] = 8,
    ACTIONS(2444), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1945), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    STATE(1264), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1947), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(1943), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
    ACTIONS(2447), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [50126] = 5,
    ACTIONS(2450), 1,
      sym_time_unit,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1877), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1875), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50178] = 5,
    ACTIONS(2450), 1,
      sym_time_unit,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1877), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1875), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50230] = 5,
    ACTIONS(2452), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1839), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1837), 25,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50281] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(629), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(627), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50330] = 5,
    ACTIONS(2454), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1847), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1843), 25,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50381] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1877), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1875), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50430] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1935), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50479] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50528] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1889), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1885), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50577] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1935), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50626] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(155), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(149), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50675] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1873), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1871), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50724] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1905), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1903), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50773] = 8,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 21,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50830] = 5,
    ACTIONS(2462), 1,
      anon_sym_SLASH,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1877), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1875), 25,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50881] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(350), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(348), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50930] = 5,
    ACTIONS(2464), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1853), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1849), 25,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [50981] = 5,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1889), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1885), 25,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51032] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1935), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51081] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1857), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1855), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51130] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1839), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1837), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51179] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1865), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1863), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51228] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1869), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1867), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51277] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1897), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1895), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51326] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(781), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(779), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51375] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1893), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1891), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51424] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51473] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(155), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(149), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51522] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(705), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(703), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51571] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1917), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1915), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51620] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1861), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1859), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51669] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1917), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1915), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51718] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1917), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1915), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51767] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51816] = 8,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(155), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(149), 21,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51873] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1929), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1927), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51922] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1883), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1881), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [51971] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(354), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(352), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [52020] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(785), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(783), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [52069] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [52118] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1901), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1899), 26,
      anon_sym_SEMI,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [52167] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(1935), 5,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [52243] = 9,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 17,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [52301] = 16,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1935), 7,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOLLAR,
  [52373] = 19,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2490), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2488), 4,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [52451] = 13,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 13,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [52517] = 14,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 11,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [52585] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(149), 5,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [52661] = 13,
    ACTIONS(1917), 1,
      anon_sym_EQ,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1915), 13,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [52727] = 19,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2490), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2103), 4,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_RBRACK,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [52805] = 9,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1935), 17,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [52863] = 16,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 7,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_LPAREN,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOLLAR,
  [52935] = 14,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 9,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [53001] = 5,
    ACTIONS(2506), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1839), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1837), 22,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [53049] = 16,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(127), 5,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [53119] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(149), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [53193] = 8,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(155), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(149), 18,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [53247] = 9,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 15,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [53303] = 8,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 18,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [53357] = 13,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 11,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [53421] = 20,
    ACTIONS(939), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2620), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [53499] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1935), 3,
      anon_sym_COLON,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [53573] = 20,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2860), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [53651] = 20,
    ACTIONS(865), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2333), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [53729] = 16,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(1935), 5,
      anon_sym_COLON,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [53799] = 9,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1935), 15,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_RBRACK,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [53855] = 13,
    ACTIONS(1917), 1,
      anon_sym_EQ,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1915), 11,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_RBRACK,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [53919] = 20,
    ACTIONS(891), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2394), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [53997] = 20,
    ACTIONS(2103), 1,
      anon_sym_RBRACK,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2490), 1,
      anon_sym_COMMA,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    ACTIONS(2516), 1,
      anon_sym_COLON,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54075] = 20,
    ACTIONS(2103), 1,
      anon_sym_RBRACK,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2490), 1,
      anon_sym_COMMA,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    ACTIONS(2518), 1,
      anon_sym_COLON,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54153] = 20,
    ACTIONS(2103), 1,
      anon_sym_RBRACE,
    ACTIONS(2153), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2490), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54231] = 20,
    ACTIONS(915), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2493), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54309] = 20,
    ACTIONS(963), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2681), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54387] = 20,
    ACTIONS(983), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2375), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54465] = 20,
    ACTIONS(899), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2605), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54543] = 20,
    ACTIONS(923), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2277), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54621] = 20,
    ACTIONS(2103), 1,
      anon_sym_RBRACK,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2490), 1,
      anon_sym_COMMA,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    ACTIONS(2520), 1,
      anon_sym_COLON,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54699] = 20,
    ACTIONS(907), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2474), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54777] = 20,
    ACTIONS(971), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2257), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54855] = 20,
    ACTIONS(987), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2514), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    STATE(2255), 1,
      sym_assert_msg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [54933] = 19,
    ACTIONS(2103), 1,
      anon_sym_COLON,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2490), 1,
      anon_sym_COMMA,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55008] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1847), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1843), 22,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [55053] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1923), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55126] = 6,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2522), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1889), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1885), 20,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_RPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [55175] = 19,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2488), 1,
      anon_sym_COLON,
    ACTIONS(2490), 1,
      anon_sym_COMMA,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55250] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1853), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1849), 22,
      anon_sym_COLON,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_COMMA,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_RBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [55295] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2524), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55367] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2526), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55439] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2528), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55511] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2530), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55583] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2532), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55655] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2534), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55727] = 18,
    ACTIONS(2177), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55799] = 18,
    ACTIONS(865), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55871] = 18,
    ACTIONS(1711), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [55943] = 18,
    ACTIONS(1655), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56015] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2536), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56087] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2538), 1,
      anon_sym_LBRACE,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56159] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2558), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56231] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2560), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56303] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2562), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56375] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2564), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56447] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2566), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56519] = 16,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(127), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56587] = 9,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(129), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(127), 13,
      anon_sym_LBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [56641] = 13,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 9,
      anon_sym_LBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [56703] = 14,
    ACTIONS(129), 1,
      anon_sym_EQ,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(127), 7,
      anon_sym_LBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [56767] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2568), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56839] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2570), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56911] = 18,
    ACTIONS(1935), 1,
      anon_sym_LBRACE,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [56983] = 16,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1935), 3,
      anon_sym_LBRACE,
      anon_sym_LPAREN,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57051] = 9,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(1937), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1935), 13,
      anon_sym_LBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [57105] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2572), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57177] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2574), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57249] = 13,
    ACTIONS(1917), 1,
      anon_sym_EQ,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
    ACTIONS(1915), 9,
      anon_sym_LBRACE,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_LPAREN,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [57311] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2576), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57383] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2578), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57455] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2580), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57527] = 18,
    ACTIONS(1755), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57599] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2582), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57671] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2584), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57743] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2586), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57815] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2588), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57887] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2590), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [57959] = 18,
    ACTIONS(2193), 1,
      anon_sym_RBRACK,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58031] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2592), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58103] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2594), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58175] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2596), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58247] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2598), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58319] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2600), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58391] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2602), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58463] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2604), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58535] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2606), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58607] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2608), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58679] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2610), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58751] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2612), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58823] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2614), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58895] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2616), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [58967] = 6,
    ACTIONS(2618), 1,
      anon_sym_LPAREN,
    STATE(1260), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1889), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1885), 19,
      anon_sym_SEMI,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [59015] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2620), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59087] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2622), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59159] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2624), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59231] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2626), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59303] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2628), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59375] = 18,
    ACTIONS(2153), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59447] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2630), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59519] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2632), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59591] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2634), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59663] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2636), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59735] = 18,
    ACTIONS(2169), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59807] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2638), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59879] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2640), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [59951] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2642), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60023] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2644), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60095] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2646), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60167] = 18,
    ACTIONS(983), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60239] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2648), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60311] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2650), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60383] = 18,
    ACTIONS(891), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60455] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2652), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60527] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2654), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60599] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2656), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60671] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2658), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60743] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2660), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60815] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2662), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60887] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2664), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [60959] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2666), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61031] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2668), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61103] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2670), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61175] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2672), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61247] = 18,
    ACTIONS(2187), 1,
      anon_sym_RBRACK,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61319] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2674), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61391] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2676), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61463] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2678), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61535] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2680), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61607] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2682), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61679] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2684), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61751] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2686), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61823] = 18,
    ACTIONS(1807), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61895] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    ACTIONS(2688), 1,
      anon_sym_COLON,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [61967] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2690), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62039] = 18,
    ACTIONS(1721), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62111] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2692), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62183] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2694), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62255] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2696), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62327] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2698), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62399] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2700), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62471] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2702), 1,
      anon_sym_RBRACK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62543] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2704), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62615] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2706), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62687] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2708), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62759] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2710), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62831] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2712), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62903] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2714), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [62975] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2716), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63047] = 18,
    ACTIONS(1497), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63119] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2718), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63191] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2720), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63263] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2722), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63335] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2724), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63407] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2726), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63479] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2728), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63551] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2730), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63623] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2732), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63695] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2734), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63767] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2736), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63839] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2738), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63911] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2740), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [63983] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2742), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64055] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2744), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64127] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2746), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64199] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2748), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64271] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2750), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64343] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2752), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64415] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2754), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64487] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2756), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64559] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2758), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64631] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2760), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64703] = 18,
    ACTIONS(2161), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64775] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2762), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64847] = 18,
    ACTIONS(923), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64919] = 18,
    ACTIONS(149), 1,
      anon_sym_LBRACE,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [64991] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2764), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65063] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2766), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65135] = 18,
    ACTIONS(2157), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65207] = 18,
    ACTIONS(915), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65279] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2768), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65351] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    ACTIONS(2770), 1,
      anon_sym_COLON,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65423] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2772), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65495] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2774), 1,
      anon_sym_RBRACK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65567] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2776), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65639] = 18,
    ACTIONS(1731), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65711] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2778), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65783] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    ACTIONS(2780), 1,
      anon_sym_COLON,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65855] = 18,
    ACTIONS(2195), 1,
      anon_sym_RBRACK,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65927] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2782), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [65999] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2784), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66071] = 18,
    ACTIONS(1821), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66143] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2786), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66215] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2788), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66287] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2790), 1,
      anon_sym_RBRACK,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66359] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2792), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66431] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2794), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66503] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2796), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66575] = 18,
    ACTIONS(2149), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66647] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2798), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66719] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    ACTIONS(2800), 1,
      anon_sym_COLON,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66791] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2802), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66863] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2804), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [66935] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2806), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67007] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2808), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67079] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2810), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67151] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2812), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67223] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2814), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67295] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2816), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67367] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2818), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67439] = 18,
    ACTIONS(2165), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67511] = 18,
    ACTIONS(987), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67583] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2820), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67655] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    ACTIONS(2822), 1,
      anon_sym_COLON,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67727] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2824), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67799] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2826), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67871] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2828), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [67943] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2544), 1,
      anon_sym_EQ,
    ACTIONS(2548), 1,
      anon_sym_BANG,
    ACTIONS(2552), 1,
      anon_sym_QMARK,
    ACTIONS(2830), 1,
      anon_sym_LBRACE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2540), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2554), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2556), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2550), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2542), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2546), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68015] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2832), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68087] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2834), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68159] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2836), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68231] = 18,
    ACTIONS(2137), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68303] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2838), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68375] = 18,
    ACTIONS(939), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68447] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2840), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68519] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2842), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68591] = 18,
    ACTIONS(2173), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68663] = 18,
    ACTIONS(899), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68735] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2844), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68807] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2846), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68879] = 18,
    ACTIONS(1775), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [68951] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2848), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69023] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2490), 1,
      anon_sym_COMMA,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69095] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2850), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69167] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2852), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69239] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2854), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69311] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2856), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69383] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2858), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69455] = 18,
    ACTIONS(907), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69527] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2860), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69599] = 18,
    ACTIONS(1733), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69671] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2862), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69743] = 18,
    ACTIONS(2141), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69815] = 18,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69887] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2864), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [69959] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2866), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70031] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2868), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70103] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2870), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70175] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2872), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70247] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2874), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70319] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2876), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70391] = 18,
    ACTIONS(1767), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70463] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2878), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70535] = 18,
    ACTIONS(1769), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70607] = 18,
    ACTIONS(2145), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70679] = 18,
    ACTIONS(963), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70751] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2880), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70823] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2882), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70895] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2884), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [70967] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2886), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71039] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2888), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71111] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2890), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71183] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2892), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71255] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2894), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71327] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2896), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71399] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2898), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71471] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2900), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71543] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2902), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71615] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2904), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71687] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2906), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71759] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2908), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71831] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2910), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71903] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2912), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [71975] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2914), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72047] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2916), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72119] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2918), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72191] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2920), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72263] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2922), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72335] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2924), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72407] = 18,
    ACTIONS(1687), 1,
      anon_sym_RPAREN,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72479] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2498), 1,
      anon_sym_BANG,
    ACTIONS(2502), 1,
      anon_sym_QMARK,
    ACTIONS(2510), 1,
      anon_sym_EQ,
    ACTIONS(2926), 1,
      anon_sym_COLON,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2494), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2504), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2508), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2512), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2500), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2492), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2496), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72551] = 18,
    ACTIONS(2131), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72623] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2928), 1,
      anon_sym_SEMI,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72695] = 18,
    ACTIONS(971), 1,
      anon_sym_SEMI,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72767] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2930), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72839] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2932), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72911] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2934), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [72983] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2936), 1,
      anon_sym_RPAREN,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [73055] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    STATE(1961), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2938), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [73106] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2940), 1,
      anon_sym_PIPE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 5,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [73177] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2468), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2942), 1,
      anon_sym_DASH_EQ,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [73248] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2944), 1,
      anon_sym_PIPE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 5,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [73319] = 7,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1605), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1956), 4,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [73368] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2468), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2946), 1,
      anon_sym_DASH_EQ,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 6,
      anon_sym_PIPE,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [73439] = 7,
    ACTIONS(2444), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1605), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1943), 4,
      anon_sym_SEMI,
      anon_sym_RBRACE,
      anon_sym_RPAREN,
      anon_sym_COMMA,
    ACTIONS(1947), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(2948), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [73488] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2951), 1,
      anon_sym_PIPE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 5,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [73559] = 18,
    ACTIONS(2456), 1,
      anon_sym_LBRACK,
    ACTIONS(2460), 1,
      anon_sym_DOLLAR,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2472), 1,
      anon_sym_EQ,
    ACTIONS(2476), 1,
      anon_sym_BANG,
    ACTIONS(2480), 1,
      anon_sym_QMARK,
    ACTIONS(2486), 1,
      anon_sym_QMARK_DOLLAR,
    ACTIONS(2953), 1,
      anon_sym_PIPE,
    STATE(1292), 1,
      sym_index_slice,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2458), 2,
      anon_sym_as,
      anon_sym_is,
    ACTIONS(2468), 2,
      anon_sym_PLUS_EQ,
      anon_sym_DASH_EQ,
    ACTIONS(2482), 2,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
    ACTIONS(2484), 2,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2478), 3,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
    ACTIONS(2470), 4,
      anon_sym_in,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
    ACTIONS(2474), 5,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
  [73630] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1611), 1,
      aux_sym__simple_type_repeat1,
    STATE(2067), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [73698] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2077), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [73766] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1618), 1,
      aux_sym__simple_type_repeat1,
    STATE(2010), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [73834] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2016), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [73902] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1635), 1,
      aux_sym__simple_type_repeat1,
    STATE(2128), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [73970] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2129), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74038] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2083), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74106] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1616), 1,
      aux_sym__simple_type_repeat1,
    STATE(2159), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74174] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2164), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74242] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1639), 1,
      aux_sym__simple_type_repeat1,
    STATE(2047), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74310] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2044), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74378] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1613), 1,
      aux_sym__simple_type_repeat1,
    STATE(2123), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74446] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1625), 1,
      aux_sym__simple_type_repeat1,
    STATE(2040), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74514] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1622), 1,
      aux_sym__simple_type_repeat1,
    STATE(1983), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74582] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(1986), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74650] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1636), 1,
      aux_sym__simple_type_repeat1,
    STATE(2054), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74718] = 6,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2971), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1889), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1885), 17,
      anon_sym_DASH_EQ,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [74764] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2043), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74832] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1609), 1,
      aux_sym__simple_type_repeat1,
    STATE(2056), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74900] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2071), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [74968] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1629), 1,
      aux_sym__simple_type_repeat1,
    STATE(2061), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75036] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2062), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75104] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1632), 1,
      aux_sym__simple_type_repeat1,
    STATE(2113), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75172] = 6,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2974), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1889), 9,
      anon_sym_EQ,
      anon_sym_PIPE,
      anon_sym_BANG,
      anon_sym_DASH,
      anon_sym_PLUS,
      anon_sym_LT,
      anon_sym_GT,
      anon_sym_AMP,
      anon_sym_QMARK,
    ACTIONS(1885), 17,
      anon_sym_DASH_EQ,
      anon_sym_in,
      anon_sym_LBRACK,
      anon_sym_as,
      anon_sym_DOLLAR,
      anon_sym_is,
      anon_sym_STAR,
      anon_sym_SLASH,
      anon_sym_PERCENT,
      anon_sym_LT_EQ,
      anon_sym_GT_EQ,
      anon_sym_CARET,
      anon_sym_EQ_EQ,
      anon_sym_BANG_EQ,
      anon_sym_AMP_AMP,
      anon_sym_PIPE_PIPE,
      anon_sym_QMARK_DOLLAR,
  [75218] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2116), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75286] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1614), 1,
      aux_sym__simple_type_repeat1,
    STATE(2184), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75354] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1637), 1,
      aux_sym__simple_type_repeat1,
    STATE(1993), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75422] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2080), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75490] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2076), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75558] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(1994), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75626] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1627), 1,
      aux_sym__simple_type_repeat1,
    STATE(2127), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75694] = 17,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2000), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75762] = 17,
    ACTIONS(2977), 1,
      anon_sym_enum,
    ACTIONS(2980), 1,
      anon_sym_record,
    ACTIONS(2986), 1,
      anon_sym_function,
    ACTIONS(2995), 1,
      anon_sym_opaque,
    ACTIONS(2998), 1,
      anon_sym_set,
    ACTIONS(3001), 1,
      anon_sym_table,
    ACTIONS(3004), 1,
      anon_sym_union,
    ACTIONS(3007), 1,
      anon_sym_vector,
    ACTIONS(3010), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1640), 1,
      aux_sym__simple_type_repeat1,
    STATE(2799), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2983), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2992), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2989), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75830] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3013), 1,
      anon_sym_function,
    ACTIONS(3015), 1,
      anon_sym_table,
    ACTIONS(3017), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1287), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75895] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3019), 1,
      anon_sym_function,
    ACTIONS(3021), 1,
      anon_sym_table,
    ACTIONS(3023), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1287), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [75960] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3025), 1,
      anon_sym_SEMI,
    STATE(2700), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [76009] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3027), 1,
      anon_sym_SEMI,
    STATE(2887), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [76058] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2582), 1,
      anon_sym_SEMI,
    STATE(2343), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [76107] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3019), 1,
      anon_sym_function,
    ACTIONS(3021), 1,
      anon_sym_table,
    ACTIONS(3023), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1276), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76172] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3029), 1,
      anon_sym_SEMI,
    STATE(2281), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [76221] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(37), 1,
      sym_type,
    STATE(80), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76286] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3019), 1,
      anon_sym_function,
    ACTIONS(3021), 1,
      anon_sym_table,
    ACTIONS(3023), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1284), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76351] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3059), 1,
      anon_sym_function,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3063), 1,
      anon_sym_table,
    ACTIONS(3065), 1,
      anon_sym_vector,
    ACTIONS(3067), 1,
      sym_id,
    STATE(772), 1,
      sym__simple_type,
    STATE(801), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3057), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76416] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3059), 1,
      anon_sym_function,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3063), 1,
      anon_sym_table,
    ACTIONS(3065), 1,
      anon_sym_vector,
    ACTIONS(3067), 1,
      sym_id,
    STATE(772), 1,
      sym__simple_type,
    STATE(813), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3057), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76481] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3019), 1,
      anon_sym_function,
    ACTIONS(3021), 1,
      anon_sym_table,
    ACTIONS(3023), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1291), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76546] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3069), 1,
      anon_sym_SEMI,
    STATE(2269), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [76595] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(192), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76660] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3071), 1,
      anon_sym_function,
    ACTIONS(3075), 1,
      anon_sym_table,
    ACTIONS(3077), 1,
      anon_sym_vector,
    STATE(80), 1,
      sym__simple_type,
    STATE(764), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3073), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76725] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(194), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76790] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(219), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76855] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3067), 1,
      sym_id,
    ACTIONS(3079), 1,
      anon_sym_function,
    ACTIONS(3081), 1,
      anon_sym_table,
    ACTIONS(3083), 1,
      anon_sym_vector,
    STATE(772), 1,
      sym__simple_type,
    STATE(801), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3057), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76920] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3067), 1,
      sym_id,
    ACTIONS(3079), 1,
      anon_sym_function,
    ACTIONS(3081), 1,
      anon_sym_table,
    ACTIONS(3083), 1,
      anon_sym_vector,
    STATE(772), 1,
      sym__simple_type,
    STATE(774), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3057), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [76985] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(760), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [77050] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3085), 1,
      anon_sym_function,
    ACTIONS(3089), 1,
      anon_sym_table,
    ACTIONS(3091), 1,
      anon_sym_vector,
    STATE(80), 1,
      sym__simple_type,
    STATE(782), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3087), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [77115] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2778), 1,
      anon_sym_SEMI,
    STATE(2508), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77164] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3093), 1,
      anon_sym_SEMI,
    STATE(2347), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77213] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3085), 1,
      anon_sym_function,
    ACTIONS(3089), 1,
      anon_sym_table,
    ACTIONS(3091), 1,
      anon_sym_vector,
    STATE(80), 1,
      sym__simple_type,
    STATE(1741), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3087), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [77278] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3095), 1,
      anon_sym_SEMI,
    STATE(2518), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77327] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3059), 1,
      anon_sym_function,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3063), 1,
      anon_sym_table,
    ACTIONS(3065), 1,
      anon_sym_vector,
    ACTIONS(3067), 1,
      sym_id,
    STATE(772), 1,
      sym__simple_type,
    STATE(796), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3057), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [77392] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3097), 1,
      anon_sym_SEMI,
    STATE(2838), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77441] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2786), 1,
      anon_sym_SEMI,
    STATE(2709), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77490] = 8,
    ACTIONS(3101), 1,
      anon_sym_EQ,
    ACTIONS(3103), 1,
      anon_sym_AMPdeprecated,
    STATE(2006), 1,
      sym_attr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3099), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(3105), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77539] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3107), 1,
      anon_sym_SEMI,
    STATE(2475), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77588] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3109), 1,
      anon_sym_SEMI,
    STATE(2535), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77637] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3111), 1,
      anon_sym_SEMI,
    STATE(2360), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77686] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3113), 1,
      anon_sym_SEMI,
    STATE(2296), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77735] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3115), 1,
      anon_sym_SEMI,
    STATE(2361), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77784] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3117), 1,
      anon_sym_SEMI,
    STATE(2537), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77833] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3119), 1,
      anon_sym_SEMI,
    STATE(2332), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [77882] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(204), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [77947] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3067), 1,
      sym_id,
    ACTIONS(3079), 1,
      anon_sym_function,
    ACTIONS(3081), 1,
      anon_sym_table,
    ACTIONS(3083), 1,
      anon_sym_vector,
    STATE(772), 1,
      sym__simple_type,
    STATE(782), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3057), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78012] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3121), 1,
      anon_sym_function,
    ACTIONS(3125), 1,
      anon_sym_table,
    ACTIONS(3127), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1302), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3123), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78077] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3071), 1,
      anon_sym_function,
    ACTIONS(3075), 1,
      anon_sym_table,
    ACTIONS(3077), 1,
      anon_sym_vector,
    STATE(37), 1,
      sym_type,
    STATE(80), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3073), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78142] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(206), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78207] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3129), 1,
      anon_sym_SEMI,
    STATE(2391), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [78256] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3067), 1,
      sym_id,
    ACTIONS(3079), 1,
      anon_sym_function,
    ACTIONS(3081), 1,
      anon_sym_table,
    ACTIONS(3083), 1,
      anon_sym_vector,
    STATE(772), 1,
      sym__simple_type,
    STATE(796), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2228), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3057), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78321] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3131), 1,
      anon_sym_SEMI,
    STATE(2280), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [78370] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3121), 1,
      anon_sym_function,
    ACTIONS(3125), 1,
      anon_sym_table,
    ACTIONS(3127), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1287), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3123), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78435] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3121), 1,
      anon_sym_function,
    ACTIONS(3125), 1,
      anon_sym_table,
    ACTIONS(3127), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1276), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3123), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78500] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3121), 1,
      anon_sym_function,
    ACTIONS(3125), 1,
      anon_sym_table,
    ACTIONS(3127), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1284), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3123), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78565] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3133), 1,
      anon_sym_SEMI,
    STATE(2591), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [78614] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3121), 1,
      anon_sym_function,
    ACTIONS(3125), 1,
      anon_sym_table,
    ACTIONS(3127), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1280), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3123), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78679] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3085), 1,
      anon_sym_function,
    ACTIONS(3089), 1,
      anon_sym_table,
    ACTIONS(3091), 1,
      anon_sym_vector,
    STATE(80), 1,
      sym__simple_type,
    STATE(1696), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3087), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78744] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3135), 1,
      anon_sym_SEMI,
    STATE(2613), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [78793] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(150), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78858] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(161), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [78923] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3137), 1,
      anon_sym_SEMI,
    STATE(2437), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [78972] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3139), 1,
      anon_sym_SEMI,
    STATE(2439), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [79021] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3141), 1,
      anon_sym_SEMI,
    STATE(2840), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [79070] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3143), 1,
      anon_sym_SEMI,
    STATE(2444), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [79119] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(151), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [79184] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(216), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [79249] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2772), 1,
      anon_sym_SEMI,
    STATE(2267), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [79298] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(217), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [79363] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3059), 1,
      anon_sym_function,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3063), 1,
      anon_sym_table,
    ACTIONS(3065), 1,
      anon_sym_vector,
    ACTIONS(3067), 1,
      sym_id,
    STATE(772), 1,
      sym__simple_type,
    STATE(774), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3057), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [79428] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(152), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [79493] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2828), 1,
      anon_sym_SEMI,
    STATE(2349), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [79542] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2524), 1,
      anon_sym_SEMI,
    STATE(2473), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [79591] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3085), 1,
      anon_sym_function,
    ACTIONS(3089), 1,
      anon_sym_table,
    ACTIONS(3091), 1,
      anon_sym_vector,
    STATE(80), 1,
      sym__simple_type,
    STATE(1728), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3087), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [79656] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3145), 1,
      anon_sym_SEMI,
    STATE(2378), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [79705] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3147), 1,
      anon_sym_SEMI,
    STATE(2870), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [79754] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3013), 1,
      anon_sym_function,
    ACTIONS(3015), 1,
      anon_sym_table,
    ACTIONS(3017), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1276), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [79819] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(154), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [79884] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3149), 1,
      anon_sym_SEMI,
    STATE(2421), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [79933] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3151), 1,
      anon_sym_SEMI,
    STATE(2422), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [79982] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3071), 1,
      anon_sym_function,
    ACTIONS(3075), 1,
      anon_sym_table,
    ACTIONS(3077), 1,
      anon_sym_vector,
    STATE(80), 1,
      sym__simple_type,
    STATE(765), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3073), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [80047] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(143), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [80112] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2694), 1,
      anon_sym_SEMI,
    STATE(2420), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [80161] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3153), 1,
      anon_sym_SEMI,
    STATE(2881), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [80210] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3155), 1,
      anon_sym_SEMI,
    STATE(2513), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [80259] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(168), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [80324] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(188), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [80389] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(145), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [80454] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(225), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [80519] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(226), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [80584] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3157), 1,
      anon_sym_SEMI,
    STATE(2653), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [80633] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3159), 1,
      anon_sym_SEMI,
    STATE(2651), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [80682] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3085), 1,
      anon_sym_function,
    ACTIONS(3089), 1,
      anon_sym_table,
    ACTIONS(3091), 1,
      anon_sym_vector,
    STATE(80), 1,
      sym__simple_type,
    STATE(796), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3087), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [80747] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2848), 1,
      anon_sym_SEMI,
    STATE(2671), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [80796] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3059), 1,
      anon_sym_function,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3063), 1,
      anon_sym_table,
    ACTIONS(3065), 1,
      anon_sym_vector,
    ACTIONS(3067), 1,
      sym_id,
    STATE(772), 1,
      sym__simple_type,
    STATE(784), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3057), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [80861] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3161), 1,
      anon_sym_SEMI,
    STATE(2550), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [80910] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3163), 1,
      anon_sym_SEMI,
    STATE(2727), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [80959] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3085), 1,
      anon_sym_function,
    ACTIONS(3089), 1,
      anon_sym_table,
    ACTIONS(3091), 1,
      anon_sym_vector,
    STATE(37), 1,
      sym_type,
    STATE(80), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3087), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [81024] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(170), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [81089] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3165), 1,
      anon_sym_SEMI,
    STATE(2746), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [81138] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3167), 1,
      anon_sym_SEMI,
    STATE(2755), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [81187] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3169), 1,
      anon_sym_SEMI,
    STATE(2427), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [81236] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3171), 1,
      anon_sym_SEMI,
    STATE(2769), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [81285] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3013), 1,
      anon_sym_function,
    ACTIONS(3015), 1,
      anon_sym_table,
    ACTIONS(3017), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1284), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [81350] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2862), 1,
      anon_sym_SEMI,
    STATE(2632), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [81399] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3013), 1,
      anon_sym_function,
    ACTIONS(3015), 1,
      anon_sym_table,
    ACTIONS(3017), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1302), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [81464] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2810), 1,
      anon_sym_SEMI,
    STATE(2350), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [81513] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3173), 1,
      anon_sym_SEMI,
    STATE(2636), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [81562] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3175), 1,
      anon_sym_SEMI,
    STATE(2424), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [81611] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(234), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [81676] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(37), 1,
      sym_type,
    STATE(1268), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [81741] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3085), 1,
      anon_sym_function,
    ACTIONS(3089), 1,
      anon_sym_table,
    ACTIONS(3091), 1,
      anon_sym_vector,
    STATE(80), 1,
      sym__simple_type,
    STATE(1599), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3087), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [81806] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(235), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [81871] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3177), 1,
      anon_sym_SEMI,
    STATE(2609), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [81920] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3179), 1,
      anon_sym_SEMI,
    STATE(2646), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [81969] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3181), 1,
      anon_sym_SEMI,
    STATE(2647), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [82018] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3183), 1,
      anon_sym_SEMI,
    STATE(2618), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [82067] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3185), 1,
      anon_sym_SEMI,
    STATE(2619), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [82116] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3013), 1,
      anon_sym_function,
    ACTIONS(3015), 1,
      anon_sym_table,
    ACTIONS(3017), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1291), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [82181] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3019), 1,
      anon_sym_function,
    ACTIONS(3021), 1,
      anon_sym_table,
    ACTIONS(3023), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1958), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [82246] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2882), 1,
      anon_sym_SEMI,
    STATE(2878), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [82295] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3187), 1,
      anon_sym_SEMI,
    STATE(2252), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [82344] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3189), 1,
      anon_sym_SEMI,
    STATE(2623), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [82393] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3071), 1,
      anon_sym_function,
    ACTIONS(3075), 1,
      anon_sym_table,
    ACTIONS(3077), 1,
      anon_sym_vector,
    STATE(36), 1,
      sym_type,
    STATE(80), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3073), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [82458] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3191), 1,
      anon_sym_SEMI,
    STATE(2699), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [82507] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(156), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [82572] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(764), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [82637] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3193), 1,
      anon_sym_SEMI,
    STATE(2577), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [82686] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3195), 1,
      anon_sym_SEMI,
    STATE(2626), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [82735] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(36), 1,
      sym_type,
    STATE(1268), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [82800] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(765), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [82865] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(243), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [82930] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(244), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [82995] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3013), 1,
      anon_sym_function,
    ACTIONS(3015), 1,
      anon_sym_table,
    ACTIONS(3017), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1280), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(65), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [83060] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3197), 1,
      anon_sym_SEMI,
    STATE(2728), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [83109] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1287), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [83174] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3199), 1,
      anon_sym_SEMI,
    STATE(2882), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [83223] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3201), 1,
      anon_sym_SEMI,
    STATE(2765), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [83272] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3019), 1,
      anon_sym_function,
    ACTIONS(3021), 1,
      anon_sym_table,
    ACTIONS(3023), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1950), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2089), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [83337] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2969), 1,
      sym_id,
    ACTIONS(3121), 1,
      anon_sym_function,
    ACTIONS(3125), 1,
      anon_sym_table,
    ACTIONS(3127), 1,
      anon_sym_vector,
    STATE(1268), 1,
      sym__simple_type,
    STATE(2015), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3123), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [83402] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3059), 1,
      anon_sym_function,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3063), 1,
      anon_sym_table,
    ACTIONS(3065), 1,
      anon_sym_vector,
    ACTIONS(3067), 1,
      sym_id,
    STATE(772), 1,
      sym__simple_type,
    STATE(782), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(811), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3057), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [83467] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3203), 1,
      anon_sym_SEMI,
    STATE(2638), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [83516] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3205), 1,
      anon_sym_SEMI,
    STATE(2649), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [83565] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1276), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [83630] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3207), 1,
      anon_sym_SEMI,
    STATE(2654), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [83679] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3209), 1,
      anon_sym_SEMI,
    STATE(2655), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [83728] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(148), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [83793] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(252), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [83858] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(253), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [83923] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3211), 1,
      anon_sym_SEMI,
    STATE(2905), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [83972] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3213), 1,
      anon_sym_SEMI,
    STATE(2216), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [84021] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(180), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84086] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(169), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84151] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(182), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84216] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(36), 1,
      sym_type,
    STATE(80), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84281] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(2928), 1,
      anon_sym_SEMI,
    STATE(2689), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [84330] = 16,
    ACTIONS(25), 1,
      anon_sym_enum,
    ACTIONS(67), 1,
      anon_sym_opaque,
    ACTIONS(73), 1,
      anon_sym_union,
    ACTIONS(2955), 1,
      anon_sym_record,
    ACTIONS(2959), 1,
      anon_sym_function,
    ACTIONS(2963), 1,
      anon_sym_set,
    ACTIONS(2965), 1,
      anon_sym_table,
    ACTIONS(2967), 1,
      anon_sym_vector,
    ACTIONS(2969), 1,
      sym_id,
    STATE(1268), 1,
      sym__simple_type,
    STATE(1284), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2957), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(2961), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(63), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84395] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3085), 1,
      anon_sym_function,
    ACTIONS(3089), 1,
      anon_sym_table,
    ACTIONS(3091), 1,
      anon_sym_vector,
    STATE(36), 1,
      sym_type,
    STATE(80), 1,
      sym__simple_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3087), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84460] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3215), 1,
      anon_sym_SEMI,
    STATE(2434), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [84509] = 16,
    ACTIONS(793), 1,
      anon_sym_enum,
    ACTIONS(813), 1,
      anon_sym_opaque,
    ACTIONS(819), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3055), 1,
      anon_sym_record,
    ACTIONS(3061), 1,
      anon_sym_set,
    ACTIONS(3085), 1,
      anon_sym_function,
    ACTIONS(3089), 1,
      anon_sym_table,
    ACTIONS(3091), 1,
      anon_sym_vector,
    STATE(80), 1,
      sym__simple_type,
    STATE(801), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3087), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(809), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84574] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3217), 1,
      anon_sym_SEMI,
    STATE(2435), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [84623] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3219), 1,
      anon_sym_SEMI,
    STATE(2691), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [84672] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(158), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84737] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3053), 1,
      sym_id,
    ACTIONS(3071), 1,
      anon_sym_function,
    ACTIONS(3075), 1,
      anon_sym_table,
    ACTIONS(3077), 1,
      anon_sym_vector,
    STATE(80), 1,
      sym__simple_type,
    STATE(760), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3073), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84802] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(260), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84867] = 16,
    ACTIONS(3031), 1,
      anon_sym_enum,
    ACTIONS(3033), 1,
      anon_sym_record,
    ACTIONS(3037), 1,
      anon_sym_function,
    ACTIONS(3043), 1,
      anon_sym_opaque,
    ACTIONS(3045), 1,
      anon_sym_set,
    ACTIONS(3047), 1,
      anon_sym_table,
    ACTIONS(3049), 1,
      anon_sym_union,
    ACTIONS(3051), 1,
      anon_sym_vector,
    ACTIONS(3053), 1,
      sym_id,
    STATE(80), 1,
      sym__simple_type,
    STATE(261), 1,
      sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3035), 2,
      anon_sym_event,
      anon_sym_hook,
    ACTIONS(3041), 2,
      anon_sym_file,
      anon_sym_list,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3039), 12,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
  [84932] = 8,
    ACTIONS(825), 1,
      anon_sym_AMPdeprecated,
    ACTIONS(3221), 1,
      anon_sym_SEMI,
    STATE(2760), 1,
      sym_attr_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1603), 2,
      sym_attr,
      aux_sym_attr_list_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(827), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [84981] = 7,
    ACTIONS(3103), 1,
      anon_sym_AMPdeprecated,
    STATE(2134), 1,
      sym_attr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3223), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(823), 9,
      anon_sym_AMPbroker_allow_complex_type,
      anon_sym_AMPerror_handler,
      anon_sym_AMPis_assigned,
      anon_sym_AMPis_used,
      anon_sym_AMPlog,
      anon_sym_AMPoptional,
      anon_sym_AMPordered,
      anon_sym_AMPraw_output,
      anon_sym_AMPredef,
    ACTIONS(3105), 13,
      anon_sym_AMPadd_func,
      anon_sym_AMPbackend,
      anon_sym_AMPbroker_store,
      anon_sym_AMPcreate_expire,
      anon_sym_AMPdefault,
      anon_sym_AMPdelete_func,
      anon_sym_AMPexpire_func,
      anon_sym_AMPgroup,
      anon_sym_AMPon_change,
      anon_sym_AMPpriority,
      anon_sym_AMPread_expire,
      anon_sym_AMPtype_column,
      anon_sym_AMPwrite_expire,
  [85027] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3225), 25,
      anon_sym_enum,
      anon_sym_record,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_addr,
      anon_sym_any,
      anon_sym_bool,
      anon_sym_count,
      anon_sym_double,
      anon_sym_file,
      anon_sym_int,
      anon_sym_interval,
      anon_sym_list,
      anon_sym_pattern,
      anon_sym_port,
      anon_sym_string,
      anon_sym_subnet,
      anon_sym_time,
      anon_sym_opaque,
      anon_sym_set,
      anon_sym_table,
      anon_sym_union,
      anon_sym_vector,
      sym_id,
  [85064] = 5,
    ACTIONS(3227), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1501), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1499), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85104] = 5,
    ACTIONS(2826), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1495), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1493), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85144] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1583), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1581), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85181] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1651), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1649), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85218] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1495), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1493), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85255] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1571), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1569), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85292] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1563), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1561), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85329] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1527), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1525), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85366] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1501), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1499), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85403] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1643), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1641), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85440] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1599), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1597), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85477] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1575), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1573), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85514] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1647), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1645), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85551] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1603), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1601), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85588] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1595), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1593), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85625] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1587), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1585), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85662] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1635), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1633), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85699] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1519), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1517), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85736] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1579), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1577), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85773] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1523), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1521), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85810] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1531), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1529), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85847] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1547), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1545), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85884] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1607), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1605), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85921] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1619), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1617), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85958] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1555), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1553), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [85995] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1535), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1533), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86032] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1551), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1549), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86069] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1539), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1537), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86106] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1611), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1609), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86143] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1631), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1629), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86180] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1559), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1557), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86217] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1543), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1541), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86254] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1615), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1613), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86291] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1623), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1621), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86328] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1639), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1637), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86365] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1511), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1509), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86402] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1567), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1565), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86439] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1591), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1589), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86476] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1627), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1625), 21,
      anon_sym_module,
      anon_sym_export,
      anon_sym_RBRACE,
      anon_sym_global,
      anon_sym_option,
      anon_sym_const,
      anon_sym_redef,
      anon_sym_type,
      anon_sym_event,
      anon_sym_function,
      anon_sym_hook,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86513] = 15,
    ACTIONS(93), 1,
      anon_sym_ATload,
    ACTIONS(97), 1,
      anon_sym_ATload_DASHplugin,
    ACTIONS(99), 1,
      anon_sym_ATprefixes,
    ACTIONS(101), 1,
      anon_sym_ATif,
    ACTIONS(107), 1,
      anon_sym_ATpragma,
    ACTIONS(3229), 1,
      anon_sym_LBRACE,
    ACTIONS(3231), 1,
      anon_sym_ATdeprecated,
    STATE(296), 1,
      sym_pragma,
    STATE(1831), 1,
      sym_func_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(95), 2,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATunload,
    ACTIONS(103), 2,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
    ACTIONS(105), 2,
      anon_sym_ATendif,
      anon_sym_ATelse,
    STATE(1846), 2,
      sym_preproc_directive,
      aux_sym_func_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [86566] = 15,
    ACTIONS(93), 1,
      anon_sym_ATload,
    ACTIONS(97), 1,
      anon_sym_ATload_DASHplugin,
    ACTIONS(99), 1,
      anon_sym_ATprefixes,
    ACTIONS(101), 1,
      anon_sym_ATif,
    ACTIONS(107), 1,
      anon_sym_ATpragma,
    ACTIONS(3231), 1,
      anon_sym_ATdeprecated,
    ACTIONS(3233), 1,
      anon_sym_LBRACE,
    STATE(296), 1,
      sym_pragma,
    STATE(324), 1,
      sym_func_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(95), 2,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATunload,
    ACTIONS(103), 2,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
    ACTIONS(105), 2,
      anon_sym_ATendif,
      anon_sym_ATelse,
    STATE(1846), 2,
      sym_preproc_directive,
      aux_sym_func_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [86619] = 15,
    ACTIONS(93), 1,
      anon_sym_ATload,
    ACTIONS(97), 1,
      anon_sym_ATload_DASHplugin,
    ACTIONS(99), 1,
      anon_sym_ATprefixes,
    ACTIONS(101), 1,
      anon_sym_ATif,
    ACTIONS(107), 1,
      anon_sym_ATpragma,
    ACTIONS(3229), 1,
      anon_sym_LBRACE,
    ACTIONS(3231), 1,
      anon_sym_ATdeprecated,
    STATE(296), 1,
      sym_pragma,
    STATE(1833), 1,
      sym_func_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(95), 2,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATunload,
    ACTIONS(103), 2,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
    ACTIONS(105), 2,
      anon_sym_ATendif,
      anon_sym_ATelse,
    STATE(1841), 2,
      sym_preproc_directive,
      aux_sym_func_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [86672] = 15,
    ACTIONS(93), 1,
      anon_sym_ATload,
    ACTIONS(97), 1,
      anon_sym_ATload_DASHplugin,
    ACTIONS(99), 1,
      anon_sym_ATprefixes,
    ACTIONS(101), 1,
      anon_sym_ATif,
    ACTIONS(107), 1,
      anon_sym_ATpragma,
    ACTIONS(3231), 1,
      anon_sym_ATdeprecated,
    ACTIONS(3233), 1,
      anon_sym_LBRACE,
    STATE(296), 1,
      sym_pragma,
    STATE(299), 1,
      sym_func_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(95), 2,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATunload,
    ACTIONS(103), 2,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
    ACTIONS(105), 2,
      anon_sym_ATendif,
      anon_sym_ATelse,
    STATE(1842), 2,
      sym_preproc_directive,
      aux_sym_func_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [86725] = 13,
    ACTIONS(849), 1,
      sym_ipv4,
    ACTIONS(851), 1,
      sym_ipv6,
    ACTIONS(853), 1,
      sym_port,
    ACTIONS(855), 1,
      sym_integer,
    ACTIONS(857), 1,
      sym_floatp,
    ACTIONS(3237), 1,
      aux_sym_string_token1,
    STATE(5), 1,
      sym_string_directive,
    STATE(1800), 1,
      sym_constant,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3235), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    STATE(769), 3,
      sym_subnet,
      sym_interval,
      sym_string,
    ACTIONS(841), 4,
      anon_sym_T,
      anon_sym_F,
      sym_hex,
      sym_hostname,
  [86774] = 14,
    ACTIONS(3239), 1,
      anon_sym_LBRACE,
    ACTIONS(3241), 1,
      anon_sym_ATdeprecated,
    ACTIONS(3244), 1,
      anon_sym_ATload,
    ACTIONS(3250), 1,
      anon_sym_ATload_DASHplugin,
    ACTIONS(3253), 1,
      anon_sym_ATprefixes,
    ACTIONS(3256), 1,
      anon_sym_ATif,
    ACTIONS(3265), 1,
      anon_sym_ATpragma,
    STATE(296), 1,
      sym_pragma,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3247), 2,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATunload,
    ACTIONS(3259), 2,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
    ACTIONS(3262), 2,
      anon_sym_ATendif,
      anon_sym_ATelse,
    STATE(1846), 2,
      sym_preproc_directive,
      aux_sym_func_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [86824] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2428), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(2424), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86851] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3270), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3268), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86878] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3274), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3272), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86905] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3278), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3276), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86932] = 4,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3282), 2,
      anon_sym_ATload,
      anon_sym_ATif,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3280), 11,
      anon_sym_LBRACE,
      anon_sym_ATdeprecated,
      anon_sym_ATload_DASHsigs,
      anon_sym_ATload_DASHplugin,
      anon_sym_ATunload,
      anon_sym_ATprefixes,
      anon_sym_ATifdef,
      anon_sym_ATifndef,
      anon_sym_ATendif,
      anon_sym_ATelse,
      anon_sym_ATpragma,
  [86959] = 8,
    ACTIONS(3284), 1,
      anon_sym_LPAREN,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3288), 1,
      sym_id,
    STATE(1985), 1,
      sym_func_params,
    STATE(1987), 1,
      sym_begin_lambda,
    STATE(1988), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [86987] = 7,
    ACTIONS(3290), 1,
      anon_sym_LPAREN,
    ACTIONS(3294), 1,
      aux_sym_string_token1,
    STATE(417), 1,
      sym_string,
    STATE(446), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3292), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87013] = 8,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3296), 1,
      anon_sym_LPAREN,
    ACTIONS(3298), 1,
      anon_sym_EQ,
    STATE(1985), 1,
      sym_func_params,
    STATE(2028), 1,
      sym_capture_list,
    STATE(2436), 1,
      sym_begin_lambda,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87041] = 8,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3296), 1,
      anon_sym_LPAREN,
    ACTIONS(3300), 1,
      anon_sym_EQ,
    STATE(1985), 1,
      sym_func_params,
    STATE(2028), 1,
      sym_capture_list,
    STATE(2262), 1,
      sym_begin_lambda,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87069] = 8,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3296), 1,
      anon_sym_LPAREN,
    ACTIONS(3302), 1,
      anon_sym_EQ,
    STATE(1985), 1,
      sym_func_params,
    STATE(2028), 1,
      sym_capture_list,
    STATE(2436), 1,
      sym_begin_lambda,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87097] = 7,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(3304), 1,
      anon_sym_LPAREN,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1802), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87123] = 7,
    ACTIONS(3237), 1,
      aux_sym_string_token1,
    ACTIONS(3306), 1,
      anon_sym_LPAREN,
    STATE(5), 1,
      sym_string_directive,
    STATE(289), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3235), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87149] = 7,
    ACTIONS(3308), 1,
      anon_sym_LPAREN,
    ACTIONS(3312), 1,
      aux_sym_string_token1,
    STATE(347), 1,
      sym_string,
    STATE(369), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3310), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87175] = 8,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3296), 1,
      anon_sym_LPAREN,
    ACTIONS(3314), 1,
      anon_sym_EQ,
    STATE(1985), 1,
      sym_func_params,
    STATE(2028), 1,
      sym_capture_list,
    STATE(2262), 1,
      sym_begin_lambda,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87203] = 7,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    ACTIONS(3316), 1,
      anon_sym_LPAREN,
    STATE(289), 1,
      sym_string,
    STATE(1209), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87229] = 7,
    ACTIONS(3318), 1,
      anon_sym_LPAREN,
    ACTIONS(3322), 1,
      aux_sym_string_token1,
    STATE(336), 1,
      sym_string_directive,
    STATE(338), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3320), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87255] = 7,
    ACTIONS(3324), 1,
      anon_sym_LPAREN,
    ACTIONS(3328), 1,
      aux_sym_string_token1,
    STATE(622), 1,
      sym_string_directive,
    STATE(661), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3326), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87281] = 7,
    ACTIONS(3330), 1,
      anon_sym_LPAREN,
    ACTIONS(3334), 1,
      aux_sym_string_token1,
    STATE(509), 1,
      sym_string_directive,
    STATE(537), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3332), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87307] = 7,
    ACTIONS(3336), 1,
      anon_sym_LPAREN,
    ACTIONS(3340), 1,
      aux_sym_string_token1,
    STATE(526), 1,
      sym_string,
    STATE(533), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3338), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87333] = 8,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3296), 1,
      anon_sym_LPAREN,
    ACTIONS(3342), 1,
      anon_sym_EQ,
    STATE(1985), 1,
      sym_func_params,
    STATE(2028), 1,
      sym_capture_list,
    STATE(2262), 1,
      sym_begin_lambda,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87361] = 7,
    ACTIONS(3344), 1,
      anon_sym_LPAREN,
    ACTIONS(3348), 1,
      aux_sym_string_token1,
    STATE(635), 1,
      sym_string,
    STATE(658), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3346), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87387] = 7,
    ACTIONS(3350), 1,
      anon_sym_LPAREN,
    ACTIONS(3354), 1,
      aux_sym_string_token1,
    STATE(404), 1,
      sym_string_directive,
    STATE(454), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3352), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87413] = 7,
    ACTIONS(3356), 1,
      anon_sym_LPAREN,
    ACTIONS(3360), 1,
      aux_sym_string_token1,
    STATE(525), 1,
      sym_string_directive,
    STATE(546), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3358), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87439] = 7,
    ACTIONS(3362), 1,
      anon_sym_LPAREN,
    ACTIONS(3366), 1,
      aux_sym_string_token1,
    STATE(469), 1,
      sym_string_directive,
    STATE(514), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3364), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87465] = 8,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3296), 1,
      anon_sym_LPAREN,
    ACTIONS(3368), 1,
      anon_sym_EQ,
    STATE(1985), 1,
      sym_func_params,
    STATE(2028), 1,
      sym_capture_list,
    STATE(2436), 1,
      sym_begin_lambda,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87493] = 7,
    ACTIONS(3370), 1,
      anon_sym_LPAREN,
    ACTIONS(3374), 1,
      aux_sym_string_token1,
    STATE(407), 1,
      sym_string,
    STATE(413), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3372), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87519] = 7,
    ACTIONS(3376), 1,
      anon_sym_LPAREN,
    ACTIONS(3380), 1,
      aux_sym_string_token1,
    STATE(370), 1,
      sym_string,
    STATE(374), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3378), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87545] = 6,
    ACTIONS(3322), 1,
      aux_sym_string_token1,
    STATE(336), 1,
      sym_string_directive,
    STATE(339), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3320), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87568] = 7,
    ACTIONS(3382), 1,
      anon_sym_RPAREN,
    ACTIONS(3384), 1,
      sym_id,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2614), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87593] = 4,
    ACTIONS(3386), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1837), 4,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [87612] = 6,
    ACTIONS(3340), 1,
      aux_sym_string_token1,
    STATE(533), 1,
      sym_string_directive,
    STATE(540), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3338), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87635] = 6,
    ACTIONS(3294), 1,
      aux_sym_string_token1,
    STATE(419), 1,
      sym_string,
    STATE(446), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3292), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87658] = 7,
    ACTIONS(2694), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2416), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87683] = 7,
    ACTIONS(2786), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2568), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87708] = 7,
    ACTIONS(2848), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2657), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87733] = 7,
    ACTIONS(2582), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2340), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87758] = 6,
    ACTIONS(3374), 1,
      aux_sym_string_token1,
    STATE(401), 1,
      sym_string,
    STATE(413), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3372), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87781] = 6,
    ACTIONS(3237), 1,
      aux_sym_string_token1,
    STATE(5), 1,
      sym_string_directive,
    STATE(288), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3235), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87804] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3392), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2328), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87829] = 7,
    ACTIONS(2778), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2505), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87854] = 7,
    ACTIONS(2928), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2687), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87879] = 6,
    ACTIONS(3360), 1,
      aux_sym_string_token1,
    STATE(525), 1,
      sym_string_directive,
    STATE(550), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3358), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87902] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3394), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2592), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87927] = 4,
    ACTIONS(3396), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1843), 4,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [87946] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3398), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2279), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87971] = 6,
    ACTIONS(3380), 1,
      aux_sym_string_token1,
    STATE(371), 1,
      sym_string,
    STATE(374), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3378), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [87994] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3400), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2863), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88019] = 6,
    ACTIONS(3312), 1,
      aux_sym_string_token1,
    STATE(349), 1,
      sym_string,
    STATE(369), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3310), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88042] = 7,
    ACTIONS(2862), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2628), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88067] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3402), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2748), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88092] = 4,
    ACTIONS(3404), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(1849), 4,
      anon_sym_LBRACE,
      anon_sym_RBRACE,
      anon_sym_COMMA,
      anon_sym_RBRACK,
  [88111] = 7,
    ACTIONS(3284), 1,
      anon_sym_LPAREN,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    STATE(1985), 1,
      sym_func_params,
    STATE(1988), 1,
      sym_capture_list,
    STATE(2034), 1,
      sym_begin_lambda,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88136] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3406), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2351), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88161] = 7,
    ACTIONS(3284), 1,
      anon_sym_LPAREN,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    STATE(1985), 1,
      sym_func_params,
    STATE(1987), 1,
      sym_begin_lambda,
    STATE(1988), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88186] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3408), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2560), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88211] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3410), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2381), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88236] = 7,
    ACTIONS(2524), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2457), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88261] = 6,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    STATE(1209), 1,
      sym_string_directive,
    STATE(1803), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88284] = 7,
    ACTIONS(2882), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2875), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88309] = 6,
    ACTIONS(3334), 1,
      aux_sym_string_token1,
    STATE(509), 1,
      sym_string_directive,
    STATE(543), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3332), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88332] = 7,
    ACTIONS(2810), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2268), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88357] = 6,
    ACTIONS(3237), 1,
      aux_sym_string_token1,
    STATE(5), 1,
      sym_string_directive,
    STATE(792), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3235), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88380] = 7,
    ACTIONS(2772), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2265), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88405] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3412), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2500), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88430] = 7,
    ACTIONS(2828), 1,
      anon_sym_RBRACE,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    STATE(1920), 1,
      aux_sym_case_list_repeat1,
    STATE(2339), 1,
      sym_case_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88455] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3414), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2608), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88480] = 6,
    ACTIONS(3328), 1,
      aux_sym_string_token1,
    STATE(622), 1,
      sym_string_directive,
    STATE(663), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3326), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88503] = 6,
    ACTIONS(3354), 1,
      aux_sym_string_token1,
    STATE(404), 1,
      sym_string_directive,
    STATE(422), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3352), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88526] = 6,
    ACTIONS(3348), 1,
      aux_sym_string_token1,
    STATE(644), 1,
      sym_string,
    STATE(658), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3346), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88549] = 6,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    STATE(288), 1,
      sym_string,
    STATE(1209), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88572] = 6,
    ACTIONS(3366), 1,
      aux_sym_string_token1,
    STATE(469), 1,
      sym_string_directive,
    STATE(518), 1,
      sym_string,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3364), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88595] = 6,
    ACTIONS(125), 1,
      aux_sym_string_token1,
    STATE(792), 1,
      sym_string,
    STATE(1209), 1,
      sym_string_directive,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(109), 2,
      anon_sym_ATDIR,
      anon_sym_ATFILENAME,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88618] = 7,
    ACTIONS(3384), 1,
      sym_id,
    ACTIONS(3416), 1,
      anon_sym_RPAREN,
    STATE(1953), 1,
      sym_formal_arg,
    STATE(1955), 1,
      aux_sym_formal_args_repeat1,
    STATE(2284), 1,
      sym_formal_args,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88643] = 6,
    ACTIONS(3388), 1,
      anon_sym_case,
    ACTIONS(3390), 1,
      anon_sym_default,
    ACTIONS(3418), 1,
      anon_sym_RBRACE,
    STATE(1923), 1,
      aux_sym_case_list_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88665] = 6,
    ACTIONS(3420), 1,
      sym_id,
    STATE(1931), 1,
      aux_sym_enum_body_repeat1,
    STATE(2017), 1,
      sym_enum_body_elem,
    STATE(2362), 1,
      sym_enum_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88687] = 6,
    ACTIONS(3422), 1,
      anon_sym_enum,
    ACTIONS(3424), 1,
      anon_sym_record,
    ACTIONS(3426), 1,
      anon_sym_event,
    ACTIONS(3428), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88709] = 6,
    ACTIONS(270), 1,
      anon_sym_RBRACE,
    ACTIONS(3430), 1,
      anon_sym_case,
    ACTIONS(3433), 1,
      anon_sym_default,
    STATE(1923), 1,
      aux_sym_case_list_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88731] = 5,
    ACTIONS(3436), 1,
      anon_sym_RBRACE,
    ACTIONS(3438), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1925), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88751] = 5,
    ACTIONS(3438), 1,
      sym_id,
    ACTIONS(3440), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1930), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88771] = 6,
    ACTIONS(3420), 1,
      sym_id,
    STATE(1931), 1,
      aux_sym_enum_body_repeat1,
    STATE(2017), 1,
      sym_enum_body_elem,
    STATE(2901), 1,
      sym_enum_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88793] = 5,
    ACTIONS(3438), 1,
      sym_id,
    ACTIONS(3442), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1930), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88813] = 6,
    ACTIONS(3444), 1,
      anon_sym_copy,
    ACTIONS(3446), 1,
      sym_id,
    STATE(1937), 1,
      aux_sym_capture_list_repeat1,
    STATE(2095), 1,
      sym_capture,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88835] = 6,
    ACTIONS(3448), 1,
      anon_sym_RBRACE,
    ACTIONS(3450), 1,
      sym_id,
    STATE(1929), 1,
      aux_sym_enum_body_repeat1,
    STATE(2716), 1,
      sym_enum_body_elem,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88857] = 5,
    ACTIONS(3453), 1,
      anon_sym_RBRACE,
    ACTIONS(3455), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1930), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88877] = 6,
    ACTIONS(3420), 1,
      sym_id,
    ACTIONS(3458), 1,
      anon_sym_RBRACE,
    STATE(1929), 1,
      aux_sym_enum_body_repeat1,
    STATE(2009), 1,
      sym_enum_body_elem,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88899] = 5,
    ACTIONS(3438), 1,
      sym_id,
    ACTIONS(3460), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1935), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88919] = 5,
    ACTIONS(3438), 1,
      sym_id,
    ACTIONS(3462), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1930), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88939] = 6,
    ACTIONS(3420), 1,
      sym_id,
    STATE(1931), 1,
      aux_sym_enum_body_repeat1,
    STATE(2017), 1,
      sym_enum_body_elem,
    STATE(2705), 1,
      sym_enum_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88961] = 5,
    ACTIONS(3438), 1,
      sym_id,
    ACTIONS(3464), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1930), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [88981] = 6,
    ACTIONS(3466), 1,
      anon_sym_copy,
    ACTIONS(3469), 1,
      sym_id,
    STATE(1936), 1,
      aux_sym_capture_list_repeat1,
    STATE(2529), 1,
      sym_capture,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89003] = 6,
    ACTIONS(3444), 1,
      anon_sym_copy,
    ACTIONS(3446), 1,
      sym_id,
    STATE(1936), 1,
      aux_sym_capture_list_repeat1,
    STATE(2051), 1,
      sym_capture,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89025] = 6,
    ACTIONS(3420), 1,
      sym_id,
    STATE(1931), 1,
      aux_sym_enum_body_repeat1,
    STATE(2017), 1,
      sym_enum_body_elem,
    STATE(2221), 1,
      sym_enum_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89047] = 5,
    ACTIONS(3438), 1,
      sym_id,
    ACTIONS(3472), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1933), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89067] = 6,
    ACTIONS(3420), 1,
      sym_id,
    STATE(1931), 1,
      aux_sym_enum_body_repeat1,
    STATE(2017), 1,
      sym_enum_body_elem,
    STATE(2346), 1,
      sym_enum_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89089] = 5,
    ACTIONS(3438), 1,
      sym_id,
    ACTIONS(3474), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1927), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89109] = 5,
    ACTIONS(3438), 1,
      sym_id,
    ACTIONS(3476), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1944), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89129] = 6,
    ACTIONS(3426), 1,
      anon_sym_event,
    ACTIONS(3478), 1,
      anon_sym_enum,
    ACTIONS(3480), 1,
      anon_sym_record,
    ACTIONS(3482), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89151] = 5,
    ACTIONS(3438), 1,
      sym_id,
    ACTIONS(3484), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    STATE(1930), 2,
      sym_type_spec,
      aux_sym_redef_record_decl_repeat1,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89171] = 4,
    ACTIONS(3488), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3486), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89188] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3490), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [89203] = 4,
    ACTIONS(3492), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1837), 2,
      anon_sym_COMMA,
      anon_sym_as,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89220] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3494), 1,
      anon_sym_LPAREN,
    STATE(2906), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89239] = 5,
    ACTIONS(3496), 1,
      sym_id,
    STATE(1949), 1,
      aux_sym_formal_args_repeat1,
    STATE(2059), 1,
      sym_formal_arg,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89258] = 5,
    ACTIONS(3499), 1,
      anon_sym_COLON,
    ACTIONS(3501), 1,
      anon_sym_COMMA,
    ACTIONS(3503), 1,
      anon_sym_as,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89277] = 4,
    ACTIONS(3505), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1843), 2,
      anon_sym_COMMA,
      anon_sym_as,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89294] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3507), 1,
      anon_sym_LPAREN,
    STATE(2616), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89313] = 4,
    ACTIONS(3509), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3486), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89330] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3511), 1,
      anon_sym_LPAREN,
    STATE(2630), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89349] = 5,
    ACTIONS(3384), 1,
      sym_id,
    STATE(1945), 1,
      sym_formal_arg,
    STATE(1949), 1,
      aux_sym_formal_args_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89368] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3513), 1,
      anon_sym_LPAREN,
    STATE(2448), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89387] = 4,
    ACTIONS(3515), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1849), 2,
      anon_sym_COMMA,
      anon_sym_as,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89404] = 5,
    ACTIONS(3501), 1,
      anon_sym_COMMA,
    ACTIONS(3517), 1,
      anon_sym_COLON,
    ACTIONS(3519), 1,
      anon_sym_as,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89423] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3521), 1,
      anon_sym_LPAREN,
    STATE(2515), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89442] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3523), 1,
      anon_sym_LPAREN,
    STATE(2729), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89461] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(3525), 3,
      anon_sym_SEMI,
      anon_sym_RPAREN,
      anon_sym_COMMA,
  [89476] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3527), 1,
      anon_sym_LPAREN,
    STATE(2744), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89495] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3529), 1,
      anon_sym_LPAREN,
    STATE(2745), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89514] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3531), 1,
      anon_sym_LPAREN,
    STATE(2756), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89533] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3533), 1,
      anon_sym_LPAREN,
    STATE(2757), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89552] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3535), 1,
      anon_sym_LPAREN,
    STATE(2767), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89571] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3537), 1,
      anon_sym_LPAREN,
    STATE(2768), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89590] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3539), 1,
      anon_sym_LPAREN,
    STATE(2778), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89609] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3541), 1,
      anon_sym_LPAREN,
    STATE(2779), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89628] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3543), 1,
      anon_sym_LPAREN,
    STATE(2789), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89647] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3545), 1,
      anon_sym_LPAREN,
    STATE(2790), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89666] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3547), 1,
      anon_sym_LPAREN,
    STATE(2800), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89685] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3549), 1,
      anon_sym_LPAREN,
    STATE(2801), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89704] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3551), 1,
      anon_sym_LPAREN,
    STATE(2811), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89723] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3553), 1,
      anon_sym_LPAREN,
    STATE(2812), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89742] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3555), 1,
      anon_sym_LPAREN,
    STATE(2822), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89761] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3557), 1,
      anon_sym_LPAREN,
    STATE(2823), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89780] = 4,
    ACTIONS(3559), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(1931), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89797] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3561), 1,
      anon_sym_LPAREN,
    STATE(2907), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89816] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
    ACTIONS(222), 3,
      anon_sym_RBRACE,
      anon_sym_case,
      anon_sym_default,
  [89831] = 5,
    ACTIONS(3286), 1,
      anon_sym_LBRACK,
    ACTIONS(3563), 1,
      anon_sym_LPAREN,
    STATE(2731), 1,
      sym_capture_list,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89850] = 4,
    ACTIONS(3565), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89866] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3569), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89882] = 4,
    ACTIONS(3571), 1,
      anon_sym_LPAREN,
    STATE(779), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89898] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3573), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89912] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3575), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89928] = 4,
    ACTIONS(3229), 1,
      anon_sym_LBRACE,
    STATE(1272), 1,
      sym_func_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89944] = 4,
    ACTIONS(3284), 1,
      anon_sym_LPAREN,
    STATE(2114), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89960] = 4,
    ACTIONS(2452), 1,
      anon_sym_of,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89976] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3577), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [89990] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3579), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90004] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2815), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90020] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3583), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90036] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3585), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90052] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3587), 2,
      anon_sym_RBRACE,
      sym_id,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90066] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3589), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90080] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3591), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90094] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2241), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90110] = 4,
    ACTIONS(3593), 1,
      anon_sym_LPAREN,
    STATE(1289), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90126] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3595), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90142] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2266), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90158] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3597), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90172] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3599), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90186] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2315), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90202] = 4,
    ACTIONS(3601), 1,
      anon_sym_LPAREN,
    STATE(1258), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90218] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3603), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90232] = 4,
    ACTIONS(3605), 1,
      anon_sym_LPAREN,
    STATE(779), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90248] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3448), 2,
      anon_sym_RBRACE,
      sym_id,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90262] = 4,
    ACTIONS(3607), 1,
      anon_sym_RBRACE,
    ACTIONS(3609), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90278] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3611), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90294] = 4,
    ACTIONS(3613), 1,
      anon_sym_COLON,
    ACTIONS(3615), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90310] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3617), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90324] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3619), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90338] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2380), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90354] = 4,
    ACTIONS(3501), 1,
      anon_sym_COMMA,
    ACTIONS(3621), 1,
      anon_sym_as,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90370] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3595), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90386] = 4,
    ACTIONS(3458), 1,
      anon_sym_RBRACE,
    ACTIONS(3609), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90402] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3623), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90416] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3625), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90430] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2468), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90446] = 4,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(1919), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90462] = 4,
    ACTIONS(3615), 1,
      anon_sym_COMMA,
    ACTIONS(3627), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90478] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2497), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90494] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3629), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90508] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3631), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90522] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2596), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90538] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2552), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90554] = 4,
    ACTIONS(3296), 1,
      anon_sym_LPAREN,
    STATE(2114), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90570] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3633), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90584] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3635), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90598] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2669), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90614] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3639), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90630] = 4,
    ACTIONS(3641), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90646] = 4,
    ACTIONS(3643), 1,
      anon_sym_LBRACE,
    STATE(802), 1,
      sym_func_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90662] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3645), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90676] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3647), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90690] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3649), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90704] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3651), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90718] = 4,
    ACTIONS(3653), 1,
      anon_sym_COMMA,
    ACTIONS(3655), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90734] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3657), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90750] = 4,
    ACTIONS(3659), 1,
      anon_sym_LPAREN,
    STATE(86), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90766] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3661), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90780] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3663), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90796] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3665), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90812] = 4,
    ACTIONS(3667), 1,
      anon_sym_COMMA,
    ACTIONS(3669), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90828] = 4,
    ACTIONS(3671), 1,
      anon_sym_COMMA,
    ACTIONS(3673), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90844] = 4,
    ACTIONS(3484), 1,
      anon_sym_RBRACK,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90860] = 4,
    ACTIONS(3675), 1,
      sym_id,
    STATE(2033), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90876] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3677), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90890] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3679), 2,
      anon_sym_copy,
      sym_id,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90904] = 4,
    ACTIONS(3681), 1,
      anon_sym_COMMA,
    ACTIONS(3683), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90920] = 4,
    ACTIONS(3685), 1,
      anon_sym_LBRACK,
    ACTIONS(3687), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90936] = 4,
    ACTIONS(3284), 1,
      anon_sym_LPAREN,
    STATE(1289), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90952] = 4,
    ACTIONS(3464), 1,
      anon_sym_RBRACK,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90968] = 4,
    ACTIONS(3689), 1,
      anon_sym_LPAREN,
    STATE(1289), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [90984] = 4,
    ACTIONS(3464), 1,
      anon_sym_RBRACE,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91000] = 4,
    ACTIONS(3691), 1,
      anon_sym_COMMA,
    ACTIONS(3693), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91016] = 4,
    ACTIONS(3296), 1,
      anon_sym_LPAREN,
    STATE(86), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91032] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3486), 2,
      anon_sym_SEMI,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91046] = 4,
    ACTIONS(3695), 1,
      anon_sym_COMMA,
    ACTIONS(3697), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91062] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3699), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91078] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3701), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91094] = 4,
    ACTIONS(3703), 1,
      anon_sym_COMMA,
    ACTIONS(3705), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91110] = 4,
    ACTIONS(3707), 1,
      anon_sym_COMMA,
    ACTIONS(3709), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91126] = 4,
    ACTIONS(1837), 1,
      anon_sym_EQ,
    ACTIONS(3711), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91142] = 4,
    ACTIONS(3713), 1,
      anon_sym_LBRACE,
    ACTIONS(3715), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91158] = 4,
    ACTIONS(3484), 1,
      anon_sym_RBRACE,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91174] = 4,
    ACTIONS(3717), 1,
      anon_sym_COMMA,
    ACTIONS(3719), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91190] = 4,
    ACTIONS(3721), 1,
      anon_sym_COMMA,
    ACTIONS(3723), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91206] = 4,
    ACTIONS(3725), 1,
      anon_sym_COMMA,
    ACTIONS(3727), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91222] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3729), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91238] = 4,
    ACTIONS(3731), 1,
      anon_sym_COMMA,
    ACTIONS(3733), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91254] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3735), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91268] = 4,
    ACTIONS(3737), 1,
      anon_sym_COMMA,
    ACTIONS(3739), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91284] = 4,
    ACTIONS(3741), 1,
      anon_sym_COMMA,
    ACTIONS(3743), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91300] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3745), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91316] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3745), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91332] = 4,
    ACTIONS(3643), 1,
      anon_sym_LBRACE,
    STATE(797), 1,
      sym_func_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91348] = 4,
    ACTIONS(3747), 1,
      anon_sym_COMMA,
    ACTIONS(3749), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91364] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3751), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91380] = 4,
    ACTIONS(3753), 1,
      anon_sym_COMMA,
    ACTIONS(3755), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91396] = 4,
    ACTIONS(3757), 1,
      anon_sym_COMMA,
    ACTIONS(3759), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91412] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3729), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91428] = 4,
    ACTIONS(3761), 1,
      anon_sym_COMMA,
    ACTIONS(3763), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91444] = 4,
    ACTIONS(3765), 1,
      anon_sym_COMMA,
    ACTIONS(3767), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91460] = 4,
    ACTIONS(3769), 1,
      anon_sym_COMMA,
    ACTIONS(3771), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91476] = 4,
    ACTIONS(3229), 1,
      anon_sym_LBRACE,
    STATE(1296), 1,
      sym_func_body,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91492] = 4,
    ACTIONS(3773), 1,
      anon_sym_COMMA,
    ACTIONS(3775), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91508] = 4,
    ACTIONS(3777), 1,
      anon_sym_COMMA,
    ACTIONS(3779), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91524] = 4,
    ACTIONS(3781), 1,
      anon_sym_COMMA,
    ACTIONS(3783), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91540] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3785), 2,
      anon_sym_COMMA,
      anon_sym_RBRACK,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91554] = 4,
    ACTIONS(3787), 1,
      anon_sym_COMMA,
    ACTIONS(3789), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91570] = 4,
    ACTIONS(3791), 1,
      anon_sym_COMMA,
    ACTIONS(3793), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91586] = 4,
    ACTIONS(3795), 1,
      anon_sym_COMMA,
    ACTIONS(3797), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91602] = 4,
    ACTIONS(3681), 1,
      anon_sym_COMMA,
    ACTIONS(3799), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91618] = 4,
    ACTIONS(3801), 1,
      anon_sym_COMMA,
    ACTIONS(3803), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91634] = 4,
    ACTIONS(3805), 1,
      anon_sym_COMMA,
    ACTIONS(3807), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91650] = 4,
    ACTIONS(3809), 1,
      anon_sym_COMMA,
    ACTIONS(3811), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91666] = 4,
    ACTIONS(1887), 1,
      anon_sym_LPAREN,
    ACTIONS(2301), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91682] = 4,
    ACTIONS(3813), 1,
      sym_id,
    STATE(2904), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91698] = 4,
    ACTIONS(3815), 1,
      anon_sym_COMMA,
    ACTIONS(3817), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91714] = 4,
    ACTIONS(3819), 1,
      anon_sym_COMMA,
    ACTIONS(3821), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91730] = 4,
    ACTIONS(3823), 1,
      anon_sym_COMMA,
    ACTIONS(3825), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91746] = 4,
    ACTIONS(3827), 1,
      anon_sym_COMMA,
    ACTIONS(3829), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91762] = 4,
    ACTIONS(3831), 1,
      anon_sym_COMMA,
    ACTIONS(3833), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91778] = 4,
    ACTIONS(3835), 1,
      anon_sym_COMMA,
    ACTIONS(3837), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91794] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3839), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91808] = 4,
    ACTIONS(2466), 1,
      anon_sym_LPAREN,
    ACTIONS(2506), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91824] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3841), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91838] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2904), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91854] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2707), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91870] = 4,
    ACTIONS(3843), 1,
      anon_sym_type,
    STATE(2156), 1,
      aux_sym_case_type_list_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91886] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3845), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91902] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3847), 2,
      anon_sym_LBRACE,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91916] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3849), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91932] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3851), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91948] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3853), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91964] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(2442), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91978] = 4,
    ACTIONS(3601), 1,
      anon_sym_LPAREN,
    STATE(86), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [91994] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3855), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92008] = 4,
    ACTIONS(3857), 1,
      anon_sym_LPAREN,
    STATE(1289), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92024] = 4,
    ACTIONS(3859), 1,
      anon_sym_COMMA,
    ACTIONS(3861), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92040] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3863), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92056] = 4,
    ACTIONS(3865), 1,
      anon_sym_LPAREN,
    ACTIONS(3867), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92072] = 4,
    ACTIONS(3865), 1,
      anon_sym_LPAREN,
    ACTIONS(3869), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92088] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3871), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92104] = 4,
    ACTIONS(3462), 1,
      anon_sym_RBRACK,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92120] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3873), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92136] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3875), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92152] = 4,
    ACTIONS(3877), 1,
      anon_sym_LBRACK,
    ACTIONS(3879), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92168] = 4,
    ACTIONS(3881), 1,
      anon_sym_LPAREN,
    ACTIONS(3883), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92184] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3885), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92200] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3887), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92216] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3889), 2,
      anon_sym_RBRACE,
      anon_sym_COMMA,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92230] = 4,
    ACTIONS(3891), 1,
      anon_sym_LBRACK,
    ACTIONS(3893), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92246] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3895), 2,
      anon_sym_RBRACE,
      sym_id,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92260] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3897), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92276] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3899), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92292] = 4,
    ACTIONS(3601), 1,
      anon_sym_LPAREN,
    STATE(1261), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92308] = 4,
    ACTIONS(3901), 1,
      anon_sym_LBRACK,
    ACTIONS(3903), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92324] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3905), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92338] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3907), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92354] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3909), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92370] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3911), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92384] = 4,
    ACTIONS(3913), 1,
      anon_sym_LBRACK,
    ACTIONS(3915), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92400] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2864), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92416] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3917), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92432] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3919), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92448] = 4,
    ACTIONS(3921), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92464] = 4,
    ACTIONS(3924), 1,
      anon_sym_LBRACK,
    ACTIONS(3926), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92480] = 4,
    ACTIONS(3601), 1,
      anon_sym_LPAREN,
    STATE(1260), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92496] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3928), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92512] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3930), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92528] = 4,
    ACTIONS(1843), 1,
      anon_sym_EQ,
    ACTIONS(3932), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92544] = 4,
    ACTIONS(3934), 1,
      anon_sym_LBRACK,
    ACTIONS(3936), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92560] = 4,
    ACTIONS(3938), 1,
      anon_sym_type,
    STATE(2156), 1,
      aux_sym_case_type_list_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92576] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3941), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92592] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3943), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92608] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3945), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92624] = 4,
    ACTIONS(3947), 1,
      anon_sym_LBRACK,
    ACTIONS(3949), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92640] = 4,
    ACTIONS(3951), 1,
      anon_sym_LPAREN,
    STATE(1261), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92656] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3953), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92672] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3955), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92688] = 4,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(3957), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92704] = 4,
    ACTIONS(3959), 1,
      anon_sym_LBRACK,
    ACTIONS(3961), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92720] = 4,
    ACTIONS(3963), 1,
      anon_sym_COMMA,
    ACTIONS(3965), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92736] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3967), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92752] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3969), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92768] = 4,
    ACTIONS(3881), 1,
      anon_sym_LPAREN,
    ACTIONS(3971), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92784] = 4,
    ACTIONS(3973), 1,
      anon_sym_LBRACK,
    ACTIONS(3975), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92800] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3977), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92814] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3979), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92830] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3981), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92846] = 4,
    ACTIONS(3983), 1,
      anon_sym_LBRACK,
    ACTIONS(3985), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92862] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3987), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92878] = 4,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(3989), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92894] = 4,
    ACTIONS(3883), 1,
      anon_sym_LBRACK,
    ACTIONS(3991), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92910] = 4,
    ACTIONS(3991), 1,
      anon_sym_LPAREN,
    ACTIONS(3993), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92926] = 4,
    ACTIONS(3995), 1,
      sym_id,
    STATE(2181), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92942] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3997), 2,
      anon_sym_push,
      anon_sym_pop,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92956] = 4,
    ACTIONS(3999), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92972] = 4,
    ACTIONS(4001), 1,
      anon_sym_LBRACE,
    ACTIONS(4003), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [92988] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(4005), 2,
      anon_sym_SEMI,
      anon_sym_RBRACE,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93002] = 4,
    ACTIONS(3462), 1,
      anon_sym_RBRACE,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93018] = 4,
    ACTIONS(3867), 1,
      anon_sym_LBRACK,
    ACTIONS(4007), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93034] = 4,
    ACTIONS(4007), 1,
      anon_sym_LPAREN,
    ACTIONS(4009), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93050] = 4,
    ACTIONS(4011), 1,
      sym_id,
    STATE(1982), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93066] = 4,
    ACTIONS(3581), 1,
      sym_id,
    STATE(2532), 1,
      sym_event_hdr,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93082] = 4,
    ACTIONS(4013), 1,
      sym_id,
    STATE(2190), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93098] = 4,
    ACTIONS(4015), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93114] = 4,
    ACTIONS(4017), 1,
      sym_id,
    STATE(2192), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93130] = 4,
    ACTIONS(4019), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93146] = 4,
    ACTIONS(4021), 1,
      sym_id,
    STATE(2194), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93162] = 4,
    ACTIONS(4023), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93178] = 4,
    ACTIONS(4025), 1,
      sym_id,
    STATE(2196), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93194] = 4,
    ACTIONS(4027), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93210] = 4,
    ACTIONS(4029), 1,
      sym_id,
    STATE(2198), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93226] = 4,
    ACTIONS(4031), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93242] = 4,
    ACTIONS(4033), 1,
      sym_id,
    STATE(2200), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93258] = 4,
    ACTIONS(4035), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93274] = 4,
    ACTIONS(4037), 1,
      sym_id,
    STATE(2202), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93290] = 4,
    ACTIONS(4039), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93306] = 4,
    ACTIONS(4041), 1,
      sym_id,
    STATE(2204), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93322] = 4,
    ACTIONS(4043), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93338] = 4,
    ACTIONS(4045), 1,
      sym_id,
    STATE(2206), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93354] = 4,
    ACTIONS(4047), 1,
      sym_id,
    STATE(2149), 1,
      aux_sym_stmt_repeat1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93370] = 4,
    ACTIONS(3883), 1,
      anon_sym_LBRACK,
    ACTIONS(4049), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93386] = 4,
    ACTIONS(3971), 1,
      anon_sym_LBRACK,
    ACTIONS(4049), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93402] = 4,
    ACTIONS(3867), 1,
      anon_sym_LBRACK,
    ACTIONS(4051), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93418] = 4,
    ACTIONS(4009), 1,
      anon_sym_LBRACK,
    ACTIONS(4051), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93434] = 4,
    ACTIONS(3601), 1,
      anon_sym_LPAREN,
    STATE(1259), 1,
      sym_func_params,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93450] = 3,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(4053), 2,
      anon_sym_PLUS_EQ,
      anon_sym_EQ,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93464] = 4,
    ACTIONS(1849), 1,
      anon_sym_EQ,
    ACTIONS(4055), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93480] = 4,
    ACTIONS(4057), 1,
      anon_sym_LBRACK,
    ACTIONS(4059), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93496] = 3,
    ACTIONS(4061), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93509] = 3,
    ACTIONS(4063), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93522] = 3,
    ACTIONS(4065), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93535] = 3,
    ACTIONS(907), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93548] = 3,
    ACTIONS(3097), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93561] = 3,
    ACTIONS(4067), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93574] = 3,
    ACTIONS(3462), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93587] = 3,
    ACTIONS(553), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93600] = 3,
    ACTIONS(2153), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93613] = 3,
    ACTIONS(601), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93626] = 3,
    ACTIONS(4069), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93639] = 3,
    ACTIONS(4071), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93652] = 3,
    ACTIONS(4073), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93665] = 3,
    ACTIONS(4075), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93678] = 3,
    ACTIONS(4077), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93691] = 3,
    ACTIONS(4079), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93704] = 3,
    ACTIONS(2301), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93717] = 3,
    ACTIONS(3197), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93730] = 3,
    ACTIONS(2131), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93743] = 3,
    ACTIONS(4081), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93756] = 3,
    ACTIONS(4083), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93769] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4085), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [93782] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4087), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [93795] = 3,
    ACTIONS(4089), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93808] = 3,
    ACTIONS(4091), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93821] = 3,
    ACTIONS(971), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93834] = 3,
    ACTIONS(971), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93847] = 3,
    ACTIONS(4093), 1,
      anon_sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93860] = 3,
    ACTIONS(1881), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93873] = 3,
    ACTIONS(4095), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93886] = 3,
    ACTIONS(4097), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93899] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4099), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [93912] = 3,
    ACTIONS(4101), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93925] = 3,
    ACTIONS(983), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93938] = 3,
    ACTIONS(2125), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93951] = 3,
    ACTIONS(4103), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93964] = 3,
    ACTIONS(4105), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93977] = 3,
    ACTIONS(4107), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [93990] = 3,
    ACTIONS(4109), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94003] = 3,
    ACTIONS(4111), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94016] = 3,
    ACTIONS(2828), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94029] = 3,
    ACTIONS(2123), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94042] = 3,
    ACTIONS(2772), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94055] = 3,
    ACTIONS(4113), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94068] = 3,
    ACTIONS(4115), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94081] = 3,
    ACTIONS(1769), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94094] = 3,
    ACTIONS(4117), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94107] = 3,
    ACTIONS(4119), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94120] = 3,
    ACTIONS(3069), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94133] = 3,
    ACTIONS(4121), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94146] = 3,
    ACTIONS(1463), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94159] = 3,
    ACTIONS(983), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94172] = 3,
    ACTIONS(1463), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94185] = 3,
    ACTIONS(1183), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94198] = 3,
    ACTIONS(1465), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94211] = 3,
    ACTIONS(4123), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94224] = 3,
    ACTIONS(2125), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94237] = 3,
    ACTIONS(3131), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94250] = 3,
    ACTIONS(583), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94263] = 3,
    ACTIONS(4125), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94276] = 3,
    ACTIONS(3029), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94289] = 3,
    ACTIONS(4127), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94302] = 3,
    ACTIONS(2786), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94315] = 3,
    ACTIONS(4129), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94328] = 3,
    ACTIONS(4131), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94341] = 3,
    ACTIONS(4133), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94354] = 3,
    ACTIONS(4135), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94367] = 3,
    ACTIONS(3615), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94380] = 3,
    ACTIONS(4137), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94393] = 3,
    ACTIONS(4139), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94406] = 3,
    ACTIONS(4141), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94419] = 3,
    ACTIONS(4143), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94432] = 3,
    ACTIONS(3460), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94445] = 3,
    ACTIONS(559), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94458] = 3,
    ACTIONS(4145), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94471] = 3,
    ACTIONS(561), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94484] = 3,
    ACTIONS(4147), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94497] = 3,
    ACTIONS(4149), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94510] = 3,
    ACTIONS(589), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94523] = 3,
    ACTIONS(2177), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94536] = 3,
    ACTIONS(2826), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94549] = 3,
    ACTIONS(4151), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94562] = 3,
    ACTIONS(1903), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94575] = 3,
    ACTIONS(4153), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94588] = 3,
    ACTIONS(4155), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94601] = 3,
    ACTIONS(3145), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94614] = 3,
    ACTIONS(4157), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94627] = 3,
    ACTIONS(4159), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94640] = 3,
    ACTIONS(4161), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94653] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4163), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [94666] = 3,
    ACTIONS(4165), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94679] = 3,
    ACTIONS(4167), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94692] = 3,
    ACTIONS(4169), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94705] = 3,
    ACTIONS(4171), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94718] = 3,
    ACTIONS(4173), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94731] = 3,
    ACTIONS(4175), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94744] = 3,
    ACTIONS(4177), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94757] = 3,
    ACTIONS(4179), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94770] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4181), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [94783] = 3,
    ACTIONS(865), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94796] = 3,
    ACTIONS(865), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94809] = 3,
    ACTIONS(4183), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94822] = 3,
    ACTIONS(4185), 1,
      sym_integer,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94835] = 3,
    ACTIONS(4187), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94848] = 3,
    ACTIONS(4189), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94861] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4191), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [94874] = 3,
    ACTIONS(4193), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94887] = 3,
    ACTIONS(4195), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94900] = 3,
    ACTIONS(2642), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94913] = 3,
    ACTIONS(4197), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94926] = 3,
    ACTIONS(4199), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94939] = 3,
    ACTIONS(4201), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94952] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4203), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [94965] = 3,
    ACTIONS(4205), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94978] = 3,
    ACTIONS(4207), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [94991] = 3,
    ACTIONS(2506), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95004] = 3,
    ACTIONS(4209), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95017] = 3,
    ACTIONS(4211), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95030] = 3,
    ACTIONS(2582), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95043] = 3,
    ACTIONS(4213), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95056] = 3,
    ACTIONS(1755), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95069] = 3,
    ACTIONS(4215), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95082] = 3,
    ACTIONS(4217), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95095] = 3,
    ACTIONS(3093), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95108] = 3,
    ACTIONS(1401), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95121] = 3,
    ACTIONS(1469), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95134] = 3,
    ACTIONS(4219), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95147] = 3,
    ACTIONS(3137), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95160] = 3,
    ACTIONS(1469), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95173] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4221), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [95186] = 3,
    ACTIONS(4223), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95199] = 3,
    ACTIONS(4225), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95212] = 3,
    ACTIONS(1471), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95225] = 3,
    ACTIONS(3139), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95238] = 3,
    ACTIONS(1401), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95251] = 3,
    ACTIONS(1183), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95264] = 3,
    ACTIONS(4227), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95277] = 3,
    ACTIONS(3669), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95290] = 3,
    ACTIONS(4229), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95303] = 3,
    ACTIONS(3111), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95316] = 3,
    ACTIONS(4231), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95329] = 3,
    ACTIONS(3143), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95342] = 3,
    ACTIONS(4233), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95355] = 3,
    ACTIONS(3115), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95368] = 3,
    ACTIONS(4235), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95381] = 3,
    ACTIONS(4237), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95394] = 3,
    ACTIONS(4239), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95407] = 3,
    ACTIONS(3464), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95420] = 3,
    ACTIONS(3867), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95433] = 3,
    ACTIONS(4241), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95446] = 3,
    ACTIONS(4243), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95459] = 3,
    ACTIONS(4245), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95472] = 3,
    ACTIONS(565), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95485] = 3,
    ACTIONS(4247), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95498] = 3,
    ACTIONS(567), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95511] = 3,
    ACTIONS(4249), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95524] = 3,
    ACTIONS(4251), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95537] = 3,
    ACTIONS(4253), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95550] = 3,
    ACTIONS(2169), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95563] = 3,
    ACTIONS(3386), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95576] = 3,
    ACTIONS(2524), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95589] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4255), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [95602] = 3,
    ACTIONS(4257), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95615] = 3,
    ACTIONS(1451), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95628] = 3,
    ACTIONS(891), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95641] = 3,
    ACTIONS(891), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95654] = 3,
    ACTIONS(4259), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95667] = 3,
    ACTIONS(4261), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95680] = 3,
    ACTIONS(4263), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95693] = 3,
    ACTIONS(4265), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95706] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4267), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [95719] = 3,
    ACTIONS(4269), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95732] = 3,
    ACTIONS(4271), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95745] = 3,
    ACTIONS(4273), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95758] = 3,
    ACTIONS(4275), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95771] = 3,
    ACTIONS(1821), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95784] = 3,
    ACTIONS(4277), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95797] = 3,
    ACTIONS(3149), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95810] = 3,
    ACTIONS(1891), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95823] = 3,
    ACTIONS(2694), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95836] = 3,
    ACTIONS(4279), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95849] = 3,
    ACTIONS(4281), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95862] = 3,
    ACTIONS(4283), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95875] = 3,
    ACTIONS(1807), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95888] = 3,
    ACTIONS(1721), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95901] = 3,
    ACTIONS(4285), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95914] = 3,
    ACTIONS(3492), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95927] = 3,
    ACTIONS(4287), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95940] = 3,
    ACTIONS(4289), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95953] = 3,
    ACTIONS(4291), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95966] = 3,
    ACTIONS(4293), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95979] = 3,
    ACTIONS(4295), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [95992] = 3,
    ACTIONS(4297), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96005] = 3,
    ACTIONS(4299), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96018] = 3,
    ACTIONS(4301), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96031] = 3,
    ACTIONS(4303), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96044] = 3,
    ACTIONS(4305), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96057] = 3,
    ACTIONS(4307), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96070] = 3,
    ACTIONS(3169), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96083] = 3,
    ACTIONS(4309), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96096] = 3,
    ACTIONS(3151), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96109] = 3,
    ACTIONS(1473), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96122] = 3,
    ACTIONS(4009), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96135] = 3,
    ACTIONS(4311), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96148] = 3,
    ACTIONS(4313), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96161] = 3,
    ACTIONS(1473), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96174] = 3,
    ACTIONS(4315), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96187] = 3,
    ACTIONS(4317), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96200] = 3,
    ACTIONS(3705), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96213] = 3,
    ACTIONS(4319), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96226] = 3,
    ACTIONS(4321), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96239] = 3,
    ACTIONS(4323), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96252] = 3,
    ACTIONS(1475), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96265] = 3,
    ACTIONS(4325), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96278] = 3,
    ACTIONS(4327), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96291] = 3,
    ACTIONS(3155), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96304] = 3,
    ACTIONS(3215), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96317] = 3,
    ACTIONS(4329), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96330] = 3,
    ACTIONS(3217), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96343] = 3,
    ACTIONS(4331), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96356] = 3,
    ACTIONS(4333), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96369] = 3,
    ACTIONS(4335), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96382] = 3,
    ACTIONS(1237), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96395] = 3,
    ACTIONS(4337), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96408] = 3,
    ACTIONS(1239), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96421] = 3,
    ACTIONS(4339), 1,
      sym_integer,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96434] = 3,
    ACTIONS(571), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96447] = 3,
    ACTIONS(4341), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96460] = 3,
    ACTIONS(4343), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96473] = 3,
    ACTIONS(1241), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96486] = 3,
    ACTIONS(4345), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96499] = 3,
    ACTIONS(4347), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96512] = 3,
    ACTIONS(573), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96525] = 3,
    ACTIONS(4349), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96538] = 3,
    ACTIONS(4351), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96551] = 3,
    ACTIONS(4353), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96564] = 3,
    ACTIONS(4355), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96577] = 3,
    ACTIONS(4357), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96590] = 3,
    ACTIONS(4359), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96603] = 3,
    ACTIONS(4361), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96616] = 3,
    ACTIONS(2157), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96629] = 3,
    ACTIONS(4363), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96642] = 3,
    ACTIONS(1291), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96655] = 3,
    ACTIONS(4365), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96668] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4367), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [96681] = 3,
    ACTIONS(4369), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96694] = 3,
    ACTIONS(3723), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96707] = 3,
    ACTIONS(4371), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96720] = 3,
    ACTIONS(4373), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96733] = 3,
    ACTIONS(4375), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96746] = 3,
    ACTIONS(4377), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96759] = 3,
    ACTIONS(4379), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96772] = 3,
    ACTIONS(915), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96785] = 3,
    ACTIONS(915), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96798] = 3,
    ACTIONS(4381), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96811] = 3,
    ACTIONS(4383), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96824] = 3,
    ACTIONS(4385), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96837] = 3,
    ACTIONS(4387), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96850] = 3,
    ACTIONS(1291), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96863] = 3,
    ACTIONS(2810), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96876] = 3,
    ACTIONS(1351), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96889] = 3,
    ACTIONS(4389), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96902] = 3,
    ACTIONS(4391), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96915] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4393), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [96928] = 3,
    ACTIONS(3193), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96941] = 3,
    ACTIONS(541), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96954] = 3,
    ACTIONS(3739), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96967] = 3,
    ACTIONS(4395), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96980] = 3,
    ACTIONS(4397), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [96993] = 3,
    ACTIONS(4399), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97006] = 3,
    ACTIONS(3107), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97019] = 3,
    ACTIONS(4401), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97032] = 3,
    ACTIONS(4403), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97045] = 3,
    ACTIONS(543), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97058] = 3,
    ACTIONS(4405), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97071] = 3,
    ACTIONS(4407), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97084] = 3,
    ACTIONS(4409), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97097] = 3,
    ACTIONS(4411), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97110] = 3,
    ACTIONS(2778), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97123] = 3,
    ACTIONS(3133), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97136] = 3,
    ACTIONS(1731), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97149] = 3,
    ACTIONS(4413), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97162] = 3,
    ACTIONS(4415), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97175] = 3,
    ACTIONS(4417), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97188] = 3,
    ACTIONS(3095), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97201] = 3,
    ACTIONS(4419), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97214] = 3,
    ACTIONS(3755), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97227] = 3,
    ACTIONS(2173), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97240] = 3,
    ACTIONS(3177), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97253] = 3,
    ACTIONS(4421), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97266] = 3,
    ACTIONS(1477), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97279] = 3,
    ACTIONS(4423), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97292] = 3,
    ACTIONS(4425), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97305] = 3,
    ACTIONS(1477), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97318] = 3,
    ACTIONS(4427), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97331] = 3,
    ACTIONS(4429), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97344] = 3,
    ACTIONS(4431), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97357] = 3,
    ACTIONS(4433), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97370] = 3,
    ACTIONS(1341), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97383] = 3,
    ACTIONS(4435), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97396] = 3,
    ACTIONS(3513), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97409] = 3,
    ACTIONS(3767), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97422] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4437), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [97435] = 3,
    ACTIONS(1479), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97448] = 3,
    ACTIONS(4439), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97461] = 3,
    ACTIONS(4441), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97474] = 3,
    ACTIONS(4443), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97487] = 3,
    ACTIONS(3183), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97500] = 3,
    ACTIONS(3109), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97513] = 3,
    ACTIONS(4445), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97526] = 3,
    ACTIONS(4447), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97539] = 3,
    ACTIONS(4449), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97552] = 3,
    ACTIONS(4451), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97565] = 3,
    ACTIONS(4453), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97578] = 3,
    ACTIONS(3681), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97591] = 3,
    ACTIONS(899), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97604] = 3,
    ACTIONS(3779), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97617] = 3,
    ACTIONS(899), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97630] = 3,
    ACTIONS(3117), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97643] = 3,
    ACTIONS(4455), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97656] = 3,
    ACTIONS(4457), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97669] = 3,
    ACTIONS(4459), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97682] = 3,
    ACTIONS(4461), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97695] = 3,
    ACTIONS(3185), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97708] = 3,
    ACTIONS(4463), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97721] = 3,
    ACTIONS(4465), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97734] = 3,
    ACTIONS(4467), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97747] = 3,
    ACTIONS(4469), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97760] = 3,
    ACTIONS(3637), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97773] = 3,
    ACTIONS(3135), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97786] = 3,
    ACTIONS(4471), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97799] = 3,
    ACTIONS(3793), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97812] = 3,
    ACTIONS(3159), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97825] = 3,
    ACTIONS(3189), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97838] = 3,
    ACTIONS(4473), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97851] = 3,
    ACTIONS(4475), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97864] = 3,
    ACTIONS(4477), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97877] = 3,
    ACTIONS(4479), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97890] = 3,
    ACTIONS(579), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97903] = 3,
    ACTIONS(4481), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97916] = 3,
    ACTIONS(4483), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97929] = 3,
    ACTIONS(4485), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97942] = 3,
    ACTIONS(4487), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97955] = 3,
    ACTIONS(4489), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97968] = 3,
    ACTIONS(4491), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97981] = 3,
    ACTIONS(4493), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [97994] = 3,
    ACTIONS(3807), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98007] = 3,
    ACTIONS(4495), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98020] = 3,
    ACTIONS(581), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98033] = 3,
    ACTIONS(4497), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98046] = 3,
    ACTIONS(4499), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98059] = 3,
    ACTIONS(4501), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98072] = 3,
    ACTIONS(4503), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98085] = 3,
    ACTIONS(1347), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98098] = 3,
    ACTIONS(4505), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98111] = 3,
    ACTIONS(4507), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98124] = 3,
    ACTIONS(4509), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98137] = 3,
    ACTIONS(4511), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98150] = 3,
    ACTIONS(2137), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98163] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4513), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [98176] = 3,
    ACTIONS(4515), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98189] = 3,
    ACTIONS(3821), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98202] = 3,
    ACTIONS(4517), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98215] = 3,
    ACTIONS(3195), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98228] = 3,
    ACTIONS(4519), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98241] = 3,
    ACTIONS(4521), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98254] = 3,
    ACTIONS(4523), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98267] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4525), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [98280] = 3,
    ACTIONS(4527), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98293] = 3,
    ACTIONS(4529), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98306] = 3,
    ACTIONS(4531), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98319] = 3,
    ACTIONS(4533), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98332] = 3,
    ACTIONS(4535), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98345] = 3,
    ACTIONS(4537), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98358] = 3,
    ACTIONS(4539), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98371] = 3,
    ACTIONS(3833), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98384] = 3,
    ACTIONS(4541), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98397] = 3,
    ACTIONS(4543), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98410] = 3,
    ACTIONS(4545), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98423] = 3,
    ACTIONS(939), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98436] = 3,
    ACTIONS(4547), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98449] = 3,
    ACTIONS(939), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98462] = 3,
    ACTIONS(4549), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98475] = 3,
    ACTIONS(4551), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98488] = 3,
    ACTIONS(4553), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98501] = 3,
    ACTIONS(4555), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98514] = 3,
    ACTIONS(4557), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98527] = 3,
    ACTIONS(4559), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98540] = 3,
    ACTIONS(4561), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98553] = 3,
    ACTIONS(2522), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98566] = 3,
    ACTIONS(2848), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98579] = 3,
    ACTIONS(4563), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98592] = 3,
    ACTIONS(4565), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98605] = 3,
    ACTIONS(4567), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98618] = 3,
    ACTIONS(1343), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98631] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4569), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [98644] = 3,
    ACTIONS(4571), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98657] = 3,
    ACTIONS(4573), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98670] = 3,
    ACTIONS(4575), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98683] = 3,
    ACTIONS(4577), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98696] = 3,
    ACTIONS(1497), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98709] = 3,
    ACTIONS(3511), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98722] = 3,
    ACTIONS(3203), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98735] = 3,
    ACTIONS(4579), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98748] = 3,
    ACTIONS(4581), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98761] = 3,
    ACTIONS(2862), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98774] = 3,
    ACTIONS(4583), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98787] = 3,
    ACTIONS(1733), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98800] = 3,
    ACTIONS(4585), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98813] = 3,
    ACTIONS(3027), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98826] = 3,
    ACTIONS(3173), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98839] = 3,
    ACTIONS(4587), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98852] = 3,
    ACTIONS(4589), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98865] = 3,
    ACTIONS(1481), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98878] = 3,
    ACTIONS(4591), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98891] = 3,
    ACTIONS(4593), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98904] = 3,
    ACTIONS(4595), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98917] = 3,
    ACTIONS(1481), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98930] = 3,
    ACTIONS(4597), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98943] = 3,
    ACTIONS(4001), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98956] = 3,
    ACTIONS(1775), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98969] = 3,
    ACTIONS(1483), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98982] = 3,
    ACTIONS(3207), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [98995] = 3,
    ACTIONS(4599), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99008] = 3,
    ACTIONS(4601), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99021] = 3,
    ACTIONS(3179), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99034] = 3,
    ACTIONS(4603), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99047] = 3,
    ACTIONS(4605), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99060] = 3,
    ACTIONS(4607), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99073] = 3,
    ACTIONS(3181), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99086] = 3,
    ACTIONS(4609), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99099] = 3,
    ACTIONS(4611), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99112] = 3,
    ACTIONS(4613), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99125] = 3,
    ACTIONS(3163), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99138] = 3,
    ACTIONS(3209), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99151] = 3,
    ACTIONS(4615), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99164] = 3,
    ACTIONS(1233), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99177] = 3,
    ACTIONS(4617), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99190] = 3,
    ACTIONS(1235), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99203] = 3,
    ACTIONS(4619), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99216] = 3,
    ACTIONS(4621), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99229] = 3,
    ACTIONS(587), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99242] = 3,
    ACTIONS(1455), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99255] = 3,
    ACTIONS(525), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99268] = 3,
    ACTIONS(3861), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99281] = 3,
    ACTIONS(4623), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99294] = 3,
    ACTIONS(3187), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99307] = 3,
    ACTIONS(2145), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99320] = 3,
    ACTIONS(3713), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99333] = 3,
    ACTIONS(555), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99346] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4625), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [99359] = 3,
    ACTIONS(4627), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99372] = 3,
    ACTIONS(4629), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99385] = 3,
    ACTIONS(963), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99398] = 3,
    ACTIONS(963), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99411] = 3,
    ACTIONS(527), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99424] = 3,
    ACTIONS(1455), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99437] = 3,
    ACTIONS(4631), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99450] = 3,
    ACTIONS(3883), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99463] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4633), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [99476] = 3,
    ACTIONS(4635), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99489] = 3,
    ACTIONS(4637), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99502] = 3,
    ACTIONS(4639), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99515] = 3,
    ACTIONS(3711), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99528] = 3,
    ACTIONS(3113), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99541] = 3,
    ACTIONS(1919), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99554] = 3,
    ACTIONS(2928), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99567] = 3,
    ACTIONS(3971), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99580] = 3,
    ACTIONS(1687), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99593] = 3,
    ACTIONS(2452), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99606] = 3,
    ACTIONS(3119), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99619] = 3,
    ACTIONS(3219), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99632] = 3,
    ACTIONS(1485), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99645] = 3,
    ACTIONS(3147), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99658] = 3,
    ACTIONS(1485), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99671] = 3,
    ACTIONS(4641), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99684] = 3,
    ACTIONS(1487), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99697] = 3,
    ACTIONS(4643), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99710] = 3,
    ACTIONS(4645), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99723] = 3,
    ACTIONS(2161), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99736] = 3,
    ACTIONS(4647), 1,
      anon_sym_COLON,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99749] = 3,
    ACTIONS(3191), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99762] = 3,
    ACTIONS(2149), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99775] = 3,
    ACTIONS(3025), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99788] = 3,
    ACTIONS(4649), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99801] = 3,
    ACTIONS(4651), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99814] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4653), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [99827] = 3,
    ACTIONS(4655), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99840] = 3,
    ACTIONS(4657), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99853] = 3,
    ACTIONS(923), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99866] = 3,
    ACTIONS(4659), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99879] = 3,
    ACTIONS(593), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99892] = 3,
    ACTIONS(923), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99905] = 3,
    ACTIONS(595), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99918] = 3,
    ACTIONS(1347), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99931] = 3,
    ACTIONS(4661), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99944] = 3,
    ACTIONS(4663), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99957] = 3,
    ACTIONS(3129), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99970] = 3,
    ACTIONS(2788), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [99983] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4665), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [99996] = 3,
    ACTIONS(4667), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100009] = 3,
    ACTIONS(3609), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100022] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4669), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [100035] = 3,
    ACTIONS(4671), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100048] = 3,
    ACTIONS(4673), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100061] = 3,
    ACTIONS(1711), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100074] = 3,
    ACTIONS(3476), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100087] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4675), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [100100] = 3,
    ACTIONS(4677), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100113] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4679), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [100126] = 3,
    ACTIONS(4681), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100139] = 3,
    ACTIONS(4683), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100152] = 3,
    ACTIONS(1457), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100165] = 3,
    ACTIONS(4685), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100178] = 3,
    ACTIONS(3563), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100191] = 3,
    ACTIONS(4687), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100204] = 3,
    ACTIONS(4689), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100217] = 3,
    ACTIONS(4691), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100230] = 3,
    ACTIONS(4693), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100243] = 3,
    ACTIONS(3165), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100256] = 3,
    ACTIONS(4695), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100269] = 3,
    ACTIONS(4697), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100282] = 3,
    ACTIONS(4699), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100295] = 3,
    ACTIONS(4701), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100308] = 3,
    ACTIONS(4703), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100321] = 3,
    ACTIONS(4705), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100334] = 3,
    ACTIONS(4707), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100347] = 3,
    ACTIONS(3167), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100360] = 3,
    ACTIONS(4709), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100373] = 3,
    ACTIONS(3529), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100386] = 3,
    ACTIONS(4711), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100399] = 3,
    ACTIONS(1349), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100412] = 3,
    ACTIONS(4713), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100425] = 3,
    ACTIONS(4715), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100438] = 3,
    ACTIONS(4717), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100451] = 3,
    ACTIONS(4719), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100464] = 3,
    ACTIONS(3869), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100477] = 3,
    ACTIONS(4721), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100490] = 3,
    ACTIONS(3221), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100503] = 3,
    ACTIONS(4723), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100516] = 3,
    ACTIONS(4725), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100529] = 3,
    ACTIONS(3533), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100542] = 3,
    ACTIONS(4727), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100555] = 3,
    ACTIONS(533), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100568] = 3,
    ACTIONS(4729), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100581] = 3,
    ACTIONS(4731), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100594] = 3,
    ACTIONS(4733), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100607] = 3,
    ACTIONS(4735), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100620] = 3,
    ACTIONS(4737), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100633] = 3,
    ACTIONS(3472), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100646] = 3,
    ACTIONS(3153), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100659] = 3,
    ACTIONS(4739), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100672] = 3,
    ACTIONS(3537), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100685] = 3,
    ACTIONS(4741), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100698] = 3,
    ACTIONS(1453), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100711] = 3,
    ACTIONS(4743), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100724] = 3,
    ACTIONS(4745), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100737] = 3,
    ACTIONS(4747), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100750] = 3,
    ACTIONS(4749), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100763] = 3,
    ACTIONS(4751), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100776] = 3,
    ACTIONS(547), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100789] = 3,
    ACTIONS(4753), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100802] = 3,
    ACTIONS(549), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100815] = 3,
    ACTIONS(3541), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100828] = 3,
    ACTIONS(4755), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100841] = 3,
    ACTIONS(4757), 1,
      anon_sym_type,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100854] = 3,
    ACTIONS(4759), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100867] = 3,
    ACTIONS(4761), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100880] = 3,
    ACTIONS(4763), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100893] = 3,
    ACTIONS(4765), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100906] = 3,
    ACTIONS(4767), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100919] = 3,
    ACTIONS(4769), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100932] = 3,
    ACTIONS(535), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100945] = 3,
    ACTIONS(4771), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100958] = 3,
    ACTIONS(3545), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100971] = 3,
    ACTIONS(4773), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100984] = 3,
    ACTIONS(4775), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [100997] = 3,
    ACTIONS(4777), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101010] = 3,
    ACTIONS(4779), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101023] = 3,
    ACTIONS(4781), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101036] = 3,
    ACTIONS(4783), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101049] = 3,
    ACTIONS(4785), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101062] = 3,
    ACTIONS(4787), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101075] = 3,
    ACTIONS(2141), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101088] = 3,
    ACTIONS(3567), 1,
      anon_sym_COMMA,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101101] = 3,
    ACTIONS(3549), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101114] = 3,
    ACTIONS(4789), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101127] = 3,
    ACTIONS(4791), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101140] = 3,
    ACTIONS(4793), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101153] = 3,
    ACTIONS(2165), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101166] = 3,
    ACTIONS(4795), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101179] = 3,
    ACTIONS(4797), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101192] = 3,
    ACTIONS(4799), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101205] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4801), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [101218] = 3,
    ACTIONS(4803), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101231] = 3,
    ACTIONS(4805), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101244] = 3,
    ACTIONS(3553), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101257] = 3,
    ACTIONS(4807), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101270] = 3,
    ACTIONS(931), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101283] = 3,
    ACTIONS(4809), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101296] = 3,
    ACTIONS(931), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101309] = 3,
    ACTIONS(4811), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101322] = 3,
    ACTIONS(4813), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101335] = 3,
    ACTIONS(4815), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101348] = 3,
    ACTIONS(4817), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101361] = 3,
    ACTIONS(3171), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101374] = 3,
    ACTIONS(4819), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101387] = 3,
    ACTIONS(3557), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101400] = 3,
    ACTIONS(4821), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101413] = 3,
    ACTIONS(4823), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101426] = 3,
    ACTIONS(4825), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101439] = 3,
    ACTIONS(4827), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101452] = 3,
    ACTIONS(4829), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101465] = 3,
    ACTIONS(4831), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101478] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4833), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [101491] = 3,
    ACTIONS(4835), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101504] = 3,
    ACTIONS(4837), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101517] = 3,
    ACTIONS(4839), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101530] = 3,
    ACTIONS(4841), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101543] = 3,
    ACTIONS(4843), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101556] = 3,
    ACTIONS(4845), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101569] = 3,
    ACTIONS(4847), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101582] = 3,
    ACTIONS(4849), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101595] = 3,
    ACTIONS(1467), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101608] = 3,
    ACTIONS(1655), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101621] = 3,
    ACTIONS(4851), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101634] = 3,
    ACTIONS(4853), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101647] = 3,
    ACTIONS(4855), 1,
      anon_sym_LBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101660] = 3,
    ACTIONS(4857), 1,
      anon_sym_in,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101673] = 3,
    ACTIONS(4859), 1,
      anon_sym_PLUS_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101686] = 3,
    ACTIONS(4861), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101699] = 3,
    ACTIONS(4863), 1,
      anon_sym_EQ,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101712] = 3,
    ACTIONS(4865), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101725] = 3,
    ACTIONS(3993), 1,
      anon_sym_LBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101738] = 3,
    ACTIONS(4867), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101751] = 3,
    ACTIONS(4869), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101764] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4871), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [101777] = 3,
    ACTIONS(4873), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101790] = 3,
    ACTIONS(4875), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101803] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4877), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [101816] = 3,
    ACTIONS(4879), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101829] = 3,
    ACTIONS(3288), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101842] = 3,
    ACTIONS(4881), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101855] = 3,
    ACTIONS(987), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101868] = 3,
    ACTIONS(4883), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101881] = 3,
    ACTIONS(2882), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101894] = 3,
    ACTIONS(4885), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101907] = 3,
    ACTIONS(4887), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101920] = 3,
    ACTIONS(4889), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101933] = 3,
    ACTIONS(987), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101946] = 3,
    ACTIONS(4891), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101959] = 3,
    ACTIONS(2422), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101972] = 3,
    ACTIONS(1767), 1,
      anon_sym_RPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101985] = 3,
    ACTIONS(4893), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [101998] = 3,
    ACTIONS(4895), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102011] = 3,
    ACTIONS(4897), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102024] = 3,
    ACTIONS(4899), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102037] = 3,
    ACTIONS(3199), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102050] = 3,
    ACTIONS(4901), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102063] = 3,
    ACTIONS(4903), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102076] = 3,
    ACTIONS(1459), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102089] = 3,
    ACTIONS(4905), 1,
      ts_builtin_sym_end,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102102] = 3,
    ACTIONS(4907), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102115] = 3,
    ACTIONS(1459), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102128] = 3,
    ACTIONS(4909), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102141] = 3,
    ACTIONS(4911), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102154] = 3,
    ACTIONS(4913), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102167] = 3,
    ACTIONS(1461), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102180] = 3,
    ACTIONS(4915), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102193] = 3,
    ACTIONS(4917), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102206] = 3,
    ACTIONS(4919), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102219] = 3,
    ACTIONS(4921), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102232] = 3,
    ACTIONS(1345), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102245] = 3,
    ACTIONS(2123), 1,
      anon_sym_RBRACK,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102258] = 3,
    ACTIONS(4923), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102271] = 3,
    ACTIONS(4925), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102284] = 3,
    ACTIONS(3), 1,
      sym_nl,
    ACTIONS(4927), 1,
      sym_file,
    ACTIONS(5), 4,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_zeekygen_next_comment,
      sym_minor_comment,
  [102297] = 3,
    ACTIONS(4929), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102310] = 3,
    ACTIONS(4931), 1,
      aux_sym_pragma_token1,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102323] = 3,
    ACTIONS(4933), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102336] = 3,
    ACTIONS(4935), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102349] = 3,
    ACTIONS(4937), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102362] = 3,
    ACTIONS(4939), 1,
      anon_sym_of,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102375] = 3,
    ACTIONS(3211), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102388] = 3,
    ACTIONS(4941), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102401] = 3,
    ACTIONS(4943), 1,
      sym_id,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102414] = 3,
    ACTIONS(3484), 1,
      anon_sym_RBRACE,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102427] = 3,
    ACTIONS(4945), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102440] = 3,
    ACTIONS(3213), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102453] = 3,
    ACTIONS(907), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102466] = 3,
    ACTIONS(4947), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102479] = 3,
    ACTIONS(3561), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102492] = 3,
    ACTIONS(4949), 1,
      anon_sym_LPAREN,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
  [102505] = 3,
    ACTIONS(3157), 1,
      anon_sym_SEMI,
    ACTIONS(5), 2,
      sym_zeekygen_next_comment,
      sym_minor_comment,
    ACTIONS(3), 3,
      sym_zeekygen_head_comment,
      sym_zeekygen_prev_comment,
      sym_nl,
};

static const uint32_t ts_small_parse_table_map[] = {
  [SMALL_STATE(878)] = 0,
  [SMALL_STATE(879)] = 143,
  [SMALL_STATE(880)] = 226,
  [SMALL_STATE(881)] = 303,
  [SMALL_STATE(882)] = 446,
  [SMALL_STATE(883)] = 523,
  [SMALL_STATE(884)] = 666,
  [SMALL_STATE(885)] = 809,
  [SMALL_STATE(886)] = 952,
  [SMALL_STATE(887)] = 1095,
  [SMALL_STATE(888)] = 1178,
  [SMALL_STATE(889)] = 1318,
  [SMALL_STATE(890)] = 1458,
  [SMALL_STATE(891)] = 1598,
  [SMALL_STATE(892)] = 1738,
  [SMALL_STATE(893)] = 1878,
  [SMALL_STATE(894)] = 2018,
  [SMALL_STATE(895)] = 2158,
  [SMALL_STATE(896)] = 2298,
  [SMALL_STATE(897)] = 2438,
  [SMALL_STATE(898)] = 2578,
  [SMALL_STATE(899)] = 2718,
  [SMALL_STATE(900)] = 2858,
  [SMALL_STATE(901)] = 2998,
  [SMALL_STATE(902)] = 3138,
  [SMALL_STATE(903)] = 3220,
  [SMALL_STATE(904)] = 3360,
  [SMALL_STATE(905)] = 3500,
  [SMALL_STATE(906)] = 3640,
  [SMALL_STATE(907)] = 3780,
  [SMALL_STATE(908)] = 3920,
  [SMALL_STATE(909)] = 4060,
  [SMALL_STATE(910)] = 4200,
  [SMALL_STATE(911)] = 4340,
  [SMALL_STATE(912)] = 4480,
  [SMALL_STATE(913)] = 4620,
  [SMALL_STATE(914)] = 4760,
  [SMALL_STATE(915)] = 4840,
  [SMALL_STATE(916)] = 4980,
  [SMALL_STATE(917)] = 5120,
  [SMALL_STATE(918)] = 5260,
  [SMALL_STATE(919)] = 5400,
  [SMALL_STATE(920)] = 5480,
  [SMALL_STATE(921)] = 5620,
  [SMALL_STATE(922)] = 5760,
  [SMALL_STATE(923)] = 5900,
  [SMALL_STATE(924)] = 6040,
  [SMALL_STATE(925)] = 6180,
  [SMALL_STATE(926)] = 6320,
  [SMALL_STATE(927)] = 6460,
  [SMALL_STATE(928)] = 6600,
  [SMALL_STATE(929)] = 6740,
  [SMALL_STATE(930)] = 6880,
  [SMALL_STATE(931)] = 7020,
  [SMALL_STATE(932)] = 7160,
  [SMALL_STATE(933)] = 7300,
  [SMALL_STATE(934)] = 7440,
  [SMALL_STATE(935)] = 7580,
  [SMALL_STATE(936)] = 7720,
  [SMALL_STATE(937)] = 7860,
  [SMALL_STATE(938)] = 8000,
  [SMALL_STATE(939)] = 8140,
  [SMALL_STATE(940)] = 8280,
  [SMALL_STATE(941)] = 8420,
  [SMALL_STATE(942)] = 8560,
  [SMALL_STATE(943)] = 8700,
  [SMALL_STATE(944)] = 8840,
  [SMALL_STATE(945)] = 8980,
  [SMALL_STATE(946)] = 9120,
  [SMALL_STATE(947)] = 9260,
  [SMALL_STATE(948)] = 9400,
  [SMALL_STATE(949)] = 9540,
  [SMALL_STATE(950)] = 9680,
  [SMALL_STATE(951)] = 9820,
  [SMALL_STATE(952)] = 9960,
  [SMALL_STATE(953)] = 10100,
  [SMALL_STATE(954)] = 10240,
  [SMALL_STATE(955)] = 10380,
  [SMALL_STATE(956)] = 10520,
  [SMALL_STATE(957)] = 10660,
  [SMALL_STATE(958)] = 10800,
  [SMALL_STATE(959)] = 10940,
  [SMALL_STATE(960)] = 11080,
  [SMALL_STATE(961)] = 11220,
  [SMALL_STATE(962)] = 11360,
  [SMALL_STATE(963)] = 11500,
  [SMALL_STATE(964)] = 11640,
  [SMALL_STATE(965)] = 11780,
  [SMALL_STATE(966)] = 11920,
  [SMALL_STATE(967)] = 12060,
  [SMALL_STATE(968)] = 12134,
  [SMALL_STATE(969)] = 12274,
  [SMALL_STATE(970)] = 12414,
  [SMALL_STATE(971)] = 12554,
  [SMALL_STATE(972)] = 12694,
  [SMALL_STATE(973)] = 12834,
  [SMALL_STATE(974)] = 12974,
  [SMALL_STATE(975)] = 13114,
  [SMALL_STATE(976)] = 13254,
  [SMALL_STATE(977)] = 13394,
  [SMALL_STATE(978)] = 13534,
  [SMALL_STATE(979)] = 13674,
  [SMALL_STATE(980)] = 13814,
  [SMALL_STATE(981)] = 13954,
  [SMALL_STATE(982)] = 14094,
  [SMALL_STATE(983)] = 14234,
  [SMALL_STATE(984)] = 14374,
  [SMALL_STATE(985)] = 14514,
  [SMALL_STATE(986)] = 14654,
  [SMALL_STATE(987)] = 14794,
  [SMALL_STATE(988)] = 14934,
  [SMALL_STATE(989)] = 15074,
  [SMALL_STATE(990)] = 15214,
  [SMALL_STATE(991)] = 15354,
  [SMALL_STATE(992)] = 15494,
  [SMALL_STATE(993)] = 15634,
  [SMALL_STATE(994)] = 15774,
  [SMALL_STATE(995)] = 15914,
  [SMALL_STATE(996)] = 16054,
  [SMALL_STATE(997)] = 16194,
  [SMALL_STATE(998)] = 16334,
  [SMALL_STATE(999)] = 16474,
  [SMALL_STATE(1000)] = 16614,
  [SMALL_STATE(1001)] = 16754,
  [SMALL_STATE(1002)] = 16894,
  [SMALL_STATE(1003)] = 17034,
  [SMALL_STATE(1004)] = 17174,
  [SMALL_STATE(1005)] = 17314,
  [SMALL_STATE(1006)] = 17454,
  [SMALL_STATE(1007)] = 17594,
  [SMALL_STATE(1008)] = 17734,
  [SMALL_STATE(1009)] = 17874,
  [SMALL_STATE(1010)] = 18014,
  [SMALL_STATE(1011)] = 18154,
  [SMALL_STATE(1012)] = 18294,
  [SMALL_STATE(1013)] = 18434,
  [SMALL_STATE(1014)] = 18574,
  [SMALL_STATE(1015)] = 18714,
  [SMALL_STATE(1016)] = 18854,
  [SMALL_STATE(1017)] = 18994,
  [SMALL_STATE(1018)] = 19134,
  [SMALL_STATE(1019)] = 19274,
  [SMALL_STATE(1020)] = 19414,
  [SMALL_STATE(1021)] = 19554,
  [SMALL_STATE(1022)] = 19694,
  [SMALL_STATE(1023)] = 19834,
  [SMALL_STATE(1024)] = 19974,
  [SMALL_STATE(1025)] = 20114,
  [SMALL_STATE(1026)] = 20254,
  [SMALL_STATE(1027)] = 20394,
  [SMALL_STATE(1028)] = 20534,
  [SMALL_STATE(1029)] = 20674,
  [SMALL_STATE(1030)] = 20814,
  [SMALL_STATE(1031)] = 20954,
  [SMALL_STATE(1032)] = 21094,
  [SMALL_STATE(1033)] = 21234,
  [SMALL_STATE(1034)] = 21374,
  [SMALL_STATE(1035)] = 21514,
  [SMALL_STATE(1036)] = 21654,
  [SMALL_STATE(1037)] = 21794,
  [SMALL_STATE(1038)] = 21934,
  [SMALL_STATE(1039)] = 22074,
  [SMALL_STATE(1040)] = 22214,
  [SMALL_STATE(1041)] = 22354,
  [SMALL_STATE(1042)] = 22494,
  [SMALL_STATE(1043)] = 22634,
  [SMALL_STATE(1044)] = 22774,
  [SMALL_STATE(1045)] = 22914,
  [SMALL_STATE(1046)] = 23054,
  [SMALL_STATE(1047)] = 23194,
  [SMALL_STATE(1048)] = 23334,
  [SMALL_STATE(1049)] = 23474,
  [SMALL_STATE(1050)] = 23614,
  [SMALL_STATE(1051)] = 23754,
  [SMALL_STATE(1052)] = 23894,
  [SMALL_STATE(1053)] = 24034,
  [SMALL_STATE(1054)] = 24174,
  [SMALL_STATE(1055)] = 24314,
  [SMALL_STATE(1056)] = 24454,
  [SMALL_STATE(1057)] = 24594,
  [SMALL_STATE(1058)] = 24734,
  [SMALL_STATE(1059)] = 24874,
  [SMALL_STATE(1060)] = 25014,
  [SMALL_STATE(1061)] = 25154,
  [SMALL_STATE(1062)] = 25294,
  [SMALL_STATE(1063)] = 25434,
  [SMALL_STATE(1064)] = 25574,
  [SMALL_STATE(1065)] = 25714,
  [SMALL_STATE(1066)] = 25854,
  [SMALL_STATE(1067)] = 25994,
  [SMALL_STATE(1068)] = 26134,
  [SMALL_STATE(1069)] = 26274,
  [SMALL_STATE(1070)] = 26414,
  [SMALL_STATE(1071)] = 26554,
  [SMALL_STATE(1072)] = 26694,
  [SMALL_STATE(1073)] = 26834,
  [SMALL_STATE(1074)] = 26974,
  [SMALL_STATE(1075)] = 27114,
  [SMALL_STATE(1076)] = 27254,
  [SMALL_STATE(1077)] = 27394,
  [SMALL_STATE(1078)] = 27534,
  [SMALL_STATE(1079)] = 27674,
  [SMALL_STATE(1080)] = 27814,
  [SMALL_STATE(1081)] = 27954,
  [SMALL_STATE(1082)] = 28094,
  [SMALL_STATE(1083)] = 28234,
  [SMALL_STATE(1084)] = 28374,
  [SMALL_STATE(1085)] = 28514,
  [SMALL_STATE(1086)] = 28654,
  [SMALL_STATE(1087)] = 28794,
  [SMALL_STATE(1088)] = 28934,
  [SMALL_STATE(1089)] = 29074,
  [SMALL_STATE(1090)] = 29214,
  [SMALL_STATE(1091)] = 29354,
  [SMALL_STATE(1092)] = 29494,
  [SMALL_STATE(1093)] = 29634,
  [SMALL_STATE(1094)] = 29774,
  [SMALL_STATE(1095)] = 29914,
  [SMALL_STATE(1096)] = 30054,
  [SMALL_STATE(1097)] = 30194,
  [SMALL_STATE(1098)] = 30334,
  [SMALL_STATE(1099)] = 30474,
  [SMALL_STATE(1100)] = 30614,
  [SMALL_STATE(1101)] = 30754,
  [SMALL_STATE(1102)] = 30894,
  [SMALL_STATE(1103)] = 31034,
  [SMALL_STATE(1104)] = 31174,
  [SMALL_STATE(1105)] = 31314,
  [SMALL_STATE(1106)] = 31454,
  [SMALL_STATE(1107)] = 31594,
  [SMALL_STATE(1108)] = 31734,
  [SMALL_STATE(1109)] = 31874,
  [SMALL_STATE(1110)] = 32014,
  [SMALL_STATE(1111)] = 32154,
  [SMALL_STATE(1112)] = 32294,
  [SMALL_STATE(1113)] = 32434,
  [SMALL_STATE(1114)] = 32574,
  [SMALL_STATE(1115)] = 32714,
  [SMALL_STATE(1116)] = 32854,
  [SMALL_STATE(1117)] = 32994,
  [SMALL_STATE(1118)] = 33134,
  [SMALL_STATE(1119)] = 33274,
  [SMALL_STATE(1120)] = 33414,
  [SMALL_STATE(1121)] = 33554,
  [SMALL_STATE(1122)] = 33694,
  [SMALL_STATE(1123)] = 33834,
  [SMALL_STATE(1124)] = 33974,
  [SMALL_STATE(1125)] = 34114,
  [SMALL_STATE(1126)] = 34254,
  [SMALL_STATE(1127)] = 34394,
  [SMALL_STATE(1128)] = 34534,
  [SMALL_STATE(1129)] = 34674,
  [SMALL_STATE(1130)] = 34814,
  [SMALL_STATE(1131)] = 34954,
  [SMALL_STATE(1132)] = 35094,
  [SMALL_STATE(1133)] = 35234,
  [SMALL_STATE(1134)] = 35374,
  [SMALL_STATE(1135)] = 35514,
  [SMALL_STATE(1136)] = 35654,
  [SMALL_STATE(1137)] = 35794,
  [SMALL_STATE(1138)] = 35934,
  [SMALL_STATE(1139)] = 36074,
  [SMALL_STATE(1140)] = 36214,
  [SMALL_STATE(1141)] = 36354,
  [SMALL_STATE(1142)] = 36494,
  [SMALL_STATE(1143)] = 36634,
  [SMALL_STATE(1144)] = 36774,
  [SMALL_STATE(1145)] = 36914,
  [SMALL_STATE(1146)] = 37054,
  [SMALL_STATE(1147)] = 37194,
  [SMALL_STATE(1148)] = 37334,
  [SMALL_STATE(1149)] = 37474,
  [SMALL_STATE(1150)] = 37614,
  [SMALL_STATE(1151)] = 37754,
  [SMALL_STATE(1152)] = 37894,
  [SMALL_STATE(1153)] = 38034,
  [SMALL_STATE(1154)] = 38174,
  [SMALL_STATE(1155)] = 38314,
  [SMALL_STATE(1156)] = 38454,
  [SMALL_STATE(1157)] = 38594,
  [SMALL_STATE(1158)] = 38734,
  [SMALL_STATE(1159)] = 38874,
  [SMALL_STATE(1160)] = 39014,
  [SMALL_STATE(1161)] = 39154,
  [SMALL_STATE(1162)] = 39294,
  [SMALL_STATE(1163)] = 39434,
  [SMALL_STATE(1164)] = 39574,
  [SMALL_STATE(1165)] = 39714,
  [SMALL_STATE(1166)] = 39854,
  [SMALL_STATE(1167)] = 39994,
  [SMALL_STATE(1168)] = 40134,
  [SMALL_STATE(1169)] = 40274,
  [SMALL_STATE(1170)] = 40414,
  [SMALL_STATE(1171)] = 40554,
  [SMALL_STATE(1172)] = 40694,
  [SMALL_STATE(1173)] = 40834,
  [SMALL_STATE(1174)] = 40974,
  [SMALL_STATE(1175)] = 41114,
  [SMALL_STATE(1176)] = 41254,
  [SMALL_STATE(1177)] = 41394,
  [SMALL_STATE(1178)] = 41534,
  [SMALL_STATE(1179)] = 41674,
  [SMALL_STATE(1180)] = 41814,
  [SMALL_STATE(1181)] = 41954,
  [SMALL_STATE(1182)] = 42094,
  [SMALL_STATE(1183)] = 42234,
  [SMALL_STATE(1184)] = 42374,
  [SMALL_STATE(1185)] = 42514,
  [SMALL_STATE(1186)] = 42654,
  [SMALL_STATE(1187)] = 42794,
  [SMALL_STATE(1188)] = 42934,
  [SMALL_STATE(1189)] = 43074,
  [SMALL_STATE(1190)] = 43214,
  [SMALL_STATE(1191)] = 43354,
  [SMALL_STATE(1192)] = 43494,
  [SMALL_STATE(1193)] = 43634,
  [SMALL_STATE(1194)] = 43774,
  [SMALL_STATE(1195)] = 43914,
  [SMALL_STATE(1196)] = 44054,
  [SMALL_STATE(1197)] = 44194,
  [SMALL_STATE(1198)] = 44334,
  [SMALL_STATE(1199)] = 44474,
  [SMALL_STATE(1200)] = 44614,
  [SMALL_STATE(1201)] = 44754,
  [SMALL_STATE(1202)] = 44894,
  [SMALL_STATE(1203)] = 45034,
  [SMALL_STATE(1204)] = 45174,
  [SMALL_STATE(1205)] = 45314,
  [SMALL_STATE(1206)] = 45403,
  [SMALL_STATE(1207)] = 45478,
  [SMALL_STATE(1208)] = 45577,
  [SMALL_STATE(1209)] = 45648,
  [SMALL_STATE(1210)] = 45719,
  [SMALL_STATE(1211)] = 45800,
  [SMALL_STATE(1212)] = 45895,
  [SMALL_STATE(1213)] = 45976,
  [SMALL_STATE(1214)] = 46065,
  [SMALL_STATE(1215)] = 46156,
  [SMALL_STATE(1216)] = 46227,
  [SMALL_STATE(1217)] = 46326,
  [SMALL_STATE(1218)] = 46421,
  [SMALL_STATE(1219)] = 46502,
  [SMALL_STATE(1220)] = 46573,
  [SMALL_STATE(1221)] = 46670,
  [SMALL_STATE(1222)] = 46745,
  [SMALL_STATE(1223)] = 46826,
  [SMALL_STATE(1224)] = 46896,
  [SMALL_STATE(1225)] = 46994,
  [SMALL_STATE(1226)] = 47072,
  [SMALL_STATE(1227)] = 47150,
  [SMALL_STATE(1228)] = 47222,
  [SMALL_STATE(1229)] = 47301,
  [SMALL_STATE(1230)] = 47380,
  [SMALL_STATE(1231)] = 47457,
  [SMALL_STATE(1232)] = 47544,
  [SMALL_STATE(1233)] = 47615,
  [SMALL_STATE(1234)] = 47712,
  [SMALL_STATE(1235)] = 47789,
  [SMALL_STATE(1236)] = 47886,
  [SMALL_STATE(1237)] = 47975,
  [SMALL_STATE(1238)] = 48068,
  [SMALL_STATE(1239)] = 48155,
  [SMALL_STATE(1240)] = 48248,
  [SMALL_STATE(1241)] = 48343,
  [SMALL_STATE(1242)] = 48422,
  [SMALL_STATE(1243)] = 48501,
  [SMALL_STATE(1244)] = 48577,
  [SMALL_STATE(1245)] = 48645,
  [SMALL_STATE(1246)] = 48713,
  [SMALL_STATE(1247)] = 48808,
  [SMALL_STATE(1248)] = 48903,
  [SMALL_STATE(1249)] = 48968,
  [SMALL_STATE(1250)] = 49025,
  [SMALL_STATE(1251)] = 49126,
  [SMALL_STATE(1252)] = 49227,
  [SMALL_STATE(1253)] = 49328,
  [SMALL_STATE(1254)] = 49429,
  [SMALL_STATE(1255)] = 49530,
  [SMALL_STATE(1256)] = 49586,
  [SMALL_STATE(1257)] = 49642,
  [SMALL_STATE(1258)] = 49698,
  [SMALL_STATE(1259)] = 49761,
  [SMALL_STATE(1260)] = 49824,
  [SMALL_STATE(1261)] = 49887,
  [SMALL_STATE(1262)] = 49950,
  [SMALL_STATE(1263)] = 50006,
  [SMALL_STATE(1264)] = 50066,
  [SMALL_STATE(1265)] = 50126,
  [SMALL_STATE(1266)] = 50178,
  [SMALL_STATE(1267)] = 50230,
  [SMALL_STATE(1268)] = 50281,
  [SMALL_STATE(1269)] = 50330,
  [SMALL_STATE(1270)] = 50381,
  [SMALL_STATE(1271)] = 50430,
  [SMALL_STATE(1272)] = 50479,
  [SMALL_STATE(1273)] = 50528,
  [SMALL_STATE(1274)] = 50577,
  [SMALL_STATE(1275)] = 50626,
  [SMALL_STATE(1276)] = 50675,
  [SMALL_STATE(1277)] = 50724,
  [SMALL_STATE(1278)] = 50773,
  [SMALL_STATE(1279)] = 50830,
  [SMALL_STATE(1280)] = 50881,
  [SMALL_STATE(1281)] = 50930,
  [SMALL_STATE(1282)] = 50981,
  [SMALL_STATE(1283)] = 51032,
  [SMALL_STATE(1284)] = 51081,
  [SMALL_STATE(1285)] = 51130,
  [SMALL_STATE(1286)] = 51179,
  [SMALL_STATE(1287)] = 51228,
  [SMALL_STATE(1288)] = 51277,
  [SMALL_STATE(1289)] = 51326,
  [SMALL_STATE(1290)] = 51375,
  [SMALL_STATE(1291)] = 51424,
  [SMALL_STATE(1292)] = 51473,
  [SMALL_STATE(1293)] = 51522,
  [SMALL_STATE(1294)] = 51571,
  [SMALL_STATE(1295)] = 51620,
  [SMALL_STATE(1296)] = 51669,
  [SMALL_STATE(1297)] = 51718,
  [SMALL_STATE(1298)] = 51767,
  [SMALL_STATE(1299)] = 51816,
  [SMALL_STATE(1300)] = 51873,
  [SMALL_STATE(1301)] = 51922,
  [SMALL_STATE(1302)] = 51971,
  [SMALL_STATE(1303)] = 52020,
  [SMALL_STATE(1304)] = 52069,
  [SMALL_STATE(1305)] = 52118,
  [SMALL_STATE(1306)] = 52167,
  [SMALL_STATE(1307)] = 52243,
  [SMALL_STATE(1308)] = 52301,
  [SMALL_STATE(1309)] = 52373,
  [SMALL_STATE(1310)] = 52451,
  [SMALL_STATE(1311)] = 52517,
  [SMALL_STATE(1312)] = 52585,
  [SMALL_STATE(1313)] = 52661,
  [SMALL_STATE(1314)] = 52727,
  [SMALL_STATE(1315)] = 52805,
  [SMALL_STATE(1316)] = 52863,
  [SMALL_STATE(1317)] = 52935,
  [SMALL_STATE(1318)] = 53001,
  [SMALL_STATE(1319)] = 53049,
  [SMALL_STATE(1320)] = 53119,
  [SMALL_STATE(1321)] = 53193,
  [SMALL_STATE(1322)] = 53247,
  [SMALL_STATE(1323)] = 53303,
  [SMALL_STATE(1324)] = 53357,
  [SMALL_STATE(1325)] = 53421,
  [SMALL_STATE(1326)] = 53499,
  [SMALL_STATE(1327)] = 53573,
  [SMALL_STATE(1328)] = 53651,
  [SMALL_STATE(1329)] = 53729,
  [SMALL_STATE(1330)] = 53799,
  [SMALL_STATE(1331)] = 53855,
  [SMALL_STATE(1332)] = 53919,
  [SMALL_STATE(1333)] = 53997,
  [SMALL_STATE(1334)] = 54075,
  [SMALL_STATE(1335)] = 54153,
  [SMALL_STATE(1336)] = 54231,
  [SMALL_STATE(1337)] = 54309,
  [SMALL_STATE(1338)] = 54387,
  [SMALL_STATE(1339)] = 54465,
  [SMALL_STATE(1340)] = 54543,
  [SMALL_STATE(1341)] = 54621,
  [SMALL_STATE(1342)] = 54699,
  [SMALL_STATE(1343)] = 54777,
  [SMALL_STATE(1344)] = 54855,
  [SMALL_STATE(1345)] = 54933,
  [SMALL_STATE(1346)] = 55008,
  [SMALL_STATE(1347)] = 55053,
  [SMALL_STATE(1348)] = 55126,
  [SMALL_STATE(1349)] = 55175,
  [SMALL_STATE(1350)] = 55250,
  [SMALL_STATE(1351)] = 55295,
  [SMALL_STATE(1352)] = 55367,
  [SMALL_STATE(1353)] = 55439,
  [SMALL_STATE(1354)] = 55511,
  [SMALL_STATE(1355)] = 55583,
  [SMALL_STATE(1356)] = 55655,
  [SMALL_STATE(1357)] = 55727,
  [SMALL_STATE(1358)] = 55799,
  [SMALL_STATE(1359)] = 55871,
  [SMALL_STATE(1360)] = 55943,
  [SMALL_STATE(1361)] = 56015,
  [SMALL_STATE(1362)] = 56087,
  [SMALL_STATE(1363)] = 56159,
  [SMALL_STATE(1364)] = 56231,
  [SMALL_STATE(1365)] = 56303,
  [SMALL_STATE(1366)] = 56375,
  [SMALL_STATE(1367)] = 56447,
  [SMALL_STATE(1368)] = 56519,
  [SMALL_STATE(1369)] = 56587,
  [SMALL_STATE(1370)] = 56641,
  [SMALL_STATE(1371)] = 56703,
  [SMALL_STATE(1372)] = 56767,
  [SMALL_STATE(1373)] = 56839,
  [SMALL_STATE(1374)] = 56911,
  [SMALL_STATE(1375)] = 56983,
  [SMALL_STATE(1376)] = 57051,
  [SMALL_STATE(1377)] = 57105,
  [SMALL_STATE(1378)] = 57177,
  [SMALL_STATE(1379)] = 57249,
  [SMALL_STATE(1380)] = 57311,
  [SMALL_STATE(1381)] = 57383,
  [SMALL_STATE(1382)] = 57455,
  [SMALL_STATE(1383)] = 57527,
  [SMALL_STATE(1384)] = 57599,
  [SMALL_STATE(1385)] = 57671,
  [SMALL_STATE(1386)] = 57743,
  [SMALL_STATE(1387)] = 57815,
  [SMALL_STATE(1388)] = 57887,
  [SMALL_STATE(1389)] = 57959,
  [SMALL_STATE(1390)] = 58031,
  [SMALL_STATE(1391)] = 58103,
  [SMALL_STATE(1392)] = 58175,
  [SMALL_STATE(1393)] = 58247,
  [SMALL_STATE(1394)] = 58319,
  [SMALL_STATE(1395)] = 58391,
  [SMALL_STATE(1396)] = 58463,
  [SMALL_STATE(1397)] = 58535,
  [SMALL_STATE(1398)] = 58607,
  [SMALL_STATE(1399)] = 58679,
  [SMALL_STATE(1400)] = 58751,
  [SMALL_STATE(1401)] = 58823,
  [SMALL_STATE(1402)] = 58895,
  [SMALL_STATE(1403)] = 58967,
  [SMALL_STATE(1404)] = 59015,
  [SMALL_STATE(1405)] = 59087,
  [SMALL_STATE(1406)] = 59159,
  [SMALL_STATE(1407)] = 59231,
  [SMALL_STATE(1408)] = 59303,
  [SMALL_STATE(1409)] = 59375,
  [SMALL_STATE(1410)] = 59447,
  [SMALL_STATE(1411)] = 59519,
  [SMALL_STATE(1412)] = 59591,
  [SMALL_STATE(1413)] = 59663,
  [SMALL_STATE(1414)] = 59735,
  [SMALL_STATE(1415)] = 59807,
  [SMALL_STATE(1416)] = 59879,
  [SMALL_STATE(1417)] = 59951,
  [SMALL_STATE(1418)] = 60023,
  [SMALL_STATE(1419)] = 60095,
  [SMALL_STATE(1420)] = 60167,
  [SMALL_STATE(1421)] = 60239,
  [SMALL_STATE(1422)] = 60311,
  [SMALL_STATE(1423)] = 60383,
  [SMALL_STATE(1424)] = 60455,
  [SMALL_STATE(1425)] = 60527,
  [SMALL_STATE(1426)] = 60599,
  [SMALL_STATE(1427)] = 60671,
  [SMALL_STATE(1428)] = 60743,
  [SMALL_STATE(1429)] = 60815,
  [SMALL_STATE(1430)] = 60887,
  [SMALL_STATE(1431)] = 60959,
  [SMALL_STATE(1432)] = 61031,
  [SMALL_STATE(1433)] = 61103,
  [SMALL_STATE(1434)] = 61175,
  [SMALL_STATE(1435)] = 61247,
  [SMALL_STATE(1436)] = 61319,
  [SMALL_STATE(1437)] = 61391,
  [SMALL_STATE(1438)] = 61463,
  [SMALL_STATE(1439)] = 61535,
  [SMALL_STATE(1440)] = 61607,
  [SMALL_STATE(1441)] = 61679,
  [SMALL_STATE(1442)] = 61751,
  [SMALL_STATE(1443)] = 61823,
  [SMALL_STATE(1444)] = 61895,
  [SMALL_STATE(1445)] = 61967,
  [SMALL_STATE(1446)] = 62039,
  [SMALL_STATE(1447)] = 62111,
  [SMALL_STATE(1448)] = 62183,
  [SMALL_STATE(1449)] = 62255,
  [SMALL_STATE(1450)] = 62327,
  [SMALL_STATE(1451)] = 62399,
  [SMALL_STATE(1452)] = 62471,
  [SMALL_STATE(1453)] = 62543,
  [SMALL_STATE(1454)] = 62615,
  [SMALL_STATE(1455)] = 62687,
  [SMALL_STATE(1456)] = 62759,
  [SMALL_STATE(1457)] = 62831,
  [SMALL_STATE(1458)] = 62903,
  [SMALL_STATE(1459)] = 62975,
  [SMALL_STATE(1460)] = 63047,
  [SMALL_STATE(1461)] = 63119,
  [SMALL_STATE(1462)] = 63191,
  [SMALL_STATE(1463)] = 63263,
  [SMALL_STATE(1464)] = 63335,
  [SMALL_STATE(1465)] = 63407,
  [SMALL_STATE(1466)] = 63479,
  [SMALL_STATE(1467)] = 63551,
  [SMALL_STATE(1468)] = 63623,
  [SMALL_STATE(1469)] = 63695,
  [SMALL_STATE(1470)] = 63767,
  [SMALL_STATE(1471)] = 63839,
  [SMALL_STATE(1472)] = 63911,
  [SMALL_STATE(1473)] = 63983,
  [SMALL_STATE(1474)] = 64055,
  [SMALL_STATE(1475)] = 64127,
  [SMALL_STATE(1476)] = 64199,
  [SMALL_STATE(1477)] = 64271,
  [SMALL_STATE(1478)] = 64343,
  [SMALL_STATE(1479)] = 64415,
  [SMALL_STATE(1480)] = 64487,
  [SMALL_STATE(1481)] = 64559,
  [SMALL_STATE(1482)] = 64631,
  [SMALL_STATE(1483)] = 64703,
  [SMALL_STATE(1484)] = 64775,
  [SMALL_STATE(1485)] = 64847,
  [SMALL_STATE(1486)] = 64919,
  [SMALL_STATE(1487)] = 64991,
  [SMALL_STATE(1488)] = 65063,
  [SMALL_STATE(1489)] = 65135,
  [SMALL_STATE(1490)] = 65207,
  [SMALL_STATE(1491)] = 65279,
  [SMALL_STATE(1492)] = 65351,
  [SMALL_STATE(1493)] = 65423,
  [SMALL_STATE(1494)] = 65495,
  [SMALL_STATE(1495)] = 65567,
  [SMALL_STATE(1496)] = 65639,
  [SMALL_STATE(1497)] = 65711,
  [SMALL_STATE(1498)] = 65783,
  [SMALL_STATE(1499)] = 65855,
  [SMALL_STATE(1500)] = 65927,
  [SMALL_STATE(1501)] = 65999,
  [SMALL_STATE(1502)] = 66071,
  [SMALL_STATE(1503)] = 66143,
  [SMALL_STATE(1504)] = 66215,
  [SMALL_STATE(1505)] = 66287,
  [SMALL_STATE(1506)] = 66359,
  [SMALL_STATE(1507)] = 66431,
  [SMALL_STATE(1508)] = 66503,
  [SMALL_STATE(1509)] = 66575,
  [SMALL_STATE(1510)] = 66647,
  [SMALL_STATE(1511)] = 66719,
  [SMALL_STATE(1512)] = 66791,
  [SMALL_STATE(1513)] = 66863,
  [SMALL_STATE(1514)] = 66935,
  [SMALL_STATE(1515)] = 67007,
  [SMALL_STATE(1516)] = 67079,
  [SMALL_STATE(1517)] = 67151,
  [SMALL_STATE(1518)] = 67223,
  [SMALL_STATE(1519)] = 67295,
  [SMALL_STATE(1520)] = 67367,
  [SMALL_STATE(1521)] = 67439,
  [SMALL_STATE(1522)] = 67511,
  [SMALL_STATE(1523)] = 67583,
  [SMALL_STATE(1524)] = 67655,
  [SMALL_STATE(1525)] = 67727,
  [SMALL_STATE(1526)] = 67799,
  [SMALL_STATE(1527)] = 67871,
  [SMALL_STATE(1528)] = 67943,
  [SMALL_STATE(1529)] = 68015,
  [SMALL_STATE(1530)] = 68087,
  [SMALL_STATE(1531)] = 68159,
  [SMALL_STATE(1532)] = 68231,
  [SMALL_STATE(1533)] = 68303,
  [SMALL_STATE(1534)] = 68375,
  [SMALL_STATE(1535)] = 68447,
  [SMALL_STATE(1536)] = 68519,
  [SMALL_STATE(1537)] = 68591,
  [SMALL_STATE(1538)] = 68663,
  [SMALL_STATE(1539)] = 68735,
  [SMALL_STATE(1540)] = 68807,
  [SMALL_STATE(1541)] = 68879,
  [SMALL_STATE(1542)] = 68951,
  [SMALL_STATE(1543)] = 69023,
  [SMALL_STATE(1544)] = 69095,
  [SMALL_STATE(1545)] = 69167,
  [SMALL_STATE(1546)] = 69239,
  [SMALL_STATE(1547)] = 69311,
  [SMALL_STATE(1548)] = 69383,
  [SMALL_STATE(1549)] = 69455,
  [SMALL_STATE(1550)] = 69527,
  [SMALL_STATE(1551)] = 69599,
  [SMALL_STATE(1552)] = 69671,
  [SMALL_STATE(1553)] = 69743,
  [SMALL_STATE(1554)] = 69815,
  [SMALL_STATE(1555)] = 69887,
  [SMALL_STATE(1556)] = 69959,
  [SMALL_STATE(1557)] = 70031,
  [SMALL_STATE(1558)] = 70103,
  [SMALL_STATE(1559)] = 70175,
  [SMALL_STATE(1560)] = 70247,
  [SMALL_STATE(1561)] = 70319,
  [SMALL_STATE(1562)] = 70391,
  [SMALL_STATE(1563)] = 70463,
  [SMALL_STATE(1564)] = 70535,
  [SMALL_STATE(1565)] = 70607,
  [SMALL_STATE(1566)] = 70679,
  [SMALL_STATE(1567)] = 70751,
  [SMALL_STATE(1568)] = 70823,
  [SMALL_STATE(1569)] = 70895,
  [SMALL_STATE(1570)] = 70967,
  [SMALL_STATE(1571)] = 71039,
  [SMALL_STATE(1572)] = 71111,
  [SMALL_STATE(1573)] = 71183,
  [SMALL_STATE(1574)] = 71255,
  [SMALL_STATE(1575)] = 71327,
  [SMALL_STATE(1576)] = 71399,
  [SMALL_STATE(1577)] = 71471,
  [SMALL_STATE(1578)] = 71543,
  [SMALL_STATE(1579)] = 71615,
  [SMALL_STATE(1580)] = 71687,
  [SMALL_STATE(1581)] = 71759,
  [SMALL_STATE(1582)] = 71831,
  [SMALL_STATE(1583)] = 71903,
  [SMALL_STATE(1584)] = 71975,
  [SMALL_STATE(1585)] = 72047,
  [SMALL_STATE(1586)] = 72119,
  [SMALL_STATE(1587)] = 72191,
  [SMALL_STATE(1588)] = 72263,
  [SMALL_STATE(1589)] = 72335,
  [SMALL_STATE(1590)] = 72407,
  [SMALL_STATE(1591)] = 72479,
  [SMALL_STATE(1592)] = 72551,
  [SMALL_STATE(1593)] = 72623,
  [SMALL_STATE(1594)] = 72695,
  [SMALL_STATE(1595)] = 72767,
  [SMALL_STATE(1596)] = 72839,
  [SMALL_STATE(1597)] = 72911,
  [SMALL_STATE(1598)] = 72983,
  [SMALL_STATE(1599)] = 73055,
  [SMALL_STATE(1600)] = 73106,
  [SMALL_STATE(1601)] = 73177,
  [SMALL_STATE(1602)] = 73248,
  [SMALL_STATE(1603)] = 73319,
  [SMALL_STATE(1604)] = 73368,
  [SMALL_STATE(1605)] = 73439,
  [SMALL_STATE(1606)] = 73488,
  [SMALL_STATE(1607)] = 73559,
  [SMALL_STATE(1608)] = 73630,
  [SMALL_STATE(1609)] = 73698,
  [SMALL_STATE(1610)] = 73766,
  [SMALL_STATE(1611)] = 73834,
  [SMALL_STATE(1612)] = 73902,
  [SMALL_STATE(1613)] = 73970,
  [SMALL_STATE(1614)] = 74038,
  [SMALL_STATE(1615)] = 74106,
  [SMALL_STATE(1616)] = 74174,
  [SMALL_STATE(1617)] = 74242,
  [SMALL_STATE(1618)] = 74310,
  [SMALL_STATE(1619)] = 74378,
  [SMALL_STATE(1620)] = 74446,
  [SMALL_STATE(1621)] = 74514,
  [SMALL_STATE(1622)] = 74582,
  [SMALL_STATE(1623)] = 74650,
  [SMALL_STATE(1624)] = 74718,
  [SMALL_STATE(1625)] = 74764,
  [SMALL_STATE(1626)] = 74832,
  [SMALL_STATE(1627)] = 74900,
  [SMALL_STATE(1628)] = 74968,
  [SMALL_STATE(1629)] = 75036,
  [SMALL_STATE(1630)] = 75104,
  [SMALL_STATE(1631)] = 75172,
  [SMALL_STATE(1632)] = 75218,
  [SMALL_STATE(1633)] = 75286,
  [SMALL_STATE(1634)] = 75354,
  [SMALL_STATE(1635)] = 75422,
  [SMALL_STATE(1636)] = 75490,
  [SMALL_STATE(1637)] = 75558,
  [SMALL_STATE(1638)] = 75626,
  [SMALL_STATE(1639)] = 75694,
  [SMALL_STATE(1640)] = 75762,
  [SMALL_STATE(1641)] = 75830,
  [SMALL_STATE(1642)] = 75895,
  [SMALL_STATE(1643)] = 75960,
  [SMALL_STATE(1644)] = 76009,
  [SMALL_STATE(1645)] = 76058,
  [SMALL_STATE(1646)] = 76107,
  [SMALL_STATE(1647)] = 76172,
  [SMALL_STATE(1648)] = 76221,
  [SMALL_STATE(1649)] = 76286,
  [SMALL_STATE(1650)] = 76351,
  [SMALL_STATE(1651)] = 76416,
  [SMALL_STATE(1652)] = 76481,
  [SMALL_STATE(1653)] = 76546,
  [SMALL_STATE(1654)] = 76595,
  [SMALL_STATE(1655)] = 76660,
  [SMALL_STATE(1656)] = 76725,
  [SMALL_STATE(1657)] = 76790,
  [SMALL_STATE(1658)] = 76855,
  [SMALL_STATE(1659)] = 76920,
  [SMALL_STATE(1660)] = 76985,
  [SMALL_STATE(1661)] = 77050,
  [SMALL_STATE(1662)] = 77115,
  [SMALL_STATE(1663)] = 77164,
  [SMALL_STATE(1664)] = 77213,
  [SMALL_STATE(1665)] = 77278,
  [SMALL_STATE(1666)] = 77327,
  [SMALL_STATE(1667)] = 77392,
  [SMALL_STATE(1668)] = 77441,
  [SMALL_STATE(1669)] = 77490,
  [SMALL_STATE(1670)] = 77539,
  [SMALL_STATE(1671)] = 77588,
  [SMALL_STATE(1672)] = 77637,
  [SMALL_STATE(1673)] = 77686,
  [SMALL_STATE(1674)] = 77735,
  [SMALL_STATE(1675)] = 77784,
  [SMALL_STATE(1676)] = 77833,
  [SMALL_STATE(1677)] = 77882,
  [SMALL_STATE(1678)] = 77947,
  [SMALL_STATE(1679)] = 78012,
  [SMALL_STATE(1680)] = 78077,
  [SMALL_STATE(1681)] = 78142,
  [SMALL_STATE(1682)] = 78207,
  [SMALL_STATE(1683)] = 78256,
  [SMALL_STATE(1684)] = 78321,
  [SMALL_STATE(1685)] = 78370,
  [SMALL_STATE(1686)] = 78435,
  [SMALL_STATE(1687)] = 78500,
  [SMALL_STATE(1688)] = 78565,
  [SMALL_STATE(1689)] = 78614,
  [SMALL_STATE(1690)] = 78679,
  [SMALL_STATE(1691)] = 78744,
  [SMALL_STATE(1692)] = 78793,
  [SMALL_STATE(1693)] = 78858,
  [SMALL_STATE(1694)] = 78923,
  [SMALL_STATE(1695)] = 78972,
  [SMALL_STATE(1696)] = 79021,
  [SMALL_STATE(1697)] = 79070,
  [SMALL_STATE(1698)] = 79119,
  [SMALL_STATE(1699)] = 79184,
  [SMALL_STATE(1700)] = 79249,
  [SMALL_STATE(1701)] = 79298,
  [SMALL_STATE(1702)] = 79363,
  [SMALL_STATE(1703)] = 79428,
  [SMALL_STATE(1704)] = 79493,
  [SMALL_STATE(1705)] = 79542,
  [SMALL_STATE(1706)] = 79591,
  [SMALL_STATE(1707)] = 79656,
  [SMALL_STATE(1708)] = 79705,
  [SMALL_STATE(1709)] = 79754,
  [SMALL_STATE(1710)] = 79819,
  [SMALL_STATE(1711)] = 79884,
  [SMALL_STATE(1712)] = 79933,
  [SMALL_STATE(1713)] = 79982,
  [SMALL_STATE(1714)] = 80047,
  [SMALL_STATE(1715)] = 80112,
  [SMALL_STATE(1716)] = 80161,
  [SMALL_STATE(1717)] = 80210,
  [SMALL_STATE(1718)] = 80259,
  [SMALL_STATE(1719)] = 80324,
  [SMALL_STATE(1720)] = 80389,
  [SMALL_STATE(1721)] = 80454,
  [SMALL_STATE(1722)] = 80519,
  [SMALL_STATE(1723)] = 80584,
  [SMALL_STATE(1724)] = 80633,
  [SMALL_STATE(1725)] = 80682,
  [SMALL_STATE(1726)] = 80747,
  [SMALL_STATE(1727)] = 80796,
  [SMALL_STATE(1728)] = 80861,
  [SMALL_STATE(1729)] = 80910,
  [SMALL_STATE(1730)] = 80959,
  [SMALL_STATE(1731)] = 81024,
  [SMALL_STATE(1732)] = 81089,
  [SMALL_STATE(1733)] = 81138,
  [SMALL_STATE(1734)] = 81187,
  [SMALL_STATE(1735)] = 81236,
  [SMALL_STATE(1736)] = 81285,
  [SMALL_STATE(1737)] = 81350,
  [SMALL_STATE(1738)] = 81399,
  [SMALL_STATE(1739)] = 81464,
  [SMALL_STATE(1740)] = 81513,
  [SMALL_STATE(1741)] = 81562,
  [SMALL_STATE(1742)] = 81611,
  [SMALL_STATE(1743)] = 81676,
  [SMALL_STATE(1744)] = 81741,
  [SMALL_STATE(1745)] = 81806,
  [SMALL_STATE(1746)] = 81871,
  [SMALL_STATE(1747)] = 81920,
  [SMALL_STATE(1748)] = 81969,
  [SMALL_STATE(1749)] = 82018,
  [SMALL_STATE(1750)] = 82067,
  [SMALL_STATE(1751)] = 82116,
  [SMALL_STATE(1752)] = 82181,
  [SMALL_STATE(1753)] = 82246,
  [SMALL_STATE(1754)] = 82295,
  [SMALL_STATE(1755)] = 82344,
  [SMALL_STATE(1756)] = 82393,
  [SMALL_STATE(1757)] = 82458,
  [SMALL_STATE(1758)] = 82507,
  [SMALL_STATE(1759)] = 82572,
  [SMALL_STATE(1760)] = 82637,
  [SMALL_STATE(1761)] = 82686,
  [SMALL_STATE(1762)] = 82735,
  [SMALL_STATE(1763)] = 82800,
  [SMALL_STATE(1764)] = 82865,
  [SMALL_STATE(1765)] = 82930,
  [SMALL_STATE(1766)] = 82995,
  [SMALL_STATE(1767)] = 83060,
  [SMALL_STATE(1768)] = 83109,
  [SMALL_STATE(1769)] = 83174,
  [SMALL_STATE(1770)] = 83223,
  [SMALL_STATE(1771)] = 83272,
  [SMALL_STATE(1772)] = 83337,
  [SMALL_STATE(1773)] = 83402,
  [SMALL_STATE(1774)] = 83467,
  [SMALL_STATE(1775)] = 83516,
  [SMALL_STATE(1776)] = 83565,
  [SMALL_STATE(1777)] = 83630,
  [SMALL_STATE(1778)] = 83679,
  [SMALL_STATE(1779)] = 83728,
  [SMALL_STATE(1780)] = 83793,
  [SMALL_STATE(1781)] = 83858,
  [SMALL_STATE(1782)] = 83923,
  [SMALL_STATE(1783)] = 83972,
  [SMALL_STATE(1784)] = 84021,
  [SMALL_STATE(1785)] = 84086,
  [SMALL_STATE(1786)] = 84151,
  [SMALL_STATE(1787)] = 84216,
  [SMALL_STATE(1788)] = 84281,
  [SMALL_STATE(1789)] = 84330,
  [SMALL_STATE(1790)] = 84395,
  [SMALL_STATE(1791)] = 84460,
  [SMALL_STATE(1792)] = 84509,
  [SMALL_STATE(1793)] = 84574,
  [SMALL_STATE(1794)] = 84623,
  [SMALL_STATE(1795)] = 84672,
  [SMALL_STATE(1796)] = 84737,
  [SMALL_STATE(1797)] = 84802,
  [SMALL_STATE(1798)] = 84867,
  [SMALL_STATE(1799)] = 84932,
  [SMALL_STATE(1800)] = 84981,
  [SMALL_STATE(1801)] = 85027,
  [SMALL_STATE(1802)] = 85064,
  [SMALL_STATE(1803)] = 85104,
  [SMALL_STATE(1804)] = 85144,
  [SMALL_STATE(1805)] = 85181,
  [SMALL_STATE(1806)] = 85218,
  [SMALL_STATE(1807)] = 85255,
  [SMALL_STATE(1808)] = 85292,
  [SMALL_STATE(1809)] = 85329,
  [SMALL_STATE(1810)] = 85366,
  [SMALL_STATE(1811)] = 85403,
  [SMALL_STATE(1812)] = 85440,
  [SMALL_STATE(1813)] = 85477,
  [SMALL_STATE(1814)] = 85514,
  [SMALL_STATE(1815)] = 85551,
  [SMALL_STATE(1816)] = 85588,
  [SMALL_STATE(1817)] = 85625,
  [SMALL_STATE(1818)] = 85662,
  [SMALL_STATE(1819)] = 85699,
  [SMALL_STATE(1820)] = 85736,
  [SMALL_STATE(1821)] = 85773,
  [SMALL_STATE(1822)] = 85810,
  [SMALL_STATE(1823)] = 85847,
  [SMALL_STATE(1824)] = 85884,
  [SMALL_STATE(1825)] = 85921,
  [SMALL_STATE(1826)] = 85958,
  [SMALL_STATE(1827)] = 85995,
  [SMALL_STATE(1828)] = 86032,
  [SMALL_STATE(1829)] = 86069,
  [SMALL_STATE(1830)] = 86106,
  [SMALL_STATE(1831)] = 86143,
  [SMALL_STATE(1832)] = 86180,
  [SMALL_STATE(1833)] = 86217,
  [SMALL_STATE(1834)] = 86254,
  [SMALL_STATE(1835)] = 86291,
  [SMALL_STATE(1836)] = 86328,
  [SMALL_STATE(1837)] = 86365,
  [SMALL_STATE(1838)] = 86402,
  [SMALL_STATE(1839)] = 86439,
  [SMALL_STATE(1840)] = 86476,
  [SMALL_STATE(1841)] = 86513,
  [SMALL_STATE(1842)] = 86566,
  [SMALL_STATE(1843)] = 86619,
  [SMALL_STATE(1844)] = 86672,
  [SMALL_STATE(1845)] = 86725,
  [SMALL_STATE(1846)] = 86774,
  [SMALL_STATE(1847)] = 86824,
  [SMALL_STATE(1848)] = 86851,
  [SMALL_STATE(1849)] = 86878,
  [SMALL_STATE(1850)] = 86905,
  [SMALL_STATE(1851)] = 86932,
  [SMALL_STATE(1852)] = 86959,
  [SMALL_STATE(1853)] = 86987,
  [SMALL_STATE(1854)] = 87013,
  [SMALL_STATE(1855)] = 87041,
  [SMALL_STATE(1856)] = 87069,
  [SMALL_STATE(1857)] = 87097,
  [SMALL_STATE(1858)] = 87123,
  [SMALL_STATE(1859)] = 87149,
  [SMALL_STATE(1860)] = 87175,
  [SMALL_STATE(1861)] = 87203,
  [SMALL_STATE(1862)] = 87229,
  [SMALL_STATE(1863)] = 87255,
  [SMALL_STATE(1864)] = 87281,
  [SMALL_STATE(1865)] = 87307,
  [SMALL_STATE(1866)] = 87333,
  [SMALL_STATE(1867)] = 87361,
  [SMALL_STATE(1868)] = 87387,
  [SMALL_STATE(1869)] = 87413,
  [SMALL_STATE(1870)] = 87439,
  [SMALL_STATE(1871)] = 87465,
  [SMALL_STATE(1872)] = 87493,
  [SMALL_STATE(1873)] = 87519,
  [SMALL_STATE(1874)] = 87545,
  [SMALL_STATE(1875)] = 87568,
  [SMALL_STATE(1876)] = 87593,
  [SMALL_STATE(1877)] = 87612,
  [SMALL_STATE(1878)] = 87635,
  [SMALL_STATE(1879)] = 87658,
  [SMALL_STATE(1880)] = 87683,
  [SMALL_STATE(1881)] = 87708,
  [SMALL_STATE(1882)] = 87733,
  [SMALL_STATE(1883)] = 87758,
  [SMALL_STATE(1884)] = 87781,
  [SMALL_STATE(1885)] = 87804,
  [SMALL_STATE(1886)] = 87829,
  [SMALL_STATE(1887)] = 87854,
  [SMALL_STATE(1888)] = 87879,
  [SMALL_STATE(1889)] = 87902,
  [SMALL_STATE(1890)] = 87927,
  [SMALL_STATE(1891)] = 87946,
  [SMALL_STATE(1892)] = 87971,
  [SMALL_STATE(1893)] = 87994,
  [SMALL_STATE(1894)] = 88019,
  [SMALL_STATE(1895)] = 88042,
  [SMALL_STATE(1896)] = 88067,
  [SMALL_STATE(1897)] = 88092,
  [SMALL_STATE(1898)] = 88111,
  [SMALL_STATE(1899)] = 88136,
  [SMALL_STATE(1900)] = 88161,
  [SMALL_STATE(1901)] = 88186,
  [SMALL_STATE(1902)] = 88211,
  [SMALL_STATE(1903)] = 88236,
  [SMALL_STATE(1904)] = 88261,
  [SMALL_STATE(1905)] = 88284,
  [SMALL_STATE(1906)] = 88309,
  [SMALL_STATE(1907)] = 88332,
  [SMALL_STATE(1908)] = 88357,
  [SMALL_STATE(1909)] = 88380,
  [SMALL_STATE(1910)] = 88405,
  [SMALL_STATE(1911)] = 88430,
  [SMALL_STATE(1912)] = 88455,
  [SMALL_STATE(1913)] = 88480,
  [SMALL_STATE(1914)] = 88503,
  [SMALL_STATE(1915)] = 88526,
  [SMALL_STATE(1916)] = 88549,
  [SMALL_STATE(1917)] = 88572,
  [SMALL_STATE(1918)] = 88595,
  [SMALL_STATE(1919)] = 88618,
  [SMALL_STATE(1920)] = 88643,
  [SMALL_STATE(1921)] = 88665,
  [SMALL_STATE(1922)] = 88687,
  [SMALL_STATE(1923)] = 88709,
  [SMALL_STATE(1924)] = 88731,
  [SMALL_STATE(1925)] = 88751,
  [SMALL_STATE(1926)] = 88771,
  [SMALL_STATE(1927)] = 88793,
  [SMALL_STATE(1928)] = 88813,
  [SMALL_STATE(1929)] = 88835,
  [SMALL_STATE(1930)] = 88857,
  [SMALL_STATE(1931)] = 88877,
  [SMALL_STATE(1932)] = 88899,
  [SMALL_STATE(1933)] = 88919,
  [SMALL_STATE(1934)] = 88939,
  [SMALL_STATE(1935)] = 88961,
  [SMALL_STATE(1936)] = 88981,
  [SMALL_STATE(1937)] = 89003,
  [SMALL_STATE(1938)] = 89025,
  [SMALL_STATE(1939)] = 89047,
  [SMALL_STATE(1940)] = 89067,
  [SMALL_STATE(1941)] = 89089,
  [SMALL_STATE(1942)] = 89109,
  [SMALL_STATE(1943)] = 89129,
  [SMALL_STATE(1944)] = 89151,
  [SMALL_STATE(1945)] = 89171,
  [SMALL_STATE(1946)] = 89188,
  [SMALL_STATE(1947)] = 89203,
  [SMALL_STATE(1948)] = 89220,
  [SMALL_STATE(1949)] = 89239,
  [SMALL_STATE(1950)] = 89258,
  [SMALL_STATE(1951)] = 89277,
  [SMALL_STATE(1952)] = 89294,
  [SMALL_STATE(1953)] = 89313,
  [SMALL_STATE(1954)] = 89330,
  [SMALL_STATE(1955)] = 89349,
  [SMALL_STATE(1956)] = 89368,
  [SMALL_STATE(1957)] = 89387,
  [SMALL_STATE(1958)] = 89404,
  [SMALL_STATE(1959)] = 89423,
  [SMALL_STATE(1960)] = 89442,
  [SMALL_STATE(1961)] = 89461,
  [SMALL_STATE(1962)] = 89476,
  [SMALL_STATE(1963)] = 89495,
  [SMALL_STATE(1964)] = 89514,
  [SMALL_STATE(1965)] = 89533,
  [SMALL_STATE(1966)] = 89552,
  [SMALL_STATE(1967)] = 89571,
  [SMALL_STATE(1968)] = 89590,
  [SMALL_STATE(1969)] = 89609,
  [SMALL_STATE(1970)] = 89628,
  [SMALL_STATE(1971)] = 89647,
  [SMALL_STATE(1972)] = 89666,
  [SMALL_STATE(1973)] = 89685,
  [SMALL_STATE(1974)] = 89704,
  [SMALL_STATE(1975)] = 89723,
  [SMALL_STATE(1976)] = 89742,
  [SMALL_STATE(1977)] = 89761,
  [SMALL_STATE(1978)] = 89780,
  [SMALL_STATE(1979)] = 89797,
  [SMALL_STATE(1980)] = 89816,
  [SMALL_STATE(1981)] = 89831,
  [SMALL_STATE(1982)] = 89850,
  [SMALL_STATE(1983)] = 89866,
  [SMALL_STATE(1984)] = 89882,
  [SMALL_STATE(1985)] = 89898,
  [SMALL_STATE(1986)] = 89912,
  [SMALL_STATE(1987)] = 89928,
  [SMALL_STATE(1988)] = 89944,
  [SMALL_STATE(1989)] = 89960,
  [SMALL_STATE(1990)] = 89976,
  [SMALL_STATE(1991)] = 89990,
  [SMALL_STATE(1992)] = 90004,
  [SMALL_STATE(1993)] = 90020,
  [SMALL_STATE(1994)] = 90036,
  [SMALL_STATE(1995)] = 90052,
  [SMALL_STATE(1996)] = 90066,
  [SMALL_STATE(1997)] = 90080,
  [SMALL_STATE(1998)] = 90094,
  [SMALL_STATE(1999)] = 90110,
  [SMALL_STATE(2000)] = 90126,
  [SMALL_STATE(2001)] = 90142,
  [SMALL_STATE(2002)] = 90158,
  [SMALL_STATE(2003)] = 90172,
  [SMALL_STATE(2004)] = 90186,
  [SMALL_STATE(2005)] = 90202,
  [SMALL_STATE(2006)] = 90218,
  [SMALL_STATE(2007)] = 90232,
  [SMALL_STATE(2008)] = 90248,
  [SMALL_STATE(2009)] = 90262,
  [SMALL_STATE(2010)] = 90278,
  [SMALL_STATE(2011)] = 90294,
  [SMALL_STATE(2012)] = 90310,
  [SMALL_STATE(2013)] = 90324,
  [SMALL_STATE(2014)] = 90338,
  [SMALL_STATE(2015)] = 90354,
  [SMALL_STATE(2016)] = 90370,
  [SMALL_STATE(2017)] = 90386,
  [SMALL_STATE(2018)] = 90402,
  [SMALL_STATE(2019)] = 90416,
  [SMALL_STATE(2020)] = 90430,
  [SMALL_STATE(2021)] = 90446,
  [SMALL_STATE(2022)] = 90462,
  [SMALL_STATE(2023)] = 90478,
  [SMALL_STATE(2024)] = 90494,
  [SMALL_STATE(2025)] = 90508,
  [SMALL_STATE(2026)] = 90522,
  [SMALL_STATE(2027)] = 90538,
  [SMALL_STATE(2028)] = 90554,
  [SMALL_STATE(2029)] = 90570,
  [SMALL_STATE(2030)] = 90584,
  [SMALL_STATE(2031)] = 90598,
  [SMALL_STATE(2032)] = 90614,
  [SMALL_STATE(2033)] = 90630,
  [SMALL_STATE(2034)] = 90646,
  [SMALL_STATE(2035)] = 90662,
  [SMALL_STATE(2036)] = 90676,
  [SMALL_STATE(2037)] = 90690,
  [SMALL_STATE(2038)] = 90704,
  [SMALL_STATE(2039)] = 90718,
  [SMALL_STATE(2040)] = 90734,
  [SMALL_STATE(2041)] = 90750,
  [SMALL_STATE(2042)] = 90766,
  [SMALL_STATE(2043)] = 90780,
  [SMALL_STATE(2044)] = 90796,
  [SMALL_STATE(2045)] = 90812,
  [SMALL_STATE(2046)] = 90828,
  [SMALL_STATE(2047)] = 90844,
  [SMALL_STATE(2048)] = 90860,
  [SMALL_STATE(2049)] = 90876,
  [SMALL_STATE(2050)] = 90890,
  [SMALL_STATE(2051)] = 90904,
  [SMALL_STATE(2052)] = 90920,
  [SMALL_STATE(2053)] = 90936,
  [SMALL_STATE(2054)] = 90952,
  [SMALL_STATE(2055)] = 90968,
  [SMALL_STATE(2056)] = 90984,
  [SMALL_STATE(2057)] = 91000,
  [SMALL_STATE(2058)] = 91016,
  [SMALL_STATE(2059)] = 91032,
  [SMALL_STATE(2060)] = 91046,
  [SMALL_STATE(2061)] = 91062,
  [SMALL_STATE(2062)] = 91078,
  [SMALL_STATE(2063)] = 91094,
  [SMALL_STATE(2064)] = 91110,
  [SMALL_STATE(2065)] = 91126,
  [SMALL_STATE(2066)] = 91142,
  [SMALL_STATE(2067)] = 91158,
  [SMALL_STATE(2068)] = 91174,
  [SMALL_STATE(2069)] = 91190,
  [SMALL_STATE(2070)] = 91206,
  [SMALL_STATE(2071)] = 91222,
  [SMALL_STATE(2072)] = 91238,
  [SMALL_STATE(2073)] = 91254,
  [SMALL_STATE(2074)] = 91268,
  [SMALL_STATE(2075)] = 91284,
  [SMALL_STATE(2076)] = 91300,
  [SMALL_STATE(2077)] = 91316,
  [SMALL_STATE(2078)] = 91332,
  [SMALL_STATE(2079)] = 91348,
  [SMALL_STATE(2080)] = 91364,
  [SMALL_STATE(2081)] = 91380,
  [SMALL_STATE(2082)] = 91396,
  [SMALL_STATE(2083)] = 91412,
  [SMALL_STATE(2084)] = 91428,
  [SMALL_STATE(2085)] = 91444,
  [SMALL_STATE(2086)] = 91460,
  [SMALL_STATE(2087)] = 91476,
  [SMALL_STATE(2088)] = 91492,
  [SMALL_STATE(2089)] = 91508,
  [SMALL_STATE(2090)] = 91524,
  [SMALL_STATE(2091)] = 91540,
  [SMALL_STATE(2092)] = 91554,
  [SMALL_STATE(2093)] = 91570,
  [SMALL_STATE(2094)] = 91586,
  [SMALL_STATE(2095)] = 91602,
  [SMALL_STATE(2096)] = 91618,
  [SMALL_STATE(2097)] = 91634,
  [SMALL_STATE(2098)] = 91650,
  [SMALL_STATE(2099)] = 91666,
  [SMALL_STATE(2100)] = 91682,
  [SMALL_STATE(2101)] = 91698,
  [SMALL_STATE(2102)] = 91714,
  [SMALL_STATE(2103)] = 91730,
  [SMALL_STATE(2104)] = 91746,
  [SMALL_STATE(2105)] = 91762,
  [SMALL_STATE(2106)] = 91778,
  [SMALL_STATE(2107)] = 91794,
  [SMALL_STATE(2108)] = 91808,
  [SMALL_STATE(2109)] = 91824,
  [SMALL_STATE(2110)] = 91838,
  [SMALL_STATE(2111)] = 91854,
  [SMALL_STATE(2112)] = 91870,
  [SMALL_STATE(2113)] = 91886,
  [SMALL_STATE(2114)] = 91902,
  [SMALL_STATE(2115)] = 91916,
  [SMALL_STATE(2116)] = 91932,
  [SMALL_STATE(2117)] = 91948,
  [SMALL_STATE(2118)] = 91964,
  [SMALL_STATE(2119)] = 91978,
  [SMALL_STATE(2120)] = 91994,
  [SMALL_STATE(2121)] = 92008,
  [SMALL_STATE(2122)] = 92024,
  [SMALL_STATE(2123)] = 92040,
  [SMALL_STATE(2124)] = 92056,
  [SMALL_STATE(2125)] = 92072,
  [SMALL_STATE(2126)] = 92088,
  [SMALL_STATE(2127)] = 92104,
  [SMALL_STATE(2128)] = 92120,
  [SMALL_STATE(2129)] = 92136,
  [SMALL_STATE(2130)] = 92152,
  [SMALL_STATE(2131)] = 92168,
  [SMALL_STATE(2132)] = 92184,
  [SMALL_STATE(2133)] = 92200,
  [SMALL_STATE(2134)] = 92216,
  [SMALL_STATE(2135)] = 92230,
  [SMALL_STATE(2136)] = 92246,
  [SMALL_STATE(2137)] = 92260,
  [SMALL_STATE(2138)] = 92276,
  [SMALL_STATE(2139)] = 92292,
  [SMALL_STATE(2140)] = 92308,
  [SMALL_STATE(2141)] = 92324,
  [SMALL_STATE(2142)] = 92338,
  [SMALL_STATE(2143)] = 92354,
  [SMALL_STATE(2144)] = 92370,
  [SMALL_STATE(2145)] = 92384,
  [SMALL_STATE(2146)] = 92400,
  [SMALL_STATE(2147)] = 92416,
  [SMALL_STATE(2148)] = 92432,
  [SMALL_STATE(2149)] = 92448,
  [SMALL_STATE(2150)] = 92464,
  [SMALL_STATE(2151)] = 92480,
  [SMALL_STATE(2152)] = 92496,
  [SMALL_STATE(2153)] = 92512,
  [SMALL_STATE(2154)] = 92528,
  [SMALL_STATE(2155)] = 92544,
  [SMALL_STATE(2156)] = 92560,
  [SMALL_STATE(2157)] = 92576,
  [SMALL_STATE(2158)] = 92592,
  [SMALL_STATE(2159)] = 92608,
  [SMALL_STATE(2160)] = 92624,
  [SMALL_STATE(2161)] = 92640,
  [SMALL_STATE(2162)] = 92656,
  [SMALL_STATE(2163)] = 92672,
  [SMALL_STATE(2164)] = 92688,
  [SMALL_STATE(2165)] = 92704,
  [SMALL_STATE(2166)] = 92720,
  [SMALL_STATE(2167)] = 92736,
  [SMALL_STATE(2168)] = 92752,
  [SMALL_STATE(2169)] = 92768,
  [SMALL_STATE(2170)] = 92784,
  [SMALL_STATE(2171)] = 92800,
  [SMALL_STATE(2172)] = 92814,
  [SMALL_STATE(2173)] = 92830,
  [SMALL_STATE(2174)] = 92846,
  [SMALL_STATE(2175)] = 92862,
  [SMALL_STATE(2176)] = 92878,
  [SMALL_STATE(2177)] = 92894,
  [SMALL_STATE(2178)] = 92910,
  [SMALL_STATE(2179)] = 92926,
  [SMALL_STATE(2180)] = 92942,
  [SMALL_STATE(2181)] = 92956,
  [SMALL_STATE(2182)] = 92972,
  [SMALL_STATE(2183)] = 92988,
  [SMALL_STATE(2184)] = 93002,
  [SMALL_STATE(2185)] = 93018,
  [SMALL_STATE(2186)] = 93034,
  [SMALL_STATE(2187)] = 93050,
  [SMALL_STATE(2188)] = 93066,
  [SMALL_STATE(2189)] = 93082,
  [SMALL_STATE(2190)] = 93098,
  [SMALL_STATE(2191)] = 93114,
  [SMALL_STATE(2192)] = 93130,
  [SMALL_STATE(2193)] = 93146,
  [SMALL_STATE(2194)] = 93162,
  [SMALL_STATE(2195)] = 93178,
  [SMALL_STATE(2196)] = 93194,
  [SMALL_STATE(2197)] = 93210,
  [SMALL_STATE(2198)] = 93226,
  [SMALL_STATE(2199)] = 93242,
  [SMALL_STATE(2200)] = 93258,
  [SMALL_STATE(2201)] = 93274,
  [SMALL_STATE(2202)] = 93290,
  [SMALL_STATE(2203)] = 93306,
  [SMALL_STATE(2204)] = 93322,
  [SMALL_STATE(2205)] = 93338,
  [SMALL_STATE(2206)] = 93354,
  [SMALL_STATE(2207)] = 93370,
  [SMALL_STATE(2208)] = 93386,
  [SMALL_STATE(2209)] = 93402,
  [SMALL_STATE(2210)] = 93418,
  [SMALL_STATE(2211)] = 93434,
  [SMALL_STATE(2212)] = 93450,
  [SMALL_STATE(2213)] = 93464,
  [SMALL_STATE(2214)] = 93480,
  [SMALL_STATE(2215)] = 93496,
  [SMALL_STATE(2216)] = 93509,
  [SMALL_STATE(2217)] = 93522,
  [SMALL_STATE(2218)] = 93535,
  [SMALL_STATE(2219)] = 93548,
  [SMALL_STATE(2220)] = 93561,
  [SMALL_STATE(2221)] = 93574,
  [SMALL_STATE(2222)] = 93587,
  [SMALL_STATE(2223)] = 93600,
  [SMALL_STATE(2224)] = 93613,
  [SMALL_STATE(2225)] = 93626,
  [SMALL_STATE(2226)] = 93639,
  [SMALL_STATE(2227)] = 93652,
  [SMALL_STATE(2228)] = 93665,
  [SMALL_STATE(2229)] = 93678,
  [SMALL_STATE(2230)] = 93691,
  [SMALL_STATE(2231)] = 93704,
  [SMALL_STATE(2232)] = 93717,
  [SMALL_STATE(2233)] = 93730,
  [SMALL_STATE(2234)] = 93743,
  [SMALL_STATE(2235)] = 93756,
  [SMALL_STATE(2236)] = 93769,
  [SMALL_STATE(2237)] = 93782,
  [SMALL_STATE(2238)] = 93795,
  [SMALL_STATE(2239)] = 93808,
  [SMALL_STATE(2240)] = 93821,
  [SMALL_STATE(2241)] = 93834,
  [SMALL_STATE(2242)] = 93847,
  [SMALL_STATE(2243)] = 93860,
  [SMALL_STATE(2244)] = 93873,
  [SMALL_STATE(2245)] = 93886,
  [SMALL_STATE(2246)] = 93899,
  [SMALL_STATE(2247)] = 93912,
  [SMALL_STATE(2248)] = 93925,
  [SMALL_STATE(2249)] = 93938,
  [SMALL_STATE(2250)] = 93951,
  [SMALL_STATE(2251)] = 93964,
  [SMALL_STATE(2252)] = 93977,
  [SMALL_STATE(2253)] = 93990,
  [SMALL_STATE(2254)] = 94003,
  [SMALL_STATE(2255)] = 94016,
  [SMALL_STATE(2256)] = 94029,
  [SMALL_STATE(2257)] = 94042,
  [SMALL_STATE(2258)] = 94055,
  [SMALL_STATE(2259)] = 94068,
  [SMALL_STATE(2260)] = 94081,
  [SMALL_STATE(2261)] = 94094,
  [SMALL_STATE(2262)] = 94107,
  [SMALL_STATE(2263)] = 94120,
  [SMALL_STATE(2264)] = 94133,
  [SMALL_STATE(2265)] = 94146,
  [SMALL_STATE(2266)] = 94159,
  [SMALL_STATE(2267)] = 94172,
  [SMALL_STATE(2268)] = 94185,
  [SMALL_STATE(2269)] = 94198,
  [SMALL_STATE(2270)] = 94211,
  [SMALL_STATE(2271)] = 94224,
  [SMALL_STATE(2272)] = 94237,
  [SMALL_STATE(2273)] = 94250,
  [SMALL_STATE(2274)] = 94263,
  [SMALL_STATE(2275)] = 94276,
  [SMALL_STATE(2276)] = 94289,
  [SMALL_STATE(2277)] = 94302,
  [SMALL_STATE(2278)] = 94315,
  [SMALL_STATE(2279)] = 94328,
  [SMALL_STATE(2280)] = 94341,
  [SMALL_STATE(2281)] = 94354,
  [SMALL_STATE(2282)] = 94367,
  [SMALL_STATE(2283)] = 94380,
  [SMALL_STATE(2284)] = 94393,
  [SMALL_STATE(2285)] = 94406,
  [SMALL_STATE(2286)] = 94419,
  [SMALL_STATE(2287)] = 94432,
  [SMALL_STATE(2288)] = 94445,
  [SMALL_STATE(2289)] = 94458,
  [SMALL_STATE(2290)] = 94471,
  [SMALL_STATE(2291)] = 94484,
  [SMALL_STATE(2292)] = 94497,
  [SMALL_STATE(2293)] = 94510,
  [SMALL_STATE(2294)] = 94523,
  [SMALL_STATE(2295)] = 94536,
  [SMALL_STATE(2296)] = 94549,
  [SMALL_STATE(2297)] = 94562,
  [SMALL_STATE(2298)] = 94575,
  [SMALL_STATE(2299)] = 94588,
  [SMALL_STATE(2300)] = 94601,
  [SMALL_STATE(2301)] = 94614,
  [SMALL_STATE(2302)] = 94627,
  [SMALL_STATE(2303)] = 94640,
  [SMALL_STATE(2304)] = 94653,
  [SMALL_STATE(2305)] = 94666,
  [SMALL_STATE(2306)] = 94679,
  [SMALL_STATE(2307)] = 94692,
  [SMALL_STATE(2308)] = 94705,
  [SMALL_STATE(2309)] = 94718,
  [SMALL_STATE(2310)] = 94731,
  [SMALL_STATE(2311)] = 94744,
  [SMALL_STATE(2312)] = 94757,
  [SMALL_STATE(2313)] = 94770,
  [SMALL_STATE(2314)] = 94783,
  [SMALL_STATE(2315)] = 94796,
  [SMALL_STATE(2316)] = 94809,
  [SMALL_STATE(2317)] = 94822,
  [SMALL_STATE(2318)] = 94835,
  [SMALL_STATE(2319)] = 94848,
  [SMALL_STATE(2320)] = 94861,
  [SMALL_STATE(2321)] = 94874,
  [SMALL_STATE(2322)] = 94887,
  [SMALL_STATE(2323)] = 94900,
  [SMALL_STATE(2324)] = 94913,
  [SMALL_STATE(2325)] = 94926,
  [SMALL_STATE(2326)] = 94939,
  [SMALL_STATE(2327)] = 94952,
  [SMALL_STATE(2328)] = 94965,
  [SMALL_STATE(2329)] = 94978,
  [SMALL_STATE(2330)] = 94991,
  [SMALL_STATE(2331)] = 95004,
  [SMALL_STATE(2332)] = 95017,
  [SMALL_STATE(2333)] = 95030,
  [SMALL_STATE(2334)] = 95043,
  [SMALL_STATE(2335)] = 95056,
  [SMALL_STATE(2336)] = 95069,
  [SMALL_STATE(2337)] = 95082,
  [SMALL_STATE(2338)] = 95095,
  [SMALL_STATE(2339)] = 95108,
  [SMALL_STATE(2340)] = 95121,
  [SMALL_STATE(2341)] = 95134,
  [SMALL_STATE(2342)] = 95147,
  [SMALL_STATE(2343)] = 95160,
  [SMALL_STATE(2344)] = 95173,
  [SMALL_STATE(2345)] = 95186,
  [SMALL_STATE(2346)] = 95199,
  [SMALL_STATE(2347)] = 95212,
  [SMALL_STATE(2348)] = 95225,
  [SMALL_STATE(2349)] = 95238,
  [SMALL_STATE(2350)] = 95251,
  [SMALL_STATE(2351)] = 95264,
  [SMALL_STATE(2352)] = 95277,
  [SMALL_STATE(2353)] = 95290,
  [SMALL_STATE(2354)] = 95303,
  [SMALL_STATE(2355)] = 95316,
  [SMALL_STATE(2356)] = 95329,
  [SMALL_STATE(2357)] = 95342,
  [SMALL_STATE(2358)] = 95355,
  [SMALL_STATE(2359)] = 95368,
  [SMALL_STATE(2360)] = 95381,
  [SMALL_STATE(2361)] = 95394,
  [SMALL_STATE(2362)] = 95407,
  [SMALL_STATE(2363)] = 95420,
  [SMALL_STATE(2364)] = 95433,
  [SMALL_STATE(2365)] = 95446,
  [SMALL_STATE(2366)] = 95459,
  [SMALL_STATE(2367)] = 95472,
  [SMALL_STATE(2368)] = 95485,
  [SMALL_STATE(2369)] = 95498,
  [SMALL_STATE(2370)] = 95511,
  [SMALL_STATE(2371)] = 95524,
  [SMALL_STATE(2372)] = 95537,
  [SMALL_STATE(2373)] = 95550,
  [SMALL_STATE(2374)] = 95563,
  [SMALL_STATE(2375)] = 95576,
  [SMALL_STATE(2376)] = 95589,
  [SMALL_STATE(2377)] = 95602,
  [SMALL_STATE(2378)] = 95615,
  [SMALL_STATE(2379)] = 95628,
  [SMALL_STATE(2380)] = 95641,
  [SMALL_STATE(2381)] = 95654,
  [SMALL_STATE(2382)] = 95667,
  [SMALL_STATE(2383)] = 95680,
  [SMALL_STATE(2384)] = 95693,
  [SMALL_STATE(2385)] = 95706,
  [SMALL_STATE(2386)] = 95719,
  [SMALL_STATE(2387)] = 95732,
  [SMALL_STATE(2388)] = 95745,
  [SMALL_STATE(2389)] = 95758,
  [SMALL_STATE(2390)] = 95771,
  [SMALL_STATE(2391)] = 95784,
  [SMALL_STATE(2392)] = 95797,
  [SMALL_STATE(2393)] = 95810,
  [SMALL_STATE(2394)] = 95823,
  [SMALL_STATE(2395)] = 95836,
  [SMALL_STATE(2396)] = 95849,
  [SMALL_STATE(2397)] = 95862,
  [SMALL_STATE(2398)] = 95875,
  [SMALL_STATE(2399)] = 95888,
  [SMALL_STATE(2400)] = 95901,
  [SMALL_STATE(2401)] = 95914,
  [SMALL_STATE(2402)] = 95927,
  [SMALL_STATE(2403)] = 95940,
  [SMALL_STATE(2404)] = 95953,
  [SMALL_STATE(2405)] = 95966,
  [SMALL_STATE(2406)] = 95979,
  [SMALL_STATE(2407)] = 95992,
  [SMALL_STATE(2408)] = 96005,
  [SMALL_STATE(2409)] = 96018,
  [SMALL_STATE(2410)] = 96031,
  [SMALL_STATE(2411)] = 96044,
  [SMALL_STATE(2412)] = 96057,
  [SMALL_STATE(2413)] = 96070,
  [SMALL_STATE(2414)] = 96083,
  [SMALL_STATE(2415)] = 96096,
  [SMALL_STATE(2416)] = 96109,
  [SMALL_STATE(2417)] = 96122,
  [SMALL_STATE(2418)] = 96135,
  [SMALL_STATE(2419)] = 96148,
  [SMALL_STATE(2420)] = 96161,
  [SMALL_STATE(2421)] = 96174,
  [SMALL_STATE(2422)] = 96187,
  [SMALL_STATE(2423)] = 96200,
  [SMALL_STATE(2424)] = 96213,
  [SMALL_STATE(2425)] = 96226,
  [SMALL_STATE(2426)] = 96239,
  [SMALL_STATE(2427)] = 96252,
  [SMALL_STATE(2428)] = 96265,
  [SMALL_STATE(2429)] = 96278,
  [SMALL_STATE(2430)] = 96291,
  [SMALL_STATE(2431)] = 96304,
  [SMALL_STATE(2432)] = 96317,
  [SMALL_STATE(2433)] = 96330,
  [SMALL_STATE(2434)] = 96343,
  [SMALL_STATE(2435)] = 96356,
  [SMALL_STATE(2436)] = 96369,
  [SMALL_STATE(2437)] = 96382,
  [SMALL_STATE(2438)] = 96395,
  [SMALL_STATE(2439)] = 96408,
  [SMALL_STATE(2440)] = 96421,
  [SMALL_STATE(2441)] = 96434,
  [SMALL_STATE(2442)] = 96447,
  [SMALL_STATE(2443)] = 96460,
  [SMALL_STATE(2444)] = 96473,
  [SMALL_STATE(2445)] = 96486,
  [SMALL_STATE(2446)] = 96499,
  [SMALL_STATE(2447)] = 96512,
  [SMALL_STATE(2448)] = 96525,
  [SMALL_STATE(2449)] = 96538,
  [SMALL_STATE(2450)] = 96551,
  [SMALL_STATE(2451)] = 96564,
  [SMALL_STATE(2452)] = 96577,
  [SMALL_STATE(2453)] = 96590,
  [SMALL_STATE(2454)] = 96603,
  [SMALL_STATE(2455)] = 96616,
  [SMALL_STATE(2456)] = 96629,
  [SMALL_STATE(2457)] = 96642,
  [SMALL_STATE(2458)] = 96655,
  [SMALL_STATE(2459)] = 96668,
  [SMALL_STATE(2460)] = 96681,
  [SMALL_STATE(2461)] = 96694,
  [SMALL_STATE(2462)] = 96707,
  [SMALL_STATE(2463)] = 96720,
  [SMALL_STATE(2464)] = 96733,
  [SMALL_STATE(2465)] = 96746,
  [SMALL_STATE(2466)] = 96759,
  [SMALL_STATE(2467)] = 96772,
  [SMALL_STATE(2468)] = 96785,
  [SMALL_STATE(2469)] = 96798,
  [SMALL_STATE(2470)] = 96811,
  [SMALL_STATE(2471)] = 96824,
  [SMALL_STATE(2472)] = 96837,
  [SMALL_STATE(2473)] = 96850,
  [SMALL_STATE(2474)] = 96863,
  [SMALL_STATE(2475)] = 96876,
  [SMALL_STATE(2476)] = 96889,
  [SMALL_STATE(2477)] = 96902,
  [SMALL_STATE(2478)] = 96915,
  [SMALL_STATE(2479)] = 96928,
  [SMALL_STATE(2480)] = 96941,
  [SMALL_STATE(2481)] = 96954,
  [SMALL_STATE(2482)] = 96967,
  [SMALL_STATE(2483)] = 96980,
  [SMALL_STATE(2484)] = 96993,
  [SMALL_STATE(2485)] = 97006,
  [SMALL_STATE(2486)] = 97019,
  [SMALL_STATE(2487)] = 97032,
  [SMALL_STATE(2488)] = 97045,
  [SMALL_STATE(2489)] = 97058,
  [SMALL_STATE(2490)] = 97071,
  [SMALL_STATE(2491)] = 97084,
  [SMALL_STATE(2492)] = 97097,
  [SMALL_STATE(2493)] = 97110,
  [SMALL_STATE(2494)] = 97123,
  [SMALL_STATE(2495)] = 97136,
  [SMALL_STATE(2496)] = 97149,
  [SMALL_STATE(2497)] = 97162,
  [SMALL_STATE(2498)] = 97175,
  [SMALL_STATE(2499)] = 97188,
  [SMALL_STATE(2500)] = 97201,
  [SMALL_STATE(2501)] = 97214,
  [SMALL_STATE(2502)] = 97227,
  [SMALL_STATE(2503)] = 97240,
  [SMALL_STATE(2504)] = 97253,
  [SMALL_STATE(2505)] = 97266,
  [SMALL_STATE(2506)] = 97279,
  [SMALL_STATE(2507)] = 97292,
  [SMALL_STATE(2508)] = 97305,
  [SMALL_STATE(2509)] = 97318,
  [SMALL_STATE(2510)] = 97331,
  [SMALL_STATE(2511)] = 97344,
  [SMALL_STATE(2512)] = 97357,
  [SMALL_STATE(2513)] = 97370,
  [SMALL_STATE(2514)] = 97383,
  [SMALL_STATE(2515)] = 97396,
  [SMALL_STATE(2516)] = 97409,
  [SMALL_STATE(2517)] = 97422,
  [SMALL_STATE(2518)] = 97435,
  [SMALL_STATE(2519)] = 97448,
  [SMALL_STATE(2520)] = 97461,
  [SMALL_STATE(2521)] = 97474,
  [SMALL_STATE(2522)] = 97487,
  [SMALL_STATE(2523)] = 97500,
  [SMALL_STATE(2524)] = 97513,
  [SMALL_STATE(2525)] = 97526,
  [SMALL_STATE(2526)] = 97539,
  [SMALL_STATE(2527)] = 97552,
  [SMALL_STATE(2528)] = 97565,
  [SMALL_STATE(2529)] = 97578,
  [SMALL_STATE(2530)] = 97591,
  [SMALL_STATE(2531)] = 97604,
  [SMALL_STATE(2532)] = 97617,
  [SMALL_STATE(2533)] = 97630,
  [SMALL_STATE(2534)] = 97643,
  [SMALL_STATE(2535)] = 97656,
  [SMALL_STATE(2536)] = 97669,
  [SMALL_STATE(2537)] = 97682,
  [SMALL_STATE(2538)] = 97695,
  [SMALL_STATE(2539)] = 97708,
  [SMALL_STATE(2540)] = 97721,
  [SMALL_STATE(2541)] = 97734,
  [SMALL_STATE(2542)] = 97747,
  [SMALL_STATE(2543)] = 97760,
  [SMALL_STATE(2544)] = 97773,
  [SMALL_STATE(2545)] = 97786,
  [SMALL_STATE(2546)] = 97799,
  [SMALL_STATE(2547)] = 97812,
  [SMALL_STATE(2548)] = 97825,
  [SMALL_STATE(2549)] = 97838,
  [SMALL_STATE(2550)] = 97851,
  [SMALL_STATE(2551)] = 97864,
  [SMALL_STATE(2552)] = 97877,
  [SMALL_STATE(2553)] = 97890,
  [SMALL_STATE(2554)] = 97903,
  [SMALL_STATE(2555)] = 97916,
  [SMALL_STATE(2556)] = 97929,
  [SMALL_STATE(2557)] = 97942,
  [SMALL_STATE(2558)] = 97955,
  [SMALL_STATE(2559)] = 97968,
  [SMALL_STATE(2560)] = 97981,
  [SMALL_STATE(2561)] = 97994,
  [SMALL_STATE(2562)] = 98007,
  [SMALL_STATE(2563)] = 98020,
  [SMALL_STATE(2564)] = 98033,
  [SMALL_STATE(2565)] = 98046,
  [SMALL_STATE(2566)] = 98059,
  [SMALL_STATE(2567)] = 98072,
  [SMALL_STATE(2568)] = 98085,
  [SMALL_STATE(2569)] = 98098,
  [SMALL_STATE(2570)] = 98111,
  [SMALL_STATE(2571)] = 98124,
  [SMALL_STATE(2572)] = 98137,
  [SMALL_STATE(2573)] = 98150,
  [SMALL_STATE(2574)] = 98163,
  [SMALL_STATE(2575)] = 98176,
  [SMALL_STATE(2576)] = 98189,
  [SMALL_STATE(2577)] = 98202,
  [SMALL_STATE(2578)] = 98215,
  [SMALL_STATE(2579)] = 98228,
  [SMALL_STATE(2580)] = 98241,
  [SMALL_STATE(2581)] = 98254,
  [SMALL_STATE(2582)] = 98267,
  [SMALL_STATE(2583)] = 98280,
  [SMALL_STATE(2584)] = 98293,
  [SMALL_STATE(2585)] = 98306,
  [SMALL_STATE(2586)] = 98319,
  [SMALL_STATE(2587)] = 98332,
  [SMALL_STATE(2588)] = 98345,
  [SMALL_STATE(2589)] = 98358,
  [SMALL_STATE(2590)] = 98371,
  [SMALL_STATE(2591)] = 98384,
  [SMALL_STATE(2592)] = 98397,
  [SMALL_STATE(2593)] = 98410,
  [SMALL_STATE(2594)] = 98423,
  [SMALL_STATE(2595)] = 98436,
  [SMALL_STATE(2596)] = 98449,
  [SMALL_STATE(2597)] = 98462,
  [SMALL_STATE(2598)] = 98475,
  [SMALL_STATE(2599)] = 98488,
  [SMALL_STATE(2600)] = 98501,
  [SMALL_STATE(2601)] = 98514,
  [SMALL_STATE(2602)] = 98527,
  [SMALL_STATE(2603)] = 98540,
  [SMALL_STATE(2604)] = 98553,
  [SMALL_STATE(2605)] = 98566,
  [SMALL_STATE(2606)] = 98579,
  [SMALL_STATE(2607)] = 98592,
  [SMALL_STATE(2608)] = 98605,
  [SMALL_STATE(2609)] = 98618,
  [SMALL_STATE(2610)] = 98631,
  [SMALL_STATE(2611)] = 98644,
  [SMALL_STATE(2612)] = 98657,
  [SMALL_STATE(2613)] = 98670,
  [SMALL_STATE(2614)] = 98683,
  [SMALL_STATE(2615)] = 98696,
  [SMALL_STATE(2616)] = 98709,
  [SMALL_STATE(2617)] = 98722,
  [SMALL_STATE(2618)] = 98735,
  [SMALL_STATE(2619)] = 98748,
  [SMALL_STATE(2620)] = 98761,
  [SMALL_STATE(2621)] = 98774,
  [SMALL_STATE(2622)] = 98787,
  [SMALL_STATE(2623)] = 98800,
  [SMALL_STATE(2624)] = 98813,
  [SMALL_STATE(2625)] = 98826,
  [SMALL_STATE(2626)] = 98839,
  [SMALL_STATE(2627)] = 98852,
  [SMALL_STATE(2628)] = 98865,
  [SMALL_STATE(2629)] = 98878,
  [SMALL_STATE(2630)] = 98891,
  [SMALL_STATE(2631)] = 98904,
  [SMALL_STATE(2632)] = 98917,
  [SMALL_STATE(2633)] = 98930,
  [SMALL_STATE(2634)] = 98943,
  [SMALL_STATE(2635)] = 98956,
  [SMALL_STATE(2636)] = 98969,
  [SMALL_STATE(2637)] = 98982,
  [SMALL_STATE(2638)] = 98995,
  [SMALL_STATE(2639)] = 99008,
  [SMALL_STATE(2640)] = 99021,
  [SMALL_STATE(2641)] = 99034,
  [SMALL_STATE(2642)] = 99047,
  [SMALL_STATE(2643)] = 99060,
  [SMALL_STATE(2644)] = 99073,
  [SMALL_STATE(2645)] = 99086,
  [SMALL_STATE(2646)] = 99099,
  [SMALL_STATE(2647)] = 99112,
  [SMALL_STATE(2648)] = 99125,
  [SMALL_STATE(2649)] = 99138,
  [SMALL_STATE(2650)] = 99151,
  [SMALL_STATE(2651)] = 99164,
  [SMALL_STATE(2652)] = 99177,
  [SMALL_STATE(2653)] = 99190,
  [SMALL_STATE(2654)] = 99203,
  [SMALL_STATE(2655)] = 99216,
  [SMALL_STATE(2656)] = 99229,
  [SMALL_STATE(2657)] = 99242,
  [SMALL_STATE(2658)] = 99255,
  [SMALL_STATE(2659)] = 99268,
  [SMALL_STATE(2660)] = 99281,
  [SMALL_STATE(2661)] = 99294,
  [SMALL_STATE(2662)] = 99307,
  [SMALL_STATE(2663)] = 99320,
  [SMALL_STATE(2664)] = 99333,
  [SMALL_STATE(2665)] = 99346,
  [SMALL_STATE(2666)] = 99359,
  [SMALL_STATE(2667)] = 99372,
  [SMALL_STATE(2668)] = 99385,
  [SMALL_STATE(2669)] = 99398,
  [SMALL_STATE(2670)] = 99411,
  [SMALL_STATE(2671)] = 99424,
  [SMALL_STATE(2672)] = 99437,
  [SMALL_STATE(2673)] = 99450,
  [SMALL_STATE(2674)] = 99463,
  [SMALL_STATE(2675)] = 99476,
  [SMALL_STATE(2676)] = 99489,
  [SMALL_STATE(2677)] = 99502,
  [SMALL_STATE(2678)] = 99515,
  [SMALL_STATE(2679)] = 99528,
  [SMALL_STATE(2680)] = 99541,
  [SMALL_STATE(2681)] = 99554,
  [SMALL_STATE(2682)] = 99567,
  [SMALL_STATE(2683)] = 99580,
  [SMALL_STATE(2684)] = 99593,
  [SMALL_STATE(2685)] = 99606,
  [SMALL_STATE(2686)] = 99619,
  [SMALL_STATE(2687)] = 99632,
  [SMALL_STATE(2688)] = 99645,
  [SMALL_STATE(2689)] = 99658,
  [SMALL_STATE(2690)] = 99671,
  [SMALL_STATE(2691)] = 99684,
  [SMALL_STATE(2692)] = 99697,
  [SMALL_STATE(2693)] = 99710,
  [SMALL_STATE(2694)] = 99723,
  [SMALL_STATE(2695)] = 99736,
  [SMALL_STATE(2696)] = 99749,
  [SMALL_STATE(2697)] = 99762,
  [SMALL_STATE(2698)] = 99775,
  [SMALL_STATE(2699)] = 99788,
  [SMALL_STATE(2700)] = 99801,
  [SMALL_STATE(2701)] = 99814,
  [SMALL_STATE(2702)] = 99827,
  [SMALL_STATE(2703)] = 99840,
  [SMALL_STATE(2704)] = 99853,
  [SMALL_STATE(2705)] = 99866,
  [SMALL_STATE(2706)] = 99879,
  [SMALL_STATE(2707)] = 99892,
  [SMALL_STATE(2708)] = 99905,
  [SMALL_STATE(2709)] = 99918,
  [SMALL_STATE(2710)] = 99931,
  [SMALL_STATE(2711)] = 99944,
  [SMALL_STATE(2712)] = 99957,
  [SMALL_STATE(2713)] = 99970,
  [SMALL_STATE(2714)] = 99983,
  [SMALL_STATE(2715)] = 99996,
  [SMALL_STATE(2716)] = 100009,
  [SMALL_STATE(2717)] = 100022,
  [SMALL_STATE(2718)] = 100035,
  [SMALL_STATE(2719)] = 100048,
  [SMALL_STATE(2720)] = 100061,
  [SMALL_STATE(2721)] = 100074,
  [SMALL_STATE(2722)] = 100087,
  [SMALL_STATE(2723)] = 100100,
  [SMALL_STATE(2724)] = 100113,
  [SMALL_STATE(2725)] = 100126,
  [SMALL_STATE(2726)] = 100139,
  [SMALL_STATE(2727)] = 100152,
  [SMALL_STATE(2728)] = 100165,
  [SMALL_STATE(2729)] = 100178,
  [SMALL_STATE(2730)] = 100191,
  [SMALL_STATE(2731)] = 100204,
  [SMALL_STATE(2732)] = 100217,
  [SMALL_STATE(2733)] = 100230,
  [SMALL_STATE(2734)] = 100243,
  [SMALL_STATE(2735)] = 100256,
  [SMALL_STATE(2736)] = 100269,
  [SMALL_STATE(2737)] = 100282,
  [SMALL_STATE(2738)] = 100295,
  [SMALL_STATE(2739)] = 100308,
  [SMALL_STATE(2740)] = 100321,
  [SMALL_STATE(2741)] = 100334,
  [SMALL_STATE(2742)] = 100347,
  [SMALL_STATE(2743)] = 100360,
  [SMALL_STATE(2744)] = 100373,
  [SMALL_STATE(2745)] = 100386,
  [SMALL_STATE(2746)] = 100399,
  [SMALL_STATE(2747)] = 100412,
  [SMALL_STATE(2748)] = 100425,
  [SMALL_STATE(2749)] = 100438,
  [SMALL_STATE(2750)] = 100451,
  [SMALL_STATE(2751)] = 100464,
  [SMALL_STATE(2752)] = 100477,
  [SMALL_STATE(2753)] = 100490,
  [SMALL_STATE(2754)] = 100503,
  [SMALL_STATE(2755)] = 100516,
  [SMALL_STATE(2756)] = 100529,
  [SMALL_STATE(2757)] = 100542,
  [SMALL_STATE(2758)] = 100555,
  [SMALL_STATE(2759)] = 100568,
  [SMALL_STATE(2760)] = 100581,
  [SMALL_STATE(2761)] = 100594,
  [SMALL_STATE(2762)] = 100607,
  [SMALL_STATE(2763)] = 100620,
  [SMALL_STATE(2764)] = 100633,
  [SMALL_STATE(2765)] = 100646,
  [SMALL_STATE(2766)] = 100659,
  [SMALL_STATE(2767)] = 100672,
  [SMALL_STATE(2768)] = 100685,
  [SMALL_STATE(2769)] = 100698,
  [SMALL_STATE(2770)] = 100711,
  [SMALL_STATE(2771)] = 100724,
  [SMALL_STATE(2772)] = 100737,
  [SMALL_STATE(2773)] = 100750,
  [SMALL_STATE(2774)] = 100763,
  [SMALL_STATE(2775)] = 100776,
  [SMALL_STATE(2776)] = 100789,
  [SMALL_STATE(2777)] = 100802,
  [SMALL_STATE(2778)] = 100815,
  [SMALL_STATE(2779)] = 100828,
  [SMALL_STATE(2780)] = 100841,
  [SMALL_STATE(2781)] = 100854,
  [SMALL_STATE(2782)] = 100867,
  [SMALL_STATE(2783)] = 100880,
  [SMALL_STATE(2784)] = 100893,
  [SMALL_STATE(2785)] = 100906,
  [SMALL_STATE(2786)] = 100919,
  [SMALL_STATE(2787)] = 100932,
  [SMALL_STATE(2788)] = 100945,
  [SMALL_STATE(2789)] = 100958,
  [SMALL_STATE(2790)] = 100971,
  [SMALL_STATE(2791)] = 100984,
  [SMALL_STATE(2792)] = 100997,
  [SMALL_STATE(2793)] = 101010,
  [SMALL_STATE(2794)] = 101023,
  [SMALL_STATE(2795)] = 101036,
  [SMALL_STATE(2796)] = 101049,
  [SMALL_STATE(2797)] = 101062,
  [SMALL_STATE(2798)] = 101075,
  [SMALL_STATE(2799)] = 101088,
  [SMALL_STATE(2800)] = 101101,
  [SMALL_STATE(2801)] = 101114,
  [SMALL_STATE(2802)] = 101127,
  [SMALL_STATE(2803)] = 101140,
  [SMALL_STATE(2804)] = 101153,
  [SMALL_STATE(2805)] = 101166,
  [SMALL_STATE(2806)] = 101179,
  [SMALL_STATE(2807)] = 101192,
  [SMALL_STATE(2808)] = 101205,
  [SMALL_STATE(2809)] = 101218,
  [SMALL_STATE(2810)] = 101231,
  [SMALL_STATE(2811)] = 101244,
  [SMALL_STATE(2812)] = 101257,
  [SMALL_STATE(2813)] = 101270,
  [SMALL_STATE(2814)] = 101283,
  [SMALL_STATE(2815)] = 101296,
  [SMALL_STATE(2816)] = 101309,
  [SMALL_STATE(2817)] = 101322,
  [SMALL_STATE(2818)] = 101335,
  [SMALL_STATE(2819)] = 101348,
  [SMALL_STATE(2820)] = 101361,
  [SMALL_STATE(2821)] = 101374,
  [SMALL_STATE(2822)] = 101387,
  [SMALL_STATE(2823)] = 101400,
  [SMALL_STATE(2824)] = 101413,
  [SMALL_STATE(2825)] = 101426,
  [SMALL_STATE(2826)] = 101439,
  [SMALL_STATE(2827)] = 101452,
  [SMALL_STATE(2828)] = 101465,
  [SMALL_STATE(2829)] = 101478,
  [SMALL_STATE(2830)] = 101491,
  [SMALL_STATE(2831)] = 101504,
  [SMALL_STATE(2832)] = 101517,
  [SMALL_STATE(2833)] = 101530,
  [SMALL_STATE(2834)] = 101543,
  [SMALL_STATE(2835)] = 101556,
  [SMALL_STATE(2836)] = 101569,
  [SMALL_STATE(2837)] = 101582,
  [SMALL_STATE(2838)] = 101595,
  [SMALL_STATE(2839)] = 101608,
  [SMALL_STATE(2840)] = 101621,
  [SMALL_STATE(2841)] = 101634,
  [SMALL_STATE(2842)] = 101647,
  [SMALL_STATE(2843)] = 101660,
  [SMALL_STATE(2844)] = 101673,
  [SMALL_STATE(2845)] = 101686,
  [SMALL_STATE(2846)] = 101699,
  [SMALL_STATE(2847)] = 101712,
  [SMALL_STATE(2848)] = 101725,
  [SMALL_STATE(2849)] = 101738,
  [SMALL_STATE(2850)] = 101751,
  [SMALL_STATE(2851)] = 101764,
  [SMALL_STATE(2852)] = 101777,
  [SMALL_STATE(2853)] = 101790,
  [SMALL_STATE(2854)] = 101803,
  [SMALL_STATE(2855)] = 101816,
  [SMALL_STATE(2856)] = 101829,
  [SMALL_STATE(2857)] = 101842,
  [SMALL_STATE(2858)] = 101855,
  [SMALL_STATE(2859)] = 101868,
  [SMALL_STATE(2860)] = 101881,
  [SMALL_STATE(2861)] = 101894,
  [SMALL_STATE(2862)] = 101907,
  [SMALL_STATE(2863)] = 101920,
  [SMALL_STATE(2864)] = 101933,
  [SMALL_STATE(2865)] = 101946,
  [SMALL_STATE(2866)] = 101959,
  [SMALL_STATE(2867)] = 101972,
  [SMALL_STATE(2868)] = 101985,
  [SMALL_STATE(2869)] = 101998,
  [SMALL_STATE(2870)] = 102011,
  [SMALL_STATE(2871)] = 102024,
  [SMALL_STATE(2872)] = 102037,
  [SMALL_STATE(2873)] = 102050,
  [SMALL_STATE(2874)] = 102063,
  [SMALL_STATE(2875)] = 102076,
  [SMALL_STATE(2876)] = 102089,
  [SMALL_STATE(2877)] = 102102,
  [SMALL_STATE(2878)] = 102115,
  [SMALL_STATE(2879)] = 102128,
  [SMALL_STATE(2880)] = 102141,
  [SMALL_STATE(2881)] = 102154,
  [SMALL_STATE(2882)] = 102167,
  [SMALL_STATE(2883)] = 102180,
  [SMALL_STATE(2884)] = 102193,
  [SMALL_STATE(2885)] = 102206,
  [SMALL_STATE(2886)] = 102219,
  [SMALL_STATE(2887)] = 102232,
  [SMALL_STATE(2888)] = 102245,
  [SMALL_STATE(2889)] = 102258,
  [SMALL_STATE(2890)] = 102271,
  [SMALL_STATE(2891)] = 102284,
  [SMALL_STATE(2892)] = 102297,
  [SMALL_STATE(2893)] = 102310,
  [SMALL_STATE(2894)] = 102323,
  [SMALL_STATE(2895)] = 102336,
  [SMALL_STATE(2896)] = 102349,
  [SMALL_STATE(2897)] = 102362,
  [SMALL_STATE(2898)] = 102375,
  [SMALL_STATE(2899)] = 102388,
  [SMALL_STATE(2900)] = 102401,
  [SMALL_STATE(2901)] = 102414,
  [SMALL_STATE(2902)] = 102427,
  [SMALL_STATE(2903)] = 102440,
  [SMALL_STATE(2904)] = 102453,
  [SMALL_STATE(2905)] = 102466,
  [SMALL_STATE(2906)] = 102479,
  [SMALL_STATE(2907)] = 102492,
  [SMALL_STATE(2908)] = 102505,
};

static const TSParseActionEntry ts_parse_actions[] = {
  [0] = {.entry = {.count = 0, .reusable = false}},
  [1] = {.entry = {.count = 1, .reusable = false}}, RECOVER(),
  [3] = {.entry = {.count = 1, .reusable = true}}, SHIFT_EXTRA(),
  [5] = {.entry = {.count = 1, .reusable = false}}, SHIFT_EXTRA(),
  [7] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 0, 0, 0),
  [9] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2869),
  [11] = {.entry = {.count = 1, .reusable = true}}, SHIFT(707),
  [13] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2225),
  [15] = {.entry = {.count = 1, .reusable = true}}, SHIFT(26),
  [17] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2220),
  [19] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2325),
  [21] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2733),
  [23] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1922),
  [25] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2589),
  [27] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2066),
  [29] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2879),
  [31] = {.entry = {.count = 1, .reusable = false}}, SHIFT(865),
  [33] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2100),
  [35] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2766),
  [37] = {.entry = {.count = 1, .reusable = true}}, SHIFT(905),
  [39] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1009),
  [41] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2291),
  [43] = {.entry = {.count = 1, .reusable = false}}, SHIFT(835),
  [45] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2477),
  [47] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2697),
  [49] = {.entry = {.count = 1, .reusable = false}}, SHIFT(863),
  [51] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1179),
  [53] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2476),
  [55] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1959),
  [57] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1180),
  [59] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1852),
  [61] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1181),
  [63] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1285),
  [65] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1267),
  [67] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2366),
  [69] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2131),
  [71] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2169),
  [73] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2559),
  [75] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1989),
  [77] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2741),
  [79] = {.entry = {.count = 1, .reusable = true}}, SHIFT(893),
  [81] = {.entry = {.count = 1, .reusable = true}}, SHIFT(896),
  [83] = {.entry = {.count = 1, .reusable = false}}, SHIFT(896),
  [85] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2902),
  [87] = {.entry = {.count = 1, .reusable = false}}, SHIFT(898),
  [89] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1270),
  [91] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1858),
  [93] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2327),
  [95] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2327),
  [97] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2334),
  [99] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2042),
  [101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2412),
  [103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2458),
  [105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(296),
  [107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2120),
  [109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1208),
  [111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1282),
  [113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1273),
  [115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1279),
  [117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1279),
  [119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1270),
  [121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1265),
  [123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1266),
  [125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1209),
  [127] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expr, 3, 0, 0),
  [129] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expr, 3, 0, 0),
  [131] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2261),
  [133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1900),
  [135] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1199),
  [137] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 1, 0, 0),
  [139] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string_directive, 1, 0, 0),
  [141] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string_directive, 1, 0, 0),
  [143] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_string, 1, 0, 0),
  [145] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_string, 1, 0, 0),
  [147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(844),
  [149] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expr, 2, 0, 0),
  [151] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 2, 0, 0),
  [153] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 2, 0, 0),
  [155] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expr, 2, 0, 0),
  [157] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [159] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2869),
  [162] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2225),
  [165] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2220),
  [168] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2325),
  [171] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2621),
  [174] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1922),
  [177] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0),
  [179] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2879),
  [182] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2788),
  [185] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2856),
  [188] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2873),
  [191] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1858),
  [194] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2327),
  [197] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2327),
  [200] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2334),
  [203] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2042),
  [206] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2412),
  [209] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2458),
  [212] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(296),
  [215] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2120),
  [218] = {.entry = {.count = 1, .reusable = true}}, SHIFT(527),
  [220] = {.entry = {.count = 1, .reusable = true}}, SHIFT(30),
  [222] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_list_repeat1, 3, 0, 0),
  [224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2791),
  [226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(862),
  [228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1998),
  [230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2763),
  [232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1131),
  [234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2874),
  [236] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2509),
  [238] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2233),
  [240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(851),
  [242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(999),
  [244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2782),
  [246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1966),
  [248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1000),
  [250] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_case_list_repeat1, 3, 0, 0),
  [252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1872),
  [254] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2376),
  [256] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2376),
  [258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2377),
  [260] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2012),
  [262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2540),
  [264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2541),
  [266] = {.entry = {.count = 1, .reusable = true}}, SHIFT(466),
  [268] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2013),
  [270] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_list_repeat1, 2, 0, 0),
  [272] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_case_list_repeat1, 2, 0, 0),
  [274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(749),
  [276] = {.entry = {.count = 1, .reusable = true}}, SHIFT(23),
  [278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(15),
  [280] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2826),
  [282] = {.entry = {.count = 1, .reusable = false}}, SHIFT(854),
  [284] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2001),
  [286] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2602),
  [288] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1063),
  [290] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2836),
  [292] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2305),
  [294] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2223),
  [296] = {.entry = {.count = 1, .reusable = false}}, SHIFT(867),
  [298] = {.entry = {.count = 1, .reusable = false}}, SHIFT(931),
  [300] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2857),
  [302] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1952),
  [304] = {.entry = {.count = 1, .reusable = false}}, SHIFT(932),
  [306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1867),
  [308] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2236),
  [310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2236),
  [312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2239),
  [314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2212),
  [316] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2309),
  [318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2310),
  [320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(711),
  [322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2073),
  [324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(20),
  [326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(14),
  [328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(19),
  [330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(16),
  [332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(18),
  [334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(17),
  [336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(13),
  [338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(11),
  [340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(12),
  [342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(9),
  [344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(10),
  [346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(7),
  [348] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_params, 5, 0, 0),
  [350] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_params, 5, 0, 0),
  [352] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_params, 4, 0, 0),
  [354] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_params, 4, 0, 0),
  [356] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt_list, 1, 0, 0),
  [358] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt_list, 1, 0, 0),
  [360] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(527),
  [363] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(30),
  [366] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0),
  [368] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2791),
  [371] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2589),
  [374] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2066),
  [377] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(862),
  [380] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1998),
  [383] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2763),
  [386] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(905),
  [389] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1131),
  [392] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2874),
  [395] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(835),
  [398] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2509),
  [401] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2233),
  [404] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(851),
  [407] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(999),
  [410] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2782),
  [413] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1966),
  [416] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1000),
  [419] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0),
  [421] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1900),
  [424] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1199),
  [427] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1285),
  [430] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1267),
  [433] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2366),
  [436] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2131),
  [439] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2169),
  [442] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2559),
  [445] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1989),
  [448] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2741),
  [451] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(893),
  [454] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(896),
  [457] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(896),
  [460] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2902),
  [463] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(898),
  [466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1270),
  [469] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1872),
  [472] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2376),
  [475] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2376),
  [478] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2377),
  [481] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2012),
  [484] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2540),
  [487] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2541),
  [490] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(466),
  [493] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2013),
  [496] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1208),
  [499] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1282),
  [502] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1273),
  [505] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1279),
  [508] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1279),
  [511] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1270),
  [514] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1265),
  [517] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1266),
  [520] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1209),
  [523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(24),
  [525] = {.entry = {.count = 1, .reusable = true}}, SHIFT(398),
  [527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(726),
  [529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(775),
  [531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(693),
  [533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(695),
  [535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(697),
  [537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(290),
  [539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(587),
  [541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(599),
  [543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(605),
  [545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(570),
  [547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(572),
  [549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(576),
  [551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(610),
  [553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(613),
  [555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(724),
  [557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(490),
  [559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(497),
  [561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(503),
  [563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(564),
  [565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(568),
  [567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(459),
  [569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(493),
  [571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(495),
  [573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(498),
  [575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(720),
  [577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(433),
  [579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(435),
  [581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(441),
  [583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(747),
  [585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(394),
  [587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(396),
  [589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(750),
  [591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(361),
  [593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(363),
  [595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(365),
  [597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1215),
  [599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(702),
  [601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(616),
  [603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_source_file, 2, 0, 0),
  [605] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2603),
  [607] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2110),
  [609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1863),
  [611] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2701),
  [613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2701),
  [615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2702),
  [617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2107),
  [619] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2409),
  [621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2410),
  [623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(729),
  [625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2109),
  [627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 1, 0, 0),
  [629] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 1, 0, 0),
  [631] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(749),
  [634] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(24),
  [637] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2826),
  [640] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(854),
  [643] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2001),
  [646] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2602),
  [649] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1063),
  [652] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2836),
  [655] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2305),
  [658] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2223),
  [661] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(867),
  [664] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(931),
  [667] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2857),
  [670] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1952),
  [673] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(932),
  [676] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1867),
  [679] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2236),
  [682] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2236),
  [685] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2239),
  [688] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2212),
  [691] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2309),
  [694] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2310),
  [697] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(711),
  [700] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2073),
  [703] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 3, 0, 0),
  [705] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 3, 0, 0),
  [707] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(707),
  [710] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(26),
  [713] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2603),
  [716] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(865),
  [719] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2110),
  [722] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2766),
  [725] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1009),
  [728] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2291),
  [731] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2477),
  [734] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2697),
  [737] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(863),
  [740] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1179),
  [743] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2476),
  [746] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1959),
  [749] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1180),
  [752] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(1863),
  [755] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2701),
  [758] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2701),
  [761] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2702),
  [764] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2107),
  [767] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2409),
  [770] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2410),
  [773] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(729),
  [776] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat2, 2, 0, 0), SHIFT_REPEAT(2109),
  [779] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 2, 0, 0),
  [781] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 2, 0, 0),
  [783] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type, 4, 0, 0),
  [785] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type, 4, 0, 0),
  [787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(640),
  [789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(850),
  [791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1786),
  [793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2303),
  [795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1248),
  [797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2182),
  [799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(930),
  [801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(838),
  [803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2460),
  [805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1898),
  [807] = {.entry = {.count = 1, .reusable = false}}, SHIFT(904),
  [809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(806),
  [811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(788),
  [813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2897),
  [815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2209),
  [817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2210),
  [819] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2307),
  [821] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2021),
  [823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(807),
  [825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1249),
  [827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2545),
  [829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2900),
  [831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(959),
  [833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(900),
  [835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(900),
  [837] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2308),
  [839] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1161),
  [841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(769),
  [843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(811),
  [845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(770),
  [847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(773),
  [849] = {.entry = {.count = 1, .reusable = false}}, SHIFT(781),
  [851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(781),
  [853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(769),
  [855] = {.entry = {.count = 1, .reusable = false}}, SHIFT(767),
  [857] = {.entry = {.count = 1, .reusable = false}}, SHIFT(766),
  [859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(812),
  [861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(321),
  [863] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1657),
  [865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(569),
  [867] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1721),
  [869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(902),
  [871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(519),
  [873] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1722),
  [875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(705),
  [877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1758),
  [879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(325),
  [881] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1795),
  [883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(713),
  [885] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1720),
  [887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1825),
  [889] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1693),
  [891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(474),
  [893] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1742),
  [895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(478),
  [897] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1745),
  [899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(628),
  [901] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1654),
  [903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(636),
  [905] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1656),
  [907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(735),
  [909] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1714),
  [911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(317),
  [913] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1779),
  [915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(418),
  [917] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1764),
  [919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(420),
  [921] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1765),
  [923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(662),
  [925] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1718),
  [927] = {.entry = {.count = 1, .reusable = true}}, SHIFT(319),
  [929] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1785),
  [931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(586),
  [933] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1677),
  [935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(590),
  [937] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1681),
  [939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(455),
  [941] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1780),
  [943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(423),
  [945] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1781),
  [947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(664),
  [949] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1731),
  [951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(320),
  [953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1719),
  [955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1824),
  [957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1692),
  [959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1834),
  [961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1698),
  [963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(348),
  [965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1797),
  [967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(350),
  [969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1798),
  [971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(542),
  [973] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1699),
  [975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(544),
  [977] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1701),
  [979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1835),
  [981] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1703),
  [983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(748),
  [985] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1710),
  [987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(595),
  [989] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1784),
  [991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(506),
  [993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(31),
  [995] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2852),
  [997] = {.entry = {.count = 1, .reusable = false}}, SHIFT(864),
  [999] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2004),
  [1001] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2774),
  [1003] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1136),
  [1005] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2877),
  [1007] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2524),
  [1009] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2294),
  [1011] = {.entry = {.count = 1, .reusable = false}}, SHIFT(876),
  [1013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1010),
  [1015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2837),
  [1017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1968),
  [1019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1011),
  [1021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1853),
  [1023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2459),
  [1025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2459),
  [1027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2463),
  [1029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2018),
  [1031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2555),
  [1033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2556),
  [1035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(502),
  [1037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2019),
  [1039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(409),
  [1041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(33),
  [1043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2230),
  [1045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(866),
  [1047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2020),
  [1049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2796),
  [1051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1146),
  [1053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2883),
  [1055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2554),
  [1057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2455),
  [1059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(871),
  [1061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1030),
  [1063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2226),
  [1065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1972),
  [1067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1031),
  [1069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1859),
  [1071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2665),
  [1073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2665),
  [1075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2666),
  [1077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2029),
  [1079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2585),
  [1081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2586),
  [1083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(402),
  [1085] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2030),
  [1087] = {.entry = {.count = 1, .reusable = true}}, SHIFT(444),
  [1089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(34),
  [1091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2254),
  [1093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(868),
  [1095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2026),
  [1097] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2807),
  [1099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1151),
  [1101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2886),
  [1103] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2569),
  [1105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2573),
  [1107] = {.entry = {.count = 1, .reusable = false}}, SHIFT(853),
  [1109] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1041),
  [1111] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2250),
  [1113] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1974),
  [1115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1042),
  [1117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1873),
  [1119] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2714),
  [1121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2714),
  [1123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2715),
  [1125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2035),
  [1127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2597),
  [1129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2598),
  [1131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(432),
  [1133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2036),
  [1135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(344),
  [1137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(35),
  [1139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2278),
  [1141] = {.entry = {.count = 1, .reusable = false}}, SHIFT(869),
  [1143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2031),
  [1145] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2818),
  [1147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1156),
  [1149] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2889),
  [1151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2584),
  [1153] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2662),
  [1155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(857),
  [1157] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1051),
  [1159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2274),
  [1161] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1976),
  [1163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1052),
  [1165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1862),
  [1167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2722),
  [1169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2722),
  [1171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2723),
  [1173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2037),
  [1175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2599),
  [1177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2600),
  [1179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(372),
  [1181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2038),
  [1183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(754),
  [1185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(700),
  [1187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(27),
  [1189] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2462),
  [1191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(859),
  [1193] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2146),
  [1195] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2725),
  [1197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1107),
  [1199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2865),
  [1201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2449),
  [1203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2804),
  [1205] = {.entry = {.count = 1, .reusable = false}}, SHIFT(873),
  [1207] = {.entry = {.count = 1, .reusable = false}}, SHIFT(968),
  [1209] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2429),
  [1211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1948),
  [1213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(969),
  [1215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1865),
  [1217] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2808),
  [1219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2808),
  [1221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2809),
  [1223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1990),
  [1225] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2490),
  [1227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2491),
  [1229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(581),
  [1231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1991),
  [1233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(731),
  [1235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(293),
  [1237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1819),
  [1239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1821),
  [1241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1827),
  [1243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(615),
  [1245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(28),
  [1247] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2565),
  [1249] = {.entry = {.count = 1, .reusable = false}}, SHIFT(860),
  [1251] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2188),
  [1253] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2740),
  [1255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1115),
  [1257] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2868),
  [1259] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2469),
  [1261] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2502),
  [1263] = {.entry = {.count = 1, .reusable = false}}, SHIFT(875),
  [1265] = {.entry = {.count = 1, .reusable = false}}, SHIFT(979),
  [1267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2558),
  [1269] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1962),
  [1271] = {.entry = {.count = 1, .reusable = false}}, SHIFT(980),
  [1273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1864),
  [1275] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2237),
  [1277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2237),
  [1279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2238),
  [1281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1996),
  [1283] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2510),
  [1285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2511),
  [1287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(620),
  [1289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1997),
  [1291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(710),
  [1293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(580),
  [1295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(29),
  [1297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2719),
  [1299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(861),
  [1301] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1992),
  [1303] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2752),
  [1305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1123),
  [1307] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2871),
  [1309] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2489),
  [1311] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2798),
  [1313] = {.entry = {.count = 1, .reusable = false}}, SHIFT(856),
  [1315] = {.entry = {.count = 1, .reusable = false}}, SHIFT(989),
  [1317] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2692),
  [1319] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1964),
  [1321] = {.entry = {.count = 1, .reusable = false}}, SHIFT(990),
  [1323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1870),
  [1325] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2304),
  [1327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2304),
  [1329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2306),
  [1331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2002),
  [1333] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2525),
  [1335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2526),
  [1337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(686),
  [1339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2003),
  [1341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(712),
  [1343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(328),
  [1345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1809),
  [1347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(669),
  [1349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(294),
  [1351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(671),
  [1353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(656),
  [1355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(25),
  [1357] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2276),
  [1359] = {.entry = {.count = 1, .reusable = false}}, SHIFT(858),
  [1361] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2111),
  [1363] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2835),
  [1365] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1087),
  [1367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2862),
  [1369] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2406),
  [1371] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2694),
  [1373] = {.entry = {.count = 1, .reusable = false}}, SHIFT(872),
  [1375] = {.entry = {.count = 1, .reusable = false}}, SHIFT(957),
  [1377] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2251),
  [1379] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1960),
  [1381] = {.entry = {.count = 1, .reusable = false}}, SHIFT(958),
  [1383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1869),
  [1385] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2517),
  [1387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2517),
  [1389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2528),
  [1391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2171),
  [1393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2470),
  [1395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2471),
  [1397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(619),
  [1399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2180),
  [1401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(623),
  [1403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(465),
  [1405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(32),
  [1407] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2890),
  [1409] = {.entry = {.count = 1, .reusable = false}}, SHIFT(877),
  [1411] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2014),
  [1413] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2785),
  [1415] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1141),
  [1417] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2880),
  [1419] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2539),
  [1421] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2373),
  [1423] = {.entry = {.count = 1, .reusable = false}}, SHIFT(874),
  [1425] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1020),
  [1427] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2884),
  [1429] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1970),
  [1431] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1021),
  [1433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1868),
  [1435] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2582),
  [1437] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2582),
  [1439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2583),
  [1441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2024),
  [1443] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2570),
  [1445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2571),
  [1447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(565),
  [1449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2025),
  [1451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(631),
  [1453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(295),
  [1455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(645),
  [1457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(648),
  [1459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(596),
  [1461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(598),
  [1463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(457),
  [1465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(549),
  [1467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(297),
  [1469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(523),
  [1471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(524),
  [1473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(482),
  [1475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(483),
  [1477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(456),
  [1479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(424),
  [1481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(386),
  [1483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(387),
  [1485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(353),
  [1487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(354),
  [1489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1275),
  [1491] = {.entry = {.count = 1, .reusable = false}}, SHIFT(836),
  [1493] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_directive, 3, 0, 0),
  [1495] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_directive, 3, 0, 0),
  [1497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(291),
  [1499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_directive, 2, 0, 0),
  [1501] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_directive, 2, 0, 0),
  [1503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(322),
  [1505] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_body, 2, 0, 0),
  [1507] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_body, 2, 0, 0),
  [1509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_directive, 4, 0, 0),
  [1511] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_directive, 4, 0, 0),
  [1513] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_body, 3, 0, 0),
  [1515] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_body, 3, 0, 0),
  [1517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_decl, 5, 0, 0),
  [1519] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_decl, 5, 0, 0),
  [1521] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_decl, 5, 0, 0),
  [1523] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_decl, 5, 0, 0),
  [1525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_decl, 5, 0, 0),
  [1527] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_decl, 5, 0, 0),
  [1529] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_preproc_directive, 1, 0, 0),
  [1531] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_preproc_directive, 1, 0, 0),
  [1533] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redef_decl, 5, 0, 0),
  [1535] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redef_decl, 5, 0, 0),
  [1537] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_decl, 5, 0, 0),
  [1539] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_decl, 5, 0, 0),
  [1541] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_decl, 2, 0, 0),
  [1543] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_decl, 2, 0, 0),
  [1545] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_decl, 1, 0, 0),
  [1547] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_decl, 1, 0, 0),
  [1549] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_decl, 6, 0, 0),
  [1551] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_decl, 6, 0, 0),
  [1553] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_decl, 6, 0, 0),
  [1555] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_decl, 6, 0, 0),
  [1557] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_decl, 6, 0, 0),
  [1559] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_decl, 6, 0, 0),
  [1561] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redef_decl, 6, 0, 0),
  [1563] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redef_decl, 6, 0, 0),
  [1565] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_decl, 6, 0, 0),
  [1567] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_type_decl, 6, 0, 0),
  [1569] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_module_decl, 3, 0, 0),
  [1571] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_module_decl, 3, 0, 0),
  [1573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_decl, 3, 0, 0),
  [1575] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_decl, 3, 0, 0),
  [1577] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_decl, 7, 0, 0),
  [1579] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_decl, 7, 0, 0),
  [1581] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_decl, 7, 0, 0),
  [1583] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_decl, 7, 0, 0),
  [1585] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_decl, 7, 0, 0),
  [1587] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_decl, 7, 0, 0),
  [1589] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redef_record_decl, 7, 0, 0),
  [1591] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redef_record_decl, 7, 0, 0),
  [1593] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redef_decl, 4, 0, 0),
  [1595] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redef_decl, 4, 0, 0),
  [1597] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redef_enum_decl, 8, 0, 0),
  [1599] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redef_enum_decl, 8, 0, 0),
  [1601] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redef_record_decl, 8, 0, 0),
  [1603] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redef_record_decl, 8, 0, 0),
  [1605] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_decl, 3, 0, 0),
  [1607] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_decl, 3, 0, 0),
  [1609] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redef_record_decl, 9, 0, 0),
  [1611] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redef_record_decl, 9, 0, 0),
  [1613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_decl, 3, 0, 0),
  [1615] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_decl, 3, 0, 0),
  [1617] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_decl, 3, 0, 0),
  [1619] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_decl, 3, 0, 0),
  [1621] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redef_decl, 3, 0, 0),
  [1623] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redef_decl, 3, 0, 0),
  [1625] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_pragma, 3, 0, 0),
  [1627] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_pragma, 3, 0, 0),
  [1629] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_decl, 3, 0, 0),
  [1631] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_decl, 3, 0, 0),
  [1633] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_const_decl, 4, 0, 0),
  [1635] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_const_decl, 4, 0, 0),
  [1637] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_export_decl, 4, 0, 0),
  [1639] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_export_decl, 4, 0, 0),
  [1641] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_global_decl, 4, 0, 0),
  [1643] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_global_decl, 4, 0, 0),
  [1645] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_option_decl, 4, 0, 0),
  [1647] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_option_decl, 4, 0, 0),
  [1649] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_redef_decl, 7, 0, 0),
  [1651] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_redef_decl, 7, 0, 0),
  [1653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(376),
  [1655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(378),
  [1657] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 6, 0, 0),
  [1659] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 6, 0, 0),
  [1661] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1149),
  [1663] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 5, 0, 0),
  [1665] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 5, 0, 0),
  [1667] = {.entry = {.count = 1, .reusable = false}}, SHIFT(129),
  [1669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1148),
  [1671] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 7, 0, 0),
  [1673] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 7, 0, 0),
  [1675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1150),
  [1677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 1, 0, 0),
  [1679] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 1, 0, 0),
  [1681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(411),
  [1683] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 3, 0, 0),
  [1685] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 3, 0, 0),
  [1687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(415),
  [1689] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 4, 0, 0),
  [1691] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 4, 0, 0),
  [1693] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 9, 0, 0),
  [1695] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 9, 0, 0),
  [1697] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 10, 0, 0),
  [1699] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 10, 0, 0),
  [1701] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 11, 0, 0),
  [1703] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 11, 0, 0),
  [1705] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_stmt, 12, 0, 0),
  [1707] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_stmt, 12, 0, 0),
  [1709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(438),
  [1711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(440),
  [1713] = {.entry = {.count = 1, .reusable = false}}, SHIFT(137),
  [1715] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1157),
  [1717] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1158),
  [1719] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1159),
  [1721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(480),
  [1723] = {.entry = {.count = 1, .reusable = false}}, SHIFT(232),
  [1725] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1133),
  [1727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(476),
  [1729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(511),
  [1731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(516),
  [1733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(467),
  [1735] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1134),
  [1737] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1135),
  [1739] = {.entry = {.count = 1, .reusable = false}}, SHIFT(211),
  [1741] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1153),
  [1743] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1154),
  [1745] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1155),
  [1747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(463),
  [1749] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1122),
  [1751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(574),
  [1753] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1120),
  [1755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(577),
  [1757] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1121),
  [1759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(588),
  [1761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(629),
  [1763] = {.entry = {.count = 1, .reusable = false}}, SHIFT(246),
  [1765] = {.entry = {.count = 1, .reusable = false}}, SHIFT(257),
  [1767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(593),
  [1769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(634),
  [1771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(632),
  [1773] = {.entry = {.count = 1, .reusable = false}}, SHIFT(221),
  [1775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(641),
  [1777] = {.entry = {.count = 1, .reusable = false}}, SHIFT(190),
  [1779] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1092),
  [1781] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1093),
  [1783] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1094),
  [1785] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1138),
  [1787] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1139),
  [1789] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1140),
  [1791] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1143),
  [1793] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1144),
  [1795] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1145),
  [1797] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1200),
  [1799] = {.entry = {.count = 1, .reusable = false}}, SHIFT(895),
  [1801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(703),
  [1803] = {.entry = {.count = 1, .reusable = false}}, SHIFT(175),
  [1805] = {.entry = {.count = 1, .reusable = false}}, SHIFT(210),
  [1807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(708),
  [1809] = {.entry = {.count = 1, .reusable = false}}, SHIFT(149),
  [1811] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1069),
  [1813] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1070),
  [1815] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1071),
  [1817] = {.entry = {.count = 1, .reusable = false}}, SHIFT(892),
  [1819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(737),
  [1821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(739),
  [1823] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1112),
  [1825] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1113),
  [1827] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1114),
  [1829] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1128),
  [1831] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1129),
  [1833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1130),
  [1835] = {.entry = {.count = 1, .reusable = false}}, SHIFT(166),
  [1837] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 1, 0, 0),
  [1839] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 1, 0, 0),
  [1841] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1660),
  [1843] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_params, 3, 0, 0),
  [1845] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1787),
  [1847] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_params, 3, 0, 0),
  [1849] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_params, 2, 0, 0),
  [1851] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1648),
  [1853] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_params, 2, 0, 0),
  [1855] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 3, 0, 0),
  [1857] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 3, 0, 0),
  [1859] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 5, 0, 0),
  [1861] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 5, 0, 0),
  [1863] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 4, 0, 0),
  [1865] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 4, 0, 0),
  [1867] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 6, 0, 0),
  [1869] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 6, 0, 0),
  [1871] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym__simple_type, 7, 0, 0),
  [1873] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym__simple_type, 7, 0, 0),
  [1875] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_constant, 1, 0, 0),
  [1877] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_constant, 1, 0, 0),
  [1879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(794),
  [1881] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_slice, 5, 0, 0),
  [1883] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_index_slice, 5, 0, 0),
  [1885] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expr, 1, 0, 0),
  [1887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(847),
  [1889] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expr, 1, 0, 0),
  [1891] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_slice, 3, 0, 0),
  [1893] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_index_slice, 3, 0, 0),
  [1895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_subnet, 3, 0, 0),
  [1897] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_subnet, 3, 0, 0),
  [1899] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expr, 1, 0, 1),
  [1901] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expr, 1, 0, 1),
  [1903] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_index_slice, 4, 0, 0),
  [1905] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_index_slice, 4, 0, 0),
  [1907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2317),
  [1909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(841),
  [1911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1702),
  [1913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2318),
  [1915] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expr, 5, 0, 0),
  [1917] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expr, 5, 0, 0),
  [1919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1650),
  [1921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1651),
  [1923] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attr, 3, 0, 0),
  [1925] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attr, 3, 0, 0),
  [1927] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_interval, 2, 0, 0),
  [1929] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_interval, 2, 0, 0),
  [1931] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attr, 1, 0, 0),
  [1933] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attr, 1, 0, 0),
  [1935] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expr, 4, 0, 0),
  [1937] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expr, 4, 0, 0),
  [1939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1727),
  [1941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1730),
  [1943] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_attr_list_repeat1, 2, 0, 0),
  [1945] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_attr_list_repeat1, 2, 0, 0),
  [1947] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(807),
  [1950] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(799),
  [1953] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2400),
  [1956] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_attr_list, 1, 0, 0),
  [1958] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_attr_list, 1, 0, 0),
  [1960] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1075),
  [1962] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1075),
  [1964] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2388),
  [1966] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1076),
  [1968] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1086),
  [1970] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1077),
  [1972] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1074),
  [1974] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1074),
  [1976] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1078),
  [1978] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2323),
  [1980] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1262),
  [1982] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1348),
  [1984] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0),
  [1986] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(844),
  [1989] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0),
  [1991] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2589),
  [1994] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2066),
  [1997] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(905),
  [2000] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(836),
  [2003] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2261),
  [2006] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1900),
  [2009] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1199),
  [2012] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1285),
  [2015] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1267),
  [2018] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2366),
  [2021] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2131),
  [2024] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2169),
  [2027] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2559),
  [2030] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1989),
  [2033] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2741),
  [2036] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(893),
  [2039] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(896),
  [2042] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(896),
  [2045] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2902),
  [2048] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(898),
  [2051] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1270),
  [2054] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1208),
  [2057] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1282),
  [2060] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1273),
  [2063] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1279),
  [2066] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1279),
  [2069] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1270),
  [2072] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1265),
  [2075] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1266),
  [2078] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_expr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1209),
  [2081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(816),
  [2083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1752),
  [2085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2896),
  [2087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1162),
  [2089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1318),
  [2091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2177),
  [2093] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2178),
  [2095] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2108),
  [2097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2894),
  [2099] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1160),
  [2101] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1160),
  [2103] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expr_list, 1, 0, 0),
  [2105] = {.entry = {.count = 1, .reusable = false}}, SHIFT(878),
  [2107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(815),
  [2109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(791),
  [2111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1222),
  [2113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2118),
  [2115] = {.entry = {.count = 1, .reusable = false}}, SHIFT(884),
  [2117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(880),
  [2119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1221),
  [2121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(879),
  [2123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1304),
  [2125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(798),
  [2127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1242),
  [2129] = {.entry = {.count = 1, .reusable = false}}, SHIFT(883),
  [2131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(536),
  [2133] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1967),
  [2135] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_expr_list, 1, 0, 0),
  [2137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(450),
  [2139] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1975),
  [2141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(584),
  [2143] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1965),
  [2145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(346),
  [2147] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1977),
  [2149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(736),
  [2151] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1956),
  [2153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(744),
  [2155] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1954),
  [2157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(416),
  [2159] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1973),
  [2161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(660),
  [2163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1981),
  [2165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(654),
  [2167] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1979),
  [2169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(471),
  [2171] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1971),
  [2173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(625),
  [2175] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1963),
  [2177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(513),
  [2179] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1969),
  [2181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2393),
  [2183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(799),
  [2185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2642),
  [2187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1277),
  [2189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1290),
  [2191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(771),
  [2193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2297),
  [2195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(778),
  [2197] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2611),
  [2199] = {.entry = {.count = 1, .reusable = false}}, SHIFT(935),
  [2201] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2207),
  [2203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2208),
  [2205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2606),
  [2207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(933),
  [2209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(934),
  [2211] = {.entry = {.count = 1, .reusable = false}}, SHIFT(934),
  [2213] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1631),
  [2215] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_init_class, 1, 0, 0),
  [2217] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_init_class, 1, 0, 0),
  [2219] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2642),
  [2222] = {.entry = {.count = 1, .reusable = true}}, SHIFT(287),
  [2224] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2446),
  [2226] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1096),
  [2228] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1232),
  [2230] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2124),
  [2232] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2125),
  [2234] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2099),
  [2236] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2445),
  [2238] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1095),
  [2240] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1095),
  [2242] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2397),
  [2244] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1073),
  [2246] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2185),
  [2248] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2186),
  [2250] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2396),
  [2252] = {.entry = {.count = 1, .reusable = true}}, SHIFT(970),
  [2254] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1072),
  [2256] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1072),
  [2258] = {.entry = {.count = 1, .reusable = true}}, SHIFT(286),
  [2260] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1403),
  [2262] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1624),
  [2264] = {.entry = {.count = 1, .reusable = true}}, SHIFT(908),
  [2266] = {.entry = {.count = 1, .reusable = false}}, SHIFT(908),
  [2268] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2319),
  [2270] = {.entry = {.count = 1, .reusable = true}}, SHIFT(909),
  [2272] = {.entry = {.count = 1, .reusable = false}}, SHIFT(943),
  [2274] = {.entry = {.count = 1, .reusable = true}}, SHIFT(907),
  [2276] = {.entry = {.count = 1, .reusable = false}}, SHIFT(907),
  [2278] = {.entry = {.count = 1, .reusable = true}}, SHIFT(910),
  [2280] = {.entry = {.count = 1, .reusable = true}}, SHIFT(912),
  [2282] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2336),
  [2284] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2336),
  [2287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2400),
  [2289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1659),
  [2291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1099),
  [2293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1098),
  [2295] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1098),
  [2297] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2442),
  [2299] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1106),
  [2301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1658),
  [2303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1097),
  [2305] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1097),
  [2307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1100),
  [2309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1101),
  [2311] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer, 2, 0, 0),
  [2313] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_initializer, 1, 0, 0),
  [2315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1908),
  [2317] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2841),
  [2320] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2842),
  [2323] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2845),
  [2326] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2850),
  [2329] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2771),
  [2332] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1943),
  [2335] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2601),
  [2338] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2788),
  [2341] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2856),
  [2344] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2873),
  [2347] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1857),
  [2350] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2851),
  [2353] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2851),
  [2356] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2853),
  [2359] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2141),
  [2362] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2450),
  [2365] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2451),
  [2368] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(1822),
  [2371] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_source_file_repeat1, 2, 0, 0), SHIFT_REPEAT(2144),
  [2374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2841),
  [2376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2842),
  [2378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1813),
  [2380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2845),
  [2382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2850),
  [2384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2771),
  [2386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1943),
  [2388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2601),
  [2390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2788),
  [2392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2856),
  [2394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2873),
  [2396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1857),
  [2398] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2851),
  [2400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2851),
  [2402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2853),
  [2404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2141),
  [2406] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2450),
  [2408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2451),
  [2410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1822),
  [2412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2144),
  [2414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(309),
  [2416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1836),
  [2418] = {.entry = {.count = 1, .reusable = true}}, SHIFT(327),
  [2420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1790),
  [2422] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1792),
  [2424] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event, 4, 0, 0),
  [2426] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2627),
  [2428] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event, 4, 0, 0),
  [2430] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func, 3, 0, 0),
  [2432] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func, 3, 0, 0),
  [2434] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hook, 3, 0, 0),
  [2436] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hook, 3, 0, 0),
  [2438] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event, 3, 0, 0),
  [2440] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event, 3, 0, 0),
  [2442] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_hdr, 3, 0, 0),
  [2444] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1249),
  [2447] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2627),
  [2450] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1300),
  [2452] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1736),
  [2454] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1766),
  [2456] = {.entry = {.count = 1, .reusable = true}}, SHIFT(849),
  [2458] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1751),
  [2460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2580),
  [2462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2440),
  [2464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1738),
  [2466] = {.entry = {.count = 1, .reusable = true}}, SHIFT(846),
  [2468] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1080),
  [2470] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1082),
  [2472] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1080),
  [2474] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1082),
  [2476] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2629),
  [2478] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1174),
  [2480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1175),
  [2482] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1176),
  [2484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1177),
  [2486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2713),
  [2488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_expr_list, 2, 0, 0),
  [2490] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1223),
  [2492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1165),
  [2494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1652),
  [2496] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1165),
  [2498] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2843),
  [2500] = {.entry = {.count = 1, .reusable = true}}, SHIFT(888),
  [2502] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1201),
  [2504] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1167),
  [2506] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1649),
  [2508] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1164),
  [2510] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1164),
  [2512] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1168),
  [2514] = {.entry = {.count = 1, .reusable = true}}, SHIFT(903),
  [2516] = {.entry = {.count = 1, .reusable = true}}, SHIFT(886),
  [2518] = {.entry = {.count = 1, .reusable = true}}, SHIFT(885),
  [2520] = {.entry = {.count = 1, .reusable = true}}, SHIFT(881),
  [2522] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1744),
  [2524] = {.entry = {.count = 1, .reusable = true}}, SHIFT(706),
  [2526] = {.entry = {.count = 1, .reusable = true}}, SHIFT(138),
  [2528] = {.entry = {.count = 1, .reusable = true}}, SHIFT(139),
  [2530] = {.entry = {.count = 1, .reusable = true}}, SHIFT(140),
  [2532] = {.entry = {.count = 1, .reusable = true}}, SHIFT(141),
  [2534] = {.entry = {.count = 1, .reusable = true}}, SHIFT(142),
  [2536] = {.entry = {.count = 1, .reusable = true}}, SHIFT(255),
  [2538] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1903),
  [2540] = {.entry = {.count = 1, .reusable = true}}, SHIFT(940),
  [2542] = {.entry = {.count = 1, .reusable = true}}, SHIFT(941),
  [2544] = {.entry = {.count = 1, .reusable = false}}, SHIFT(940),
  [2546] = {.entry = {.count = 1, .reusable = false}}, SHIFT(941),
  [2548] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2322),
  [2550] = {.entry = {.count = 1, .reusable = true}}, SHIFT(942),
  [2552] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1166),
  [2554] = {.entry = {.count = 1, .reusable = true}}, SHIFT(944),
  [2556] = {.entry = {.count = 1, .reusable = true}}, SHIFT(945),
  [2558] = {.entry = {.count = 1, .reusable = true}}, SHIFT(72),
  [2560] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2027),
  [2562] = {.entry = {.count = 1, .reusable = true}}, SHIFT(127),
  [2564] = {.entry = {.count = 1, .reusable = true}}, SHIFT(153),
  [2566] = {.entry = {.count = 1, .reusable = true}}, SHIFT(155),
  [2568] = {.entry = {.count = 1, .reusable = true}}, SHIFT(245),
  [2570] = {.entry = {.count = 1, .reusable = true}}, SHIFT(157),
  [2572] = {.entry = {.count = 1, .reusable = true}}, SHIFT(241),
  [2574] = {.entry = {.count = 1, .reusable = true}}, SHIFT(159),
  [2576] = {.entry = {.count = 1, .reusable = true}}, SHIFT(77),
  [2578] = {.entry = {.count = 1, .reusable = true}}, SHIFT(55),
  [2580] = {.entry = {.count = 1, .reusable = true}}, SHIFT(41),
  [2582] = {.entry = {.count = 1, .reusable = true}}, SHIFT(521),
  [2584] = {.entry = {.count = 1, .reusable = true}}, SHIFT(231),
  [2586] = {.entry = {.count = 1, .reusable = true}}, SHIFT(247),
  [2588] = {.entry = {.count = 1, .reusable = true}}, SHIFT(248),
  [2590] = {.entry = {.count = 1, .reusable = true}}, SHIFT(249),
  [2592] = {.entry = {.count = 1, .reusable = true}}, SHIFT(135),
  [2594] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1880),
  [2596] = {.entry = {.count = 1, .reusable = true}}, SHIFT(250),
  [2598] = {.entry = {.count = 1, .reusable = true}}, SHIFT(167),
  [2600] = {.entry = {.count = 1, .reusable = true}}, SHIFT(121),
  [2602] = {.entry = {.count = 1, .reusable = true}}, SHIFT(171),
  [2604] = {.entry = {.count = 1, .reusable = true}}, SHIFT(172),
  [2606] = {.entry = {.count = 1, .reusable = true}}, SHIFT(144),
  [2608] = {.entry = {.count = 1, .reusable = true}}, SHIFT(43),
  [2610] = {.entry = {.count = 1, .reusable = true}}, SHIFT(44),
  [2612] = {.entry = {.count = 1, .reusable = true}}, SHIFT(254),
  [2614] = {.entry = {.count = 1, .reusable = true}}, SHIFT(45),
  [2616] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1911),
  [2618] = {.entry = {.count = 1, .reusable = true}}, SHIFT(832),
  [2620] = {.entry = {.count = 1, .reusable = true}}, SHIFT(236),
  [2622] = {.entry = {.count = 1, .reusable = true}}, SHIFT(179),
  [2624] = {.entry = {.count = 1, .reusable = true}}, SHIFT(181),
  [2626] = {.entry = {.count = 1, .reusable = true}}, SHIFT(183),
  [2628] = {.entry = {.count = 1, .reusable = true}}, SHIFT(184),
  [2630] = {.entry = {.count = 1, .reusable = true}}, SHIFT(47),
  [2632] = {.entry = {.count = 1, .reusable = true}}, SHIFT(48),
  [2634] = {.entry = {.count = 1, .reusable = true}}, SHIFT(49),
  [2636] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1881),
  [2638] = {.entry = {.count = 1, .reusable = true}}, SHIFT(191),
  [2640] = {.entry = {.count = 1, .reusable = true}}, SHIFT(193),
  [2642] = {.entry = {.count = 1, .reusable = true}}, SHIFT(802),
  [2644] = {.entry = {.count = 1, .reusable = true}}, SHIFT(195),
  [2646] = {.entry = {.count = 1, .reusable = true}}, SHIFT(196),
  [2648] = {.entry = {.count = 1, .reusable = true}}, SHIFT(50),
  [2650] = {.entry = {.count = 1, .reusable = true}}, SHIFT(51),
  [2652] = {.entry = {.count = 1, .reusable = true}}, SHIFT(52),
  [2654] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1905),
  [2656] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1283),
  [2658] = {.entry = {.count = 1, .reusable = true}}, SHIFT(203),
  [2660] = {.entry = {.count = 1, .reusable = true}}, SHIFT(205),
  [2662] = {.entry = {.count = 1, .reusable = true}}, SHIFT(207),
  [2664] = {.entry = {.count = 1, .reusable = true}}, SHIFT(208),
  [2666] = {.entry = {.count = 1, .reusable = true}}, SHIFT(53),
  [2668] = {.entry = {.count = 1, .reusable = true}}, SHIFT(54),
  [2670] = {.entry = {.count = 1, .reusable = true}}, SHIFT(78),
  [2672] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1909),
  [2674] = {.entry = {.count = 1, .reusable = true}}, SHIFT(215),
  [2676] = {.entry = {.count = 1, .reusable = true}}, SHIFT(146),
  [2678] = {.entry = {.count = 1, .reusable = true}}, SHIFT(56),
  [2680] = {.entry = {.count = 1, .reusable = true}}, SHIFT(256),
  [2682] = {.entry = {.count = 1, .reusable = true}}, SHIFT(57),
  [2684] = {.entry = {.count = 1, .reusable = true}}, SHIFT(800),
  [2686] = {.entry = {.count = 1, .reusable = true}}, SHIFT(58),
  [2688] = {.entry = {.count = 1, .reusable = true}}, SHIFT(923),
  [2690] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1882),
  [2692] = {.entry = {.count = 1, .reusable = true}}, SHIFT(224),
  [2694] = {.entry = {.count = 1, .reusable = true}}, SHIFT(479),
  [2696] = {.entry = {.count = 1, .reusable = true}}, SHIFT(59),
  [2698] = {.entry = {.count = 1, .reusable = true}}, SHIFT(60),
  [2700] = {.entry = {.count = 1, .reusable = true}}, SHIFT(61),
  [2702] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1301),
  [2704] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1879),
  [2706] = {.entry = {.count = 1, .reusable = true}}, SHIFT(233),
  [2708] = {.entry = {.count = 1, .reusable = true}}, SHIFT(62),
  [2710] = {.entry = {.count = 1, .reusable = true}}, SHIFT(63),
  [2712] = {.entry = {.count = 1, .reusable = true}}, SHIFT(64),
  [2714] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1886),
  [2716] = {.entry = {.count = 1, .reusable = true}}, SHIFT(160),
  [2718] = {.entry = {.count = 1, .reusable = true}}, SHIFT(242),
  [2720] = {.entry = {.count = 1, .reusable = true}}, SHIFT(66),
  [2722] = {.entry = {.count = 1, .reusable = true}}, SHIFT(67),
  [2724] = {.entry = {.count = 1, .reusable = true}}, SHIFT(68),
  [2726] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1895),
  [2728] = {.entry = {.count = 1, .reusable = true}}, SHIFT(162),
  [2730] = {.entry = {.count = 1, .reusable = true}}, SHIFT(163),
  [2732] = {.entry = {.count = 1, .reusable = true}}, SHIFT(251),
  [2734] = {.entry = {.count = 1, .reusable = true}}, SHIFT(258),
  [2736] = {.entry = {.count = 1, .reusable = true}}, SHIFT(164),
  [2738] = {.entry = {.count = 1, .reusable = true}}, SHIFT(202),
  [2740] = {.entry = {.count = 1, .reusable = true}}, SHIFT(70),
  [2742] = {.entry = {.count = 1, .reusable = true}}, SHIFT(165),
  [2744] = {.entry = {.count = 1, .reusable = true}}, SHIFT(71),
  [2746] = {.entry = {.count = 1, .reusable = true}}, SHIFT(40),
  [2748] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1887),
  [2750] = {.entry = {.count = 1, .reusable = true}}, SHIFT(259),
  [2752] = {.entry = {.count = 1, .reusable = true}}, SHIFT(262),
  [2754] = {.entry = {.count = 1, .reusable = true}}, SHIFT(263),
  [2756] = {.entry = {.count = 1, .reusable = true}}, SHIFT(73),
  [2758] = {.entry = {.count = 1, .reusable = true}}, SHIFT(74),
  [2760] = {.entry = {.count = 1, .reusable = true}}, SHIFT(75),
  [2762] = {.entry = {.count = 1, .reusable = true}}, SHIFT(264),
  [2764] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2023),
  [2766] = {.entry = {.count = 1, .reusable = true}}, SHIFT(265),
  [2768] = {.entry = {.count = 1, .reusable = true}}, SHIFT(230),
  [2770] = {.entry = {.count = 1, .reusable = true}}, SHIFT(951),
  [2772] = {.entry = {.count = 1, .reusable = true}}, SHIFT(545),
  [2774] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2243),
  [2776] = {.entry = {.count = 1, .reusable = true}}, SHIFT(266),
  [2778] = {.entry = {.count = 1, .reusable = true}}, SHIFT(421),
  [2780] = {.entry = {.count = 1, .reusable = true}}, SHIFT(936),
  [2782] = {.entry = {.count = 1, .reusable = true}}, SHIFT(122),
  [2784] = {.entry = {.count = 1, .reusable = true}}, SHIFT(174),
  [2786] = {.entry = {.count = 1, .reusable = true}}, SHIFT(665),
  [2788] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1272),
  [2790] = {.entry = {.count = 1, .reusable = true}}, SHIFT(768),
  [2792] = {.entry = {.count = 1, .reusable = true}}, SHIFT(123),
  [2794] = {.entry = {.count = 1, .reusable = true}}, SHIFT(124),
  [2796] = {.entry = {.count = 1, .reusable = true}}, SHIFT(147),
  [2798] = {.entry = {.count = 1, .reusable = true}}, SHIFT(125),
  [2800] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1084),
  [2802] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1907),
  [2804] = {.entry = {.count = 1, .reusable = true}}, SHIFT(176),
  [2806] = {.entry = {.count = 1, .reusable = true}}, SHIFT(177),
  [2808] = {.entry = {.count = 1, .reusable = true}}, SHIFT(178),
  [2810] = {.entry = {.count = 1, .reusable = true}}, SHIFT(741),
  [2812] = {.entry = {.count = 1, .reusable = true}}, SHIFT(185),
  [2814] = {.entry = {.count = 1, .reusable = true}}, SHIFT(69),
  [2816] = {.entry = {.count = 1, .reusable = true}}, SHIFT(186),
  [2818] = {.entry = {.count = 1, .reusable = true}}, SHIFT(126),
  [2820] = {.entry = {.count = 1, .reusable = true}}, SHIFT(238),
  [2822] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1105),
  [2824] = {.entry = {.count = 1, .reusable = true}}, SHIFT(189),
  [2826] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1837),
  [2828] = {.entry = {.count = 1, .reusable = true}}, SHIFT(643),
  [2830] = {.entry = {.count = 1, .reusable = true}}, SHIFT(65),
  [2832] = {.entry = {.count = 1, .reusable = true}}, SHIFT(197),
  [2834] = {.entry = {.count = 1, .reusable = true}}, SHIFT(198),
  [2836] = {.entry = {.count = 1, .reusable = true}}, SHIFT(199),
  [2838] = {.entry = {.count = 1, .reusable = true}}, SHIFT(200),
  [2840] = {.entry = {.count = 1, .reusable = true}}, SHIFT(201),
  [2842] = {.entry = {.count = 1, .reusable = true}}, SHIFT(239),
  [2844] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_assert_msg, 2, 0, 0),
  [2846] = {.entry = {.count = 1, .reusable = true}}, SHIFT(209),
  [2848] = {.entry = {.count = 1, .reusable = true}}, SHIFT(638),
  [2850] = {.entry = {.count = 1, .reusable = true}}, SHIFT(285),
  [2852] = {.entry = {.count = 1, .reusable = true}}, SHIFT(128),
  [2854] = {.entry = {.count = 1, .reusable = true}}, SHIFT(212),
  [2856] = {.entry = {.count = 1, .reusable = true}}, SHIFT(213),
  [2858] = {.entry = {.count = 1, .reusable = true}}, SHIFT(214),
  [2860] = {.entry = {.count = 1, .reusable = true}}, SHIFT(218),
  [2862] = {.entry = {.count = 1, .reusable = true}}, SHIFT(384),
  [2864] = {.entry = {.count = 1, .reusable = true}}, SHIFT(130),
  [2866] = {.entry = {.count = 1, .reusable = true}}, SHIFT(131),
  [2868] = {.entry = {.count = 1, .reusable = true}}, SHIFT(132),
  [2870] = {.entry = {.count = 1, .reusable = true}}, SHIFT(220),
  [2872] = {.entry = {.count = 1, .reusable = true}}, SHIFT(133),
  [2874] = {.entry = {.count = 1, .reusable = true}}, SHIFT(134),
  [2876] = {.entry = {.count = 1, .reusable = true}}, SHIFT(173),
  [2878] = {.entry = {.count = 1, .reusable = true}}, SHIFT(187),
  [2880] = {.entry = {.count = 1, .reusable = true}}, SHIFT(240),
  [2882] = {.entry = {.count = 1, .reusable = true}}, SHIFT(591),
  [2884] = {.entry = {.count = 1, .reusable = true}}, SHIFT(267),
  [2886] = {.entry = {.count = 1, .reusable = true}}, SHIFT(268),
  [2888] = {.entry = {.count = 1, .reusable = true}}, SHIFT(269),
  [2890] = {.entry = {.count = 1, .reusable = true}}, SHIFT(270),
  [2892] = {.entry = {.count = 1, .reusable = true}}, SHIFT(271),
  [2894] = {.entry = {.count = 1, .reusable = true}}, SHIFT(272),
  [2896] = {.entry = {.count = 1, .reusable = true}}, SHIFT(273),
  [2898] = {.entry = {.count = 1, .reusable = true}}, SHIFT(274),
  [2900] = {.entry = {.count = 1, .reusable = true}}, SHIFT(275),
  [2902] = {.entry = {.count = 1, .reusable = true}}, SHIFT(276),
  [2904] = {.entry = {.count = 1, .reusable = true}}, SHIFT(277),
  [2906] = {.entry = {.count = 1, .reusable = true}}, SHIFT(278),
  [2908] = {.entry = {.count = 1, .reusable = true}}, SHIFT(279),
  [2910] = {.entry = {.count = 1, .reusable = true}}, SHIFT(280),
  [2912] = {.entry = {.count = 1, .reusable = true}}, SHIFT(281),
  [2914] = {.entry = {.count = 1, .reusable = true}}, SHIFT(222),
  [2916] = {.entry = {.count = 1, .reusable = true}}, SHIFT(223),
  [2918] = {.entry = {.count = 1, .reusable = true}}, SHIFT(227),
  [2920] = {.entry = {.count = 1, .reusable = true}}, SHIFT(228),
  [2922] = {.entry = {.count = 1, .reusable = true}}, SHIFT(136),
  [2924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(229),
  [2926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1173),
  [2928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(351),
  [2930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(282),
  [2932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(283),
  [2934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(284),
  [2936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(237),
  [2938] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_arg, 3, 0, 0),
  [2940] = {.entry = {.count = 1, .reusable = false}}, SHIFT(759),
  [2942] = {.entry = {.count = 1, .reusable = true}}, SHIFT(925),
  [2944] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2),
  [2946] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1171),
  [2948] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_attr_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2545),
  [2951] = {.entry = {.count = 1, .reusable = false}}, SHIFT(337),
  [2953] = {.entry = {.count = 1, .reusable = false}}, SHIFT(6),
  [2955] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2663),
  [2957] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2667),
  [2959] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2053),
  [2961] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1876),
  [2963] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2673),
  [2965] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2631),
  [2967] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2374),
  [2969] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1268),
  [2971] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expr, 1, 0, 0), SHIFT(2341),
  [2974] = {.entry = {.count = 2, .reusable = true}}, REDUCE(sym_expr, 1, 0, 0), SHIFT(2810),
  [2977] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2589),
  [2980] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2663),
  [2983] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2667),
  [2986] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2053),
  [2989] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1285),
  [2992] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1876),
  [2995] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2366),
  [2998] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2673),
  [3001] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2631),
  [3004] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2559),
  [3007] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(2374),
  [3010] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0), SHIFT_REPEAT(1268),
  [3013] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2121),
  [3015] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2682),
  [3017] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2684),
  [3019] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1999),
  [3021] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2848),
  [3023] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2330),
  [3025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(356),
  [3027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1818),
  [3029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(517),
  [3031] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2404),
  [3033] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2382),
  [3035] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2285),
  [3037] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2041),
  [3039] = {.entry = {.count = 1, .reusable = false}}, SHIFT(762),
  [3041] = {.entry = {.count = 1, .reusable = false}}, SHIFT(756),
  [3043] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2253),
  [3045] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2368),
  [3047] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2329),
  [3049] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2408),
  [3051] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2677),
  [3053] = {.entry = {.count = 1, .reusable = false}}, SHIFT(80),
  [3055] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2634),
  [3057] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2355),
  [3059] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1984),
  [3061] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2363),
  [3063] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2417),
  [3065] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2680),
  [3067] = {.entry = {.count = 1, .reusable = false}}, SHIFT(772),
  [3069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(547),
  [3071] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2058),
  [3073] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2065),
  [3075] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2739),
  [3077] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2678),
  [3079] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2007),
  [3081] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2751),
  [3083] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2231),
  [3085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2119),
  [3087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1257),
  [3089] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2711),
  [3091] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2866),
  [3093] = {.entry = {.count = 1, .reusable = true}}, SHIFT(522),
  [3095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(383),
  [3097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(314),
  [3099] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body_elem, 1, 0, 0),
  [3101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1845),
  [3103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1978),
  [3105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2337),
  [3107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(667),
  [3109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(425),
  [3111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(528),
  [3113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(304),
  [3115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(530),
  [3117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(426),
  [3119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(305),
  [3121] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2055),
  [3123] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1947),
  [3125] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2732),
  [3127] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2401),
  [3129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(306),
  [3131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(552),
  [3133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(672),
  [3135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(673),
  [3137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1811),
  [3139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1814),
  [3141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(298),
  [3143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1816),
  [3145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(685),
  [3147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1832),
  [3149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(649),
  [3151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(652),
  [3153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(316),
  [3155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(709),
  [3157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(331),
  [3159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(730),
  [3161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1829),
  [3163] = {.entry = {.count = 1, .reusable = true}}, SHIFT(701),
  [3165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(332),
  [3167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(666),
  [3169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(481),
  [3171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(333),
  [3173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(385),
  [3175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2136),
  [3177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(326),
  [3179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(388),
  [3181] = {.entry = {.count = 1, .reusable = true}}, SHIFT(389),
  [3183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1828),
  [3185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1826),
  [3187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(303),
  [3189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1808),
  [3191] = {.entry = {.count = 1, .reusable = true}}, SHIFT(355),
  [3193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(742),
  [3195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(714),
  [3197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(718),
  [3199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(594),
  [3201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(313),
  [3203] = {.entry = {.count = 1, .reusable = true}}, SHIFT(715),
  [3205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1839),
  [3207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(329),
  [3209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1815),
  [3211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(601),
  [3213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(602),
  [3215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(485),
  [3217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(486),
  [3219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(352),
  [3221] = {.entry = {.count = 1, .reusable = true}}, SHIFT(668),
  [3223] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body_elem, 3, 0, 0),
  [3225] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym__simple_type_repeat1, 2, 0, 0),
  [3227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1806),
  [3229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(76),
  [3231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1861),
  [3233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(46),
  [3235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(4),
  [3237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(5),
  [3239] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_func_decl_repeat1, 2, 0, 0),
  [3241] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_func_decl_repeat1, 2, 0, 0), SHIFT_REPEAT(1861),
  [3244] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_func_decl_repeat1, 2, 0, 0), SHIFT_REPEAT(2327),
  [3247] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_func_decl_repeat1, 2, 0, 0), SHIFT_REPEAT(2327),
  [3250] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_func_decl_repeat1, 2, 0, 0), SHIFT_REPEAT(2334),
  [3253] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_func_decl_repeat1, 2, 0, 0), SHIFT_REPEAT(2042),
  [3256] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_func_decl_repeat1, 2, 0, 0), SHIFT_REPEAT(2412),
  [3259] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_func_decl_repeat1, 2, 0, 0), SHIFT_REPEAT(2458),
  [3262] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_func_decl_repeat1, 2, 0, 0), SHIFT_REPEAT(296),
  [3265] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_func_decl_repeat1, 2, 0, 0), SHIFT_REPEAT(2120),
  [3268] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func, 4, 0, 0),
  [3270] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func, 4, 0, 0),
  [3272] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event, 5, 0, 0),
  [3274] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_event, 5, 0, 0),
  [3276] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_func_hdr, 1, 0, 0),
  [3278] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_func_hdr, 1, 0, 0),
  [3280] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_hook, 4, 0, 0),
  [3282] = {.entry = {.count = 1, .reusable = false}}, REDUCE(sym_hook, 4, 0, 0),
  [3284] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1912),
  [3286] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1928),
  [3288] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2211),
  [3290] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1878),
  [3292] = {.entry = {.count = 1, .reusable = true}}, SHIFT(445),
  [3294] = {.entry = {.count = 1, .reusable = true}}, SHIFT(446),
  [3296] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1899),
  [3298] = {.entry = {.count = 1, .reusable = true}}, SHIFT(916),
  [3300] = {.entry = {.count = 1, .reusable = true}}, SHIFT(906),
  [3302] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1079),
  [3304] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1904),
  [3306] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1884),
  [3308] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1894),
  [3310] = {.entry = {.count = 1, .reusable = true}}, SHIFT(368),
  [3312] = {.entry = {.count = 1, .reusable = true}}, SHIFT(369),
  [3314] = {.entry = {.count = 1, .reusable = true}}, SHIFT(947),
  [3316] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1916),
  [3318] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1874),
  [3320] = {.entry = {.count = 1, .reusable = true}}, SHIFT(335),
  [3322] = {.entry = {.count = 1, .reusable = true}}, SHIFT(336),
  [3324] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1913),
  [3326] = {.entry = {.count = 1, .reusable = true}}, SHIFT(621),
  [3328] = {.entry = {.count = 1, .reusable = true}}, SHIFT(622),
  [3330] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1906),
  [3332] = {.entry = {.count = 1, .reusable = true}}, SHIFT(507),
  [3334] = {.entry = {.count = 1, .reusable = true}}, SHIFT(509),
  [3336] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1877),
  [3338] = {.entry = {.count = 1, .reusable = true}}, SHIFT(529),
  [3340] = {.entry = {.count = 1, .reusable = true}}, SHIFT(533),
  [3342] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1169),
  [3344] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1915),
  [3346] = {.entry = {.count = 1, .reusable = true}}, SHIFT(657),
  [3348] = {.entry = {.count = 1, .reusable = true}}, SHIFT(658),
  [3350] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1914),
  [3352] = {.entry = {.count = 1, .reusable = true}}, SHIFT(403),
  [3354] = {.entry = {.count = 1, .reusable = true}}, SHIFT(404),
  [3356] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1888),
  [3358] = {.entry = {.count = 1, .reusable = true}}, SHIFT(551),
  [3360] = {.entry = {.count = 1, .reusable = true}}, SHIFT(525),
  [3362] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1917),
  [3364] = {.entry = {.count = 1, .reusable = true}}, SHIFT(468),
  [3366] = {.entry = {.count = 1, .reusable = true}}, SHIFT(469),
  [3368] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1102),
  [3370] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1883),
  [3372] = {.entry = {.count = 1, .reusable = true}}, SHIFT(410),
  [3374] = {.entry = {.count = 1, .reusable = true}}, SHIFT(413),
  [3376] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1892),
  [3378] = {.entry = {.count = 1, .reusable = true}}, SHIFT(373),
  [3380] = {.entry = {.count = 1, .reusable = true}}, SHIFT(374),
  [3382] = {.entry = {.count = 1, .reusable = true}}, SHIFT(810),
  [3384] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2604),
  [3386] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1789),
  [3388] = {.entry = {.count = 1, .reusable = true}}, SHIFT(833),
  [3390] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2264),
  [3392] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1957),
  [3394] = {.entry = {.count = 1, .reusable = true}}, SHIFT(83),
  [3396] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1762),
  [3398] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1256),
  [3400] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1245),
  [3402] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1293),
  [3404] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1743),
  [3406] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2213),
  [3408] = {.entry = {.count = 1, .reusable = true}}, SHIFT(758),
  [3410] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1281),
  [3412] = {.entry = {.count = 1, .reusable = true}}, SHIFT(785),
  [3414] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1897),
  [3416] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1350),
  [3418] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_list, 1, 0, 0),
  [3420] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1669),
  [3422] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2454),
  [3424] = {.entry = {.count = 1, .reusable = false}}, SHIFT(899),
  [3426] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2465),
  [3428] = {.entry = {.count = 1, .reusable = false}}, SHIFT(89),
  [3430] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_list_repeat1, 2, 0, 0), SHIFT_REPEAT(833),
  [3433] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2264),
  [3436] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1775),
  [3438] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2258),
  [3440] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1778),
  [3442] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1716),
  [3444] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2520),
  [3446] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2091),
  [3448] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2, 0, 0),
  [3450] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_enum_body_repeat1, 2, 0, 0), SHIFT_REPEAT(1669),
  [3453] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_redef_record_decl_repeat1, 2, 0, 0),
  [3455] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_redef_record_decl_repeat1, 2, 0, 0), SHIFT_REPEAT(2258),
  [3458] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 1, 0, 0),
  [3460] = {.entry = {.count = 1, .reusable = true}}, SHIFT(801),
  [3462] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1286),
  [3464] = {.entry = {.count = 1, .reusable = true}}, SHIFT(804),
  [3466] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_capture_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2520),
  [3469] = {.entry = {.count = 2, .reusable = false}}, REDUCE(aux_sym_capture_list_repeat1, 2, 0, 0), SHIFT_REPEAT(2091),
  [3472] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1284),
  [3474] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1770),
  [3476] = {.entry = {.count = 1, .reusable = true}}, SHIFT(760),
  [3478] = {.entry = {.count = 1, .reusable = false}}, SHIFT(2895),
  [3480] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1198),
  [3482] = {.entry = {.count = 1, .reusable = false}}, SHIFT(118),
  [3484] = {.entry = {.count = 1, .reusable = true}}, SHIFT(763),
  [3486] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2425),
  [3488] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_args, 2, 0, 0),
  [3490] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_list_repeat1, 4, 0, 0),
  [3492] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1687),
  [3494] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1202),
  [3496] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_formal_args_repeat1, 2, 0, 0), SHIFT_REPEAT(2604),
  [3499] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_type_list, 3, 0, 0),
  [3501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2780),
  [3503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2892),
  [3505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1689),
  [3507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1065),
  [3509] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_args, 1, 0, 0),
  [3511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1066),
  [3513] = {.entry = {.count = 1, .reusable = true}}, SHIFT(901),
  [3515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1679),
  [3517] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_type_list, 2, 0, 0),
  [3519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2797),
  [3521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(924),
  [3523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1089),
  [3525] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_formal_arg, 4, 0, 0),
  [3527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1109),
  [3529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1110),
  [3531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1183),
  [3533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1184),
  [3535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1117),
  [3537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1118),
  [3539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1186),
  [3541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1187),
  [3543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1189),
  [3545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1190),
  [3547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1125),
  [3549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1126),
  [3551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1192),
  [3553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1193),
  [3555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1195),
  [3557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1196),
  [3559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1918),
  [3561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1203),
  [3563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1090),
  [3565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2133),
  [3567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1801),
  [3569] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2690),
  [3571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1875),
  [3573] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_begin_lambda, 1, 0, 0),
  [3575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2743),
  [3577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2829),
  [3579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2830),
  [3581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2885),
  [3583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2228),
  [3585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2229),
  [3587] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_spec, 5, 0, 0),
  [3589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2246),
  [3591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2247),
  [3593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1919),
  [3595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(761),
  [3597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2320),
  [3599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2321),
  [3601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1891),
  [3603] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body_elem, 2, 0, 0),
  [3605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1893),
  [3607] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body, 2, 0, 0),
  [3609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2008),
  [3611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2487),
  [3613] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_type_list, 4, 0, 0),
  [3615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2242),
  [3617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2385),
  [3619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2386),
  [3621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2245),
  [3623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2478),
  [3625] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2215),
  [3627] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_case_type_list, 5, 0, 0),
  [3629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2610),
  [3631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2612),
  [3633] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2674),
  [3635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2675),
  [3637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2456),
  [3639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2122),
  [3641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2126),
  [3643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(42),
  [3645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2717),
  [3647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2718),
  [3649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2724),
  [3651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2730),
  [3653] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2643),
  [3655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(950),
  [3657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2562),
  [3659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1901),
  [3661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2344),
  [3663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2645),
  [3665] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2607),
  [3667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2650),
  [3669] = {.entry = {.count = 1, .reusable = true}}, SHIFT(952),
  [3671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2652),
  [3673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(953),
  [3675] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2032),
  [3677] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_capture, 2, 0, 0),
  [3679] = {.entry = {.count = 1, .reusable = false}}, REDUCE(aux_sym_capture_list_repeat1, 2, 0, 0),
  [3681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2050),
  [3683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2498),
  [3685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2048),
  [3687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2057),
  [3689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1885),
  [3691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2289),
  [3693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(927),
  [3695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2735),
  [3697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(963),
  [3699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2402),
  [3701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2403),
  [3703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2737),
  [3705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(964),
  [3707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2738),
  [3709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(965),
  [3711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1796),
  [3713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1939),
  [3715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(870),
  [3717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2747),
  [3719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(974),
  [3721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2749),
  [3723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(975),
  [3725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2750),
  [3727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(976),
  [3729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1295),
  [3731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2759),
  [3733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(984),
  [3735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2316),
  [3737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2761),
  [3739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(985),
  [3741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2762),
  [3743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(986),
  [3745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(787),
  [3747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2770),
  [3749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(994),
  [3751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2847),
  [3753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2772),
  [3755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(995),
  [3757] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2773),
  [3759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(996),
  [3761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2781),
  [3763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1004),
  [3765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2783),
  [3767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1005),
  [3769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2784),
  [3771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1006),
  [3773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2792),
  [3775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1015),
  [3777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2794),
  [3779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1016),
  [3781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2795),
  [3783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1017),
  [3785] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_capture, 1, 0, 0),
  [3787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2803),
  [3789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1025),
  [3791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2805),
  [3793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1026),
  [3795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2806),
  [3797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1027),
  [3799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2372),
  [3801] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2814),
  [3803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1035),
  [3805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2816),
  [3807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1036),
  [3809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2817),
  [3811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1037),
  [3813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2161),
  [3815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2825),
  [3817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1046),
  [3819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2827),
  [3821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1047),
  [3823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2828),
  [3825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1048),
  [3827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2831),
  [3829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1056),
  [3831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2833),
  [3833] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1057),
  [3835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2834),
  [3837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1058),
  [3839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2854),
  [3841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2855),
  [3843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1771),
  [3845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2345),
  [3847] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_begin_lambda, 2, 0, 0),
  [3849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2045),
  [3851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2353),
  [3853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2046),
  [3855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2438),
  [3857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1902),
  [3859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2507),
  [3861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1182),
  [3863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2407),
  [3865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(843),
  [3867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1623),
  [3869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1634),
  [3871] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2166),
  [3873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2483),
  [3875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2514),
  [3877] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2187),
  [3879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2060),
  [3881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(845),
  [3883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1638),
  [3885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2063),
  [3887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2064),
  [3889] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_enum_body_elem, 4, 0, 0),
  [3891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2189),
  [3893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2068),
  [3895] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_type_spec, 4, 0, 0),
  [3897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2069),
  [3899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2070),
  [3901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2191),
  [3903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2072),
  [3905] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2891),
  [3907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2074),
  [3909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2075),
  [3911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2893),
  [3913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2193),
  [3915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2079),
  [3917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2081),
  [3919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2082),
  [3921] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_stmt_repeat1, 2, 0, 0), SHIFT_REPEAT(2543),
  [3924] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2195),
  [3926] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2084),
  [3928] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2085),
  [3930] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2086),
  [3932] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1756),
  [3934] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2197),
  [3936] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2088),
  [3938] = {.entry = {.count = 2, .reusable = true}}, REDUCE(aux_sym_case_type_list_repeat1, 2, 0, 0), SHIFT_REPEAT(1772),
  [3941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2089),
  [3943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2090),
  [3945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2370),
  [3947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2199),
  [3949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2092),
  [3951] = {.entry = {.count = 1, .reusable = true}}, SHIFT(830),
  [3953] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2093),
  [3955] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2094),
  [3957] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2395),
  [3959] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2201),
  [3961] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2096),
  [3963] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2821),
  [3965] = {.entry = {.count = 1, .reusable = true}}, SHIFT(890),
  [3967] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2097),
  [3969] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2098),
  [3971] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1612),
  [3973] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2203),
  [3975] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2101),
  [3977] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2574),
  [3979] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2102),
  [3981] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2103),
  [3983] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2205),
  [3985] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2104),
  [3987] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2105),
  [3989] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2106),
  [3991] = {.entry = {.count = 1, .reusable = true}}, SHIFT(839),
  [3993] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1630),
  [3995] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2115),
  [3997] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2575),
  [3999] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2117),
  [4001] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1932),
  [4003] = {.entry = {.count = 1, .reusable = true}}, SHIFT(855),
  [4005] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_event_hdr, 4, 0, 0),
  [4007] = {.entry = {.count = 1, .reusable = true}}, SHIFT(837),
  [4009] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1610),
  [4011] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2132),
  [4013] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2137),
  [4015] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2138),
  [4017] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2142),
  [4019] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2143),
  [4021] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2147),
  [4023] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2148),
  [4025] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2152),
  [4027] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2153),
  [4029] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2157),
  [4031] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2158),
  [4033] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2162),
  [4035] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2163),
  [4037] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2167),
  [4039] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2168),
  [4041] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2172),
  [4043] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2173),
  [4045] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2175),
  [4047] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2176),
  [4049] = {.entry = {.count = 1, .reusable = true}}, SHIFT(848),
  [4051] = {.entry = {.count = 1, .reusable = true}}, SHIFT(842),
  [4053] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2313),
  [4055] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1680),
  [4057] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2179),
  [4059] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2039),
  [4061] = {.entry = {.count = 1, .reusable = true}}, SHIFT(512),
  [4063] = {.entry = {.count = 1, .reusable = true}}, SHIFT(606),
  [4065] = {.entry = {.count = 1, .reusable = true}}, SHIFT(897),
  [4067] = {.entry = {.count = 1, .reusable = true}}, SHIFT(101),
  [4069] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1252),
  [4071] = {.entry = {.count = 1, .reusable = true}}, SHIFT(102),
  [4073] = {.entry = {.count = 1, .reusable = true}}, SHIFT(618),
  [4075] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1678),
  [4077] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1683),
  [4079] = {.entry = {.count = 1, .reusable = true}}, SHIFT(103),
  [4081] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2183),
  [4083] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2495),
  [4085] = {.entry = {.count = 1, .reusable = false}}, SHIFT(746),
  [4087] = {.entry = {.count = 1, .reusable = false}}, SHIFT(626),
  [4089] = {.entry = {.count = 1, .reusable = true}}, SHIFT(626),
  [4091] = {.entry = {.count = 1, .reusable = true}}, SHIFT(746),
  [4093] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_type_list_repeat1, 5, 0, 0),
  [4095] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1807),
  [4097] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2282),
  [4099] = {.entry = {.count = 1, .reusable = false}}, SHIFT(629),
  [4101] = {.entry = {.count = 1, .reusable = true}}, SHIFT(630),
  [4103] = {.entry = {.count = 1, .reusable = true}}, SHIFT(108),
  [4105] = {.entry = {.count = 1, .reusable = true}}, SHIFT(104),
  [4107] = {.entry = {.count = 1, .reusable = true}}, SHIFT(310),
  [4109] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2721),
  [4111] = {.entry = {.count = 1, .reusable = true}}, SHIFT(109),
  [4113] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1664),
  [4115] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2622),
  [4117] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2301),
  [4119] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2087),
  [4121] = {.entry = {.count = 1, .reusable = true}}, SHIFT(22),
  [4123] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1274),
  [4125] = {.entry = {.count = 1, .reusable = true}}, SHIFT(114),
  [4127] = {.entry = {.count = 1, .reusable = true}}, SHIFT(110),
  [4129] = {.entry = {.count = 1, .reusable = true}}, SHIFT(115),
  [4131] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1255),
  [4133] = {.entry = {.count = 1, .reusable = true}}, SHIFT(566),
  [4135] = {.entry = {.count = 1, .reusable = true}}, SHIFT(472),
  [4137] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2683),
  [4139] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1346),
  [4141] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1889),
  [4143] = {.entry = {.count = 1, .reusable = true}}, SHIFT(292),
  [4145] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2659),
  [4147] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2052),
  [4149] = {.entry = {.count = 1, .reusable = true}}, SHIFT(505),
  [4151] = {.entry = {.count = 1, .reusable = true}}, SHIFT(311),
  [4153] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2720),
  [4155] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2398),
  [4157] = {.entry = {.count = 1, .reusable = true}}, SHIFT(926),
  [4159] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2839),
  [4161] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1921),
  [4163] = {.entry = {.count = 1, .reusable = false}}, SHIFT(571),
  [4165] = {.entry = {.count = 1, .reusable = true}}, SHIFT(937),
  [4167] = {.entry = {.count = 1, .reusable = true}}, SHIFT(571),
  [4169] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1626),
  [4171] = {.entry = {.count = 1, .reusable = true}}, SHIFT(938),
  [4173] = {.entry = {.count = 1, .reusable = true}}, SHIFT(939),
  [4175] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2299),
  [4177] = {.entry = {.count = 1, .reusable = true}}, SHIFT(946),
  [4179] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1706),
  [4181] = {.entry = {.count = 1, .reusable = false}}, SHIFT(703),
  [4183] = {.entry = {.count = 1, .reusable = true}}, SHIFT(704),
  [4185] = {.entry = {.count = 1, .reusable = true}}, SHIFT(776),
  [4187] = {.entry = {.count = 1, .reusable = true}}, SHIFT(808),
  [4189] = {.entry = {.count = 1, .reusable = true}}, SHIFT(917),
  [4191] = {.entry = {.count = 1, .reusable = false}}, SHIFT(574),
  [4193] = {.entry = {.count = 1, .reusable = true}}, SHIFT(575),
  [4195] = {.entry = {.count = 1, .reusable = true}}, SHIFT(948),
  [4197] = {.entry = {.count = 1, .reusable = true}}, SHIFT(949),
  [4199] = {.entry = {.count = 1, .reusable = true}}, SHIFT(105),
  [4201] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2390),
  [4203] = {.entry = {.count = 1, .reusable = false}}, SHIFT(302),
  [4205] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1951),
  [4207] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1619),
  [4209] = {.entry = {.count = 1, .reusable = true}}, SHIFT(732),
  [4211] = {.entry = {.count = 1, .reusable = true}}, SHIFT(312),
  [4213] = {.entry = {.count = 1, .reusable = true}}, SHIFT(302),
  [4215] = {.entry = {.count = 1, .reusable = true}}, SHIFT(956),
  [4217] = {.entry = {.count = 1, .reusable = true}}, SHIFT(918),
  [4219] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1924),
  [4221] = {.entry = {.count = 1, .reusable = false}}, SHIFT(322),
  [4223] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1642),
  [4225] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2754),
  [4227] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2154),
  [4229] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1646),
  [4231] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1910),
  [4233] = {.entry = {.count = 1, .reusable = true}}, SHIFT(954),
  [4235] = {.entry = {.count = 1, .reusable = true}}, SHIFT(955),
  [4237] = {.entry = {.count = 1, .reusable = true}}, SHIFT(532),
  [4239] = {.entry = {.count = 1, .reusable = true}}, SHIFT(534),
  [4241] = {.entry = {.count = 1, .reusable = true}}, SHIFT(805),
  [4243] = {.entry = {.count = 1, .reusable = true}}, SHIFT(920),
  [4245] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2764),
  [4247] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1617),
  [4249] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1661),
  [4251] = {.entry = {.count = 1, .reusable = true}}, SHIFT(462),
  [4253] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_capture_list, 3, 0, 0),
  [4255] = {.entry = {.count = 1, .reusable = false}}, SHIFT(473),
  [4257] = {.entry = {.count = 1, .reusable = true}}, SHIFT(473),
  [4259] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1269),
  [4261] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1942),
  [4263] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2765),
  [4265] = {.entry = {.count = 1, .reusable = true}}, SHIFT(882),
  [4267] = {.entry = {.count = 1, .reusable = false}}, SHIFT(476),
  [4269] = {.entry = {.count = 1, .reusable = true}}, SHIFT(477),
  [4271] = {.entry = {.count = 1, .reusable = true}}, SHIFT(21),
  [4273] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1081),
  [4275] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1083),
  [4277] = {.entry = {.count = 1, .reusable = true}}, SHIFT(334),
  [4279] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1725),
  [4281] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1856),
  [4283] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2389),
  [4285] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1085),
  [4287] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1685),
  [4289] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1686),
  [4291] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1926),
  [4293] = {.entry = {.count = 1, .reusable = true}}, SHIFT(809),
  [4295] = {.entry = {.count = 1, .reusable = true}}, SHIFT(960),
  [4297] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1759),
  [4299] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1608),
  [4301] = {.entry = {.count = 1, .reusable = true}}, SHIFT(961),
  [4303] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2326),
  [4305] = {.entry = {.count = 1, .reusable = true}}, SHIFT(962),
  [4307] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1040),
  [4309] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1219),
  [4311] = {.entry = {.count = 1, .reusable = true}}, SHIFT(780),
  [4313] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2615),
  [4315] = {.entry = {.count = 1, .reusable = true}}, SHIFT(683),
  [4317] = {.entry = {.count = 1, .reusable = true}}, SHIFT(690),
  [4319] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1995),
  [4321] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_formal_args_repeat1, 2, 0, 0),
  [4323] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1204),
  [4325] = {.entry = {.count = 1, .reusable = true}}, SHIFT(966),
  [4327] = {.entry = {.count = 1, .reusable = true}}, SHIFT(120),
  [4329] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1178),
  [4331] = {.entry = {.count = 1, .reusable = true}}, SHIFT(488),
  [4333] = {.entry = {.count = 1, .reusable = true}}, SHIFT(489),
  [4335] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2078),
  [4337] = {.entry = {.count = 1, .reusable = true}}, SHIFT(323),
  [4339] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1288),
  [4341] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1103),
  [4343] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1104),
  [4345] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1871),
  [4347] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2443),
  [4349] = {.entry = {.count = 1, .reusable = true}}, SHIFT(928),
  [4351] = {.entry = {.count = 1, .reusable = true}}, SHIFT(971),
  [4353] = {.entry = {.count = 1, .reusable = true}}, SHIFT(972),
  [4355] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2482),
  [4357] = {.entry = {.count = 1, .reusable = true}}, SHIFT(973),
  [4359] = {.entry = {.count = 1, .reusable = true}}, SHIFT(500),
  [4361] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2824),
  [4363] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_stmt_repeat1, 2, 0, 0),
  [4365] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2419),
  [4367] = {.entry = {.count = 1, .reusable = false}}, SHIFT(508),
  [4369] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2365),
  [4371] = {.entry = {.count = 1, .reusable = true}}, SHIFT(88),
  [4373] = {.entry = {.count = 1, .reusable = true}}, SHIFT(508),
  [4375] = {.entry = {.count = 1, .reusable = true}}, SHIFT(977),
  [4377] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2005),
  [4379] = {.entry = {.count = 1, .reusable = true}}, SHIFT(978),
  [4381] = {.entry = {.count = 1, .reusable = true}}, SHIFT(981),
  [4383] = {.entry = {.count = 1, .reusable = true}}, SHIFT(982),
  [4385] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2588),
  [4387] = {.entry = {.count = 1, .reusable = true}}, SHIFT(983),
  [4389] = {.entry = {.count = 1, .reusable = true}}, SHIFT(100),
  [4391] = {.entry = {.count = 1, .reusable = true}}, SHIFT(921),
  [4393] = {.entry = {.count = 1, .reusable = false}}, SHIFT(511),
  [4395] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2295),
  [4397] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1641),
  [4399] = {.entry = {.count = 1, .reusable = true}}, SHIFT(987),
  [4401] = {.entry = {.count = 1, .reusable = true}}, SHIFT(988),
  [4403] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1773),
  [4405] = {.entry = {.count = 1, .reusable = true}}, SHIFT(991),
  [4407] = {.entry = {.count = 1, .reusable = true}}, SHIFT(992),
  [4409] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2736),
  [4411] = {.entry = {.count = 1, .reusable = true}}, SHIFT(993),
  [4413] = {.entry = {.count = 1, .reusable = true}}, SHIFT(611),
  [4415] = {.entry = {.count = 1, .reusable = true}}, SHIFT(803),
  [4417] = {.entry = {.count = 1, .reusable = true}}, REDUCE(sym_capture_list, 4, 0, 0),
  [4419] = {.entry = {.count = 1, .reusable = true}}, SHIFT(789),
  [4421] = {.entry = {.count = 1, .reusable = true}}, SHIFT(997),
  [4423] = {.entry = {.count = 1, .reusable = true}}, SHIFT(998),
  [4425] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2819),
  [4427] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1001),
  [4429] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1002),
  [4431] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2802),
  [4433] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1003),
  [4435] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1763),
  [4437] = {.entry = {.count = 1, .reusable = false}}, SHIFT(627),
  [4439] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1007),
  [4441] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2049),
  [4443] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1008),
  [4445] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1012),
  [4447] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1013),
  [4449] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2861),
  [4451] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1014),
  [4453] = {.entry = {.count = 1, .reusable = true}}, SHIFT(627),
  [4455] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1018),
  [4457] = {.entry = {.count = 1, .reusable = true}}, SHIFT(428),
  [4459] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1019),
  [4461] = {.entry = {.count = 1, .reusable = true}}, SHIFT(429),
  [4463] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1022),
  [4465] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1023),
  [4467] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2899),
  [4469] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1024),
  [4471] = {.entry = {.count = 1, .reusable = true}}, SHIFT(922),
  [4473] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1028),
  [4475] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1838),
  [4477] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1029),
  [4479] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1297),
  [4481] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1032),
  [4483] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1033),
  [4485] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2235),
  [4487] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1034),
  [4489] = {.entry = {.count = 1, .reusable = true}}, SHIFT(98),
  [4491] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1633),
  [4493] = {.entry = {.count = 1, .reusable = true}}, SHIFT(757),
  [4495] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1768),
  [4497] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1038),
  [4499] = {.entry = {.count = 1, .reusable = true}}, SHIFT(99),
  [4501] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1039),
  [4503] = {.entry = {.count = 1, .reusable = true}}, SHIFT(443),
  [4505] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1043),
  [4507] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1044),
  [4509] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2259),
  [4511] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1045),
  [4513] = {.entry = {.count = 1, .reusable = false}}, SHIFT(632),
  [4515] = {.entry = {.count = 1, .reusable = true}}, SHIFT(633),
  [4517] = {.entry = {.count = 1, .reusable = true}}, SHIFT(751),
  [4519] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1049),
  [4521] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1298),
  [4523] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1050),
  [4525] = {.entry = {.count = 1, .reusable = false}}, SHIFT(460),
  [4527] = {.entry = {.count = 1, .reusable = true}}, SHIFT(460),
  [4529] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1053),
  [4531] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1054),
  [4533] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2283),
  [4535] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1055),
  [4537] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2635),
  [4539] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1938),
  [4541] = {.entry = {.count = 1, .reusable = true}}, SHIFT(675),
  [4543] = {.entry = {.count = 1, .reusable = true}}, SHIFT(87),
  [4545] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1059),
  [4547] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1060),
  [4549] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1061),
  [4551] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2298),
  [4553] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1062),
  [4555] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2302),
  [4557] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2312),
  [4559] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1064),
  [4561] = {.entry = {.count = 1, .reusable = true}}, SHIFT(92),
  [4563] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1860),
  [4565] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1666),
  [4567] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1890),
  [4569] = {.entry = {.count = 1, .reusable = false}}, SHIFT(463),
  [4571] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2324),
  [4573] = {.entry = {.count = 1, .reusable = true}}, SHIFT(464),
  [4575] = {.entry = {.count = 1, .reusable = true}}, SHIFT(691),
  [4577] = {.entry = {.count = 1, .reusable = true}}, SHIFT(790),
  [4579] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1820),
  [4581] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1804),
  [4583] = {.entry = {.count = 1, .reusable = true}}, SHIFT(93),
  [4585] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1805),
  [4587] = {.entry = {.count = 1, .reusable = true}}, SHIFT(717),
  [4589] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1067),
  [4591] = {.entry = {.count = 1, .reusable = true}}, SHIFT(915),
  [4593] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1068),
  [4595] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1620),
  [4597] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1210),
  [4599] = {.entry = {.count = 1, .reusable = true}}, SHIFT(719),
  [4601] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1934),
  [4603] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1812),
  [4605] = {.entry = {.count = 1, .reusable = true}}, SHIFT(911),
  [4607] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2352),
  [4609] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1776),
  [4611] = {.entry = {.count = 1, .reusable = true}}, SHIFT(391),
  [4613] = {.entry = {.count = 1, .reusable = true}}, SHIFT(392),
  [4615] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2357),
  [4617] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2359),
  [4619] = {.entry = {.count = 1, .reusable = true}}, SHIFT(330),
  [4621] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1830),
  [4623] = {.entry = {.count = 1, .reusable = true}}, SHIFT(400),
  [4625] = {.entry = {.count = 1, .reusable = false}}, SHIFT(408),
  [4627] = {.entry = {.count = 1, .reusable = true}}, SHIFT(408),
  [4629] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1896),
  [4631] = {.entry = {.count = 1, .reusable = true}}, SHIFT(728),
  [4633] = {.entry = {.count = 1, .reusable = false}}, SHIFT(411),
  [4635] = {.entry = {.count = 1, .reusable = true}}, SHIFT(412),
  [4637] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1206),
  [4639] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1660),
  [4641] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1655),
  [4643] = {.entry = {.count = 1, .reusable = true}}, SHIFT(106),
  [4645] = {.entry = {.count = 1, .reusable = true}}, SHIFT(308),
  [4647] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1690),
  [4649] = {.entry = {.count = 1, .reusable = true}}, SHIFT(358),
  [4651] = {.entry = {.count = 1, .reusable = true}}, SHIFT(359),
  [4653] = {.entry = {.count = 1, .reusable = false}}, SHIFT(734),
  [4655] = {.entry = {.count = 1, .reusable = true}}, SHIFT(734),
  [4657] = {.entry = {.count = 1, .reusable = true}}, SHIFT(887),
  [4659] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2641),
  [4661] = {.entry = {.count = 1, .reusable = true}}, SHIFT(367),
  [4663] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1615),
  [4665] = {.entry = {.count = 1, .reusable = false}}, SHIFT(436),
  [4667] = {.entry = {.count = 1, .reusable = true}}, SHIFT(436),
  [4669] = {.entry = {.count = 1, .reusable = false}}, SHIFT(438),
  [4671] = {.entry = {.count = 1, .reusable = true}}, SHIFT(439),
  [4673] = {.entry = {.count = 1, .reusable = true}}, SHIFT(107),
  [4675] = {.entry = {.count = 1, .reusable = false}}, SHIFT(375),
  [4677] = {.entry = {.count = 1, .reusable = true}}, SHIFT(375),
  [4679] = {.entry = {.count = 1, .reusable = false}}, SHIFT(376),
  [4681] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1088),
  [4683] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2649),
  [4685] = {.entry = {.count = 1, .reusable = true}}, SHIFT(745),
  [4687] = {.entry = {.count = 1, .reusable = true}}, SHIFT(377),
  [4689] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1091),
  [4691] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1628),
  [4693] = {.entry = {.count = 1, .reusable = true}}, SHIFT(111),
  [4695] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2423),
  [4697] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2867),
  [4699] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2426),
  [4701] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2428),
  [4703] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1621),
  [4705] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1108),
  [4707] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1855),
  [4709] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1713),
  [4711] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1111),
  [4713] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2461),
  [4715] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1303),
  [4717] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2464),
  [4719] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2466),
  [4721] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1116),
  [4723] = {.entry = {.count = 1, .reusable = true}}, SHIFT(315),
  [4725] = {.entry = {.count = 1, .reusable = true}}, SHIFT(682),
  [4727] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1185),
  [4729] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2481),
  [4731] = {.entry = {.count = 1, .reusable = true}}, SHIFT(684),
  [4733] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2484),
  [4735] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2486),
  [4737] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1124),
  [4739] = {.entry = {.count = 1, .reusable = true}}, SHIFT(913),
  [4741] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1119),
  [4743] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2501),
  [4745] = {.entry = {.count = 1, .reusable = true}}, SHIFT(95),
  [4747] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2504),
  [4749] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2506),
  [4751] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1132),
  [4753] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1940),
  [4755] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1188),
  [4757] = {.entry = {.count = 1, .reusable = true}}, REDUCE(aux_sym_case_type_list_repeat1, 3, 0, 0),
  [4759] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2516),
  [4761] = {.entry = {.count = 1, .reusable = true}}, SHIFT(116),
  [4763] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2519),
  [4765] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2521),
  [4767] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1137),
  [4769] = {.entry = {.count = 1, .reusable = true}}, SHIFT(579),
  [4771] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2139),
  [4773] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1191),
  [4775] = {.entry = {.count = 1, .reusable = true}}, SHIFT(117),
  [4777] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2531),
  [4779] = {.entry = {.count = 1, .reusable = true}}, SHIFT(699),
  [4781] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2534),
  [4783] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2536),
  [4785] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1142),
  [4787] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2011),
  [4789] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1127),
  [4791] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2260),
  [4793] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2546),
  [4795] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2549),
  [4797] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2551),
  [4799] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1147),
  [4801] = {.entry = {.count = 1, .reusable = false}}, SHIFT(585),
  [4803] = {.entry = {.count = 1, .reusable = true}}, SHIFT(585),
  [4805] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1941),
  [4807] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1194),
  [4809] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2561),
  [4811] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2564),
  [4813] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2566),
  [4815] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1152),
  [4817] = {.entry = {.count = 1, .reusable = true}}, SHIFT(894),
  [4819] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2217),
  [4821] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1197),
  [4823] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2776),
  [4825] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2576),
  [4827] = {.entry = {.count = 1, .reusable = true}}, SHIFT(94),
  [4829] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2579),
  [4831] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2581),
  [4833] = {.entry = {.count = 1, .reusable = false}}, SHIFT(588),
  [4835] = {.entry = {.count = 1, .reusable = true}}, SHIFT(589),
  [4837] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2590),
  [4839] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1271),
  [4841] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2593),
  [4843] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2595),
  [4845] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1163),
  [4847] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2214),
  [4849] = {.entry = {.count = 1, .reusable = true}}, SHIFT(90),
  [4851] = {.entry = {.count = 1, .reusable = true}}, SHIFT(307),
  [4853] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2244),
  [4855] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1251),
  [4857] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1170),
  [4859] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2639),
  [4861] = {.entry = {.count = 1, .reusable = true}}, SHIFT(112),
  [4863] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1172),
  [4865] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1709),
  [4867] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1228),
  [4869] = {.entry = {.count = 1, .reusable = true}}, SHIFT(113),
  [4871] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1810),
  [4873] = {.entry = {.count = 1, .reusable = true}}, SHIFT(91),
  [4875] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1810),
  [4877] = {.entry = {.count = 1, .reusable = false}}, SHIFT(737),
  [4879] = {.entry = {.count = 1, .reusable = true}}, SHIFT(738),
  [4881] = {.entry = {.count = 1, .reusable = true}}, SHIFT(119),
  [4883] = {.entry = {.count = 1, .reusable = true}}, SHIFT(814),
  [4885] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2335),
  [4887] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2130),
  [4889] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1244),
  [4891] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2135),
  [4893] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2140),
  [4895] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2693),
  [4897] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1817),
  [4899] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2145),
  [4901] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2151),
  [4903] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2150),
  [4905] = {.entry = {.count = 1, .reusable = true}},  ACCEPT_INPUT(),
  [4907] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2155),
  [4909] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2695),
  [4911] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2160),
  [4913] = {.entry = {.count = 1, .reusable = true}}, SHIFT(318),
  [4915] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2165),
  [4917] = {.entry = {.count = 1, .reusable = true}}, SHIFT(96),
  [4919] = {.entry = {.count = 1, .reusable = true}}, SHIFT(840),
  [4921] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2170),
  [4923] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2174),
  [4925] = {.entry = {.count = 1, .reusable = true}}, SHIFT(97),
  [4927] = {.entry = {.count = 1, .reusable = false}}, SHIFT(1806),
  [4929] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2022),
  [4931] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1840),
  [4933] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1866),
  [4935] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2844),
  [4937] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2846),
  [4939] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2287),
  [4941] = {.entry = {.count = 1, .reusable = true}}, SHIFT(2399),
  [4943] = {.entry = {.count = 1, .reusable = true}}, SHIFT(1854),
  [4945] = {.entry = {.count = 1, .reusable = true}}, SHIFT(929),
  [4947] = {.entry = {.count = 1, .reusable = true}}, SHIFT(604),
  [4949] = {.entry = {.count = 1, .reusable = true}}, SHIFT(889),
};

#ifdef __cplusplus
extern "C" {
#endif
#ifdef TREE_SITTER_HIDE_SYMBOLS
#define TS_PUBLIC
#elif defined(_WIN32)
#define TS_PUBLIC __declspec(dllexport)
#else
#define TS_PUBLIC __attribute__((visibility("default")))
#endif

TS_PUBLIC const TSLanguage *tree_sitter_zeek(void) {
  static const TSLanguage language = {
    .abi_version = LANGUAGE_VERSION,
    .symbol_count = SYMBOL_COUNT,
    .alias_count = ALIAS_COUNT,
    .token_count = TOKEN_COUNT,
    .external_token_count = EXTERNAL_TOKEN_COUNT,
    .state_count = STATE_COUNT,
    .large_state_count = LARGE_STATE_COUNT,
    .production_id_count = PRODUCTION_ID_COUNT,
    .field_count = FIELD_COUNT,
    .max_alias_sequence_length = MAX_ALIAS_SEQUENCE_LENGTH,
    .parse_table = &ts_parse_table[0][0],
    .small_parse_table = ts_small_parse_table,
    .small_parse_table_map = ts_small_parse_table_map,
    .parse_actions = ts_parse_actions,
    .symbol_names = ts_symbol_names,
    .symbol_metadata = ts_symbol_metadata,
    .public_symbol_map = ts_symbol_map,
    .alias_map = ts_non_terminal_alias_map,
    .alias_sequences = &ts_alias_sequences[0][0],
    .lex_modes = (const void*)ts_lex_modes,
    .lex_fn = ts_lex,
    .primary_state_ids = ts_primary_state_ids,
  };
  return &language;
}
#ifdef __cplusplus
}
#endif
